pub unsafe extern "C" fn EOS_Auth_AddNotifyLoginStatusChanged(
Handle: EOS_HAuth,
Options: *const EOS_Auth_AddNotifyLoginStatusChangedOptions,
ClientData: *mut c_void,
Notification: EOS_Auth_OnLoginStatusChangedCallback,
) -> EOS_NotificationIdExpand description
Register to receive login status updates. @note If the returned NotificationId is valid, you must call EOS_Auth_RemoveNotifyLoginStatusChanged when you no longer wish to have your NotificationHandler called.
@param Options structure containing the api version of AddNotifyLoginStatusChanged to use @param ClientData arbitrary data that is passed back to you in the callback @param Notification a callback that is fired when the login status for a user changes
@see EOS_Auth_AddNotifyLoginStatusChangedOptions @see EOS_Auth_OnLoginStatusChangedCallback
@return handle representing the registered callback