pub unsafe extern "C" fn EOS_Auth_CopyIdToken(
Handle: EOS_HAuth,
Options: *const EOS_Auth_CopyIdTokenOptions,
OutIdToken: *mut *mut EOS_Auth_IdToken,
) -> EOS_EResultExpand description
Fetch an ID token for an Epic Account ID.
ID tokens are used to securely verify user identities with online services. The most common use case is using an ID token to authenticate the local user by their selected account ID, which is the account ID that should be used to access any game-scoped data for the current application.
An ID token for the selected account ID of a locally authenticated user will always be readily available. To retrieve it for the selected account ID, you can use EOS_Auth_CopyIdToken directly after a successful user login.
@param Options Structure containing the account ID for which to copy an ID token. @param OutIdToken An ID token for the given user, if it exists and is valid; use EOS_Auth_IdToken_Release when finished.
@see EOS_Auth_CopyIdTokenOptions @see EOS_Auth_IdToken @see EOS_Auth_IdToken_Release
@return EOS_EResult containing the result of the operation. Possible result codes:
- EOS_Success if the information is available and passed out in OutUserIdToken
- EOS_InvalidParameters if you pass a null pointer for the out parameter
- EOS_NotFound if the Id token is not found or expired.