EOS_Auth_LinkAccount

Function EOS_Auth_LinkAccount 

pub unsafe extern "C" fn EOS_Auth_LinkAccount(
    Handle: EOS_HAuth,
    Options: *const EOS_Auth_LinkAccountOptions,
    ClientData: *mut c_void,
    CompletionDelegate: EOS_Auth_OnLinkAccountCallback,
)
Link external account by continuing previous login attempt with a continuance token.

The user will be presented with Epic Accounts onboarding flow managed by the SDK.

On success, the user will be logged in at the completion of this action. This will commit this external account to the Epic Account and cannot be undone in the SDK.

@param Options structure containing the account credentials to use during the link account operation @param ClientData arbitrary data that is passed back to you in the CompletionDelegate @param CompletionDelegate a callback that is fired when the link account operation completes, either successfully or in error

@see EOS_Auth_LinkAccountOptions @see EOS_Auth_OnLinkAccountCallback