EOS_Auth_Login

Function EOS_Auth_Login 

pub unsafe extern "C" fn EOS_Auth_Login(
    Handle: EOS_HAuth,
    Options: *const EOS_Auth_LoginOptions,
    ClientData: *mut c_void,
    CompletionDelegate: EOS_Auth_OnLoginCallback,
)
Login/Authenticate with user credentials.

@param Options structure containing the account credentials to use during the login operation @param ClientData arbitrary data that is passed back to you in the CompletionDelegate @param CompletionDelegate a callback that is fired when the login operation completes, either successfully or in error

@see EOS_Auth_LoginOptions @see EOS_Auth_OnLoginCallback