EOS_Auth_VerifyIdToken

Function EOS_Auth_VerifyIdToken 

pub unsafe extern "C" fn EOS_Auth_VerifyIdToken(
    Handle: EOS_HAuth,
    Options: *const EOS_Auth_VerifyIdTokenOptions,
    ClientData: *mut c_void,
    CompletionDelegate: EOS_Auth_OnVerifyIdTokenCallback,
)
Verify a given ID token for authenticity and validity.

@param Options Structure containing information about the ID token to verify. @param ClientData Arbitrary data that is passed back to you in the CompletionDelegate @param CompletionDelegate A callback that is fired when the operation completes, either successfully or in error.

@see EOS_Auth_VerifyIdTokenOptions @see EOS_Auth_OnVerifyIdTokenCallback