pub unsafe extern "C" fn EOS_Auth_VerifyUserAuth(
Handle: EOS_HAuth,
Options: *const EOS_Auth_VerifyUserAuthOptions,
ClientData: *mut c_void,
CompletionDelegate: EOS_Auth_OnVerifyUserAuthCallback,
)Expand description
Contact the backend service to verify validity of an existing user auth token. This function is intended for server-side use only.
@param Options structure containing information about the auth token being verified @param ClientData arbitrary data that is passed back to you in the CompletionDelegate @param CompletionDelegate a callback that is fired when the logout operation completes, either successfully or in error
@see EOS_Auth_VerifyUserAuthOptions @see EOS_Auth_OnVerifyUserAuthCallback @see EOS_Auth_CopyUserAuthToken