EOS_ByteArray_ToString

Function EOS_ByteArray_ToString 

pub unsafe extern "C" fn EOS_ByteArray_ToString(
    ByteArray: *const u8,
    Length: u32,
    OutBuffer: *mut c_char,
    InOutBufferLength: *mut u32,
) -> EOS_EResult
Encode a byte array into hex encoded string

@return An EOS_EResult that indicates whether the byte array was converted and copied into the OutBuffer. EOS_Success if the encoding was successful and passed out in OutBuffer EOS_InvalidParameters if you pass a null pointer on invalid length for any of the parameters EOS_LimitExceeded - The OutBuffer is not large enough to receive the encoding. InOutBufferLength contains the required minimum length to perform the operation successfully.