pub unsafe extern "C" fn EOS_Connect_AddNotifyLoginStatusChanged(
Handle: EOS_HConnect,
Options: *const EOS_Connect_AddNotifyLoginStatusChangedOptions,
ClientData: *mut c_void,
Notification: EOS_Connect_OnLoginStatusChangedCallback,
) -> EOS_NotificationIdExpand description
Register to receive user login status updates. @note If the returned NotificationId is valid, you must call EOS_Connect_RemoveNotifyLoginStatusChanged when you no longer wish to have your NotificationHandler called.
@param Options structure containing the API version of the callback to use. @param ClientData arbitrary data that is passed back to you in the callback. @param Notification a callback that is fired when the login status for a user changes.
@see EOS_Connect_AddNotifyLoginStatusChangedOptions @see EOS_Connect_OnLoginStatusChangedCallback
@return handle representing the registered callback.