pub unsafe extern "C" fn EOS_Connect_CreateDeviceId(
Handle: EOS_HConnect,
Options: *const EOS_Connect_CreateDeviceIdOptions,
ClientData: *mut c_void,
CompletionDelegate: EOS_Connect_OnCreateDeviceIdCallback,
)Expand description
Create a new unique pseudo-account that can be used to identify the current user profile on the local device.
This function is intended to be used by mobile games and PC games that wish to allow a new user to start playing without requiring to login to the game using any user identity. In addition to this, the Device ID feature is used to automatically login the local user also when they have linked at least one external user account(s) with the local Device ID.
It is possible to link many devices with the same user’s account keyring using the Device ID feature.
Linking a device later or immediately with a real user account will ensure that the player will not lose their progress if they switch devices or lose the device at some point, as they will be always able to login with one of their linked real accounts and also link another new device with the user account associations keychain. Otherwise, without having at least one permanent user account linked to the Device ID, the player would lose all of their game data and progression permanently should something happen to their device or the local user profile on the device.
After a successful one-time CreateDeviceId operation, the game can login the local user automatically on subsequent game starts with EOS_Connect_Login using the EOS_ECT_DEVICEID_ACCESS_TOKEN credentials type. If a Device ID already exists for the local user on the device then EOS_DuplicateNotAllowed error result is returned and the caller should proceed to calling EOS_Connect_Login directly.
@param Options structure containing operation input parameters. @param ClientData arbitrary data that is passed back to you in the CompletionDelegate. @param CompletionDelegate a callback that is fired when the create operation completes, either successfully or in error.
@see EOS_Connect_CreateDeviceIdOptions @see EOS_Connect_OnCreateDeviceIdCallback