pub unsafe extern "C" fn EOS_Connect_DeleteDeviceId(
Handle: EOS_HConnect,
Options: *const EOS_Connect_DeleteDeviceIdOptions,
ClientData: *mut c_void,
CompletionDelegate: EOS_Connect_OnDeleteDeviceIdCallback,
)Expand description
Delete any existing Device ID access credentials for the current user profile on the local device.
The deletion is permanent and it is not possible to recover lost game data and progression if the Device ID had not been linked with at least one real external user account.
On Android and iOS devices, uninstalling the application will automatically delete any local Device ID credentials created by the application.
On Desktop platforms (Linux, macOS, Windows), Device ID credentials are not automatically deleted. Applications may re-use existing Device ID credentials for the local OS user when the application is re-installed, or call the DeleteDeviceId API on the first run to ensure a fresh start for the user.
@param Options structure containing operation input parameters @param ClientData arbitrary data that is passed back to you in the CompletionDelegate @param CompletionDelegate a callback that is fired when the delete operation completes, either successfully or in error
@see EOS_Connect_DeleteDeviceIdOptions @see EOS_Connect_OnDeleteDeviceIdCallback