EOS_Connect_ExternalAccountInfo_Release

Function EOS_Connect_ExternalAccountInfo_Release 

pub unsafe extern "C" fn EOS_Connect_ExternalAccountInfo_Release(
    ExternalAccountInfo: *mut EOS_Connect_ExternalAccountInfo,
)
Release the memory associated with an external account info. This must be called on data retrieved from EOS_Connect_CopyProductUserExternalAccountByIndex, EOS_Connect_CopyProductUserExternalAccountByAccountType, EOS_Connect_CopyProductUserExternalAccountByAccountId or EOS_Connect_CopyProductUserInfo.

@param ExternalAccountInfo The external account info data to release.

@see EOS_Connect_CopyProductUserExternalAccountByIndex @see EOS_Connect_CopyProductUserExternalAccountByAccountType @see EOS_Connect_CopyProductUserExternalAccountByAccountId @see EOS_Connect_CopyProductUserInfo