EOS_Connect_GetLoggedInUserByIndex

Function EOS_Connect_GetLoggedInUserByIndex 

pub unsafe extern "C" fn EOS_Connect_GetLoggedInUserByIndex(
    Handle: EOS_HConnect,
    Index: i32,
) -> EOS_ProductUserId
Fetch a Product User ID that is logged in. This Product User ID is in the Epic Online Services namespace.

@param Index an index into the list of logged in users. If the index is out of bounds, the returned Product User ID will be invalid.

@return the Product User ID associated with the index passed.