pub unsafe extern "C" fn EOS_Connect_GetLoggedInUsersCount(
Handle: EOS_HConnect,
) -> i32Expand description
Fetch the number of product users that are logged in.
@return the number of product users logged in.
pub unsafe extern "C" fn EOS_Connect_GetLoggedInUsersCount(
Handle: EOS_HConnect,
) -> i32Fetch the number of product users that are logged in.
@return the number of product users logged in.