EOS_Connect_GetLoginStatus

Function EOS_Connect_GetLoginStatus 

pub unsafe extern "C" fn EOS_Connect_GetLoginStatus(
    Handle: EOS_HConnect,
    LocalUserId: EOS_ProductUserId,
) -> EOS_ELoginStatus
Fetches the login status for an Product User ID. This Product User ID is considered logged in as long as the underlying access token has not expired.

@param LocalUserId the Product User ID of the user being queried.

@return the enum value of a user’s login status.