pub unsafe extern "C" fn EOS_Connect_GetProductUserExternalAccountCount(
Handle: EOS_HConnect,
Options: *const EOS_Connect_GetProductUserExternalAccountCountOptions,
) -> u32Expand description
Fetch the number of linked external accounts for a Product User ID.
@param Options The Options associated with retrieving the external account info count.
@see EOS_Connect_GetProductUserExternalAccountCountOptions @see EOS_Connect_CopyProductUserExternalAccountByIndex
@return Number of external accounts or 0 otherwise.