pub unsafe extern "C" fn EOS_Connect_LinkAccount(
Handle: EOS_HConnect,
Options: *const EOS_Connect_LinkAccountOptions,
ClientData: *mut c_void,
CompletionDelegate: EOS_Connect_OnLinkAccountCallback,
)Expand description
Link a set of external auth credentials with an existing product user on the Epic Online Service.
@param Options structure containing a continuance token from a “user not found” response during Login (always try login first) and a currently logged in user not already associated with this external auth provider. @param ClientData arbitrary data that is passed back to you in the CompletionDelegate. @param CompletionDelegate a callback that is fired when the link operation completes, either successfully or in error.
@see EOS_Connect_LinkAccountOptions @see EOS_Connect_OnLinkAccountCallback