EOS_Connect_Login

Function EOS_Connect_Login 

pub unsafe extern "C" fn EOS_Connect_Login(
    Handle: EOS_HConnect,
    Options: *const EOS_Connect_LoginOptions,
    ClientData: *mut c_void,
    CompletionDelegate: EOS_Connect_OnLoginCallback,
)
Login/Authenticate given a valid set of external auth credentials.

@param Options structure containing the external account credentials and type to use during the login operation. @param ClientData arbitrary data that is passed back to you in the CompletionDelegate. @param CompletionDelegate a callback that is fired when the login operation completes, either successfully or in error.

@see EOS_Connect_LoginOptions @see EOS_Connect_OnLoginCallback