EOS_Connect_Logout

Function EOS_Connect_Logout 

pub unsafe extern "C" fn EOS_Connect_Logout(
    Handle: EOS_HConnect,
    Options: *const EOS_Connect_LogoutOptions,
    ClientData: *mut c_void,
    CompletionDelegate: EOS_Connect_OnLogoutCallback,
)
Logout a currently logged in user. NOTE: Access tokens for Product User IDs cannot be revoked. This operation really just cleans up state for the Product User ID and locally discards any associated access token.

@param Options Structure containing the input parameters for the operation @param ClientData Arbitrary data that is passed back to the caller in the CompletionDelegate. @param CompletionDelegate A callback that is fired when the operation completes, either successfully or in error.

@see EOS_Connect_LogoutOptions @see EOS_Connect_OnLogoutCallback