pub unsafe extern "C" fn EOS_Connect_QueryExternalAccountMappings(
Handle: EOS_HConnect,
Options: *const EOS_Connect_QueryExternalAccountMappingsOptions,
ClientData: *mut c_void,
CompletionDelegate: EOS_Connect_OnQueryExternalAccountMappingsCallback,
)Expand description
Retrieve the equivalent Product User IDs from a list of external account IDs from supported account providers. The values will be cached and retrievable through EOS_Connect_GetExternalAccountMapping.
@note A common use case is to query other users who are connected through the same account system as the local user. Queries using external account IDs of another account system may not be available, depending on the account system specifics.
@param Options structure containing a list of external account IDs, in string form, to query for the Product User ID representation. @param ClientData arbitrary data that is passed back to you in the CompletionDelegate. @param CompletionDelegate a callback that is fired when the query operation completes, either successfully or in error.
@see EOS_Connect_QueryExternalAccountMappingsOptions @see EOS_Connect_OnQueryExternalAccountMappingsCallback