EOS_Connect_QueryProductUserIdMappings

Function EOS_Connect_QueryProductUserIdMappings 

pub unsafe extern "C" fn EOS_Connect_QueryProductUserIdMappings(
    Handle: EOS_HConnect,
    Options: *const EOS_Connect_QueryProductUserIdMappingsOptions,
    ClientData: *mut c_void,
    CompletionDelegate: EOS_Connect_OnQueryProductUserIdMappingsCallback,
)
Retrieve the equivalent external account mappings from a list of Product User IDs.

The values will be cached and retrievable via EOS_Connect_GetProductUserIdMapping, EOS_Connect_CopyProductUserExternalAccountByIndex, EOS_Connect_CopyProductUserExternalAccountByAccountType or EOS_Connect_CopyProductUserExternalAccountByAccountId.

@see EOS_Connect_QueryProductUserIdMappingsOptions @see EOS_Connect_OnQueryProductUserIdMappingsCallback @see EOS_Connect_ExternalAccountInfo @see EOS_Connect_GetProductUserExternalAccountCount @see EOS_Connect_GetProductUserIdMapping @see EOS_Connect_CopyProductUserExternalAccountByIndex @see EOS_Connect_CopyProductUserExternalAccountByAccountType @see EOS_Connect_CopyProductUserExternalAccountByAccountId @see EOS_Connect_CopyProductUserInfo

@param Options structure containing a list of Product User IDs to query for the external account representation. @param ClientData arbitrary data that is passed back to you in the CompletionDelegate. @param CompletionDelegate a callback that is fired when the query operation completes, either successfully or in error.