pub unsafe extern "C" fn EOS_EApplicationStatus_ToString(
ApplicationStatus: EOS_EApplicationStatus,
) -> *const c_charExpand description
Gets the string representation of an EOS_EApplicationStatus value.
Example: EOS_EApplicationStatus_ToString(EOS_EApplicationStatus::EOS_AS_Foreground) returns “EOS_AS_Foreground”.
@param ApplicationStatus EOS_EApplicationStatus value to get as string.
@return Pointer to a static string representing the input enum value. The returned string is guaranteed to be non-null, and must not be freed by the application.