EOS_EResult_IsOperationComplete

Function EOS_EResult_IsOperationComplete 

pub unsafe extern "C" fn EOS_EResult_IsOperationComplete(
    Result: EOS_EResult,
) -> EOS_Bool
Returns whether a result is to be considered the final result, or false if the callback that returned this result will be called again either after some time or from another action.

@param Result The result to check against being a final result for an operation @return True if this result means the operation is complete, false otherwise