EOS_EpicAccountId_FromString

Function EOS_EpicAccountId_FromString 

pub unsafe extern "C" fn EOS_EpicAccountId_FromString(
    AccountIdString: *const c_char,
) -> EOS_EpicAccountId
Retrieve an EOS_EpicAccountId from a raw string representing an Epic Account ID. The input string must be null-terminated. NOTE: There is no validation on the string format, this should only be used with values serialized from legitimate sources such as EOS_EpicAccountId_ToString

@param AccountIdString The stringified account ID for which to retrieve the Epic Account ID @return The EOS_EpicAccountId that corresponds to the AccountIdString