EOS_IntegratedPlatformOptionsContainer_Release

Function EOS_IntegratedPlatformOptionsContainer_Release 

pub unsafe extern "C" fn EOS_IntegratedPlatformOptionsContainer_Release(
    IntegratedPlatformOptionsContainerHandle: EOS_HIntegratedPlatformOptionsContainer,
)
Release the memory associated with an EOS_HIntegratedPlatformOptionsContainer handle. This must be called on Handles retrieved from EOS_IntegratedPlatform_CreateIntegratedPlatformOptionsContainer. This can be safely called on a NULL integrated platform options container handle.

@param IntegratedPlatformOptionsContainerHandle The integrated platform options container handle to release.

@see EOS_IntegratedPlatform_CreateIntegratedPlatformOptionsContainer