EOS_LobbyDetails_GetAttributeCount

Function EOS_LobbyDetails_GetAttributeCount 

pub unsafe extern "C" fn EOS_LobbyDetails_GetAttributeCount(
    Handle: EOS_HLobbyDetails,
    Options: *const EOS_LobbyDetails_GetAttributeCountOptions,
) -> u32
Get the number of attributes associated with this lobby

@param Options the Options associated with retrieving the attribute count

@return number of attributes on the lobby or 0 if there is an error

@see EOS_LobbyDetails_GetAttributeCountOptions