EOS_LobbyDetails_GetMemberAttributeCount

Function EOS_LobbyDetails_GetMemberAttributeCount 

pub unsafe extern "C" fn EOS_LobbyDetails_GetMemberAttributeCount(
    Handle: EOS_HLobbyDetails,
    Options: *const EOS_LobbyDetails_GetMemberAttributeCountOptions,
) -> u32
EOS_LobbyDetails_GetMemberAttributeCount is used to immediately retrieve the attribute count for members in a lobby. Note: this information is only available if you are actively in the lobby. It is not available for search results.

@param Options Structure containing the input parameters

@return the number of attributes associated with a given lobby member or 0 if that member is invalid

@see EOS_LobbyDetails_GetMemberCount @see EOS_LobbyDetails_GetMemberAttributeCountOptions