EOS_LobbyDetails_GetMemberCount

Function EOS_LobbyDetails_GetMemberCount 

pub unsafe extern "C" fn EOS_LobbyDetails_GetMemberCount(
    Handle: EOS_HLobbyDetails,
    Options: *const EOS_LobbyDetails_GetMemberCountOptions,
) -> u32
Get the number of members associated with this lobby

@param Options the Options associated with retrieving the member count

@return number of members in the existing lobby or 0 if there is an error

@see EOS_LobbyDetails_GetMemberCountOptions