pub unsafe extern "C" fn EOS_LobbyModification_RemoveMemberAttribute(
Handle: EOS_HLobbyModification,
Options: *const EOS_LobbyModification_RemoveMemberAttributeOptions,
) -> EOS_EResultExpand description
Remove an attribute associated with of member of the lobby
@param Options Specify the key of the member attribute to remove
@return EOS_EResult containing the result of the operation. Possible result codes:
- EOS_Success if removing this parameter was successful
- EOS_InvalidParameters if the key is null or empty
- EOS_IncompatibleVersion if the API version passed in is incorrect
@see EOS_LobbyModification_RemoveMemberAttributeOptions