EOS_LobbyModification_SetBucketId

Function EOS_LobbyModification_SetBucketId 

pub unsafe extern "C" fn EOS_LobbyModification_SetBucketId(
    Handle: EOS_HLobbyModification,
    Options: *const EOS_LobbyModification_SetBucketIdOptions,
) -> EOS_EResult
Set the bucket ID associated with this lobby. Values such as region, game mode, etc can be combined here depending on game need. Setting this is strongly recommended to improve search performance.

@param Options Options associated with the bucket ID of the lobby

@return EOS_EResult containing the result of the operation. Possible result codes:

  • EOS_Success if setting this parameter was successful
  • EOS_InvalidParameters if the bucket ID is invalid or null
  • EOS_IncompatibleVersion if the API version passed in is incorrect

@see EOS_LobbyModification_SetBucketIdOptions