EOS_LobbyModification_SetMaxMembers

Function EOS_LobbyModification_SetMaxMembers 

pub unsafe extern "C" fn EOS_LobbyModification_SetMaxMembers(
    Handle: EOS_HLobbyModification,
    Options: *const EOS_LobbyModification_SetMaxMembersOptions,
) -> EOS_EResult
Set the maximum number of members allowed in this lobby. When updating the lobby, it is not possible to reduce this number below the current number of existing members

@param Options Options associated with max number of members in this lobby

@return EOS_EResult containing the result of the operation. Possible result codes:

  • EOS_Success if setting this parameter was successful
  • EOS_IncompatibleVersion if the API version passed in is incorrect

@see EOS_LobbyModification_SetMaxMembersOptions