EOS_LobbySearch_Find

Function EOS_LobbySearch_Find 

pub unsafe extern "C" fn EOS_LobbySearch_Find(
    Handle: EOS_HLobbySearch,
    Options: *const EOS_LobbySearch_FindOptions,
    ClientData: *mut c_void,
    CompletionDelegate: EOS_LobbySearch_OnFindCallback,
)
Find lobbies matching the search criteria setup via this lobby search handle. When the operation completes, this handle will have the search results that can be parsed

@param Options Structure containing information about the search criteria to use @param ClientData Arbitrary data that is passed back to you in the CompletionDelegate @param CompletionDelegate A callback that is fired when the search operation completes, either successfully or in error

@see EOS_LobbySearch_FindOptions @see EOS_LobbySearch_OnFindCallback