EOS_LobbySearch_SetMaxResults

Function EOS_LobbySearch_SetMaxResults 

pub unsafe extern "C" fn EOS_LobbySearch_SetMaxResults(
    Handle: EOS_HLobbySearch,
    Options: *const EOS_LobbySearch_SetMaxResultsOptions,
) -> EOS_EResult
Set the maximum number of search results to return in the query, can’t be more than EOS_LOBBY_MAX_SEARCH_RESULTS

@param Options maximum number of search results to return in the query

@return EOS_EResult containing the result of the operation. Possible result codes:

  • EOS_Success if setting the max results was successful
  • EOS_InvalidParameters if the number of results requested is invalid
  • EOS_IncompatibleVersion if the API version passed in is incorrect

@see EOS_LobbySearch_SetMaxResultsOptions