EOS_Lobby_AddNotifyLobbyMemberUpdateReceived

Function EOS_Lobby_AddNotifyLobbyMemberUpdateReceived 

pub unsafe extern "C" fn EOS_Lobby_AddNotifyLobbyMemberUpdateReceived(
    Handle: EOS_HLobby,
    Options: *const EOS_Lobby_AddNotifyLobbyMemberUpdateReceivedOptions,
    ClientData: *mut c_void,
    NotificationFn: EOS_Lobby_OnLobbyMemberUpdateReceivedCallback,
) -> EOS_NotificationId
Register to receive notifications when a lobby member updates the attributes associated with themselves inside the lobby. @note If the returned NotificationId is valid, you must call EOS_Lobby_RemoveNotifyLobbyMemberUpdateReceived when you no longer wish to have your NotificationHandler called.

@param Options Structure containing information about the request. @param ClientData Arbitrary data that is passed back to you in the CompletionDelegate. @param NotificationFn A callback that is fired when a a notification is received.

@return handle representing the registered callback

@see EOS_Lobby_AddNotifyLobbyMemberUpdateReceivedOptions @see EOS_Lobby_OnLobbyMemberUpdateReceivedCallback