EOS_Lobby_AddNotifyLobbyUpdateReceived

Function EOS_Lobby_AddNotifyLobbyUpdateReceived 

pub unsafe extern "C" fn EOS_Lobby_AddNotifyLobbyUpdateReceived(
    Handle: EOS_HLobby,
    Options: *const EOS_Lobby_AddNotifyLobbyUpdateReceivedOptions,
    ClientData: *mut c_void,
    NotificationFn: EOS_Lobby_OnLobbyUpdateReceivedCallback,
) -> EOS_NotificationId
Register to receive notifications when a lobby owner updates the attributes associated with the lobby. @note If the returned NotificationId is valid, you must call EOS_Lobby_RemoveNotifyLobbyUpdateReceived when you no longer wish to have your NotificationHandler called.

@param Options Structure containing information about the request. @param ClientData Arbitrary data that is passed back to you in the CompletionDelegate. @param NotificationFn A callback that is fired when a a notification is received.

@return handle representing the registered callback

@see EOS_Lobby_AddNotifyLobbyUpdateReceivedOptions @see EOS_Lobby_OnLobbyUpdateReceivedCallback