EOS_Lobby_AddNotifyRTCRoomConnectionChanged

Function EOS_Lobby_AddNotifyRTCRoomConnectionChanged 

pub unsafe extern "C" fn EOS_Lobby_AddNotifyRTCRoomConnectionChanged(
    Handle: EOS_HLobby,
    Options: *const EOS_Lobby_AddNotifyRTCRoomConnectionChangedOptions,
    ClientData: *mut c_void,
    NotificationFn: EOS_Lobby_OnRTCRoomConnectionChangedCallback,
) -> EOS_NotificationId
Register to receive notifications of when the RTC Room for a particular lobby has a connection status change.

The RTC Room connection status is independent of the lobby connection status, however the lobby system will attempt to keep them consistent, automatically connecting to the RTC room after joining a lobby which has an associated RTC room and disconnecting from the RTC room when a lobby is left or disconnected.

This notification is entirely informational and requires no action in response by the application. If the connected status is offline (bIsConnected is EOS_FALSE), the connection will automatically attempt to reconnect. The purpose of this notification is to allow applications to show the current connection status of the RTC room when the connection is not established.

Unlike EOS_RTC_AddNotifyDisconnected, EOS_RTC_LeaveRoom should not be called when the RTC room is disconnected.

This function will only succeed when called on a lobby the local user is currently a member of.

@param Options Structure containing information about the lobby to receive updates about @param ClientData Arbitrary data that is passed back to you in the CompletionDelegate. @param NotificationFn The function to call if the RTC Room’s connection status changes

@return A valid notification ID if the NotificationFn was successfully registered, or EOS_INVALID_NOTIFICATIONID if the input was invalid, the lobby did not exist, or the lobby did not have an RTC room.

@see EOS_Lobby_RemoveNotifyRTCRoomConnectionChanged @see EOS_Lobby_AddNotifyRTCRoomConnectionChangedOptions @see EOS_Lobby_OnRTCRoomConnectionChangedCallback