EOS_Lobby_AddNotifySendLobbyNativeInviteRequested

Function EOS_Lobby_AddNotifySendLobbyNativeInviteRequested 

pub unsafe extern "C" fn EOS_Lobby_AddNotifySendLobbyNativeInviteRequested(
    Handle: EOS_HLobby,
    Options: *const EOS_Lobby_AddNotifySendLobbyNativeInviteRequestedOptions,
    ClientData: *mut c_void,
    NotificationFn: EOS_Lobby_OnSendLobbyNativeInviteRequestedCallback,
) -> EOS_NotificationId
Register to receive notifications about a lobby “INVITE” performed by a local user via the overlay. This is only needed when a configured integrated platform has EOS_IPMF_DisableSDKManagedSessions set. The EOS SDK will then use the state of EOS_IPMF_PreferEOSIdentity and EOS_IPMF_PreferIntegratedIdentity to determine when the NotificationFn is called.

@note If the returned NotificationId is valid, you must call EOS_Lobby_RemoveNotifySendLobbyNativeInviteRequested when you no longer wish to have your NotificationHandler called.

@param Options Structure containing information about the request. @param ClientData Arbitrary data that is passed back to you in the CompletionDelegate. @param NotificationFn A callback that is fired when a notification is received.

@return handle representing the registered callback

@see EOS_IPMF_DisableSDKManagedSessions @see EOS_IPMF_PreferEOSIdentity @see EOS_IPMF_PreferIntegratedIdentity

@see EOS_Lobby_AddNotifySendLobbyNativeInviteRequestedOptions @see EOS_Lobby_OnSendLobbyNativeInviteRequestedCallback