EOS_Lobby_CreateLobby

Function EOS_Lobby_CreateLobby 

pub unsafe extern "C" fn EOS_Lobby_CreateLobby(
    Handle: EOS_HLobby,
    Options: *const EOS_Lobby_CreateLobbyOptions,
    ClientData: *mut c_void,
    CompletionDelegate: EOS_Lobby_OnCreateLobbyCallback,
)
Creates a lobby and adds the user to the lobby membership. There is no data associated with the lobby at the start and can be added vis EOS_Lobby_UpdateLobbyModification

If the lobby is successfully created with an RTC Room enabled, the lobby system will automatically join and maintain the connection to the RTC room as long as the local user remains in the lobby. Applications can use the EOS_Lobby_GetRTCRoomName to get the name of the RTC Room associated with a lobby, which may be used with many of the functions in the RTC interface. This can be useful to: register for notifications for talking status; to mute or unmute the local user’s audio output; to block or unblock room participants; to set local audio device settings; and more.

@param Options Required fields for the creation of a lobby such as a user count and its starting advertised state @param ClientData Arbitrary data that is passed back to you in the CompletionDelegate @param CompletionDelegate A callback that is fired when the create operation completes, either successfully or in error

@see EOS_Lobby_CreateLobbyOptions @see EOS_Lobby_OnCreateLobbyCallback