EOS_Lobby_GetConnectString

Function EOS_Lobby_GetConnectString 

pub unsafe extern "C" fn EOS_Lobby_GetConnectString(
    Handle: EOS_HLobby,
    Options: *const EOS_Lobby_GetConnectStringOptions,
    OutBuffer: *mut c_char,
    InOutBufferLength: *mut u32,
) -> EOS_EResult
Get the Connection string for an EOS lobby. The connection string describes the presence of a player in terms of game state. Xbox platforms expect titles to embed this into their MultiplayerActivity at creation. When present, the SDK will use this value to populate session presence in the social overlay and facilitate platform invitations.

@param Options Structure containing the input parameters. API version, the LobbyID of the lobby to generate the string from and the PUID of the requesting user. @param OutBuffer The buffer to store the null-terminated ConnectString within @param InOutBufferLength In: The maximum amount of writable chars in OutBuffer see EOS_LOBBY_GETCONNECTSTRING_BUFFER_SIZE, Out: The minimum amount of chars needed in OutBuffer to store the ConnectString (including the null-terminator). May be set to zero depending on the error result.

@return EOS_EResult containing the result of the operation. Possible result codes:

  • EOS_Success if retrieving the string was successful.
  • EOS_InvalidParameters if the OutBuffer or InOutBufferLength are null.
  • EOS_IncompatibleVersion if the API version passed in is incorrect.
  • EOS_NotFound if no lobby is found matching the LobbyID and PUID provided.
  • EOS_LimitExceeded if the provided InOutBufferLength is too small to contain the resulting string.

@see EOS_Lobby_GetConnectStringOptions