pub unsafe extern "C" fn EOS_Lobby_GetInviteCount(
Handle: EOS_HLobby,
Options: *const EOS_Lobby_GetInviteCountOptions,
) -> u32Expand description
Get the number of known invites for a given user
@param Options the Options associated with retrieving the current invite count
@return number of known invites for a given user or 0 if there is an error
@see EOS_Lobby_GetInviteCountOptions