EOS_Lobby_GetInviteIdByIndex

Function EOS_Lobby_GetInviteIdByIndex 

pub unsafe extern "C" fn EOS_Lobby_GetInviteIdByIndex(
    Handle: EOS_HLobby,
    Options: *const EOS_Lobby_GetInviteIdByIndexOptions,
    OutBuffer: *mut c_char,
    InOutBufferLength: *mut i32,
) -> EOS_EResult
Retrieve an invite ID from a list of active invites for a given user

@param Options Structure containing the input parameters

@return EOS_EResult containing the result of the operation. Possible result codes:

  • EOS_Success if the input is valid and an invite ID was returned
  • EOS_InvalidParameters if any of the options are incorrect
  • EOS_NotFound if the invite doesn’t exist

@see EOS_Lobby_GetInviteCount @see EOS_Lobby_CopyLobbyDetailsHandleByInviteId

@see EOS_Lobby_GetInviteIdByIndexOptions