pub unsafe extern "C" fn EOS_Lobby_JoinLobby(
Handle: EOS_HLobby,
Options: *const EOS_Lobby_JoinLobbyOptions,
ClientData: *mut c_void,
CompletionDelegate: EOS_Lobby_OnJoinLobbyCallback,
)Expand description
Join a lobby, creating a local instance under a given lobby ID. Backend will validate various conditions to make sure it is possible to join the lobby.
If the lobby is successfully join has an RTC Room enabled, the lobby system will automatically join and maintain the connection to the RTC room as long as the local user remains in the lobby. Applications can use the EOS_Lobby_GetRTCRoomName to get the name of the RTC Room associated with a lobby, which may be used with many of the functions in the RTC interface. This can be useful to: register for notifications for talking status; to mute or unmute the local user’s audio output; to block or unblock room participants; to set local audio device settings; and more.
@param Options Structure containing information about the lobby to be joined @param ClientData Arbitrary data that is passed back to you in the CompletionDelegate @param CompletionDelegate A callback that is fired when the join operation completes, either successfully or in error
@see EOS_Lobby_JoinLobbyOptions @see EOS_Lobby_OnJoinLobbyCallback