EOS_Lobby_JoinRTCRoom

Function EOS_Lobby_JoinRTCRoom 

pub unsafe extern "C" fn EOS_Lobby_JoinRTCRoom(
    Handle: EOS_HLobby,
    Options: *const EOS_Lobby_JoinRTCRoomOptions,
    ClientData: *mut c_void,
    CompletionDelegate: EOS_Lobby_OnJoinRTCRoomCallback,
)
Joins the RTC room associated with a specific lobby a local user belongs to.

This function will only succeed when called on a lobby that has the RTC Room feature enabled. Clients may check if the RTC Room feature is enabled by inspecting the value of EOS_LobbyDetails_Info::bRTCRoomEnabled.

@param Options Structure containing information about which lobby a local user should join the RTC Room for @param ClientData Arbitrary data that is passed back to you in the CompletionDelegate @param CompletionDelegate A callback that is fired when the join RTC Room operation completes, either successfully or in error

@see EOS_Lobby_JoinRTCRoomOptions @see EOS_Lobby_OnJoinRTCRoomCallback