EOS_Lobby_KickMember

Function EOS_Lobby_KickMember 

pub unsafe extern "C" fn EOS_Lobby_KickMember(
    Handle: EOS_HLobby,
    Options: *const EOS_Lobby_KickMemberOptions,
    ClientData: *mut c_void,
    CompletionDelegate: EOS_Lobby_OnKickMemberCallback,
)
Kick an existing member from the lobby

@param Options Structure containing information about the lobby and member to be kicked @param ClientData Arbitrary data that is passed back to you in the CompletionDelegate @param CompletionDelegate A callback that is fired when the kick operation completes, either successfully or in error

@see EOS_Lobby_KickMemberOptions @see EOS_Lobby_OnKickMemberCallback