pub unsafe extern "C" fn EOS_Lobby_PromoteMember(
Handle: EOS_HLobby,
Options: *const EOS_Lobby_PromoteMemberOptions,
ClientData: *mut c_void,
CompletionDelegate: EOS_Lobby_OnPromoteMemberCallback,
)Expand description
Promote an existing member of the lobby to owner, allowing them to make lobby data modifications
@param Options Structure containing information about the lobby and member to be promoted @param ClientData Arbitrary data that is passed back to you in the CompletionDelegate @param CompletionDelegate A callback that is fired when the promotion operation completes, either successfully or in error
@see EOS_Lobby_PromoteMemberOptions @see EOS_Lobby_OnPromoteMemberCallback