pub unsafe extern "C" fn EOS_Lobby_RejectInvite(
Handle: EOS_HLobby,
Options: *const EOS_Lobby_RejectInviteOptions,
ClientData: *mut c_void,
CompletionDelegate: EOS_Lobby_OnRejectInviteCallback,
)Expand description
Reject an invite from another user.
@param Options Structure containing information about the invite to reject @param ClientData Arbitrary data that is passed back to you in the CompletionDelegate @param CompletionDelegate A callback that is fired when the reject invite operation completes, either successfully or in error
@see EOS_Lobby_RejectInviteOptions @see EOS_Lobby_OnRejectInviteCallback