EOS_Lobby_SendInvite

Function EOS_Lobby_SendInvite 

pub unsafe extern "C" fn EOS_Lobby_SendInvite(
    Handle: EOS_HLobby,
    Options: *const EOS_Lobby_SendInviteOptions,
    ClientData: *mut c_void,
    CompletionDelegate: EOS_Lobby_OnSendInviteCallback,
)
Send an invite to another user. User must be a member of the lobby or else the call will fail

@param Options Structure containing information about the lobby and user to invite @param ClientData Arbitrary data that is passed back to you in the CompletionDelegate @param CompletionDelegate A callback that is fired when the send invite operation completes, either successfully or in error

@see EOS_Lobby_SendInviteOptions @see EOS_Lobby_OnSendInviteCallback