EOS_Lobby_UpdateLobby

Function EOS_Lobby_UpdateLobby 

pub unsafe extern "C" fn EOS_Lobby_UpdateLobby(
    Handle: EOS_HLobby,
    Options: *const EOS_Lobby_UpdateLobbyOptions,
    ClientData: *mut c_void,
    CompletionDelegate: EOS_Lobby_OnUpdateLobbyCallback,
)
Update a lobby given a lobby modification handle created by EOS_Lobby_UpdateLobbyModification

@param Options Structure containing information about the lobby to be updated @param ClientData Arbitrary data that is passed back to you in the CompletionDelegate @param CompletionDelegate A callback that is fired when the update operation completes, either successfully or in error

@see EOS_Lobby_UpdateLobbyOptions @see EOS_Lobby_OnUpdateLobbyCallback