EOS_P2P_AddNotifyIncomingPacketQueueFull

Function EOS_P2P_AddNotifyIncomingPacketQueueFull 

pub unsafe extern "C" fn EOS_P2P_AddNotifyIncomingPacketQueueFull(
    Handle: EOS_HP2P,
    Options: *const EOS_P2P_AddNotifyIncomingPacketQueueFullOptions,
    ClientData: *mut c_void,
    IncomingPacketQueueFullHandler: EOS_P2P_OnIncomingPacketQueueFullCallback,
) -> EOS_NotificationId
Listen for when our packet queue has become full. This event gives an opportunity to read packets to make room for new incoming packets. If this event fires and no packets are read by calling EOS_P2P_ReceivePacket or the packet queue size is not increased by EOS_P2P_SetPacketQueueSize, any packets that are received after this event are discarded until there is room again in the queue.

@param Options Information about what version of the EOS_P2P_AddNotifyIncomingPacketQueueFull API is supported @param ClientData Arbitrary data that is passed back to you in the CompletionDelegate @param IncomingPacketQueueFullHandler The callback to be fired when the incoming packet queue is full @return A valid notification ID if successfully bound, or EOS_INVALID_NOTIFICATIONID otherwise

@see EOS_P2P_AddNotifyIncomingPacketQueueFullOptions @see EOS_P2P_OnIncomingPacketQueueFullCallback