pub unsafe extern "C" fn EOS_P2P_AddNotifyPeerConnectionEstablished(
Handle: EOS_HP2P,
Options: *const EOS_P2P_AddNotifyPeerConnectionEstablishedOptions,
ClientData: *mut c_void,
ConnectionEstablishedHandler: EOS_P2P_OnPeerConnectionEstablishedCallback,
) -> EOS_NotificationIdExpand description
Listen for when a connection is established. This is fired when we first connect to a peer, when we reconnect to a peer after a connection interruption, and when our underlying network connection type changes (for example, from a direct connection to relay, or vice versa). Network Connection Type changes will always be broadcast with a EOS_CET_Reconnection connection type, even if the connection was not interrupted. If the network status changes from offline or disabled to online, you must call this function again.
@param Options Information about who would like notifications about established connections, and for which socket @param ClientData This value is returned to the caller when ConnectionEstablishedHandler is invoked @param ConnectionEstablishedHandler The callback to be fired when a connection has been established @return A valid notification ID if successfully bound, or EOS_INVALID_NOTIFICATIONID otherwise
@see EOS_P2P_AddNotifyPeerConnectionEstablishedOptions @see EOS_P2P_OnPeerConnectionEstablishedCallback @see EOS_P2P_AddNotifyPeerConnectionInterrupted @see EOS_P2P_AddNotifyPeerConnectionClosed @see EOS_P2P_RemoveNotifyPeerConnectionEstablished