pub unsafe extern "C" fn EOS_P2P_AddNotifyPeerConnectionInterrupted(
Handle: EOS_HP2P,
Options: *const EOS_P2P_AddNotifyPeerConnectionInterruptedOptions,
ClientData: *mut c_void,
ConnectionInterruptedHandler: EOS_P2P_OnPeerConnectionInterruptedCallback,
) -> EOS_NotificationIdExpand description
Listen for when a previously opened connection is interrupted. The connection will automatically attempt to reestablish, but it may not be successful.
If a connection reconnects, it will trigger the P2P PeerConnectionEstablished notification with the EOS_CET_Reconnection connection type. If a connection fails to reconnect, it will trigger the P2P PeerConnectionClosed notification. Packets remain queued during connection interruptions. When a connection closes, packets are flushed. This includes reliable packets.
@param Options Information about who would like notifications about interrupted connections, and for which socket @param ClientData This value is returned to the caller when ConnectionInterruptedHandler is invoked @param ConnectionInterruptedHandler The callback to be fired when an open connection has been interrupted @return A valid notification ID if successfully bound, or EOS_INVALID_NOTIFICATIONID otherwise
@see EOS_P2P_AddNotifyPeerConnectionInterruptedOptions @see EOS_P2P_OnPeerConnectionInterruptedCallback @see EOS_P2P_AddNotifyPeerConnectionEstablished @see EOS_P2P_AddNotifyPeerConnectionClosed @see EOS_P2P_RemoveNotifyPeerConnectionInterrupted