pub unsafe extern "C" fn EOS_P2P_AddNotifyPeerConnectionRequest(
Handle: EOS_HP2P,
Options: *const EOS_P2P_AddNotifyPeerConnectionRequestOptions,
ClientData: *mut c_void,
ConnectionRequestHandler: EOS_P2P_OnIncomingConnectionRequestCallback,
) -> EOS_NotificationIdExpand description
Listen for incoming connection requests on a particular Socket ID, or optionally all Socket IDs. The bound function will only be called if the connection has not already been accepted. If the network status changes from offline or disabled to online, you must call this function again. @param Options Information about who would like notifications, and (optionally) only for a specific socket @param ClientData This value is returned to the caller when ConnectionRequestHandler is invoked @param ConnectionRequestHandler The callback to be fired when we receive a connection request @return A valid notification ID if successfully bound, or EOS_INVALID_NOTIFICATIONID otherwise
@see EOS_P2P_RemoveNotifyPeerConnectionRequest @see EOS_P2P_AddNotifyPeerConnectionRequestOptions @see EOS_P2P_OnIncomingConnectionRequestCallback