EOS_P2P_ClearPacketQueue

Function EOS_P2P_ClearPacketQueue 

pub unsafe extern "C" fn EOS_P2P_ClearPacketQueue(
    Handle: EOS_HP2P,
    Options: *const EOS_P2P_ClearPacketQueueOptions,
) -> EOS_EResult
Clear queued incoming and outgoing packets.

@param Options Information about which queues should be cleared @return EOS_EResult containing the result of the operation. Possible result codes:

  • EOS_Success - if the input options were valid (even if queues were empty and no packets where cleared)
  • EOS_IncompatibleVersion - if wrong API version
  • EOS_InvalidUser - if an invalid/remote user was used
  • EOS_InvalidParameters - if input was invalid in other way

@see EOS_P2P_ClearPacketQueueOptions