pub unsafe extern "C" fn EOS_P2P_GetPacketQueueInfo(
Handle: EOS_HP2P,
Options: *const EOS_P2P_GetPacketQueueInfoOptions,
OutPacketQueueInfo: *mut EOS_P2P_PacketQueueInfo,
) -> EOS_EResultExpand description
Gets the current cached information related to the incoming and outgoing packet queues.
@param Options Information about what version of the EOS_P2P_GetPacketQueueInfo API is supported @param OutPacketQueueInfo The current information of the incoming and outgoing packet queues @return EOS_EResult containing the result of the operation. Possible result codes:
- EOS_Success - if the input options were valid
- EOS_InvalidParameters - if the input was invalid in some way
@see EOS_P2P_GetPacketQueueInfoOptions @see EOS_P2P_PacketQueueInfo