EOS_P2P_QueryNATType

Function EOS_P2P_QueryNATType 

pub unsafe extern "C" fn EOS_P2P_QueryNATType(
    Handle: EOS_HP2P,
    Options: *const EOS_P2P_QueryNATTypeOptions,
    ClientData: *mut c_void,
    CompletionDelegate: EOS_P2P_OnQueryNATTypeCompleteCallback,
)
Query the current NAT-type of our connection.

@param Options Information about what version of the EOS_P2P_QueryNATType API is supported @param ClientData arbitrary data that is passed back to you in the CompletionDelegate @param CompletionDelegate The callback to be fired when we finish querying our NAT type

@see EOS_P2P_QueryNATTypeOptions @see EOS_P2P_OnQueryNATTypeCompleteCallback