pub unsafe extern "C" fn EOS_P2P_SendPacket(
Handle: EOS_HP2P,
Options: *const EOS_P2P_SendPacketOptions,
) -> EOS_EResultExpand description
Send a packet to a peer at the specified address. If there is already an open connection to this peer, it will be sent immediately. If there is no open connection, an attempt to connect to the peer will be made. An EOS_Success result only means the data was accepted to be sent, not that it has been successfully delivered to the peer.
@param Options Information about the data being sent, by who, to who @return EOS_EResult containing the result of the operation. Possible result codes:
- EOS_Success - If packet was queued to be sent successfully
- EOS_InvalidParameters - If input was invalid
- EOS_LimitExceeded - If amount of data being sent is too large, or the outgoing packet queue was full
- EOS_NoConnection - If bDisableAutoAcceptConnection was set to EOS_TRUE and the connection was not currently accepted (call EOS_P2P_AcceptConnection first, or set bDisableAutoAcceptConnection to EOS_FALSE)
@see EOS_P2P_SendPacketOptions