EOS_P2P_SetPacketQueueSize

Function EOS_P2P_SetPacketQueueSize 

pub unsafe extern "C" fn EOS_P2P_SetPacketQueueSize(
    Handle: EOS_HP2P,
    Options: *const EOS_P2P_SetPacketQueueSizeOptions,
) -> EOS_EResult
Sets the maximum packet queue sizes that packets waiting to be sent or received can use. If the packet queue size is made smaller than the current queue size while there are packets in the queue that would push this packet size over, existing packets are kept but new packets may not be added to the full queue until enough packets are sent or received.

@param Options Information about packet queue size @return EOS_EResult containing the result of the operation. Possible result codes:

  • EOS_Success - if the input options were valid
  • EOS_InvalidParameters - if the input was invalid in some way

@see EOS_P2P_SetPacketQueueSizeOptions