pub unsafe extern "C" fn EOS_Platform_CheckForLauncherAndRestart(
Handle: EOS_HPlatform,
) -> EOS_EResultExpand description
Checks if the app was launched through the Epic Games Launcher, and relaunches it through the Epic Games Launcher if it wasn’t.
NOTE: During the call to EOS_Platform_Create, the command line that was used to launch the app is inspected, and if it is recognized as coming from the Epic Games Launcher, an environment variable is set to 1. The name of the environment variable is defined by EOS_PLATFORM_CHECKFORLAUNCHERANDRESTART_ENV_VAR.
You can force the EOS_Platform_CheckForLauncherAndRestart API to relaunch the title by explicitly unsetting this environment variable before calling EOS_Platform_CheckForLauncherAndRestart.
@return An EOS_EResult is returned to indicate success or an error.
EOS_Success is returned if the app is being restarted. You should quit your process as soon as possible. EOS_NoChange is returned if the app was already launched through the Epic Launcher, and no action needs to be taken. EOS_UnexpectedError is returned if the LauncherCheck module failed to initialize, or the module tried and failed to restart the app.