pub unsafe extern "C" fn EOS_Platform_Create(
Options: *const EOS_Platform_Options,
) -> EOS_HPlatformExpand description
Create a single Epic Online Services Platform Instance.
The platform instance is used to gain access to the various Epic Online Services.
This function returns an opaque handle to the platform instance, and that handle must be passed to EOS_Platform_Release to release the instance.
@return An opaque handle to the platform instance.