EOS_Platform_GetDesktopCrossplayStatus

Function EOS_Platform_GetDesktopCrossplayStatus 

pub unsafe extern "C" fn EOS_Platform_GetDesktopCrossplayStatus(
    Handle: EOS_HPlatform,
    Options: *const EOS_Platform_GetDesktopCrossplayStatusOptions,
    OutDesktopCrossplayStatusInfo: *mut EOS_Platform_DesktopCrossplayStatusInfo,
) -> EOS_EResult
Windows only. Checks that the application is ready to use desktop crossplay functionality, with the necessary prerequisites having been met.

This function verifies that the application was launched through the Bootstrapper application, the redistributable service has been installed and is running in the background, and that the overlay has been loaded successfully.

On Windows, the desktop crossplay functionality is required to use Epic accounts login with applications that are distributed outside the Epic Games Store.

@param Options input structure that specifies the API version. @param OutDesktopCrossplayStatusInfo output structure to receive the desktop crossplay status information.

@return An EOS_EResult is returned to indicate success or an error.

  • EOS_NotImplemented is returned on non-Windows platforms.

@see EOS_Platform_GetDesktopCrossplayStatusOptions @see EOS_Platform_DesktopCrossplayStatusInfo