pub unsafe extern "C" fn EOS_Platform_GetKWSInterface(
Handle: EOS_HPlatform,
) -> EOS_HKWSExpand description
Get a handle to the Kids Web Service Interface. @return EOS_HKWS handle
@see eos_kws.h @see eos_kws_types.h
pub unsafe extern "C" fn EOS_Platform_GetKWSInterface(
Handle: EOS_HPlatform,
) -> EOS_HKWSGet a handle to the Kids Web Service Interface. @return EOS_HKWS handle
@see eos_kws.h @see eos_kws_types.h