pub unsafe extern "C" fn EOS_Platform_GetNetworkStatus(
Handle: EOS_HPlatform,
) -> EOS_ENetworkStatusExpand description
Retrieves the current network state as told to the SDK by the application.
@return The current network status.
pub unsafe extern "C" fn EOS_Platform_GetNetworkStatus(
Handle: EOS_HPlatform,
) -> EOS_ENetworkStatusRetrieves the current network state as told to the SDK by the application.
@return The current network status.