EOS_Platform_GetRTCInterface

Function EOS_Platform_GetRTCInterface 

pub unsafe extern "C" fn EOS_Platform_GetRTCInterface(
    Handle: EOS_HPlatform,
) -> EOS_HRTC
Get a handle to the Real Time Communications Interface (RTC). From the RTC interface you can retrieve the handle to the audio interface (RTCAudio), which is a component of RTC. @return EOS_HRTC handle

@see EOS_RTC_GetAudioInterface @see eos_rtc.h @see eos_rtc_types.h