EOS_Platform_SetApplicationStatus

Function EOS_Platform_SetApplicationStatus 

pub unsafe extern "C" fn EOS_Platform_SetApplicationStatus(
    Handle: EOS_HPlatform,
    NewStatus: EOS_EApplicationStatus,
) -> EOS_EResult
Notify a change in application state.

@note Calling SetApplicationStatus must happen before Tick when foregrounding for the cases where we won’t get the background notification.

@param NewStatus The new status for the application.

@return An EOS_EResult that indicates whether we changed the application status successfully.

  • EOS_Success if the application was changed successfully.
  • EOS_InvalidParameters if the value of NewStatus is invalid.
  • EOS_NotImplemented if EOS_AS_BackgroundConstrained or EOS_AS_BackgroundUnconstrained are attempted to be set on platforms that do not have such application states.