EOS_Platform_Tick

Function EOS_Platform_Tick 

pub unsafe extern "C" fn EOS_Platform_Tick(Handle: EOS_HPlatform)
Notify the platform instance to do work. This function must be called frequently in order for the services provided by the SDK to properly function. For tick-based applications, it is usually desirable to call this once per-tick.