#[repr(C)]pub struct _tagEOS_Achievements_Definition {Show 13 fields
pub ApiVersion: i32,
pub AchievementId: *const c_char,
pub DisplayName: *const c_char,
pub Description: *const c_char,
pub LockedDisplayName: *const c_char,
pub LockedDescription: *const c_char,
pub HiddenDescription: *const c_char,
pub CompletionDescription: *const c_char,
pub UnlockedIconId: *const c_char,
pub LockedIconId: *const c_char,
pub bIsHidden: EOS_Bool,
pub StatThresholdsCount: i32,
pub StatThresholds: *const EOS_Achievements_StatThresholds,
}Expand description
Contains information about a single achievement definition with localized text.
Fields
ApiVersion: i32API Version: Set this to EOS_ACHIEVEMENTS_DEFINITION_API_LATEST.
AchievementId: *const c_charAchievement ID that can be used to uniquely identify the achievement.
DisplayName: *const c_charText representing the Name to display in-game when achievement has been unlocked.
Description: *const c_charText representing the description to display in-game when achievement has been unlocked.
LockedDisplayName: *const c_charText representing the name to display in-game when achievement is locked.
LockedDescription: *const c_charText representing the description of what needs to be done to trigger the unlock of this achievement.
HiddenDescription: *const c_charText representing the description to display in-game when achievement is hidden.
CompletionDescription: *const c_charText representing the description of what happens when the achievement is unlocked.
UnlockedIconId: *const c_charText representing the icon to display in-game when achievement is unlocked.
LockedIconId: *const c_charText representing the icon to display in-game when achievement is locked.
bIsHidden: EOS_BoolTrue if achievement is hidden, false otherwise.
StatThresholdsCount: i32The number of stat thresholds.
StatThresholds: *const EOS_Achievements_StatThresholdsArray of stat thresholds that need to be satisfied to unlock the achievement.