#[repr(C)]pub struct _tagEOS_Achievements_PlayerStatInfo {
pub ApiVersion: i32,
pub Name: *const c_char,
pub CurrentValue: i32,
pub ThresholdValue: i32,
}Expand description
Contains information about a collection of stat info data.
@see EOS_Achievements_PlayerAchievement
Fields
ApiVersion: i32API Version: Set this to EOS_ACHIEVEMENTS_PLAYERSTATINFO_API_LATEST.
Name: *const c_charThe name of the stat.
CurrentValue: i32The current value of the stat.
ThresholdValue: i32The threshold value of the stat, used in determining when to unlock an achievement.