#[repr(C)]pub struct _tagEOS_Achievements_QueryDefinitionsOptions {
pub ApiVersion: i32,
pub LocalUserId: EOS_ProductUserId,
pub EpicUserId_DEPRECATED: EOS_EpicAccountId,
pub HiddenAchievementIds_DEPRECATED: *mut *const c_char,
pub HiddenAchievementsCount_DEPRECATED: u32,
}Expand description
Input parameters for the EOS_Achievements_QueryDefinitions function.
Fields
ApiVersion: i32API Version: Set this to EOS_ACHIEVEMENTS_QUERYDEFINITIONS_API_LATEST.
LocalUserId: EOS_ProductUserIdProduct User ID for user who is querying definitions. The localized text returned will be based on the locale code of the given user if they have a linked Epic Account ID. The localized text returned can also be overridden using EOS_Platform_SetOverrideLocaleCode to override the locale. If the locale code is not overridden and LocalUserId is not valid, default text will be returned.
EpicUserId_DEPRECATED: EOS_EpicAccountIdDeprecated
HiddenAchievementIds_DEPRECATED: *mut *const c_charDeprecated
HiddenAchievementsCount_DEPRECATED: u32Deprecated