#[repr(C)]pub struct _tagEOS_AntiCheatClient_OnMessageToServerCallbackInfo {
pub ClientData: *mut c_void,
pub MessageData: *const c_void,
pub MessageDataSizeBytes: u32,
}Expand description
Structure containing details about a new message that must be dispatched to the game server.
Fields
ClientData: *mut c_voidCaller-specified context data
MessageData: *const c_voidThe message data that must be sent to the server
MessageDataSizeBytes: u32The size in bytes of MessageData