#[repr(C)]pub struct _tagEOS_AntiCheatCommon_LogGameRoundStartOptions {
pub ApiVersion: i32,
pub SessionIdentifier: *const c_char,
pub LevelName: *const c_char,
pub ModeName: *const c_char,
pub RoundTimeSeconds: u32,
pub CompetitionType: EOS_EAntiCheatCommonGameRoundCompetitionType,
}Expand description
Input parameters for the EOS_AntiCheatServer_LogGameRoundStart function.
Fields
ApiVersion: i32API Version: Set this to EOS_ANTICHEATCOMMON_LOGGAMEROUNDSTART_API_LATEST.
SessionIdentifier: *const c_charOptional game session or match identifier useful for some backend API integrations
LevelName: *const c_charOptional name of the map being played
ModeName: *const c_charOptional name of the game mode being played
RoundTimeSeconds: u32Optional length of the game round to be played, in seconds. If none, use 0.
CompetitionType: EOS_EAntiCheatCommonGameRoundCompetitionTypeType of competition for this game round