#[repr(C)]pub struct _tagEOS_AntiCheatCommon_LogPlayerUseAbilityOptions {
pub ApiVersion: i32,
pub PlayerHandle: EOS_AntiCheatCommon_ClientHandle,
pub AbilityId: u32,
pub AbilityDurationMs: u32,
pub AbilityCooldownMs: u32,
}Expand description
Input parameters for the EOS_AntiCheatServer_LogPlayerUseAbility function.
Fields
ApiVersion: i32API Version: Set this to EOS_ANTICHEATCOMMON_LOGPLAYERUSEABILITY_API_LATEST.
PlayerHandle: EOS_AntiCheatCommon_ClientHandleLocally unique value used in RegisterClient/RegisterPeer
AbilityId: u32Game defined unique identifier for the ability being used
AbilityDurationMs: u32Duration of the ability effect in milliseconds. If not applicable, use 0.
AbilityCooldownMs: u32Cooldown until the ability can be used again in milliseconds. If not applicable, use 0.