_tagEOS_AntiCheatServer_BeginSessionOptions

Struct _tagEOS_AntiCheatServer_BeginSessionOptions 

#[repr(C)]
pub struct _tagEOS_AntiCheatServer_BeginSessionOptions { pub ApiVersion: i32, pub RegisterTimeoutSeconds: u32, pub ServerName: *const c_char, pub bEnableGameplayData: EOS_Bool, pub LocalUserId: EOS_ProductUserId, }
Input parameters for the EOS_AntiCheatServer_BeginSession function.

Fields

ApiVersion: i32

API Version: Set this to EOS_ANTICHEATSERVER_BEGINSESSION_API_LATEST.

RegisterTimeoutSeconds: u32

Time in seconds to allow newly registered clients to complete anti-cheat authentication. Recommended value: 60 Minimum value: EOS_ANTICHEATSERVER_BEGINSESSION_MIN_REGISTERTIMEOUT Maximum value: EOS_ANTICHEATSERVER_BEGINSESSION_MAX_REGISTERTIMEOUT

ServerName: *const c_char

Optional name of this game server

bEnableGameplayData: EOS_Bool

Gameplay data collection APIs such as LogPlayerTick will be enabled if set to true. If you do not use these APIs you should set this value to false to reduce memory use.

LocalUserId: EOS_ProductUserId

The Product User ID of the local user who is associated with this session. Dedicated servers should set this to null.