#[repr(C)]pub struct _tagEOS_Auth_AccountFeatureRestrictedInfo {
pub ApiVersion: i32,
pub VerificationURI: *const c_char,
}Expand description
Intermediate data needed to complete account restriction verification during login flow, returned by EOS_Auth_LoginCallbackInfo when the ResultCode is EOS_Auth_AccountFeatureRestricted. The URI inside should be exposed to the user for entry in a web browser. The URI must be copied out of this struct before completion of the callback.
Fields
ApiVersion: i32API Version: Set this to EOS_AUTH_ACCOUNTFEATURERESTRICTEDINFO_API_LATEST.
VerificationURI: *const c_charThe end-user verification URI. Users must be asked to open the page in a browser to address the restrictions.