_tagEOS_Auth_Credentials

Struct _tagEOS_Auth_Credentials 

#[repr(C)]
pub struct _tagEOS_Auth_Credentials { pub ApiVersion: i32, pub Id: *const c_char, pub Token: *const c_char, pub Type: EOS_ELoginCredentialType, pub SystemAuthCredentialsOptions: *mut c_void, pub ExternalType: EOS_EExternalCredentialType, }
Login credentials filled as part of the EOS_Auth_LoginOptions struct for EOS_Auth_Login API.

Required input parameters to be set depend on the login credential type. Any parameters not being used must be set to NULL. Otherwise, EOS_InvalidParameters error is returned.

EOS_LCT_Password | ID is the email address, and Token is the password. EOS_LCT_ExchangeCode | Set ID to NULL. Token is the exchange code. EOS_LCT_PersistentAuth | Set ID to NULL. On console platforms, Token is the long-lived refresh token. Otherwise, set to NULL. EOS_LCT_Developer | Set ID as the host (e.g. localhost:6547). Token is the credential name registered in the EOS Developer Authentication Tool. EOS_LCT_RefreshToken | Set ID to NULL. Token is the refresh token. EOS_LCT_AccountPortal | Set ID and Token to NULL. SystemAuthCredentialsOptions may be required on mobile platforms. EOS_LCT_ExternalAuth | Set ID to NULL or the External Account ID that belongs to the external auth token. Token is the external auth token specified by ExternalType. External Account IDs set to the ID are expected as either base-10 numeric strings for integer-based external Account IDs, or the actual string for everything else. If ID is provided, login will automatically be cancelled if the EOS SDK is able to and does detect the external account signing-out. If ID is provided, it must match the external account ID belonging to the auth-token, or login will fail.

@see EOS_ELoginCredentialType @see EOS_Auth_Login @see EOS_Auth_DeletePersistentAuthOptions

Fields

ApiVersion: i32

API Version: Set this to EOS_AUTH_CREDENTIALS_API_LATEST.

Id: *const c_char

Authentication ID value based on the used EOS_ELoginCredentialType. If not used, must be set to NULL.

Token: *const c_char

Authentication Token value based on the used EOS_ELoginCredentialType. If not used, must be set to NULL.

Type: EOS_ELoginCredentialType

Login credentials type based on the authentication method used.

SystemAuthCredentialsOptions: *mut c_void

This field is for system specific options, if any.

If provided, the structure will be located in (System)/eos_(system).h. The structure will be named EOS_(System)_Auth_CredentialsOptions.

ExternalType: EOS_EExternalCredentialType

Type of external login. Needed to identify the external auth method to use. Used when login type is set to EOS_LCT_ExternalAuth, ignored for other EOS_ELoginCredentialType methods.