_tagEOS_Auth_DeletePersistentAuthOptions

Struct _tagEOS_Auth_DeletePersistentAuthOptions 

#[repr(C)]
pub struct _tagEOS_Auth_DeletePersistentAuthOptions { pub ApiVersion: i32, pub RefreshToken: *const c_char, }
Input parameters for the EOS_Auth_DeletePersistentAuth function.

Fields

ApiVersion: i32

API Version: Set this to EOS_AUTH_DELETEPERSISTENTAUTH_API_LATEST.

RefreshToken: *const c_char

A long-lived refresh token that is used with the EOS_LCT_PersistentAuth login type and is to be revoked from the authentication server. Only used on Console platforms. On Desktop and Mobile platforms, set this parameter to NULL.