_tagEOS_Auth_LinkAccountCallbackInfo

Struct _tagEOS_Auth_LinkAccountCallbackInfo 

#[repr(C)]
pub struct _tagEOS_Auth_LinkAccountCallbackInfo { pub ResultCode: EOS_EResult, pub ClientData: *mut c_void, pub LocalUserId: EOS_EpicAccountId, pub PinGrantInfo: *const EOS_Auth_PinGrantInfo, pub SelectedAccountId: EOS_EpicAccountId, }
Output parameters for the EOS_Auth_LinkAccount Function.

Fields

ResultCode: EOS_EResult

The EOS_EResult code for the operation. EOS_Success indicates that the operation succeeded; other codes indicate errors.

ClientData: *mut c_void

Context that was passed into EOS_Auth_LinkAccount.

LocalUserId: EOS_EpicAccountId

The Epic Account ID of the local user whose account has been linked during login.

PinGrantInfo: *const EOS_Auth_PinGrantInfo

Optional data that may be returned in the middle of the login flow, when neither the in-game overlay or a platform browser is used. This data is present when the ResultCode is EOS_Auth_PinGrantCode.

SelectedAccountId: EOS_EpicAccountId

The Epic Account ID that has been previously selected to be used for the current application. Applications should use this ID to authenticate with online backend services that store game-scoped data for users.

Note: This ID may be different from LocalUserId if the user has previously merged Epic accounts into the account represented by LocalUserId, and one of the accounts that got merged had game data associated with it for the application.