_tagEOS_Auth_LinkAccountOptions

Struct _tagEOS_Auth_LinkAccountOptions 

#[repr(C)]
pub struct _tagEOS_Auth_LinkAccountOptions { pub ApiVersion: i32, pub LinkAccountFlags: EOS_ELinkAccountFlags, pub ContinuanceToken: EOS_ContinuanceToken, pub LocalUserId: EOS_EpicAccountId, }
Input parameters for the EOS_Auth_LinkAccount function.

Fields

ApiVersion: i32

API Version: Set this to EOS_AUTH_LINKACCOUNT_API_LATEST.

LinkAccountFlags: EOS_ELinkAccountFlags

Combination of the enumeration flags to specify how the account linking operation will be performed.

ContinuanceToken: EOS_ContinuanceToken

Continuance token received from a previous call to the EOS_Auth_Login API.

A continuance token is received in the case when the external account used for login was not found to be linked against any existing Epic Account. In such case, the application needs to proceed with an account linking operation in which case the user is first asked to create a new account or login into their existing Epic Account, and then link their external account to it. Alternatively, the application may suggest the user to login using another external account that they have already linked to their existing Epic Account. In this flow, the external account is typically the currently logged in local platform user account. It can also be another external user account that the user is offered to login with.

LocalUserId: EOS_EpicAccountId

The Epic Account ID of the logged in local user whose Epic Account will be linked with the local Nintendo NSA ID Account. By default set to NULL.

This parameter is only used and required to be set when EOS_ELinkAccountFlags::EOS_LA_NintendoNsaId is specified. Otherwise, set to NULL, as the standard account linking and login flow using continuance token will handle logging in the user to their Epic Account.