_tagEOS_Auth_QueryIdTokenOptions

Struct _tagEOS_Auth_QueryIdTokenOptions 

#[repr(C)]
pub struct _tagEOS_Auth_QueryIdTokenOptions { pub ApiVersion: i32, pub LocalUserId: EOS_EpicAccountId, pub TargetAccountId: EOS_EpicAccountId, }
Input parameters for the EOS_Auth_QueryIdToken function.

Fields

ApiVersion: i32

API Version: Set this to EOS_AUTH_QUERYIDTOKEN_API_LATEST.

LocalUserId: EOS_EpicAccountId

The Epic Account ID of the local authenticated user.

TargetAccountId: EOS_EpicAccountId

The target Epic Account ID for which to query an ID token. This account id may be the same as the input LocalUserId or another merged account id associated with the local user’s Epic account.

An ID token for the selected account id of a locally authenticated user will always be readily available. To retrieve it for the selected account ID, you can use EOS_Auth_CopyIdToken directly after a successful user login.