#[repr(C)]pub struct _tagEOS_Auth_Token {
pub ApiVersion: i32,
pub App: *const c_char,
pub ClientId: *const c_char,
pub AccountId: EOS_EpicAccountId,
pub AccessToken: *const c_char,
pub ExpiresIn: f64,
pub ExpiresAt: *const c_char,
pub AuthType: EOS_EAuthTokenType,
pub RefreshToken: *const c_char,
pub RefreshExpiresIn: f64,
pub RefreshExpiresAt: *const c_char,
}Expand description
A structure that contains an auth token. These structures are created by EOS_Auth_CopyUserAuthToken and must be passed to EOS_Auth_Token_Release.
Fields
ApiVersion: i32API Version: Set this to EOS_AUTH_TOKEN_API_LATEST.
App: *const c_charName of the app related to the client ID involved with this token
ClientId: *const c_charClient ID that requested this token
AccountId: EOS_EpicAccountIdThe Epic Account ID associated with this auth token
AccessToken: *const c_charAccess token for the current user login session
ExpiresIn: f64Time before the access token expires, in seconds, relative to the call to EOS_Auth_CopyUserAuthToken
ExpiresAt: *const c_charAbsolute time in UTC before the access token expires, in ISO 8601 format
AuthType: EOS_EAuthTokenTypeType of auth token
RefreshToken: *const c_charRefresh token.
@see EOS_ELoginCredentialType::EOS_LCT_RefreshToken
RefreshExpiresIn: f64Time before the access token expires, in seconds, relative to the call to EOS_Auth_CopyUserAuthToken
RefreshExpiresAt: *const c_charAbsolute time in UTC before the refresh token expires, in ISO 8601 format