#[repr(C)]pub struct _tagEOS_Auth_VerifyIdTokenCallbackInfo {Show 13 fields
pub ResultCode: EOS_EResult,
pub ClientData: *mut c_void,
pub ApplicationId: *const c_char,
pub ClientId: *const c_char,
pub ProductId: *const c_char,
pub SandboxId: *const c_char,
pub DeploymentId: *const c_char,
pub DisplayName: *const c_char,
pub bIsExternalAccountInfoPresent: EOS_Bool,
pub ExternalAccountIdType: EOS_EExternalAccountType,
pub ExternalAccountId: *const c_char,
pub ExternalAccountDisplayName: *const c_char,
pub Platform: *const c_char,
}Expand description
Output parameters for the EOS_Auth_VerifyIdToken Function.
Fields
ResultCode: EOS_EResultThe EOS_EResult code for the operation. EOS_Success indicates that the operation succeeded; other codes indicate errors.
ClientData: *mut c_voidContext that was passed into EOS_Auth_VerifyIdToken
ApplicationId: *const c_charEpic Account Services Application ID.
ClientId: *const c_charClient ID of the authorized client.
ProductId: *const c_charProduct ID.
SandboxId: *const c_charSandbox ID.
DeploymentId: *const c_charDeployment ID.
DisplayName: *const c_charEpic Account display name.
This value may be set to an empty string.
bIsExternalAccountInfoPresent: EOS_BoolFlag set to indicate whether external account information is present. Applications must always first check this value to be set before attempting to read the ExternalAccountIdType, ExternalAccountId, ExternalAccountDisplayName and Platform fields.
This flag is set when the user has logged in to their Epic Account using external account credentials, e.g. through local platform authentication.
ExternalAccountIdType: EOS_EExternalAccountTypeThe identity provider that the user logged in with to their Epic Account.
If bIsExternalAccountInfoPresent is set, this field describes the external account type.
ExternalAccountId: *const c_charThe external account ID of the logged in user.
This value may be set to an empty string.
ExternalAccountDisplayName: *const c_charThe external account display name.
This value may be set to an empty string.
Platform: *const c_charPlatform that the user is connected from.
This value may be set to an empty string.