#[repr(C)]pub struct _tagEOS_Auth_VerifyUserAuthOptions {
pub ApiVersion: i32,
pub AuthToken: *const EOS_Auth_Token,
}Expand description
Input parameters for the EOS_Auth_VerifyUserAuth function. This operation is destructive, the pointer will remain the same but the data pointers inside will update
Fields
ApiVersion: i32API Version: Set this to EOS_AUTH_VERIFYUSERAUTH_API_LATEST.
AuthToken: *const EOS_Auth_TokenAuth token to verify against the backend service