_tagEOS_Connect_ExternalAccountInfo

Struct _tagEOS_Connect_ExternalAccountInfo 

#[repr(C)]
pub struct _tagEOS_Connect_ExternalAccountInfo { pub ApiVersion: i32, pub ProductUserId: EOS_ProductUserId, pub DisplayName: *const c_char, pub AccountId: *const c_char, pub AccountIdType: EOS_EExternalAccountType, pub LastLoginTime: i64, }
Contains information about an external account linked with a Product User ID.

Fields

ApiVersion: i32

API Version: Set this to EOS_CONNECT_EXTERNALACCOUNTINFO_API_LATEST.

ProductUserId: EOS_ProductUserId

The Product User ID of the target user.

DisplayName: *const c_char

Display name, can be null if not set.

AccountId: *const c_char

External account ID.

May be set to an empty string if the AccountIdType of another user belongs to different account system than the local user’s authenticated account. The availability of this field is dependent on account system specifics.

AccountIdType: EOS_EExternalAccountType

The identity provider that owns the external account.

LastLoginTime: i64

The POSIX timestamp for the time the user last logged in, or EOS_CONNECT_TIME_UNDEFINED.