#[repr(C)]pub struct _tagEOS_Connect_LinkAccountOptions {
pub ApiVersion: i32,
pub LocalUserId: EOS_ProductUserId,
pub ContinuanceToken: EOS_ContinuanceToken,
}Expand description
Input parameters for the EOS_Connect_LinkAccount function.
Fields
ApiVersion: i32API Version: Set this to EOS_CONNECT_LINKACCOUNT_API_LATEST.
LocalUserId: EOS_ProductUserIdThe existing logged in product user for which to link the external account described by the continuance token.
ContinuanceToken: EOS_ContinuanceTokenContinuance token from previous call to EOS_Connect_Login.