_tagEOS_Connect_LoginOptions

Struct _tagEOS_Connect_LoginOptions 

#[repr(C)]
pub struct _tagEOS_Connect_LoginOptions { pub ApiVersion: i32, pub Credentials: *const EOS_Connect_Credentials, pub UserLoginInfo: *const EOS_Connect_UserLoginInfo, }
Input parameters for the EOS_Connect_Login function.

Fields

ApiVersion: i32

API Version: Set this to EOS_CONNECT_LOGIN_API_LATEST.

Credentials: *const EOS_Connect_Credentials

Credentials specified for a given login method

UserLoginInfo: *const EOS_Connect_UserLoginInfo

Additional information about the local user.

This field is required to be set and used when authenticating the user using Amazon, Apple, Google, Nintendo Account, Nintendo Service Account, Oculus or the Device ID feature login. It is also required for using the Lobbies and Sessions interfaces when running on the Nintendo Switch device, and using any other credential type than EOS_ECT_NINTENDO_NSA_ID_TOKEN. In all other cases, set this field to NULL.