#[repr(C)]pub struct _tagEOS_Connect_UnlinkAccountOptions {
pub ApiVersion: i32,
pub LocalUserId: EOS_ProductUserId,
}Expand description
Input parameters for the EOS_Connect_UnlinkAccount Function.
Fields
ApiVersion: i32API Version: Set this to EOS_CONNECT_UNLINKACCOUNT_API_LATEST.
LocalUserId: EOS_ProductUserIdExisting logged in product user that is subject for the unlinking operation. The external account that was used to login to the product user will be unlinked from the owning keychain.
On a successful operation, the product user will be logged out as the external account used to authenticate the user was unlinked from the owning keychain.