_tagEOS_CustomInvites_SendCustomNativeInviteRequestedCallbackInfo

Struct _tagEOS_CustomInvites_SendCustomNativeInviteRequestedCallbackInfo 

#[repr(C)]
pub struct _tagEOS_CustomInvites_SendCustomNativeInviteRequestedCallbackInfo { pub ClientData: *mut c_void, pub UiEventId: EOS_UI_EventId, pub LocalUserId: EOS_ProductUserId, pub TargetNativeAccountType: EOS_IntegratedPlatformType, pub TargetUserNativeAccountId: *const c_char, pub InviteId: *const c_char, }
Output parameters for the EOS_CustomInvites_OnSendCustomNativeInviteRequestedCallback Function.

Fields

ClientData: *mut c_void

Context that was passed into EOS_CustomInvites_AddNotifySendCustomNativeInviteRequested

UiEventId: EOS_UI_EventId

Identifies this event which will need to be acknowledged with EOS_UI_AcknowledgeEventId(). @see EOS_UI_AcknowledgeEventId

LocalUserId: EOS_ProductUserId

The Product User ID of the local user who is inviting.

TargetNativeAccountType: EOS_IntegratedPlatformType

The Native Platform Account Type. If only a single integrated platform is configured then this will always reference that platform.

TargetUserNativeAccountId: *const c_char

The Native Platform Account ID of the target user being invited.

InviteId: *const c_char

Invite ID that the user is being invited to