#[repr(C)]pub struct _tagEOS_Ecom_CheckoutCallbackInfo {
pub ResultCode: EOS_EResult,
pub ClientData: *mut c_void,
pub LocalUserId: EOS_EpicAccountId,
pub TransactionId: *const c_char,
}Expand description
Output parameters for the EOS_Ecom_Checkout Function.
Fields
ResultCode: EOS_EResultResult code for the operation. EOS_Success is returned for a successful request, otherwise one of the error codes is returned. See eos_common.h
ClientData: *mut c_voidContext that was passed into EOS_Ecom_Checkout
LocalUserId: EOS_EpicAccountIdThe Epic Account ID of the user who initiated the purchase
TransactionId: *const c_charThe transaction ID which can be used to obtain an EOS_Ecom_HTransaction using EOS_Ecom_CopyTransactionById.