#[repr(C)]pub struct _tagEOS_Ecom_CopyEntitlementByNameAndIndexOptions {
pub ApiVersion: i32,
pub LocalUserId: EOS_EpicAccountId,
pub EntitlementName: EOS_Ecom_EntitlementName,
pub Index: u32,
}Expand description
Input parameters for the EOS_Ecom_CopyEntitlementByNameAndIndex function.
Fields
ApiVersion: i32API Version: Set this to EOS_ECOM_COPYENTITLEMENTBYNAMEANDINDEX_API_LATEST.
LocalUserId: EOS_EpicAccountIdThe Epic Account ID of the local user whose entitlement is being copied
EntitlementName: EOS_Ecom_EntitlementNameName of the entitlement to retrieve from the cache
Index: u32Index of the entitlement within the named set to retrieve from the cache.