#[repr(C)]pub struct _tagEOS_Ecom_Entitlement {
pub ApiVersion: i32,
pub EntitlementName: EOS_Ecom_EntitlementName,
pub EntitlementId: EOS_Ecom_EntitlementId,
pub CatalogItemId: EOS_Ecom_CatalogItemId,
pub ServerIndex: i32,
pub bRedeemed: EOS_Bool,
pub EndTimestamp: i64,
}Expand description
Contains information about a single entitlement associated with an account. Instances of this structure are created by EOS_Ecom_CopyEntitlementByIndex, EOS_Ecom_CopyEntitlementByNameAndIndex, or EOS_Ecom_CopyEntitlementById. They must be passed to EOS_Ecom_Entitlement_Release.
Fields
ApiVersion: i32API Version: Set this to EOS_ECOM_ENTITLEMENT_API_LATEST.
EntitlementName: EOS_Ecom_EntitlementNameName of the entitlement
EntitlementId: EOS_Ecom_EntitlementIdID of the entitlement owned by an account
CatalogItemId: EOS_Ecom_CatalogItemIdID of the item associated with the offer which granted this entitlement
ServerIndex: i32If queried using pagination then ServerIndex represents the index of the entitlement as it exists on the server. If not queried using pagination then ServerIndex will be -1.
bRedeemed: EOS_BoolIf true then the catalog has this entitlement marked as redeemed
EndTimestamp: i64If not -1 then this is a POSIX timestamp that this entitlement will end