#[repr(C)]pub struct _tagEOS_Ecom_GetOfferImageInfoCountOptions {
pub ApiVersion: i32,
pub LocalUserId: EOS_EpicAccountId,
pub OfferId: EOS_Ecom_CatalogOfferId,
}Expand description
Input parameters for the EOS_Ecom_GetOfferImageInfoCount function.
Fields
ApiVersion: i32API Version: Set this to EOS_ECOM_GETOFFERIMAGEINFOCOUNT_API_LATEST.
LocalUserId: EOS_EpicAccountIdThe Epic Account ID of the local user whose offer image is being accessed.
OfferId: EOS_Ecom_CatalogOfferIdThe ID of the offer to get the images for.