#[repr(C)]pub struct _tagEOS_Ecom_GetOfferItemCountOptions {
pub ApiVersion: i32,
pub LocalUserId: EOS_EpicAccountId,
pub OfferId: EOS_Ecom_CatalogOfferId,
}Expand description
Input parameters for the EOS_Ecom_GetOfferItemCount function.
Fields
ApiVersion: i32API Version: Set this to EOS_ECOM_GETOFFERITEMCOUNT_API_LATEST.
LocalUserId: EOS_EpicAccountIdThe Epic Account ID of the local user who made the initial request for the Catalog Offer through EOS_Ecom_QueryOffers
OfferId: EOS_Ecom_CatalogOfferIdAn ID that corresponds to a cached Catalog Offer (retrieved by EOS_Ecom_CopyOfferByIndex)