#[repr(C)]pub struct _tagEOS_Ecom_ItemOwnership {
pub ApiVersion: i32,
pub Id: EOS_Ecom_CatalogItemId,
pub OwnershipStatus: EOS_EOwnershipStatus,
}Expand description
Contains information about a single item ownership associated with an account. This structure is returned as part of the EOS_Ecom_QueryOwnershipCallbackInfo structure.
Fields
ApiVersion: i32API Version: Set this to EOS_ECOM_ITEMOWNERSHIP_API_LATEST.
Id: EOS_Ecom_CatalogItemIdID of the catalog item
OwnershipStatus: EOS_EOwnershipStatusIs this catalog item owned by the local user