#[repr(C)]pub struct _tagEOS_Ecom_KeyImageInfo {
pub ApiVersion: i32,
pub Type: *const c_char,
pub Url: *const c_char,
pub Width: u32,
pub Height: u32,
}Expand description
Contains information about a key image used by the catalog. Instances of this structure are created by EOS_Ecom_CopyItemImageInfoByIndex. They must be passed to EOS_Ecom_KeyImageInfo_Release. A Key Image is defined within Dev Portal and is associated with a Catalog Item. A Key Image is intended to be used to provide imagery for an in-game store.
@see EOS_Ecom_CopyItemImageInfoByIndex @see EOS_Ecom_KeyImageInfo_Release
Fields
ApiVersion: i32API Version: Set this to EOS_ECOM_KEYIMAGEINFO_API_LATEST.
Type: *const c_charDescribes the usage of the image (ex: home_thumbnail)
Url: *const c_charThe URL of the image
Width: u32The expected width in pixels of the image
Height: u32The expected height in pixels of the image