#[repr(C)]pub struct _tagEOS_Ecom_QueryEntitlementsOptions {
pub ApiVersion: i32,
pub LocalUserId: EOS_EpicAccountId,
pub EntitlementNames: *mut EOS_Ecom_EntitlementName,
pub EntitlementNameCount: u32,
pub bIncludeRedeemed: EOS_Bool,
pub OverrideCatalogNamespace: *const c_char,
}Expand description
Input parameters for the EOS_Ecom_QueryEntitlements function.
Fields
ApiVersion: i32API Version: Set this to EOS_ECOM_QUERYENTITLEMENTS_API_LATEST.
LocalUserId: EOS_EpicAccountIdThe Epic Account ID of the local user whose Entitlements you want to retrieve
EntitlementNames: *mut EOS_Ecom_EntitlementNameAn array of Entitlement Names that you want to check
EntitlementNameCount: u32The number of Entitlement Names included in the array, up to EOS_ECOM_QUERYENTITLEMENTS_MAX_ENTITLEMENT_IDS; use zero to request all Entitlements associated with the user’s Epic Online Services account.
bIncludeRedeemed: EOS_BoolIf true, Entitlements that have been redeemed will be included in the results.
OverrideCatalogNamespace: *const c_charIf not provided then the SandboxId is used as the catalog namespace