#[repr(C)]pub struct _tagEOS_Ecom_QueryOwnershipBySandboxIdsCallbackInfo {
pub ResultCode: EOS_EResult,
pub ClientData: *mut c_void,
pub LocalUserId: EOS_EpicAccountId,
pub SandboxIdItemOwnerships: *const EOS_Ecom_SandboxIdItemOwnership,
pub SandboxIdItemOwnershipsCount: u32,
}Expand description
Output parameters for the EOS_Ecom_QueryOwnershipBySandboxIds Function.
Fields
ResultCode: EOS_EResultThe EOS_EResult code for the operation. EOS_Success indicates that the operation succeeded; other codes indicate errors.
ClientData: *mut c_voidContext that was passed into EOS_Ecom_QueryOwnership
LocalUserId: EOS_EpicAccountIdThe Epic Account ID of the local user whose ownership was queried
SandboxIdItemOwnerships: *const EOS_Ecom_SandboxIdItemOwnershipList of SandboxIds and their corresponding owned catalog item Ids. If there are no ownership items, the OwnedCatalogItemIdsCount is 0 and OwnedCatalogItemIds is null.
SandboxIdItemOwnershipsCount: u32Number of ownership results are included in this callback