#[repr(C)]pub struct _tagEOS_Ecom_QueryOwnershipCallbackInfo {
pub ResultCode: EOS_EResult,
pub ClientData: *mut c_void,
pub LocalUserId: EOS_EpicAccountId,
pub ItemOwnership: *const EOS_Ecom_ItemOwnership,
pub ItemOwnershipCount: u32,
}Expand description
Output parameters for the EOS_Ecom_QueryOwnership Function.
Fields
ResultCode: EOS_EResultThe EOS_EResult code for the operation. EOS_Success indicates that the operation succeeded; other codes indicate errors.
ClientData: *mut c_voidContext that was passed into EOS_Ecom_QueryOwnership
LocalUserId: EOS_EpicAccountIdThe Epic Account ID of the local user whose ownership was queried
ItemOwnership: *const EOS_Ecom_ItemOwnershipList of catalog items and their ownership status
ItemOwnershipCount: u32Number of ownership results are included in this callback