#[repr(C)]pub struct _tagEOS_Ecom_QueryOwnershipOptions {
pub ApiVersion: i32,
pub LocalUserId: EOS_EpicAccountId,
pub CatalogItemIds: *mut EOS_Ecom_CatalogItemId,
pub CatalogItemIdCount: u32,
pub CatalogNamespace: *const c_char,
}Expand description
Input parameters for the EOS_Ecom_QueryOwnership function.
Fields
ApiVersion: i32API Version: Set this to EOS_ECOM_QUERYOWNERSHIP_API_LATEST.
LocalUserId: EOS_EpicAccountIdThe Epic Account ID of the local user whose ownership to query
CatalogItemIds: *mut EOS_Ecom_CatalogItemIdThe array of Catalog Item IDs to check for ownership
CatalogItemIdCount: u32The number of Catalog Item IDs to in the array
CatalogNamespace: *const c_charOptional product namespace, if not the one specified during initialization