#[repr(C)]pub struct _tagEOS_Friends_AcceptInviteCallbackInfo {
pub ResultCode: EOS_EResult,
pub ClientData: *mut c_void,
pub LocalUserId: EOS_EpicAccountId,
pub TargetUserId: EOS_EpicAccountId,
}Expand description
Output parameters for the EOS_Friends_AcceptInvite Function.
Fields
ResultCode: EOS_EResultResult code for the operation. EOS_Success is returned if an invite was accepted, otherwise one of the error codes is returned. See eos_common.h
ClientData: *mut c_voidContext that is passed into EOS_Friends_AcceptInvite
LocalUserId: EOS_EpicAccountIdThe Epic Account ID of the user who is accepting the friends list invitation
TargetUserId: EOS_EpicAccountIdThe Epic Account ID of the user who sent the local user a friends list invitation