#[repr(C)]pub struct _tagEOS_Friends_OnBlockedUsersUpdateInfo {
pub ClientData: *mut c_void,
pub LocalUserId: EOS_EpicAccountId,
pub TargetUserId: EOS_EpicAccountId,
pub bBlocked: EOS_Bool,
}Expand description
Structure containing information about a blocklist update.
Fields
ClientData: *mut c_voidClient-specified data passed into EOS_Friends_AddNotifyBlockedUsersUpdate
LocalUserId: EOS_EpicAccountIdThe Epic Account ID of the local user who is receiving the update
TargetUserId: EOS_EpicAccountIdThe Epic Account ID of the user whose blocked status is being updated.
bBlocked: EOS_BoolTargetUserId block status (blocked or not).