#[repr(C)]pub struct _tagEOS_Friends_OnFriendsUpdateInfo {
pub ClientData: *mut c_void,
pub LocalUserId: EOS_EpicAccountId,
pub TargetUserId: EOS_EpicAccountId,
pub PreviousStatus: EOS_EFriendsStatus,
pub CurrentStatus: EOS_EFriendsStatus,
}Expand description
Structure containing information about a friend status update.
Fields
ClientData: *mut c_voidClient-specified data passed into EOS_Friends_AddNotifyFriendsUpdate
LocalUserId: EOS_EpicAccountIdThe Epic Account ID of the local user who is receiving the update
TargetUserId: EOS_EpicAccountIdThe Epic Account ID of the user whose status is being updated.
PreviousStatus: EOS_EFriendsStatusThe previous status of the user.
CurrentStatus: EOS_EFriendsStatusThe current status of the user.