#[repr(C)]pub struct _tagEOS_Friends_SendInviteCallbackInfo {
pub ResultCode: EOS_EResult,
pub ClientData: *mut c_void,
pub LocalUserId: EOS_EpicAccountId,
pub TargetUserId: EOS_EpicAccountId,
}Expand description
Output parameters for the EOS_Friends_SendInvite API.
Fields
ResultCode: EOS_EResultResult code for the operation. EOS_Success is returned if the invitation was sent, otherwise one of the error codes is returned. See eos_common.h
ClientData: *mut c_voidContext that was passed into EOS_Friends_SendInvite
LocalUserId: EOS_EpicAccountIdThe Epic Account ID of the user who sent the friends list invitation
TargetUserId: EOS_EpicAccountIdThe Epic Account ID of the user to whom the friends list invitation was sent