_tagEOS_InitializeOptions

Struct _tagEOS_InitializeOptions 

#[repr(C)]
pub struct _tagEOS_InitializeOptions { pub ApiVersion: i32, pub AllocateMemoryFunction: EOS_AllocateMemoryFunc, pub ReallocateMemoryFunction: EOS_ReallocateMemoryFunc, pub ReleaseMemoryFunction: EOS_ReleaseMemoryFunc, pub ProductName: *const c_char, pub ProductVersion: *const c_char, pub Reserved: *mut c_void, pub SystemInitializeOptions: *mut c_void, pub OverrideThreadAffinity: *mut EOS_Initialize_ThreadAffinity, }
Options for initializing the Epic Online Services SDK.

Fields

ApiVersion: i32

API Version: Set this to EOS_INITIALIZE_API_LATEST.

AllocateMemoryFunction: EOS_AllocateMemoryFunc

A custom memory allocator, if desired.

ReallocateMemoryFunction: EOS_ReallocateMemoryFunc

A corresponding memory reallocator. If the AllocateMemoryFunction is nulled, then this field must also be nulled.

ReleaseMemoryFunction: EOS_ReleaseMemoryFunc

A corresponding memory releaser. If the AllocateMemoryFunction is nulled, then this field must also be nulled.

ProductName: *const c_char

The name of the product using the Epic Online Services SDK.

The name string is required to be non-empty and at maximum of EOS_INITIALIZEOPTIONS_PRODUCTNAME_MAX_LENGTH bytes long. The string buffer can consist of the following characters: A-Z, a-z, 0-9, dot, underscore, space, exclamation mark, question mark, and sign, hyphen, parenthesis, plus, minus, colon.

ProductVersion: *const c_char

Product version of the running application.

The version string is required to be non-empty and at maximum of EOS_INITIALIZEOPTIONS_PRODUCTVERSION_MAX_LENGTH bytes long. The string buffer can consist of the following characters: A-Z, a-z, 0-9, dot, underscore, space, exclamation mark, question mark, and sign, hyphen, parenthesis, plus, minus, colon.

Reserved: *mut c_void

A reserved field that should always be nulled.

SystemInitializeOptions: *mut c_void

This field is for system specific initialization if any.

If provided then the structure will be located in /eos_.h. The structure will be named EOS__InitializeOptions.

OverrideThreadAffinity: *mut EOS_Initialize_ThreadAffinity

The thread affinity override values for each category of thread.