#[repr(C)]pub struct _tagEOS_KWS_PermissionsUpdateReceivedCallbackInfo {
pub ClientData: *mut c_void,
pub LocalUserId: EOS_ProductUserId,
pub KWSUserId: *const c_char,
pub DateOfBirth: *const c_char,
pub bIsMinor: EOS_Bool,
pub ParentEmail: *const c_char,
}Expand description
Output parameters for the EOS_KWS_OnPermissionsUpdateReceivedCallback Function.
Fields
ClientData: *mut c_voidContext that was passed into EOS_KWS_AddNotifyPermissionsUpdateReceived
LocalUserId: EOS_ProductUserIdRecipient Local user id
KWSUserId: *const c_charRecipient’s associated KWS UserId
DateOfBirth: *const c_charDate of birth in ISO8601 form (YYYY-MM-DD)
bIsMinor: EOS_BoolIs this user a minor
ParentEmail: *const c_charParent email. This value may be set to an empty string if the originally registered email recipient declined to be the right person to give consent.