#[repr(C)]pub struct _tagEOS_KWS_QueryAgeGateCallbackInfo {
pub ResultCode: EOS_EResult,
pub ClientData: *mut c_void,
pub CountryCode: *const c_char,
pub AgeOfConsent: u32,
}Expand description
Output parameters for the EOS_KWS_QueryAgeGate Function. These parameters are received through the callback provided to EOS_KWS_QueryAgeGate
Fields
ResultCode: EOS_EResultThe EOS_EResult code for the operation. EOS_Success indicates that the operation succeeded; other codes indicate errors.
ClientData: *mut c_voidContext that was passed into EOS_KWS_QueryAgeGate
CountryCode: *const c_charCountry code determined for this request based on the local client’s ip address that the backend resolves
AgeOfConsent: u32Age of consent in the given country