_tagEOS_KWS_QueryPermissionsCallbackInfo

Struct _tagEOS_KWS_QueryPermissionsCallbackInfo 

#[repr(C)]
pub struct _tagEOS_KWS_QueryPermissionsCallbackInfo { pub ResultCode: EOS_EResult, pub ClientData: *mut c_void, pub LocalUserId: EOS_ProductUserId, pub KWSUserId: *const c_char, pub DateOfBirth: *const c_char, pub bIsMinor: EOS_Bool, pub ParentEmail: *const c_char, }
Output parameters for the EOS_KWS_QueryPermissionsOptions Function. These parameters are received through the callback provided to EOS_KWS_QueryPermissions

Fields

ResultCode: EOS_EResult

The EOS_EResult code for the operation. EOS_Success indicates that the operation succeeded; other codes indicate errors.

ClientData: *mut c_void

Context that was passed into EOS_KWS_QueryPermissions

LocalUserId: EOS_ProductUserId

Local user querying their permissions

KWSUserId: *const c_char

KWS UserId created

DateOfBirth: *const c_char

Date of birth in ISO8601 form (YYYY-MM-DD)

bIsMinor: EOS_Bool

Is this user a minor

ParentEmail: *const c_char

Parent email. This value may be set to an empty string if the originally registered email recipient declined to be the right person to give consent.