#[repr(C)]pub struct _tagEOS_Leaderboards_QueryLeaderboardRanksOptions {
pub ApiVersion: i32,
pub LeaderboardId: *const c_char,
pub LocalUserId: EOS_ProductUserId,
}Expand description
Input parameters for the EOS_Leaderboards_QueryLeaderboardRanks function.
@see EOS_Leaderboards_Definition
Fields
ApiVersion: i32API Version: Set this to EOS_LEADERBOARDS_QUERYLEADERBOARDRANKS_API_LATEST.
LeaderboardId: *const c_charThe ID of the leaderboard whose information you want to retrieve.
LocalUserId: EOS_ProductUserIdProduct User ID for user who is querying ranks. Must be set when using a client policy that requires a valid logged in user. Not used for Dedicated Server where no user is available.