_tagEOS_LobbyModification_AddAttributeOptions

Struct _tagEOS_LobbyModification_AddAttributeOptions 

#[repr(C)]
pub struct _tagEOS_LobbyModification_AddAttributeOptions { pub ApiVersion: i32, pub Attribute: *const EOS_Lobby_AttributeData, pub Visibility: EOS_ELobbyAttributeVisibility, }
Input parameters for the EOS_LobbyModification_AddAttribute function.

Fields

ApiVersion: i32

API Version: Set this to EOS_LOBBYMODIFICATION_ADDATTRIBUTE_API_LATEST.

Attribute: *const EOS_Lobby_AttributeData

Key/Value pair describing the attribute to add to the lobby

Visibility: EOS_ELobbyAttributeVisibility

Is this attribute public or private to the lobby and its members