#[repr(C)]pub struct _tagEOS_LobbySearch_SetParameterOptions {
pub ApiVersion: i32,
pub Parameter: *const EOS_Lobby_AttributeData,
pub ComparisonOp: EOS_EComparisonOp,
}Expand description
Input parameters for the EOS_LobbySearch_SetParameter function.
Fields
ApiVersion: i32API Version: Set this to EOS_LOBBYSEARCH_SETPARAMETER_API_LATEST.
Parameter: *const EOS_Lobby_AttributeDataSearch parameter describing a key and a value to compare
ComparisonOp: EOS_EComparisonOpThe type of comparison to make against the search parameter