#[repr(C)]pub struct _tagEOS_LobbySearch_SetTargetUserIdOptions {
pub ApiVersion: i32,
pub TargetUserId: EOS_ProductUserId,
}Expand description
Input parameters for the EOS_LobbySearch_SetTargetUserId function.
Fields
ApiVersion: i32API Version: Set this to EOS_LOBBYSEARCH_SETTARGETUSERID_API_LATEST.
TargetUserId: EOS_ProductUserIdSearch lobbies for given user by Product User ID, returning any lobbies where this user is currently registered