#[repr(C)]pub struct _tagEOS_Lobby_Attribute {
pub ApiVersion: i32,
pub Data: *mut EOS_Lobby_AttributeData,
pub Visibility: EOS_ELobbyAttributeVisibility,
}Expand description
An attribute and its visibility setting stored with a lobby. Used to store both lobby and lobby member data
Fields
ApiVersion: i32API Version: Set this to EOS_LOBBY_ATTRIBUTE_API_LATEST.
Data: *mut EOS_Lobby_AttributeDataKey/Value pair describing the attribute
Visibility: EOS_ELobbyAttributeVisibilityIs this attribute public or private to the lobby and its members