#[repr(C)]pub struct _tagEOS_Lobby_JoinLobbyOptions {
pub ApiVersion: i32,
pub LobbyDetailsHandle: EOS_HLobbyDetails,
pub LocalUserId: EOS_ProductUserId,
pub bPresenceEnabled: EOS_Bool,
pub LocalRTCOptions: *const EOS_Lobby_LocalRTCOptions,
pub bCrossplayOptOut: EOS_Bool,
pub RTCRoomJoinActionType: EOS_ELobbyRTCRoomJoinActionType,
}Expand description
Input parameters for the EOS_Lobby_JoinLobby function.
Fields
ApiVersion: i32API Version: Set this to EOS_LOBBY_JOINLOBBY_API_LATEST.
LobbyDetailsHandle: EOS_HLobbyDetailsThe handle of the lobby to join
LocalUserId: EOS_ProductUserIdThe Product User ID of the local user joining the lobby
bPresenceEnabled: EOS_BoolIf true, this lobby will be associated with the local user’s presence information. A user can only associate one lobby at a time with their presence information. This affects the ability of the Social Overlay to show game related actions to take in the user’s social graph.
@note The Social Overlay can handle only one of the following three options at a time:
- using the bPresenceEnabled flags within the Sessions interface
- using the bPresenceEnabled flags within the Lobby interface
- using EOS_PresenceModification_SetJoinInfo
@see EOS_PresenceModification_SetJoinInfoOptions @see EOS_Lobby_CreateLobbyOptions @see EOS_Lobby_JoinLobbyOptions @see EOS_Sessions_CreateSessionModificationOptions @see EOS_Sessions_JoinSessionOptions
LocalRTCOptions: *const EOS_Lobby_LocalRTCOptions(Optional) Set this value to override the default local options for the RTC Room, if it is enabled for this lobby. Set this to NULL if your application does not use the Lobby RTC Rooms feature, or if you would like to use the default settings. This option is ignored if the specified lobby does not have an RTC Room enabled and will not cause errors.
bCrossplayOptOut: EOS_BoolThis value indicates whether or not the local user allows crossplay interactions. If it is false, the local user will be treated as allowing crossplay.
RTCRoomJoinActionType: EOS_ELobbyRTCRoomJoinActionTypeFor lobbies with the RTC Room feature enabled, this value indicates the action to take against the RTC Room when joining the lobby. This may be used to indicate the RTCRoom should be joined immediately or manually at a later time.