_tagEOS_Lobby_LocalRTCOptions

Struct _tagEOS_Lobby_LocalRTCOptions 

#[repr(C)]
pub struct _tagEOS_Lobby_LocalRTCOptions { pub ApiVersion: i32, pub Flags: u32, pub bUseManualAudioInput: EOS_Bool, pub bUseManualAudioOutput: EOS_Bool, pub bLocalAudioDeviceInputStartsMuted: EOS_Bool, pub Reserved: *mut c_void, }
Input parameters to use with Lobby RTC Rooms.

Fields

ApiVersion: i32

API Version: Set this to EOS_LOBBY_LOCALRTCOPTIONS_API_LATEST.

Flags: u32

Flags for the local user in this room. The default is 0 if this struct is not specified. @see EOS_RTC_JoinRoomOptions::Flags

bUseManualAudioInput: EOS_Bool

Set to EOS_TRUE to enable Manual Audio Input. If manual audio input is enabled, audio recording is not started and the audio buffers must be passed manually using EOS_RTCAudio_SendAudio. The default is EOS_FALSE if this struct is not specified.

bUseManualAudioOutput: EOS_Bool

Set to EOS_TRUE to enable Manual Audio Output. If manual audio output is enabled, audio rendering is not started and the audio buffers must be received with EOS_RTCAudio_AddNotifyAudioBeforeRender and rendered manually. The default is EOS_FALSE if this struct is not specified.

bLocalAudioDeviceInputStartsMuted: EOS_Bool

Set to EOS_TRUE to start the audio input device’s stream as muted when first connecting to the RTC room.

It must be manually unmuted with a call to EOS_RTCAudio_UpdateSending. If manual audio output is enabled, this value is ignored. The default value is EOS_FALSE if this struct is not specified.

Reserved: *mut c_void

Reserved field, should be nullptr by default