#[repr(C)]pub struct _tagEOS_Metrics_BeginPlayerSessionOptions {
pub ApiVersion: i32,
pub AccountIdType: EOS_EMetricsAccountIdType,
pub AccountId: _tagEOS_Metrics_BeginPlayerSessionOptions__bindgen_ty_1,
pub DisplayName: *const c_char,
pub ControllerType: EOS_EUserControllerType,
pub ServerIp: *const c_char,
pub GameSessionId: *const c_char,
}Expand description
BeginPlayerSession.
Fields
ApiVersion: i32API Version: Set this to EOS_METRICS_BEGINPLAYERSESSION_API_LATEST.
AccountIdType: EOS_EMetricsAccountIdTypeAccount ID type that is set in the union.
AccountId: _tagEOS_Metrics_BeginPlayerSessionOptions__bindgen_ty_1The Account ID for the player whose session is beginning.
DisplayName: *const c_charThe in-game display name for the user as UTF-8 string.
ControllerType: EOS_EUserControllerTypeThe user’s game controller type.
ServerIp: *const c_charIP address of the game server hosting the game session. For a localhost session, set to NULL.
@details Must be in either one of the following IPv4 or IPv6 string formats:
- “127.0.0.1”.
- “1200:0000:AB00:1234:0000:2552:7777:1313”. If both IPv4 and IPv6 addresses are available, use the IPv6 address.
GameSessionId: *const c_charOptional, application-defined custom match session identifier. If the identifier is not used, set to NULL.
@details The game can tag each game session with a custom session match identifier, which will be shown in the Played Sessions listing at the user profile dashboard.