#[repr(C)]pub struct _tagEOS_Mods_InstallModOptions {
pub ApiVersion: i32,
pub LocalUserId: EOS_EpicAccountId,
pub Mod: *const EOS_Mod_Identifier,
pub bRemoveAfterExit: EOS_Bool,
}Expand description
Input parameters for the EOS_Mods_InstallMod Function.
Fields
ApiVersion: i32API Version: Set this to EOS_MODS_INSTALLMOD_API_LATEST.
LocalUserId: EOS_EpicAccountIdThe Epic Account ID of the user for which the mod should be installed
Mod: *const EOS_Mod_IdentifierThe mod to install
bRemoveAfterExit: EOS_BoolIndicates whether the mod should be uninstalled after exiting the game or not.