#[repr(C)]pub struct _tagEOS_P2P_AcceptConnectionOptions {
pub ApiVersion: i32,
pub LocalUserId: EOS_ProductUserId,
pub RemoteUserId: EOS_ProductUserId,
pub SocketId: *const EOS_P2P_SocketId,
}Expand description
Structure containing information about who would like to accept a connection, and which connection.
Fields
ApiVersion: i32API Version: Set this to EOS_P2P_ACCEPTCONNECTION_API_LATEST.
LocalUserId: EOS_ProductUserIdThe Product User ID of the local user who is accepting any pending or future connections with RemoteUserId
RemoteUserId: EOS_ProductUserIdThe Product User ID of the remote user who has either sent a connection request or is expected to in the future
SocketId: *const EOS_P2P_SocketIdThe socket ID of the connection to accept on