#[repr(C)]pub struct _tagEOS_P2P_AddNotifyPeerConnectionClosedOptions {
pub ApiVersion: i32,
pub LocalUserId: EOS_ProductUserId,
pub SocketId: *const EOS_P2P_SocketId,
}Expand description
Structure containing information about who would like notifications about closed connections, and for which socket.
Fields
ApiVersion: i32API Version: Set this to EOS_P2P_ADDNOTIFYPEERCONNECTIONCLOSED_API_LATEST.
LocalUserId: EOS_ProductUserIdThe Product User ID of the local user who would like notifications
SocketId: *const EOS_P2P_SocketIdThe optional socket ID to listen for to be closed. If NULL, this function handler will be called for all closed connections