#[repr(C)]pub struct _tagEOS_P2P_AddNotifyPeerConnectionEstablishedOptions {
pub ApiVersion: i32,
pub LocalUserId: EOS_ProductUserId,
pub SocketId: *const EOS_P2P_SocketId,
}Expand description
Structure containing information about which connections should be notified
Fields
ApiVersion: i32API Version: Set this to EOS_P2P_ADDNOTIFYPEERCONNECTIONESTABLISHED_API_LATEST.
LocalUserId: EOS_ProductUserIdThe Product User ID of the local user who would like to receive notifications
SocketId: *const EOS_P2P_SocketIdThe optional socket ID, used as a filter for established connections. If NULL, this function handler will be called for all sockets