#[repr(C)]pub struct _tagEOS_P2P_AddNotifyPeerConnectionInterruptedOptions {
pub ApiVersion: i32,
pub LocalUserId: EOS_ProductUserId,
pub SocketId: *const EOS_P2P_SocketId,
}Expand description
Structure containing information about who would like notifications about interrupted connections, and for which socket.
Fields
ApiVersion: i32API Version: Set this to EOS_P2P_ADDNOTIFYPEERCONNECTIONINTERRUPTED_API_LATEST.
LocalUserId: EOS_ProductUserIdThe Product User ID of the local user who would like notifications
SocketId: *const EOS_P2P_SocketIdAn optional socket ID to filter interrupted connections on. If NULL, this function handler will be called for all interrupted connections