#[repr(C)]pub struct _tagEOS_P2P_AddNotifyPeerConnectionRequestOptions {
pub ApiVersion: i32,
pub LocalUserId: EOS_ProductUserId,
pub SocketId: *const EOS_P2P_SocketId,
}Expand description
Structure containing information about who would like connection notifications, and about which socket.
Fields
ApiVersion: i32API Version: Set this to EOS_P2P_ADDNOTIFYPEERCONNECTIONREQUEST_API_LATEST.
LocalUserId: EOS_ProductUserIdThe Product User ID of the user who is listening for incoming connection requests
SocketId: *const EOS_P2P_SocketIdThe optional socket ID to listen for, used as a filter for incoming connection requests; If NULL, incoming connection requests will not be filtered