#[repr(C)]pub struct _tagEOS_P2P_ClearPacketQueueOptions {
pub ApiVersion: i32,
pub LocalUserId: EOS_ProductUserId,
pub RemoteUserId: EOS_ProductUserId,
pub SocketId: *const EOS_P2P_SocketId,
}Expand description
Structure containing information about the packet queue to be cleared
Fields
ApiVersion: i32API Version: Set this to EOS_P2P_CLEARPACKETQUEUE_API_LATEST.
LocalUserId: EOS_ProductUserIdThe Product User ID of the local user for whom we want to clear the queued packets
RemoteUserId: EOS_ProductUserIdThe Product User ID to who (outgoing) or from who (incoming) packets are queued
SocketId: *const EOS_P2P_SocketIdThe socket used for packets to be cleared