#[repr(C)]pub struct _tagEOS_P2P_CloseConnectionOptions {
pub ApiVersion: i32,
pub LocalUserId: EOS_ProductUserId,
pub RemoteUserId: EOS_ProductUserId,
pub SocketId: *const EOS_P2P_SocketId,
}Expand description
Structure containing information about who would like to close a connection, and which connection.
Fields
ApiVersion: i32API Version: Set this to EOS_P2P_CLOSECONNECTION_API_LATEST.
LocalUserId: EOS_ProductUserIdThe Product User ID of the local user who would like to close a previously accepted connection (or decline a pending invite)
RemoteUserId: EOS_ProductUserIdThe Product User ID of the remote user to disconnect from (or to reject a pending invite from)
SocketId: *const EOS_P2P_SocketIdThe socket ID of the connection to close (or optionally NULL to not accept any connection requests from the Remote User)