#[repr(C)]pub struct _tagEOS_P2P_CloseConnectionsOptions {
pub ApiVersion: i32,
pub LocalUserId: EOS_ProductUserId,
pub SocketId: *const EOS_P2P_SocketId,
}Expand description
Structure containing information about who would like to close connections, and by what socket ID
Fields
ApiVersion: i32API Version: Set this to EOS_P2P_CLOSECONNECTIONS_API_LATEST.
LocalUserId: EOS_ProductUserIdThe Product User ID of the local user who would like to close all connections that use a particular socket ID
SocketId: *const EOS_P2P_SocketIdThe socket ID of the connections to close