#[repr(C)]pub struct _tagEOS_P2P_OnPeerConnectionEstablishedInfo {
pub ClientData: *mut c_void,
pub LocalUserId: EOS_ProductUserId,
pub RemoteUserId: EOS_ProductUserId,
pub SocketId: *const EOS_P2P_SocketId,
pub ConnectionType: EOS_EConnectionEstablishedType,
pub NetworkType: EOS_ENetworkConnectionType,
}Expand description
Structure containing information about a connection being established
Fields
ClientData: *mut c_voidClient-specified data passed into EOS_P2P_AddNotifyPeerConnectionEstablished
LocalUserId: EOS_ProductUserIdThe Product User ID of the local user who is being notified of a connection being established
RemoteUserId: EOS_ProductUserIdThe Product User ID of the remote user who this connection was with
SocketId: *const EOS_P2P_SocketIdThe socket ID of the connection being established
ConnectionType: EOS_EConnectionEstablishedTypeInformation if this is a new connection or reconnection
NetworkType: EOS_ENetworkConnectionTypeWhat type of network connection is being used for this connection