#[repr(C)]pub struct _tagEOS_P2P_OnPeerConnectionInterruptedInfo {
pub ClientData: *mut c_void,
pub LocalUserId: EOS_ProductUserId,
pub RemoteUserId: EOS_ProductUserId,
pub SocketId: *const EOS_P2P_SocketId,
}Expand description
Structure containing information about an connection request that is that was interrupted.
Fields
ClientData: *mut c_voidClient-specified data passed into EOS_Presence_AddNotifyOnPresenceChanged
LocalUserId: EOS_ProductUserIdThe local user who is being notified of a connection that was interrupted
RemoteUserId: EOS_ProductUserIdThe Product User ID of the remote user who this connection was with
SocketId: *const EOS_P2P_SocketIdThe socket ID of the connection that was interrupted