#[repr(C)]pub struct _tagEOS_P2P_ReceivePacketOptions {
pub ApiVersion: i32,
pub LocalUserId: EOS_ProductUserId,
pub MaxDataSizeBytes: u32,
pub RequestedChannel: *const u8,
}Expand description
Structure containing information about who would like to receive a packet, and how much data can be stored safely.
Fields
ApiVersion: i32API Version: Set this to EOS_P2P_RECEIVEPACKET_API_LATEST.
LocalUserId: EOS_ProductUserIdThe Product User ID of the user who is receiving the packet
MaxDataSizeBytes: u32The maximum amount of data in bytes that can be safely copied to OutData in the function call
RequestedChannel: *const u8An optional channel to request the data for. If NULL, we’re retrieving the next packet on any channel