#[repr(C)]pub struct _tagEOS_PresenceModification_SetJoinInfoOptions {
pub ApiVersion: i32,
pub JoinInfo: *const c_char,
}Expand description
Data for the EOS_PresenceModification_SetJoinInfo function.
Fields
ApiVersion: i32API Version: Set this to EOS_PRESENCEMODIFICATION_SETJOININFO_API_LATEST.
JoinInfo: *const c_charThe string which will be advertised as this player’s join info. An application is expected to freely define the meaning of this string to use for connecting to an active game session. The string should not exceed EOS_PRESENCEMODIFICATION_JOININFO_MAX_LENGTH in length. This affects the ability of the Social Overlay to show game related actions to take in the player’s social graph.
@note The Social Overlay can handle only one of the following three options at a time:
- using the bPresenceEnabled flags within the Sessions interface
- using the bPresenceEnabled flags within the Lobby interface
- using EOS_PresenceModification_SetJoinInfo
@see EOS_Lobby_CreateLobbyOptions @see EOS_Lobby_JoinLobbyOptions @see EOS_Sessions_CreateSessionModificationOptions @see EOS_Sessions_JoinSessionOptions