#[repr(C)]pub struct _tagEOS_Presence_QueryPresenceCallbackInfo {
pub ResultCode: EOS_EResult,
pub ClientData: *mut c_void,
pub LocalUserId: EOS_EpicAccountId,
pub TargetUserId: EOS_EpicAccountId,
}Expand description
The result meta-data for a presence query.
Fields
ResultCode: EOS_EResultResult code for the operation. EOS_Success is returned for a successful query, other codes indicate an error
ClientData: *mut c_voidClient-specified data passed into EOS_Presence_QueryPresence
LocalUserId: EOS_EpicAccountIdThe Epic Account ID of the local user who made this request
TargetUserId: EOS_EpicAccountIdThe Epic Account ID of the user whose presence was potentially queried