#[repr(C)]pub struct _tagEOS_Presence_QueryPresenceOptions {
pub ApiVersion: i32,
pub LocalUserId: EOS_EpicAccountId,
pub TargetUserId: EOS_EpicAccountId,
}Expand description
Data for the EOS_Presence_QueryPresence function
Fields
ApiVersion: i32API Version: Set this to EOS_PRESENCE_QUERYPRESENCE_API_LATEST.
LocalUserId: EOS_EpicAccountIdThe Epic Account ID of the local, logged-in user making the request
TargetUserId: EOS_EpicAccountIdThe Epic Account ID of the user whose presence data you want to retrieve; this value must be either the user making the request, or a friend of that user