_tagEOS_RTCAdmin_QueryJoinRoomTokenOptions

Struct _tagEOS_RTCAdmin_QueryJoinRoomTokenOptions 

#[repr(C)]
pub struct _tagEOS_RTCAdmin_QueryJoinRoomTokenOptions { pub ApiVersion: i32, pub LocalUserId: EOS_ProductUserId, pub RoomName: *const c_char, pub TargetUserIds: *mut EOS_ProductUserId, pub TargetUserIdsCount: u32, pub TargetUserIpAddresses: *mut *const c_char, }
Input parameters for the EOS_RTCAdmin_QueryJoinRoomToken function.

Fields

ApiVersion: i32

API Version: Set this to EOS_RTCADMIN_QUERYJOINROOMTOKEN_API_LATEST.

LocalUserId: EOS_ProductUserId

Product User ID for local user who is querying join room tokens.

RoomName: *const c_char

Room name to request a token for.

TargetUserIds: *mut EOS_ProductUserId

An array of Product User IDs indicating the users to retrieve a token for.

TargetUserIdsCount: u32

The number of users included in the query.

TargetUserIpAddresses: *mut *const c_char

Array of IP Addresses, one for each of the users we’re querying tokens for. There should be TargetUserIdsCount Ip Addresses, you can set an entry to NULL if not known. If TargetUserIpAddresses is set to NULL IP Addresses will be ignored. IPv4 format: “0.0.0.0” IPv6 format: “0:0:0:0:0:0:0:0”