#[repr(C)]pub struct _tagEOS_RTCAdmin_UserToken {
pub ApiVersion: i32,
pub ProductUserId: EOS_ProductUserId,
pub Token: *const c_char,
}Expand description
Contains information about a collection of user tokens for joining a room.
Fields
ApiVersion: i32API Version: Set this to EOS_RTCADMIN_USERTOKEN_API_LATEST.
ProductUserId: EOS_ProductUserIdThe Product User ID for the user who owns this user token.
Token: *const c_charAccess token to enable a user to join a room