#[repr(C)]pub struct _tagEOS_RTC_DisconnectedCallbackInfo {
pub ResultCode: EOS_EResult,
pub ClientData: *mut c_void,
pub LocalUserId: EOS_ProductUserId,
pub RoomName: *const c_char,
}Expand description
This struct is passed in with a call to EOS_RTC_AddNotifyDisconnected registered event.
Fields
ResultCode: EOS_EResultThis returns: EOS_Success The room was left cleanly. EOS_NoConnection: There was a network issue connecting to the server (retryable). EOS_RTC_UserKicked: The user has been kicked by the server (retryable). EOS_ServiceFailure: A known error occurred during interaction with the server (retryable). EOS_UnexpectedError Unexpected error (retryable).
ClientData: *mut c_voidClient-specified data passed into EOS_RTC_AddNotifyDisconnected.
LocalUserId: EOS_ProductUserIdThe Product User ID of the user who initiated this request.
RoomName: *const c_charThe room associated with this event.