#[repr(C)]pub struct _tagEOS_RTC_JoinRoomCallbackInfo {
pub ResultCode: EOS_EResult,
pub ClientData: *mut c_void,
pub LocalUserId: EOS_ProductUserId,
pub RoomName: *const c_char,
pub RoomOptionsCount: u32,
pub RoomOptions: *const EOS_RTC_Option,
}Expand description
This struct is passed in with a call to EOS_RTC_OnJoinRoomCallback.
Fields
ResultCode: EOS_EResultThis returns: EOS_Success if the channel was successfully joined. EOS_NoConnection: unable to connect to RTC servers (retryable). EOS_InvalidAuth: if the token is invalid (not retryable). EOS_RTC_TooManyParticipants: if the room cannot accept more participants (not retryable). EOS_AccessDenied: if the room name belongs to the Lobby voice system (not retryable). EOS_UnexpectedError otherwise (retryable).
ClientData: *mut c_voidClient-specified data passed into EOS_RTC_JoinRoom.
LocalUserId: EOS_ProductUserIdThe Product User ID of the user who initiated this request.
RoomName: *const c_charThe room the user was trying to join.
RoomOptionsCount: u32The room option items count.
RoomOptions: *const EOS_RTC_OptionThe room option items.