_tagEOS_RTC_ParticipantStatusChangedCallbackInfo

Struct _tagEOS_RTC_ParticipantStatusChangedCallbackInfo 

#[repr(C)]
pub struct _tagEOS_RTC_ParticipantStatusChangedCallbackInfo { pub ClientData: *mut c_void, pub LocalUserId: EOS_ProductUserId, pub RoomName: *const c_char, pub ParticipantId: EOS_ProductUserId, pub ParticipantStatus: EOS_ERTCParticipantStatus, pub ParticipantMetadataCount: u32, pub ParticipantMetadata: *const EOS_RTC_ParticipantMetadata, pub bParticipantInBlocklist: EOS_Bool, }
This struct is passed in with a call to EOS_RTC_AddNotifyParticipantStatusChanged registered event.

Fields

ClientData: *mut c_void

Client-specified data passed into EOS_RTC_AddNotifyParticipantStatusChanged.

LocalUserId: EOS_ProductUserId

The Product User ID of the user who initiated this request.

RoomName: *const c_char

The room associated with this event.

ParticipantId: EOS_ProductUserId

The participant whose status changed.

ParticipantStatus: EOS_ERTCParticipantStatus

What status change occurred

ParticipantMetadataCount: u32

The participant metadata items count. This is only set for the first notification where ParticipantStatus is EOS_RTCPS_Joined. Subsequent notifications such as when bParticipantInBlocklist changes will not contain any metadata.

ParticipantMetadata: *const EOS_RTC_ParticipantMetadata

The participant metadata items. This is only set for the first notification where ParticipantStatus is EOS_RTCPS_Joined. Subsequent notifications such as when bParticipantInBlocklist changes will not contain any metadata.

bParticipantInBlocklist: EOS_Bool

The participant’s block list status, if ParticipantStatus is EOS_RTCPS_Joined. This is set to true if the participant is in any of the local user’s applicable block lists, such Epic block list or any of the current platform’s block lists. It can be used to detect when an internal automatic RTC block is applied because of trust and safety restrictions.