#[repr(C)]pub struct _tagEOS_RTC_SetSettingOptions {
pub ApiVersion: i32,
pub SettingName: *const c_char,
pub SettingValue: *const c_char,
}Expand description
This struct is used to call EOS_RTC_SetSetting
Available values of SettingName:
- DisableEchoCancelation: Disables the use of echo cancellation for the audio channel. Default “False”.
- DisableNoiseSupression: Disables the use of noise suppression for the audio channel. Default “False”.
- DisableAutoGainControl: Disables the use of auto gain control for the audio channel. Default “False”.
- DisableDtx: Allows to disable the use of DTX. Default “False”.
Fields
ApiVersion: i32API Version: Set this to EOS_RTC_SETSETTING_API_LATEST.
SettingName: *const c_charSetting that should be set.
SettingValue: *const c_charValue to set the setting to.