#[repr(C)]pub struct _tagEOS_SessionDetails_Info {
pub ApiVersion: i32,
pub SessionId: *const c_char,
pub HostAddress: *const c_char,
pub NumOpenPublicConnections: u32,
pub Settings: *const EOS_SessionDetails_Settings,
pub OwnerUserId: EOS_ProductUserId,
pub OwnerServerClientId: *const c_char,
}Expand description
Internal details about a session, found on both active sessions and within search results
Fields
ApiVersion: i32API Version: Set this to EOS_SESSIONDETAILS_INFO_API_LATEST.
SessionId: *const c_charSession ID assigned by the backend service
HostAddress: *const c_charIP address of this session as visible by the backend service
NumOpenPublicConnections: u32Number of remaining open spaces on the session (NumPublicConnections - RegisteredPlayers
Settings: *const EOS_SessionDetails_SettingsReference to the additional settings associated with this session
OwnerUserId: EOS_ProductUserIdThe Product User ID of the session owner. Null if the session is not owned by a user.
OwnerServerClientId: *const c_charThe client id of the session owner. Null if the session is not owned by a server. The session is owned by a server if EOS_Platform_Options::bIsServer is EOS_TRUE.