#[repr(C)]pub struct _tagEOS_Sessions_LeaveSessionRequestedCallbackInfo {
pub ClientData: *mut c_void,
pub LocalUserId: EOS_ProductUserId,
pub SessionName: *const c_char,
}Expand description
Output parameters for the EOS_Sessions_OnLeaveSessionRequestedCallback Function.
Fields
ClientData: *mut c_voidContext that was passed into EOS_Sessions_OnLeaveSessionRequestedCallback
LocalUserId: EOS_ProductUserIdThe Product User ID of the local user who received the leave session notification.
SessionName: *const c_charName of the session associated with the leave session request.