#[repr(C)]pub struct _tagEOS_Sessions_SendSessionNativeInviteRequestedCallbackInfo {
pub ClientData: *mut c_void,
pub UiEventId: EOS_UI_EventId,
pub LocalUserId: EOS_ProductUserId,
pub TargetNativeAccountType: EOS_IntegratedPlatformType,
pub TargetUserNativeAccountId: *const c_char,
pub SessionId: *const c_char,
}Expand description
Output parameters for the EOS_Sessions_OnSendSessionNativeInviteRequestedCallback Function.
Fields
ClientData: *mut c_voidContext that was passed into EOS_Sessions_AddNotifySendSessionNativeInviteRequested
UiEventId: EOS_UI_EventIdIdentifies this event which will need to be acknowledged with EOS_UI_AcknowledgeEventId(). @see EOS_UI_AcknowledgeEventId
LocalUserId: EOS_ProductUserIdThe Product User ID of the local user who is inviting.
TargetNativeAccountType: EOS_IntegratedPlatformTypeThe Native Platform Account Type. If only a single integrated platform is configured then this will always reference that platform.
TargetUserNativeAccountId: *const c_charThe Native Platform Account ID of the target user being invited.
SessionId: *const c_charSession ID that the user is being invited to