#[repr(C)]pub struct _tagEOS_Stats_IngestStatOptions {
pub ApiVersion: i32,
pub LocalUserId: EOS_ProductUserId,
pub Stats: *const EOS_Stats_IngestData,
pub StatsCount: u32,
pub TargetUserId: EOS_ProductUserId,
}Expand description
Input parameters for the EOS_Stats_IngestStat function.
Fields
ApiVersion: i32API Version: Set this to EOS_STATS_INGESTSTAT_API_LATEST.
LocalUserId: EOS_ProductUserIdThe Product User ID of the local user requesting the ingest. Set to null for dedicated server.
Stats: *const EOS_Stats_IngestDataStats to ingest.
StatsCount: u32The number of stats to ingest, may not exceed EOS_STATS_MAX_INGEST_STATS.
TargetUserId: EOS_ProductUserIdThe Product User ID for the user whose stat is being ingested.