#[repr(C)]pub struct _tagEOS_Stats_QueryStatsOptions {
pub ApiVersion: i32,
pub LocalUserId: EOS_ProductUserId,
pub StartTime: i64,
pub EndTime: i64,
pub StatNames: *mut *const c_char,
pub StatNamesCount: u32,
pub TargetUserId: EOS_ProductUserId,
}Expand description
Input parameters for the EOS_Stats_QueryStats function.
Fields
ApiVersion: i32API Version: Set this to EOS_STATS_QUERYSTATS_API_LATEST.
LocalUserId: EOS_ProductUserIdThe Product User ID of the local user requesting the stats. Set to null for dedicated server.
StartTime: i64If not EOS_STATS_TIME_UNDEFINED then this is the POSIX timestamp for start time (Optional - set to EOS_STATS_TIME_UNDEFINED to ignore this parameter).
EndTime: i64If not EOS_STATS_TIME_UNDEFINED then this is the POSIX timestamp for end time (Optional - set to EOS_STATS_TIME_UNDEFINED to ignore this parameter).
StatNames: *mut *const c_charAn array of stat names to query for (Optional - set to nullptr to query for all stats).
StatNamesCount: u32The number of stat names included in query (Optional - set to 0 when querying for all stats), may not exceed EOS_STATS_MAX_QUERY_STATS.
TargetUserId: EOS_ProductUserIdThe Product User ID for the user whose stats are being retrieved