#[repr(C)]pub struct _tagEOS_UI_OnDisplaySettingsUpdatedCallbackInfo {
pub ClientData: *mut c_void,
pub bIsVisible: EOS_Bool,
pub bIsExclusiveInput: EOS_Bool,
}Expand description
Output parameters for the EOS_UI_AddNotifyDisplaySettingsUpdated function.
Fields
ClientData: *mut c_voidContext that was passed into EOS_UI_AddNotifyDisplaySettingsUpdated
bIsVisible: EOS_BoolTrue when any portion of the overlay is visible.
bIsExclusiveInput: EOS_BoolTrue when the overlay has switched to exclusive input mode. While in exclusive input mode, no keyboard or mouse input will be sent to the game.