#[repr(C)]pub struct _tagEOS_UserInfo_BestDisplayName {
pub ApiVersion: i32,
pub UserId: EOS_EpicAccountId,
pub DisplayName: *const c_char,
pub DisplayNameSanitized: *const c_char,
pub Nickname: *const c_char,
pub PlatformType: EOS_OnlinePlatformType,
}Expand description
A structure that contains the user information. These structures are created by EOS_UserInfo_CopyBestDisplayName or EOS_UserInfo_CopyBestDisplayNameWithPlatform and must be passed to EOS_UserInfo_BestDisplayName_Release.
Fields
ApiVersion: i32API Version: Set this to EOS_USERINFO_BESTDISPLAYNAME_API_LATEST.
UserId: EOS_EpicAccountIdThe Epic Account ID of the user
DisplayName: *const c_charThe display name (un-sanitized). This may be null
DisplayNameSanitized: *const c_charThe raw display name (sanitized). This may be null
Nickname: *const c_charA nickname/alias for the target user assigned by the local user. This may be null
PlatformType: EOS_OnlinePlatformTypeThe platform type for the user which corresponds to the display name