#[repr(C)]pub struct _tagEOS_UserInfo_CopyExternalUserInfoByIndexOptions {
pub ApiVersion: i32,
pub LocalUserId: EOS_EpicAccountId,
pub TargetUserId: EOS_EpicAccountId,
pub Index: u32,
}Expand description
Input parameters for the EOS_UserInfo_CopyExternalUserInfoByIndex function.
Fields
ApiVersion: i32API Version: Set this to EOS_USERINFO_COPYEXTERNALUSERINFOBYINDEX_API_LATEST.
LocalUserId: EOS_EpicAccountIdThe Epic Account ID of the local player requesting the information
TargetUserId: EOS_EpicAccountIdThe Epic Account ID of the player whose information is being retrieved
Index: u32Index of the external user info to retrieve from the cache