#[repr(C)]pub struct _tagEOS_UserInfo_QueryUserInfoByDisplayNameCallbackInfo {
pub ResultCode: EOS_EResult,
pub ClientData: *mut c_void,
pub LocalUserId: EOS_EpicAccountId,
pub TargetUserId: EOS_EpicAccountId,
pub DisplayName: *const c_char,
}Expand description
Output parameters for the EOS_UserInfo_QueryUserInfoByDisplayName Function.
Fields
ResultCode: EOS_EResultThe EOS_EResult code for the operation. EOS_Success indicates that the operation succeeded; other codes indicate errors.
ClientData: *mut c_voidContext that was passed into EOS_UserInfo_QueryUserInfoByDisplayName
LocalUserId: EOS_EpicAccountIdThe Epic Account ID of the local player requesting the information
TargetUserId: EOS_EpicAccountIdThe Epic Account ID of the player whose information is being retrieved
DisplayName: *const c_charDisplay name (un-sanitized) of the player being queried. This memory is only valid during the scope of the callback.