EOS_Achievements_CopyPlayerAchievementByIndexOptions

Type Alias EOS_Achievements_CopyPlayerAchievementByIndexOptions 

pub type EOS_Achievements_CopyPlayerAchievementByIndexOptions = _tagEOS_Achievements_CopyPlayerAchievementByIndexOptions;
Input parameters for the EOS_Achievements_CopyPlayerAchievementByIndex function.

Aliased Type

#[repr(C)]
pub struct EOS_Achievements_CopyPlayerAchievementByIndexOptions { pub ApiVersion: i32, pub TargetUserId: *mut EOS_ProductUserIdDetails, pub AchievementIndex: u32, pub LocalUserId: *mut EOS_ProductUserIdDetails, }

Fields

ApiVersion: i32

API Version: Set this to EOS_ACHIEVEMENTS_COPYPLAYERACHIEVEMENTBYINDEX_API_LATEST.

TargetUserId: *mut EOS_ProductUserIdDetails

The Product User ID for the user whose achievement is to be retrieved.

AchievementIndex: u32

The index of the player achievement data to retrieve from the cache.

LocalUserId: *mut EOS_ProductUserIdDetails

The Product User ID for the user who is querying for a player achievement. For a Dedicated Server this should be null.