EOS_Achievements_Definition

Type Alias EOS_Achievements_Definition 

pub type EOS_Achievements_Definition = _tagEOS_Achievements_Definition;
Contains information about a single achievement definition with localized text.

Aliased Type

#[repr(C)]
pub struct EOS_Achievements_Definition {
Show 13 fields pub ApiVersion: i32, pub AchievementId: *const i8, pub DisplayName: *const i8, pub Description: *const i8, pub LockedDisplayName: *const i8, pub LockedDescription: *const i8, pub HiddenDescription: *const i8, pub CompletionDescription: *const i8, pub UnlockedIconId: *const i8, pub LockedIconId: *const i8, pub bIsHidden: i32, pub StatThresholdsCount: i32, pub StatThresholds: *const _tagEOS_Achievements_StatThresholds,
}

Fields

ApiVersion: i32

API Version: Set this to EOS_ACHIEVEMENTS_DEFINITION_API_LATEST.

AchievementId: *const i8

Achievement ID that can be used to uniquely identify the achievement.

DisplayName: *const i8

Text representing the Name to display in-game when achievement has been unlocked.

Description: *const i8

Text representing the description to display in-game when achievement has been unlocked.

LockedDisplayName: *const i8

Text representing the name to display in-game when achievement is locked.

LockedDescription: *const i8

Text representing the description of what needs to be done to trigger the unlock of this achievement.

HiddenDescription: *const i8

Text representing the description to display in-game when achievement is hidden.

CompletionDescription: *const i8

Text representing the description of what happens when the achievement is unlocked.

UnlockedIconId: *const i8

Text representing the icon to display in-game when achievement is unlocked.

LockedIconId: *const i8

Text representing the icon to display in-game when achievement is locked.

bIsHidden: i32

True if achievement is hidden, false otherwise.

StatThresholdsCount: i32

The number of stat thresholds.

StatThresholds: *const _tagEOS_Achievements_StatThresholds

Array of stat thresholds that need to be satisfied to unlock the achievement.