pub type EOS_Achievements_PlayerStatInfo = _tagEOS_Achievements_PlayerStatInfo;Expand description
Contains information about a collection of stat info data.
@see EOS_Achievements_PlayerAchievement
Aliased Type
#[repr(C)]pub struct EOS_Achievements_PlayerStatInfo {
pub ApiVersion: i32,
pub Name: *const i8,
pub CurrentValue: i32,
pub ThresholdValue: i32,
}Fields
ApiVersion: i32API Version: Set this to EOS_ACHIEVEMENTS_PLAYERSTATINFO_API_LATEST.
Name: *const i8The name of the stat.
CurrentValue: i32The current value of the stat.
ThresholdValue: i32The threshold value of the stat, used in determining when to unlock an achievement.