EOS_Achievements_StatThresholds

Type Alias EOS_Achievements_StatThresholds 

pub type EOS_Achievements_StatThresholds = _tagEOS_Achievements_StatThresholds;
Contains information about a collection of stat threshold data.

The threshold will depend on the stat aggregate type: LATEST (Tracks the latest value) MAX (Tracks the maximum value) MIN (Tracks the minimum value) SUM (Generates a rolling sum of the value)

@see EOS_Achievements_Definition

Aliased Type

#[repr(C)]
pub struct EOS_Achievements_StatThresholds { pub ApiVersion: i32, pub Name: *const u8, pub Threshold: i32, }

Fields

ApiVersion: i32

API Version: Set this to EOS_ACHIEVEMENTS_STATTHRESHOLDS_API_LATEST.

Name: *const u8

The name of the stat.

Threshold: i32

The value that the stat must surpass to satisfy the requirement for unlocking an achievement.