EOS_AntiCheatClient_OnClientIntegrityViolatedCallback

Type Alias EOS_AntiCheatClient_OnClientIntegrityViolatedCallback 

pub type EOS_AntiCheatClient_OnClientIntegrityViolatedCallback = Option<unsafe extern "C" fn(Data: *const EOS_AntiCheatClient_OnClientIntegrityViolatedCallbackInfo)>;
Callback issued when the local client triggers an integrity violation.

The message contains descriptive string of up to 256 characters and must be displayed to the player.

This callback is always issued from within EOS_Platform_Tick on its calling thread.

Aliased Type

pub enum EOS_AntiCheatClient_OnClientIntegrityViolatedCallback {
    None,
    Some(unsafe extern "C" fn(*const _tagEOS_AntiCheatClient_OnClientIntegrityViolatedCallbackInfo)),
}

Variants

1.0.0

None

No value.

1.0.0

Some(unsafe extern "C" fn(*const _tagEOS_AntiCheatClient_OnClientIntegrityViolatedCallbackInfo))

Some value of type T.