EOS_AntiCheatClient_OnClientIntegrityViolatedCallbackInfo

Type Alias EOS_AntiCheatClient_OnClientIntegrityViolatedCallbackInfo 

pub type EOS_AntiCheatClient_OnClientIntegrityViolatedCallbackInfo = _tagEOS_AntiCheatClient_OnClientIntegrityViolatedCallbackInfo;
Structure containing details about integrity violation related to the local client

Aliased Type

#[repr(C)]
pub struct EOS_AntiCheatClient_OnClientIntegrityViolatedCallbackInfo { pub ClientData: *mut c_void, pub ViolationType: i32, pub ViolationMessage: *const u8, }

Fields

ClientData: *mut c_void

Caller-specified context data

ViolationType: i32

Code describing the violation that occurred

ViolationMessage: *const u8

String describing the violation which should be displayed to the user