EOS_AntiCheatClient_OnMessageToServerCallback

Type Alias EOS_AntiCheatClient_OnMessageToServerCallback 

pub type EOS_AntiCheatClient_OnMessageToServerCallback = Option<unsafe extern "C" fn(Data: *const EOS_AntiCheatClient_OnMessageToServerCallbackInfo)>;
Callback issued when a new message must be dispatched to the game server.

Messages contain opaque binary data and must be transmitted to the game server using the game’s own networking layer, then delivered to the server anti-cheat instance using the EOS_AntiCheatServer_ReceiveMessageFromClient function. The upper limit of the message size is EOS_ANTICHEATCLIENT_ONMESSAGETOSERVERCALLBACK_MAX_MESSAGE_SIZE.

This callback is always issued from within EOS_Platform_Tick on its calling thread.

Aliased Type

pub enum EOS_AntiCheatClient_OnMessageToServerCallback {
    None,
    Some(unsafe extern "C" fn(*const _tagEOS_AntiCheatClient_OnMessageToServerCallbackInfo)),
}

Variants

1.0.0

None

No value.

1.0.0

Some(unsafe extern "C" fn(*const _tagEOS_AntiCheatClient_OnMessageToServerCallbackInfo))

Some value of type T.