EOS_AntiCheatCommon_ClientHandle

Type Alias EOS_AntiCheatCommon_ClientHandle 

pub type EOS_AntiCheatCommon_ClientHandle = *mut c_void;
Arbitrary data that is a unique local identifier for a single remote client or peer.

Typically this is a pointer to an object describing the player, but it can be anything that is locally unique.