EOS_AntiCheatCommon_LogGameRoundStartOptions

Type Alias EOS_AntiCheatCommon_LogGameRoundStartOptions 

pub type EOS_AntiCheatCommon_LogGameRoundStartOptions = _tagEOS_AntiCheatCommon_LogGameRoundStartOptions;
Input parameters for the EOS_AntiCheatServer_LogGameRoundStart function.

Aliased Type

#[repr(C)]
pub struct EOS_AntiCheatCommon_LogGameRoundStartOptions { pub ApiVersion: i32, pub SessionIdentifier: *const i8, pub LevelName: *const i8, pub ModeName: *const i8, pub RoundTimeSeconds: u32, pub CompetitionType: i32, }

Fields

ApiVersion: i32

API Version: Set this to EOS_ANTICHEATCOMMON_LOGGAMEROUNDSTART_API_LATEST.

SessionIdentifier: *const i8

Optional game session or match identifier useful for some backend API integrations

LevelName: *const i8

Optional name of the map being played

ModeName: *const i8

Optional name of the game mode being played

RoundTimeSeconds: u32

Optional length of the game round to be played, in seconds. If none, use 0.

CompetitionType: i32

Type of competition for this game round