EOS_AntiCheatCommon_OnMessageToClientCallbackInfo

Type Alias EOS_AntiCheatCommon_OnMessageToClientCallbackInfo 

pub type EOS_AntiCheatCommon_OnMessageToClientCallbackInfo = _tagEOS_AntiCheatCommon_OnMessageToClientCallbackInfo;
Structure containing details about a new message that must be dispatched to a connected client/peer.

Aliased Type

#[repr(C)]
pub struct EOS_AntiCheatCommon_OnMessageToClientCallbackInfo { pub ClientData: *mut c_void, pub ClientHandle: *mut c_void, pub MessageData: *const c_void, pub MessageDataSizeBytes: u32, }

Fields

ClientData: *mut c_void

Caller-specified context data

ClientHandle: *mut c_void

The identifier of the client/peer that this message must be delivered to. See the RegisterClient and RegisterPeer functions.

MessageData: *const c_void

The message data that must be sent to the client

MessageDataSizeBytes: u32

The size in bytes of MessageData