EOS_AntiCheatServer_BeginSessionOptions

Type Alias EOS_AntiCheatServer_BeginSessionOptions 

pub type EOS_AntiCheatServer_BeginSessionOptions = _tagEOS_AntiCheatServer_BeginSessionOptions;
Input parameters for the EOS_AntiCheatServer_BeginSession function.

Aliased Type

#[repr(C)]
pub struct EOS_AntiCheatServer_BeginSessionOptions { pub ApiVersion: i32, pub RegisterTimeoutSeconds: u32, pub ServerName: *const i8, pub bEnableGameplayData: i32, pub LocalUserId: *mut EOS_ProductUserIdDetails, }

Fields

ApiVersion: i32

API Version: Set this to EOS_ANTICHEATSERVER_BEGINSESSION_API_LATEST.

RegisterTimeoutSeconds: u32

Time in seconds to allow newly registered clients to complete anti-cheat authentication. Recommended value: 60 Minimum value: EOS_ANTICHEATSERVER_BEGINSESSION_MIN_REGISTERTIMEOUT Maximum value: EOS_ANTICHEATSERVER_BEGINSESSION_MAX_REGISTERTIMEOUT

ServerName: *const i8

Optional name of this game server

bEnableGameplayData: i32

Gameplay data collection APIs such as LogPlayerTick will be enabled if set to true. If you do not use these APIs you should set this value to false to reduce memory use.

LocalUserId: *mut EOS_ProductUserIdDetails

The Product User ID of the local user who is associated with this session. Dedicated servers should set this to null.