EOS_AntiCheatServer_OnMessageToClientCallback

Type Alias EOS_AntiCheatServer_OnMessageToClientCallback 

pub type EOS_AntiCheatServer_OnMessageToClientCallback = Option<unsafe extern "C" fn(Data: *const EOS_AntiCheatCommon_OnMessageToClientCallbackInfo)>;
Callback issued when a new message must be dispatched to a connected client.

Messages contain opaque binary data and must be transmitted to the correct client using the game’s own networking layer, then delivered to the client anti-cheat instance using the EOS_AntiCheatClient_ReceiveMessageFromServer function. The upper limit of the message size is EOS_ANTICHEATSERVER_ONMESSAGETOCLIENTCALLBACK_MAX_MESSAGE_SIZE.

This callback is always issued from within EOS_Platform_Tick on its calling thread.

Aliased Type

pub enum EOS_AntiCheatServer_OnMessageToClientCallback {
    None,
    Some(unsafe extern "C" fn(*const _tagEOS_AntiCheatCommon_OnMessageToClientCallbackInfo)),
}

Variants

1.0.0

None

No value.

1.0.0

Some(unsafe extern "C" fn(*const _tagEOS_AntiCheatCommon_OnMessageToClientCallbackInfo))

Some value of type T.