pub type EOS_AntiCheatServer_RegisterClientOptions = _tagEOS_AntiCheatServer_RegisterClientOptions;Expand description
Input parameters for the EOS_AntiCheatServer_RegisterClient function.
Aliased Type
#[repr(C)]pub struct EOS_AntiCheatServer_RegisterClientOptions {
pub ApiVersion: i32,
pub ClientHandle: *mut c_void,
pub ClientType: i32,
pub ClientPlatform: i32,
pub AccountId_DEPRECATED: *const i8,
pub IpAddress: *const i8,
pub UserId: *mut EOS_ProductUserIdDetails,
pub Reserved01: i32,
}Fields
ApiVersion: i32API Version: Set this to EOS_ANTICHEATSERVER_REGISTERCLIENT_API_LATEST.
ClientHandle: *mut c_voidLocally unique value describing the remote user (e.g. a player object pointer)
ClientType: i32Type of remote user being registered
ClientPlatform: i32Remote user’s platform, if known
AccountId_DEPRECATED: *const i8DEPRECATED - New code should set this to null and specify UserId instead.
Identifier for the remote user. This is typically a string representation of an account ID, but it can be any string which is both unique (two different users will never have the same string) and consistent (if the same user connects to this game session twice, the same string will be used) in the scope of a single protected game session.
IpAddress: *const i8Optional IP address for the remote user. May be null if not available. IPv4 format: “0.0.0.0” IPv6 format: “0:0:0:0:0:0:0:0”
UserId: *mut EOS_ProductUserIdDetailsThe Product User ID for the remote user who is being registered.
Reserved01: i32Reserved for future use. Must be set to 0.