EOS_Auth_DeletePersistentAuthOptions

Type Alias EOS_Auth_DeletePersistentAuthOptions 

pub type EOS_Auth_DeletePersistentAuthOptions = _tagEOS_Auth_DeletePersistentAuthOptions;
Input parameters for the EOS_Auth_DeletePersistentAuth function.

Aliased Type

#[repr(C)]
pub struct EOS_Auth_DeletePersistentAuthOptions { pub ApiVersion: i32, pub RefreshToken: *const u8, }

Fields

ApiVersion: i32

API Version: Set this to EOS_AUTH_DELETEPERSISTENTAUTH_API_LATEST.

RefreshToken: *const u8

A long-lived refresh token that is used with the EOS_LCT_PersistentAuth login type and is to be revoked from the authentication server. Only used on Console platforms. On Desktop and Mobile platforms, set this parameter to NULL.