EOS_Auth_LinkAccountCallbackInfo

Type Alias EOS_Auth_LinkAccountCallbackInfo 

pub type EOS_Auth_LinkAccountCallbackInfo = _tagEOS_Auth_LinkAccountCallbackInfo;
Output parameters for the EOS_Auth_LinkAccount Function.

Aliased Type

#[repr(C)]
pub struct EOS_Auth_LinkAccountCallbackInfo { pub ResultCode: i32, pub ClientData: *mut c_void, pub LocalUserId: *mut EOS_EpicAccountIdDetails, pub PinGrantInfo: *const _tagEOS_Auth_PinGrantInfo, pub SelectedAccountId: *mut EOS_EpicAccountIdDetails, }

Fields

ResultCode: i32

The EOS_EResult code for the operation. EOS_Success indicates that the operation succeeded; other codes indicate errors.

ClientData: *mut c_void

Context that was passed into EOS_Auth_LinkAccount.

LocalUserId: *mut EOS_EpicAccountIdDetails

The Epic Account ID of the local user whose account has been linked during login.

PinGrantInfo: *const _tagEOS_Auth_PinGrantInfo

Optional data that may be returned in the middle of the login flow, when neither the in-game overlay or a platform browser is used. This data is present when the ResultCode is EOS_Auth_PinGrantCode.

SelectedAccountId: *mut EOS_EpicAccountIdDetails

The Epic Account ID that has been previously selected to be used for the current application. Applications should use this ID to authenticate with online backend services that store game-scoped data for users.

Note: This ID may be different from LocalUserId if the user has previously merged Epic accounts into the account represented by LocalUserId, and one of the accounts that got merged had game data associated with it for the application.