EOS_Auth_LoginCallbackInfo

Type Alias EOS_Auth_LoginCallbackInfo 

pub type EOS_Auth_LoginCallbackInfo = _tagEOS_Auth_LoginCallbackInfo;
Output parameters for the EOS_Auth_Login Function.

Aliased Type

#[repr(C)]
pub struct EOS_Auth_LoginCallbackInfo { pub ResultCode: i32, pub ClientData: *mut c_void, pub LocalUserId: *mut EOS_EpicAccountIdDetails, pub PinGrantInfo: *const _tagEOS_Auth_PinGrantInfo, pub ContinuanceToken: *mut EOS_ContinuanceTokenDetails, pub AccountFeatureRestrictedInfo_DEPRECATED: *const _tagEOS_Auth_AccountFeatureRestrictedInfo, pub SelectedAccountId: *mut EOS_EpicAccountIdDetails, }

Fields

ResultCode: i32

The EOS_EResult code for the operation. EOS_Success indicates that the operation succeeded; other codes indicate errors.

ClientData: *mut c_void

Context that was passed into EOS_Auth_Login.

LocalUserId: *mut EOS_EpicAccountIdDetails

The Epic Account ID of the local user who has logged in.

PinGrantInfo: *const _tagEOS_Auth_PinGrantInfo

Optional data that may be returned in the middle of the login flow, when neither the in-game overlay or a platform browser is used. This data is present when the ResultCode is EOS_Auth_PinGrantCode.

ContinuanceToken: *mut EOS_ContinuanceTokenDetails

If the user was not found with external auth credentials passed into EOS_Auth_Login, this continuance token can be passed to EOS_Auth_LinkAccount to continue the flow.

AccountFeatureRestrictedInfo_DEPRECATED: *const _tagEOS_Auth_AccountFeatureRestrictedInfo

Deprecated field that is no longer used.

SelectedAccountId: *mut EOS_EpicAccountIdDetails

The Epic Account ID that has been previously selected to be used for the current application. Applications should use this ID to authenticate with online backend services that store game-scoped data for users.

Note: This ID may be different from LocalUserId if the user has previously merged Epic accounts into the account represented by LocalUserId, and one of the accounts that got merged had game data associated with it for the application.