EOS_Auth_VerifyUserAuthOptions

Type Alias EOS_Auth_VerifyUserAuthOptions 

pub type EOS_Auth_VerifyUserAuthOptions = _tagEOS_Auth_VerifyUserAuthOptions;
Input parameters for the EOS_Auth_VerifyUserAuth function. This operation is destructive, the pointer will remain the same but the data pointers inside will update

Aliased Type

#[repr(C)]
pub struct EOS_Auth_VerifyUserAuthOptions { pub ApiVersion: i32, pub AuthToken: *const _tagEOS_Auth_Token, }

Fields

ApiVersion: i32

API Version: Set this to EOS_AUTH_VERIFYUSERAUTH_API_LATEST.

AuthToken: *const _tagEOS_Auth_Token

Auth token to verify against the backend service