pub type EOS_Connect_CreateDeviceIdOptions = _tagEOS_Connect_CreateDeviceIdOptions;Expand description
Input parameters for the EOS_Connect_CreateDeviceId function.
Aliased Type
#[repr(C)]pub struct EOS_Connect_CreateDeviceIdOptions {
pub ApiVersion: i32,
pub DeviceModel: *const i8,
}Fields
ApiVersion: i32API Version: Set this to EOS_CONNECT_CREATEDEVICEID_API_LATEST.
DeviceModel: *const i8A freeform text description identifying the device type and model, which can be used in account linking management to allow the player and customer support to identify different devices linked to an EOS user keychain. For example ‘iPhone 6S’ or ‘PC Windows’.
The input string must be in UTF-8 character format, with a maximum length of 64 characters. Longer string will be silently truncated.
This field is required to be present.