pub type EOS_Connect_ExternalAccountInfo = _tagEOS_Connect_ExternalAccountInfo;Expand description
Contains information about an external account linked with a Product User ID.
Aliased Type
#[repr(C)]pub struct EOS_Connect_ExternalAccountInfo {
pub ApiVersion: i32,
pub ProductUserId: *mut EOS_ProductUserIdDetails,
pub DisplayName: *const u8,
pub AccountId: *const u8,
pub AccountIdType: i32,
pub LastLoginTime: i64,
}Fields
ApiVersion: i32API Version: Set this to EOS_CONNECT_EXTERNALACCOUNTINFO_API_LATEST.
ProductUserId: *mut EOS_ProductUserIdDetailsThe Product User ID of the target user.
DisplayName: *const u8Display name, can be null if not set.
AccountId: *const u8External account ID.
May be set to an empty string if the AccountIdType of another user belongs to different account system than the local user’s authenticated account. The availability of this field is dependent on account system specifics.
AccountIdType: i32The identity provider that owns the external account.
LastLoginTime: i64The POSIX timestamp for the time the user last logged in, or EOS_CONNECT_TIME_UNDEFINED.