EOS_Connect_LoginCallbackInfo

Type Alias EOS_Connect_LoginCallbackInfo 

pub type EOS_Connect_LoginCallbackInfo = _tagEOS_Connect_LoginCallbackInfo;
Output parameters for the EOS_Connect_Login function.

Aliased Type

#[repr(C)]
pub struct EOS_Connect_LoginCallbackInfo { pub ResultCode: i32, pub ClientData: *mut c_void, pub LocalUserId: *mut EOS_ProductUserIdDetails, pub ContinuanceToken: *mut EOS_ContinuanceTokenDetails, }

Fields

ResultCode: i32

The EOS_EResult code for the operation. EOS_Success indicates that the operation succeeded; other codes indicate errors.

ClientData: *mut c_void

Context that was passed into EOS_Connect_Login.

LocalUserId: *mut EOS_ProductUserIdDetails

If login was successful, this is the Product User ID of the local player that logged in.

ContinuanceToken: *mut EOS_ContinuanceTokenDetails

If the user was not found with credentials passed into EOS_Connect_Login, this continuance token can be passed to either EOS_Connect_CreateUser or EOS_Connect_LinkAccount to continue the flow.