pub type EOS_Connect_TransferDeviceIdAccountOptions = _tagEOS_Connect_TransferDeviceIdAccountOptions;Expand description
Input parameters for the EOS_Connect_TransferDeviceIdAccount Function.
Aliased Type
#[repr(C)]pub struct EOS_Connect_TransferDeviceIdAccountOptions {
pub ApiVersion: i32,
pub PrimaryLocalUserId: *mut EOS_ProductUserIdDetails,
pub LocalDeviceUserId: *mut EOS_ProductUserIdDetails,
pub ProductUserIdToPreserve: *mut EOS_ProductUserIdDetails,
}Fields
ApiVersion: i32API Version: Set this to EOS_CONNECT_TRANSFERDEVICEIDACCOUNT_API_LATEST.
PrimaryLocalUserId: *mut EOS_ProductUserIdDetailsThe primary product user id, currently logged in, that is already associated with a real external user account (such as Epic Games, PlayStation(TM)Network, Xbox Live and other).
The account linking keychain that owns this product user will be preserved and receive the Device ID login credentials under it.
LocalDeviceUserId: *mut EOS_ProductUserIdDetailsThe product user id, currently logged in, that has been originally created using the anonymous local Device ID login type, and whose Device ID login will be transferred to the keychain of the PrimaryLocalUserId.
ProductUserIdToPreserve: *mut EOS_ProductUserIdDetailsSpecifies which EOS_ProductUserId (i.e. game progression) will be preserved in the operation.
After a successful transfer operation, subsequent logins using the same external account or the same local Device ID login will return user session for the ProductUserIdToPreserve.
Set to either PrimaryLocalUserId or LocalDeviceUserId.