pub type EOS_Connect_UserLoginInfo = _tagEOS_Connect_UserLoginInfo;Expand description
Additional information about the local user.
Aliased Type
#[repr(C)]pub struct EOS_Connect_UserLoginInfo {
pub ApiVersion: i32,
pub DisplayName: *const u8,
pub NsaIdToken: *const u8,
}Fields
ApiVersion: i32API Version: Set this to EOS_CONNECT_USERLOGININFO_API_LATEST.
DisplayName: *const u8The user’s display name on the identity provider systems as UTF-8 encoded null-terminated string. The length of the name can be at maximum up to EOS_CONNECT_USERLOGININFO_DISPLAYNAME_MAX_LENGTH bytes.
As the display name passed here is client-controlled and not part of user authentication tokens, it is only treated as non-authoritative informational data to be used by some of the feature services. For example displaying player names in Leaderboards rankings.
NsaIdToken: *const u8Nintendo Service Account ID Token (NSA ID).
This field is required to be set and only used when running on the Nintendo Switch device, and the user is being authenticated using any other credential type than EOS_ECT_NINTENDO_NSA_ID_TOKEN.
In order to use the Lobbies and Sessions interfaces, a valid NSA ID Token is required to be provided for the active local Nintendo Switch user. Otherwise, attempting to use either of the Lobbies or Sessions interfaces will return the EOS_Permission_OnlinePlayRestricted error result.