EOS_CustomInvites_SendCustomNativeInviteRequestedCallbackInfo

Type Alias EOS_CustomInvites_SendCustomNativeInviteRequestedCallbackInfo 

pub type EOS_CustomInvites_SendCustomNativeInviteRequestedCallbackInfo = _tagEOS_CustomInvites_SendCustomNativeInviteRequestedCallbackInfo;
Output parameters for the EOS_CustomInvites_OnSendCustomNativeInviteRequestedCallback Function.

Aliased Type

#[repr(C)]
pub struct EOS_CustomInvites_SendCustomNativeInviteRequestedCallbackInfo { pub ClientData: *mut c_void, pub UiEventId: u64, pub LocalUserId: *mut EOS_ProductUserIdDetails, pub TargetNativeAccountType: *const u8, pub TargetUserNativeAccountId: *const u8, pub InviteId: *const u8, }

Fields

ClientData: *mut c_void

Context that was passed into EOS_CustomInvites_AddNotifySendCustomNativeInviteRequested

UiEventId: u64

Identifies this event which will need to be acknowledged with EOS_UI_AcknowledgeEventId(). @see EOS_UI_AcknowledgeEventId

LocalUserId: *mut EOS_ProductUserIdDetails

The Product User ID of the local user who is inviting.

TargetNativeAccountType: *const u8

The Native Platform Account Type. If only a single integrated platform is configured then this will always reference that platform.

TargetUserNativeAccountId: *const u8

The Native Platform Account ID of the target user being invited.

InviteId: *const u8

Invite ID that the user is being invited to