pub type EOS_EExternalCredentialType = c_int;Expand description
List of the supported identity providers to authenticate a user.
The type of authentication token is specific to each provider. Tokens in string format should be passed as-is to the function. Tokens retrieved as raw byte arrays should be converted into a hex-encoded UTF-8 string (e.g. “FA87097A..”) before being passed to the function. EOS_ByteArray_ToString can be used for this conversion.
@see EOS_Auth_Login @see EOS_Connect_Login