EOS_EPacketReliability

Type Alias EOS_EPacketReliability 

pub type EOS_EPacketReliability = c_int;
Types of packet reliability.

Ordered packets will only be ordered relative to other ordered packets. Reliable/unreliable and ordered/unordered communication can be sent on the same Socket ID and Channel.