EOS_ERelayControl

Type Alias EOS_ERelayControl 

pub type EOS_ERelayControl = c_int;
Setting for controlling whether relay servers are used.

Please see the following EOS_ERelayControl value compatibility-chart to better understand how changing this value can affect compatibility between clients with different settings. Connections between clients using Incompatible settings may succeed in limited scenarios but should be treated as though they will consistently fail.

+——————————+———————+—————————––+———————+ | | EOS_RC_NoRelays | EOS_RC_AllowRelays (Default) | EOS_RC_ForceRelays | +——————————+———————+—————————––+———————+ | EOS_RC_NoRelays | Compatible | Compatible | Incompatible | | EOS_RC_AllowRelays (Default) | Compatible | Compatible | Compatible | | EOS_RC_ForceRelays | Incompatible | Compatible | Compatible | +——————————+———————+—————————––+———————+