EOS_ESessionAttributeType

Type Alias EOS_ESessionAttributeType 

pub type EOS_ESessionAttributeType = c_int;
Supported types of data that can be stored with inside an attribute (used by sessions/lobbies/etc)

@see EOS_LobbySearch_SetParameter @see EOS_SessionSearch_SetParameter Supported types of data that can be stored with inside an attribute (used by sessions/lobbies/etc)

@see EOS_LobbySearch_SetParameter @see EOS_SessionSearch_SetParameter