pub type EOS_Ecom_CheckoutCallbackInfo = _tagEOS_Ecom_CheckoutCallbackInfo;Expand description
Output parameters for the EOS_Ecom_Checkout Function.
Aliased Type
#[repr(C)]pub struct EOS_Ecom_CheckoutCallbackInfo {
pub ResultCode: i32,
pub ClientData: *mut c_void,
pub LocalUserId: *mut EOS_EpicAccountIdDetails,
pub TransactionId: *const u8,
}Fields
ResultCode: i32Result code for the operation. EOS_Success is returned for a successful request, otherwise one of the error codes is returned. See eos_common.h
ClientData: *mut c_voidContext that was passed into EOS_Ecom_Checkout
LocalUserId: *mut EOS_EpicAccountIdDetailsThe Epic Account ID of the user who initiated the purchase
TransactionId: *const u8The transaction ID which can be used to obtain an EOS_Ecom_HTransaction using EOS_Ecom_CopyTransactionById.