EOS_Ecom_CheckoutEntry

Type Alias EOS_Ecom_CheckoutEntry 

pub type EOS_Ecom_CheckoutEntry = _tagEOS_Ecom_CheckoutEntry;
Contains information about a request to purchase a single offer. This structure is set as part of the EOS_Ecom_CheckoutOptions structure.

Aliased Type

#[repr(C)]
pub struct EOS_Ecom_CheckoutEntry { pub ApiVersion: i32, pub OfferId: *const u8, }

Fields

ApiVersion: i32

API Version: Set this to EOS_ECOM_CHECKOUTENTRY_API_LATEST.

OfferId: *const u8

The ID of the offer to purchase