pub type EOS_Ecom_CheckoutOptions = _tagEOS_Ecom_CheckoutOptions;Expand description
Input parameters for the EOS_Ecom_Checkout function.
Aliased Type
#[repr(C)]pub struct EOS_Ecom_CheckoutOptions {
pub ApiVersion: i32,
pub LocalUserId: *mut EOS_EpicAccountIdDetails,
pub OverrideCatalogNamespace: *const i8,
pub EntryCount: u32,
pub Entries: *const _tagEOS_Ecom_CheckoutEntry,
pub PreferredOrientation: i32,
}Fields
ApiVersion: i32API Version: Set this to EOS_ECOM_CHECKOUT_API_LATEST.
LocalUserId: *mut EOS_EpicAccountIdDetailsThe Epic Account ID of the local user who is making the purchase
OverrideCatalogNamespace: *const i8The catalog namespace will be the current Sandbox ID (in EOS_Platform_Options) unless overridden by this field
EntryCount: u32The number of EOS_Ecom_CheckoutEntry elements contained in Entries
Entries: *const _tagEOS_Ecom_CheckoutEntryAn array of EOS_Ecom_CheckoutEntry elements, each containing the details of a single offer
PreferredOrientation: i32Preferred device orientation, specifies Default, Portrait or Landscape. This is used only on mobile platforms currently. SDK can use it to optimize how the Checkout page should be displayed. Please check the mobile SDK documentation for additional required setup.