EOS_Ecom_CopyEntitlementByIdOptions

Type Alias EOS_Ecom_CopyEntitlementByIdOptions 

pub type EOS_Ecom_CopyEntitlementByIdOptions = _tagEOS_Ecom_CopyEntitlementByIdOptions;
Input parameters for the EOS_Ecom_CopyEntitlementById function.

Aliased Type

#[repr(C)]
pub struct EOS_Ecom_CopyEntitlementByIdOptions { pub ApiVersion: i32, pub LocalUserId: *mut EOS_EpicAccountIdDetails, pub EntitlementId: *const u8, }

Fields

ApiVersion: i32

API Version: Set this to EOS_ECOM_COPYENTITLEMENTBYID_API_LATEST.

LocalUserId: *mut EOS_EpicAccountIdDetails

The Epic Account ID of the local user whose entitlement is being copied

EntitlementId: *const u8

ID of the entitlement to retrieve from the cache