EOS_Ecom_CopyEntitlementByIndexOptions

Type Alias EOS_Ecom_CopyEntitlementByIndexOptions 

pub type EOS_Ecom_CopyEntitlementByIndexOptions = _tagEOS_Ecom_CopyEntitlementByIndexOptions;
Input parameters for the EOS_Ecom_CopyEntitlementByIndex function.

Aliased Type

#[repr(C)]
pub struct EOS_Ecom_CopyEntitlementByIndexOptions { pub ApiVersion: i32, pub LocalUserId: *mut EOS_EpicAccountIdDetails, pub EntitlementIndex: u32, }

Fields

ApiVersion: i32

API Version: Set this to EOS_ECOM_COPYENTITLEMENTBYINDEX_API_LATEST.

LocalUserId: *mut EOS_EpicAccountIdDetails

The Epic Account ID of the local user whose entitlement is being copied

EntitlementIndex: u32

Index of the entitlement to retrieve from the cache