pub type EOS_Ecom_CopyEntitlementByNameAndIndexOptions = _tagEOS_Ecom_CopyEntitlementByNameAndIndexOptions;Expand description
Input parameters for the EOS_Ecom_CopyEntitlementByNameAndIndex function.
Aliased Type
#[repr(C)]pub struct EOS_Ecom_CopyEntitlementByNameAndIndexOptions {
pub ApiVersion: i32,
pub LocalUserId: *mut EOS_EpicAccountIdDetails,
pub EntitlementName: *const u8,
pub Index: u32,
}Fields
ApiVersion: i32API Version: Set this to EOS_ECOM_COPYENTITLEMENTBYNAMEANDINDEX_API_LATEST.
LocalUserId: *mut EOS_EpicAccountIdDetailsThe Epic Account ID of the local user whose entitlement is being copied
EntitlementName: *const u8Name of the entitlement to retrieve from the cache
Index: u32Index of the entitlement within the named set to retrieve from the cache.