pub type EOS_Ecom_CopyItemImageInfoByIndexOptions = _tagEOS_Ecom_CopyItemImageInfoByIndexOptions;Expand description
Input parameters for the EOS_Ecom_CopyItemImageInfoByIndex function.
Aliased Type
#[repr(C)]pub struct EOS_Ecom_CopyItemImageInfoByIndexOptions {
pub ApiVersion: i32,
pub LocalUserId: *mut EOS_EpicAccountIdDetails,
pub ItemId: *const u8,
pub ImageInfoIndex: u32,
}Fields
ApiVersion: i32API Version: Set this to EOS_ECOM_COPYITEMIMAGEINFOBYINDEX_API_LATEST.
LocalUserId: *mut EOS_EpicAccountIdDetailsThe Epic Account ID of the local user whose item image is being copied
ItemId: *const u8The ID of the item to get the images for.
ImageInfoIndex: u32The index of the image to get.