EOS_Ecom_CopyLastRedeemedEntitlementByIndexOptions

Type Alias EOS_Ecom_CopyLastRedeemedEntitlementByIndexOptions 

pub type EOS_Ecom_CopyLastRedeemedEntitlementByIndexOptions = _tagEOS_Ecom_CopyLastRedeemedEntitlementByIndexOptions;
Input parameters for the EOS_Ecom_CopyLastRedeemedEntitlementByIndex function.

Aliased Type

#[repr(C)]
pub struct EOS_Ecom_CopyLastRedeemedEntitlementByIndexOptions { pub ApiVersion: i32, pub LocalUserId: *mut EOS_EpicAccountIdDetails, pub RedeemedEntitlementIndex: u32, }

Fields

ApiVersion: i32

API Version: Set this to EOS_ECOM_COPYLASTREDEEMEDENTITLEMENTBYINDEX_API_LATEST.

LocalUserId: *mut EOS_EpicAccountIdDetails

The Epic Account ID of the local user whose last redeemed entitlement id is being copied

RedeemedEntitlementIndex: u32

Index of the last redeemed entitlement id to retrieve from the cache