pub type EOS_Ecom_CopyOfferImageInfoByIndexOptions = _tagEOS_Ecom_CopyOfferImageInfoByIndexOptions;Expand description
Input parameters for the EOS_Ecom_CopyOfferImageInfoByIndex function.
Aliased Type
#[repr(C)]pub struct EOS_Ecom_CopyOfferImageInfoByIndexOptions {
pub ApiVersion: i32,
pub LocalUserId: *mut EOS_EpicAccountIdDetails,
pub OfferId: *const i8,
pub ImageInfoIndex: u32,
}Fields
ApiVersion: i32API Version: Set this to EOS_ECOM_COPYOFFERIMAGEINFOBYINDEX_API_LATEST.
LocalUserId: *mut EOS_EpicAccountIdDetailsThe Epic Account ID of the local user whose offer image is being copied.
OfferId: *const i8The ID of the offer to get the images for.
ImageInfoIndex: u32The index of the image to get.