EOS_Ecom_Entitlement

Type Alias EOS_Ecom_Entitlement 

pub type EOS_Ecom_Entitlement = _tagEOS_Ecom_Entitlement;
Contains information about a single entitlement associated with an account. Instances of this structure are created by EOS_Ecom_CopyEntitlementByIndex, EOS_Ecom_CopyEntitlementByNameAndIndex, or EOS_Ecom_CopyEntitlementById. They must be passed to EOS_Ecom_Entitlement_Release.

Aliased Type

#[repr(C)]
pub struct EOS_Ecom_Entitlement { pub ApiVersion: i32, pub EntitlementName: *const u8, pub EntitlementId: *const u8, pub CatalogItemId: *const u8, pub ServerIndex: i32, pub bRedeemed: i32, pub EndTimestamp: i64, }

Fields

ApiVersion: i32

API Version: Set this to EOS_ECOM_ENTITLEMENT_API_LATEST.

EntitlementName: *const u8

Name of the entitlement

EntitlementId: *const u8

ID of the entitlement owned by an account

CatalogItemId: *const u8

ID of the item associated with the offer which granted this entitlement

ServerIndex: i32

If queried using pagination then ServerIndex represents the index of the entitlement as it exists on the server. If not queried using pagination then ServerIndex will be -1.

bRedeemed: i32

If true then the catalog has this entitlement marked as redeemed

EndTimestamp: i64

If not -1 then this is a POSIX timestamp that this entitlement will end