EOS_Ecom_EntitlementId

Type Alias EOS_Ecom_EntitlementId 

pub type EOS_Ecom_EntitlementId = *const c_char;
A unique identifier for an entitlement owned by an account. An entitlement is always associated with a single account. The entitlement ID is provided to allow redeeming the entitlement as well as identify individual entitlement grants.

@see EOS_Ecom_QueryEntitlements @see EOS_Ecom_RedeemEntitlements