pub type EOS_Ecom_GetEntitlementsByNameCountOptions = _tagEOS_Ecom_GetEntitlementsByNameCountOptions;Expand description
Input parameters for the EOS_Ecom_GetEntitlementsByNameCount function.
Aliased Type
#[repr(C)]pub struct EOS_Ecom_GetEntitlementsByNameCountOptions {
pub ApiVersion: i32,
pub LocalUserId: *mut EOS_EpicAccountIdDetails,
pub EntitlementName: *const i8,
}Fields
ApiVersion: i32API Version: Set this to EOS_ECOM_GETENTITLEMENTSBYNAMECOUNT_API_LATEST.
LocalUserId: *mut EOS_EpicAccountIdDetailsThe Epic Account ID of the local user for which to retrieve the entitlement count
EntitlementName: *const i8Name of the entitlement to count in the cache