pub type EOS_Ecom_GetItemImageInfoCountOptions = _tagEOS_Ecom_GetItemImageInfoCountOptions;Expand description
Input parameters for the EOS_Ecom_GetItemImageInfoCount function.
Aliased Type
#[repr(C)]pub struct EOS_Ecom_GetItemImageInfoCountOptions {
pub ApiVersion: i32,
pub LocalUserId: *mut EOS_EpicAccountIdDetails,
pub ItemId: *const i8,
}Fields
ApiVersion: i32API Version: Set this to EOS_ECOM_GETITEMIMAGEINFOCOUNT_API_LATEST.
LocalUserId: *mut EOS_EpicAccountIdDetailsThe Epic Account ID of the local user whose item image is being accessed
ItemId: *const i8The ID of the item to get the images for.