EOS_Ecom_GetOfferImageInfoCountOptions

Type Alias EOS_Ecom_GetOfferImageInfoCountOptions 

pub type EOS_Ecom_GetOfferImageInfoCountOptions = _tagEOS_Ecom_GetOfferImageInfoCountOptions;
Input parameters for the EOS_Ecom_GetOfferImageInfoCount function.

Aliased Type

#[repr(C)]
pub struct EOS_Ecom_GetOfferImageInfoCountOptions { pub ApiVersion: i32, pub LocalUserId: *mut EOS_EpicAccountIdDetails, pub OfferId: *const i8, }

Fields

ApiVersion: i32

API Version: Set this to EOS_ECOM_GETOFFERIMAGEINFOCOUNT_API_LATEST.

LocalUserId: *mut EOS_EpicAccountIdDetails

The Epic Account ID of the local user whose offer image is being accessed.

OfferId: *const i8

The ID of the offer to get the images for.