EOS_Ecom_ItemOwnership

Type Alias EOS_Ecom_ItemOwnership 

pub type EOS_Ecom_ItemOwnership = _tagEOS_Ecom_ItemOwnership;
Contains information about a single item ownership associated with an account. This structure is returned as part of the EOS_Ecom_QueryOwnershipCallbackInfo structure.

Aliased Type

#[repr(C)]
pub struct EOS_Ecom_ItemOwnership { pub ApiVersion: i32, pub Id: *const i8, pub OwnershipStatus: i32, }

Fields

ApiVersion: i32

API Version: Set this to EOS_ECOM_ITEMOWNERSHIP_API_LATEST.

Id: *const i8

ID of the catalog item

OwnershipStatus: i32

Is this catalog item owned by the local user