pub type EOS_Ecom_OnQueryOffersCallback = Option<unsafe extern "C" fn(Data: *const EOS_Ecom_QueryOffersCallbackInfo)>;Expand description
Function prototype definition for callbacks passed to EOS_Ecom_QueryOffers. When one or more cached offers have an invalid price, the callback returns the result code EOS_EResult::EOS_Ecom_CatalogOfferPriceInvalid. @param Data A EOS_Ecom_QueryOffersCallbackInfo containing the output information and result
Aliased Type
pub enum EOS_Ecom_OnQueryOffersCallback {
None,
Some(unsafe extern "C" fn(*const _tagEOS_Ecom_QueryOffersCallbackInfo)),
}Variants
None
No value.
Some(unsafe extern "C" fn(*const _tagEOS_Ecom_QueryOffersCallbackInfo))
Some value of type T.