EOS_Ecom_QueryEntitlementTokenCallbackInfo

Type Alias EOS_Ecom_QueryEntitlementTokenCallbackInfo 

pub type EOS_Ecom_QueryEntitlementTokenCallbackInfo = _tagEOS_Ecom_QueryEntitlementTokenCallbackInfo;
Output parameters for the EOS_Ecom_QueryEntitlementToken Function.

Aliased Type

#[repr(C)]
pub struct EOS_Ecom_QueryEntitlementTokenCallbackInfo { pub ResultCode: i32, pub ClientData: *mut c_void, pub LocalUserId: *mut EOS_EpicAccountIdDetails, pub EntitlementToken: *const u8, }

Fields

ResultCode: i32

The EOS_EResult code for the operation. EOS_Success indicates that the operation succeeded; other codes indicate errors.

ClientData: *mut c_void

Context that was passed into EOS_Ecom_QueryEntitlementToken

LocalUserId: *mut EOS_EpicAccountIdDetails

The Epic Account ID of the local user whose entitlement was queried

EntitlementToken: *const u8

Entitlements token containing details about the catalog items queried