pub type EOS_Ecom_QueryEntitlementsOptions = _tagEOS_Ecom_QueryEntitlementsOptions;Expand description
Input parameters for the EOS_Ecom_QueryEntitlements function.
Aliased Type
#[repr(C)]pub struct EOS_Ecom_QueryEntitlementsOptions {
pub ApiVersion: i32,
pub LocalUserId: *mut EOS_EpicAccountIdDetails,
pub EntitlementNames: *mut *const u8,
pub EntitlementNameCount: u32,
pub bIncludeRedeemed: i32,
pub OverrideCatalogNamespace: *const u8,
}Fields
ApiVersion: i32API Version: Set this to EOS_ECOM_QUERYENTITLEMENTS_API_LATEST.
LocalUserId: *mut EOS_EpicAccountIdDetailsThe Epic Account ID of the local user whose Entitlements you want to retrieve
EntitlementNames: *mut *const u8An array of Entitlement Names that you want to check
EntitlementNameCount: u32The number of Entitlement Names included in the array, up to EOS_ECOM_QUERYENTITLEMENTS_MAX_ENTITLEMENT_IDS; use zero to request all Entitlements associated with the user’s Epic Online Services account.
bIncludeRedeemed: i32If true, Entitlements that have been redeemed will be included in the results.
OverrideCatalogNamespace: *const u8If not provided then the SandboxId is used as the catalog namespace