EOS_Ecom_QueryOwnershipBySandboxIdsCallbackInfo

Type Alias EOS_Ecom_QueryOwnershipBySandboxIdsCallbackInfo 

pub type EOS_Ecom_QueryOwnershipBySandboxIdsCallbackInfo = _tagEOS_Ecom_QueryOwnershipBySandboxIdsCallbackInfo;
Output parameters for the EOS_Ecom_QueryOwnershipBySandboxIds Function.

Aliased Type

#[repr(C)]
pub struct EOS_Ecom_QueryOwnershipBySandboxIdsCallbackInfo { pub ResultCode: i32, pub ClientData: *mut c_void, pub LocalUserId: *mut EOS_EpicAccountIdDetails, pub SandboxIdItemOwnerships: *const _tagEOS_Ecom_SandboxIdItemOwnership, pub SandboxIdItemOwnershipsCount: u32, }

Fields

ResultCode: i32

The EOS_EResult code for the operation. EOS_Success indicates that the operation succeeded; other codes indicate errors.

ClientData: *mut c_void

Context that was passed into EOS_Ecom_QueryOwnership

LocalUserId: *mut EOS_EpicAccountIdDetails

The Epic Account ID of the local user whose ownership was queried

SandboxIdItemOwnerships: *const _tagEOS_Ecom_SandboxIdItemOwnership

List of SandboxIds and their corresponding owned catalog item Ids. If there are no ownership items, the OwnedCatalogItemIdsCount is 0 and OwnedCatalogItemIds is null.

SandboxIdItemOwnershipsCount: u32

Number of ownership results are included in this callback