EOS_Ecom_QueryOwnershipCallbackInfo

Type Alias EOS_Ecom_QueryOwnershipCallbackInfo 

pub type EOS_Ecom_QueryOwnershipCallbackInfo = _tagEOS_Ecom_QueryOwnershipCallbackInfo;
Output parameters for the EOS_Ecom_QueryOwnership Function.

Aliased Type

#[repr(C)]
pub struct EOS_Ecom_QueryOwnershipCallbackInfo { pub ResultCode: i32, pub ClientData: *mut c_void, pub LocalUserId: *mut EOS_EpicAccountIdDetails, pub ItemOwnership: *const _tagEOS_Ecom_ItemOwnership, pub ItemOwnershipCount: u32, }

Fields

ResultCode: i32

The EOS_EResult code for the operation. EOS_Success indicates that the operation succeeded; other codes indicate errors.

ClientData: *mut c_void

Context that was passed into EOS_Ecom_QueryOwnership

LocalUserId: *mut EOS_EpicAccountIdDetails

The Epic Account ID of the local user whose ownership was queried

ItemOwnership: *const _tagEOS_Ecom_ItemOwnership

List of catalog items and their ownership status

ItemOwnershipCount: u32

Number of ownership results are included in this callback