pub type EOS_Ecom_QueryOwnershipTokenCallbackInfo = _tagEOS_Ecom_QueryOwnershipTokenCallbackInfo;Expand description
Output parameters for the EOS_Ecom_QueryOwnershipToken Function.
Aliased Type
#[repr(C)]pub struct EOS_Ecom_QueryOwnershipTokenCallbackInfo {
pub ResultCode: i32,
pub ClientData: *mut c_void,
pub LocalUserId: *mut EOS_EpicAccountIdDetails,
pub OwnershipToken: *const u8,
}Fields
ResultCode: i32The EOS_EResult code for the operation. EOS_Success indicates that the operation succeeded; other codes indicate errors.
ClientData: *mut c_voidContext that was passed into EOS_Ecom_QueryOwnershipToken
LocalUserId: *mut EOS_EpicAccountIdDetailsThe Epic Account ID of the local user whose ownership token was queried
OwnershipToken: *const u8Ownership token containing details about the catalog items queried