pub type EOS_Ecom_QueryOwnershipTokenOptions = _tagEOS_Ecom_QueryOwnershipTokenOptions;Expand description
Input parameters for the EOS_Ecom_QueryOwnershipToken function.
Aliased Type
#[repr(C)]pub struct EOS_Ecom_QueryOwnershipTokenOptions {
pub ApiVersion: i32,
pub LocalUserId: *mut EOS_EpicAccountIdDetails,
pub CatalogItemIds: *mut *const u8,
pub CatalogItemIdCount: u32,
pub CatalogNamespace: *const u8,
}Fields
ApiVersion: i32API Version: Set this to EOS_ECOM_QUERYOWNERSHIPTOKEN_API_LATEST.
LocalUserId: *mut EOS_EpicAccountIdDetailsThe Epic Account ID of the local user whose ownership token you want to query
CatalogItemIds: *mut *const u8The array of Catalog Item IDs to check for ownership, matching in number to the CatalogItemIdCount
CatalogItemIdCount: u32The number of catalog item IDs to query
CatalogNamespace: *const u8Optional product namespace, if not the one specified during initialization