EOS_Ecom_SandboxIdItemOwnership

Type Alias EOS_Ecom_SandboxIdItemOwnership 

pub type EOS_Ecom_SandboxIdItemOwnership = _tagEOS_Ecom_SandboxIdItemOwnership;
Contains all owned catalog items for a sandbox ID. This structure is returned as part of the EOS_Ecom_QueryOwnershipBySandboxIdsCallbackInfo structure. Note: The SandboxID and CatalogItemId strings will not remain valid after EOS_Ecom_OnQueryOwnershipBySandboxIdsCallback, so a copy should be as needed.

Aliased Type

#[repr(C)]
pub struct EOS_Ecom_SandboxIdItemOwnership { pub SandboxId: *const i8, pub OwnedCatalogItemIds: *const *const i8, pub OwnedCatalogItemIdsCount: u32, }

Fields

SandboxId: *const i8

SandboxId

OwnedCatalogItemIds: *const *const i8

List of all owned catalog items for this SandboxId

OwnedCatalogItemIdsCount: u32

Number of owned catalog items for this SandboxId