pub type EOS_EpicAccountId = *mut EOS_EpicAccountIdDetails;Expand description
A handle to a user’s Epic Account ID This ID is associated with a specific login associated with Epic Account Services
@see EOS_Auth_Login
pub type EOS_EpicAccountId = *mut EOS_EpicAccountIdDetails;A handle to a user’s Epic Account ID This ID is associated with a specific login associated with Epic Account Services
@see EOS_Auth_Login