EOS_Friends_AcceptInviteCallbackInfo

Type Alias EOS_Friends_AcceptInviteCallbackInfo 

pub type EOS_Friends_AcceptInviteCallbackInfo = _tagEOS_Friends_AcceptInviteCallbackInfo;
Output parameters for the EOS_Friends_AcceptInvite Function.

Aliased Type

#[repr(C)]
pub struct EOS_Friends_AcceptInviteCallbackInfo { pub ResultCode: i32, pub ClientData: *mut c_void, pub LocalUserId: *mut EOS_EpicAccountIdDetails, pub TargetUserId: *mut EOS_EpicAccountIdDetails, }

Fields

ResultCode: i32

Result code for the operation. EOS_Success is returned if an invite was accepted, otherwise one of the error codes is returned. See eos_common.h

ClientData: *mut c_void

Context that is passed into EOS_Friends_AcceptInvite

LocalUserId: *mut EOS_EpicAccountIdDetails

The Epic Account ID of the user who is accepting the friends list invitation

TargetUserId: *mut EOS_EpicAccountIdDetails

The Epic Account ID of the user who sent the local user a friends list invitation