EOS_Friends_OnFriendsUpdateInfo

Type Alias EOS_Friends_OnFriendsUpdateInfo 

pub type EOS_Friends_OnFriendsUpdateInfo = _tagEOS_Friends_OnFriendsUpdateInfo;
Structure containing information about a friend status update.

Aliased Type

#[repr(C)]
pub struct EOS_Friends_OnFriendsUpdateInfo { pub ClientData: *mut c_void, pub LocalUserId: *mut EOS_EpicAccountIdDetails, pub TargetUserId: *mut EOS_EpicAccountIdDetails, pub PreviousStatus: i32, pub CurrentStatus: i32, }

Fields

ClientData: *mut c_void

Client-specified data passed into EOS_Friends_AddNotifyFriendsUpdate

LocalUserId: *mut EOS_EpicAccountIdDetails

The Epic Account ID of the local user who is receiving the update

TargetUserId: *mut EOS_EpicAccountIdDetails

The Epic Account ID of the user whose status is being updated.

PreviousStatus: i32

The previous status of the user.

CurrentStatus: i32

The current status of the user.