pub type EOS_Friends_RejectInviteCallbackInfo = _tagEOS_Friends_RejectInviteCallbackInfo;Expand description
Output parameters for the EOS_Friends_RejectInvite Function.
Aliased Type
#[repr(C)]pub struct EOS_Friends_RejectInviteCallbackInfo {
pub ResultCode: i32,
pub ClientData: *mut c_void,
pub LocalUserId: *mut EOS_EpicAccountIdDetails,
pub TargetUserId: *mut EOS_EpicAccountIdDetails,
}Fields
ResultCode: i32Result code for the operation. EOS_Success is returned if an invite was accepted, otherwise one of the error codes is returned. See eos_common.h
ClientData: *mut c_voidContext that is passed into EOS_Friends_RejectInvite
LocalUserId: *mut EOS_EpicAccountIdDetailsThe Epic Account ID of the user who is rejecting the friends list invitation
TargetUserId: *mut EOS_EpicAccountIdDetailsThe Epic Account ID of the user who sent the friends list invitation