pub type EOS_HLobbySearch = *mut EOS_LobbySearchHandle;Expand description
Handle to the calls responsible for creating a search object
pub type EOS_HLobbySearch = *mut EOS_LobbySearchHandle;Handle to the calls responsible for creating a search object