pub type EOS_HSessionDetails = *mut EOS_SessionDetailsHandle;Expand description
Handle to a single session that may be part of a named session, search result, or invite
pub type EOS_HSessionDetails = *mut EOS_SessionDetailsHandle;Handle to a single session that may be part of a named session, search result, or invite