pub type EOS_HSessionSearch = *mut EOS_SessionSearchHandle;Expand description
Handle to the calls responsible for creating a search object
pub type EOS_HSessionSearch = *mut EOS_SessionSearchHandle;Handle to the calls responsible for creating a search object