pub type EOS_InitializeOptions = _tagEOS_InitializeOptions;Expand description
Options for initializing the Epic Online Services SDK.
Aliased Type
#[repr(C)]pub struct EOS_InitializeOptions {
pub ApiVersion: i32,
pub AllocateMemoryFunction: Option<unsafe extern "C" fn(usize, usize) -> *mut c_void>,
pub ReallocateMemoryFunction: Option<unsafe extern "C" fn(*mut c_void, usize, usize) -> *mut c_void>,
pub ReleaseMemoryFunction: Option<unsafe extern "C" fn(*mut c_void)>,
pub ProductName: *const u8,
pub ProductVersion: *const u8,
pub Reserved: *mut c_void,
pub SystemInitializeOptions: *mut c_void,
pub OverrideThreadAffinity: *mut _tagEOS_Initialize_ThreadAffinity,
}Fields
ApiVersion: i32API Version: Set this to EOS_INITIALIZE_API_LATEST.
AllocateMemoryFunction: Option<unsafe extern "C" fn(usize, usize) -> *mut c_void>A custom memory allocator, if desired.
ReallocateMemoryFunction: Option<unsafe extern "C" fn(*mut c_void, usize, usize) -> *mut c_void>A corresponding memory reallocator. If the AllocateMemoryFunction is nulled, then this field must also be nulled.
ReleaseMemoryFunction: Option<unsafe extern "C" fn(*mut c_void)>A corresponding memory releaser. If the AllocateMemoryFunction is nulled, then this field must also be nulled.
ProductName: *const u8The name of the product using the Epic Online Services SDK.
The name string is required to be non-empty and at maximum of EOS_INITIALIZEOPTIONS_PRODUCTNAME_MAX_LENGTH bytes long. The string buffer can consist of the following characters: A-Z, a-z, 0-9, dot, underscore, space, exclamation mark, question mark, and sign, hyphen, parenthesis, plus, minus, colon.
ProductVersion: *const u8Product version of the running application.
The version string is required to be non-empty and at maximum of EOS_INITIALIZEOPTIONS_PRODUCTVERSION_MAX_LENGTH bytes long. The string buffer can consist of the following characters: A-Z, a-z, 0-9, dot, underscore, space, exclamation mark, question mark, and sign, hyphen, parenthesis, plus, minus, colon.
Reserved: *mut c_voidA reserved field that should always be nulled.
SystemInitializeOptions: *mut c_voidThis field is for system specific initialization if any.
If provided then the structure will be located in
OverrideThreadAffinity: *mut _tagEOS_Initialize_ThreadAffinityThe thread affinity override values for each category of thread.