EOS_IntegratedPlatformType

Type Alias EOS_IntegratedPlatformType 

pub type EOS_IntegratedPlatformType = *const c_char;
This type is used to distinguish between different supported integrated platforms. Integrated platforms which are common across multiple host platforms will be defined here.