EOS_IntegratedPlatform_FinalizeDeferredUserLogoutOptions

Type Alias EOS_IntegratedPlatform_FinalizeDeferredUserLogoutOptions 

pub type EOS_IntegratedPlatform_FinalizeDeferredUserLogoutOptions = _tagEOS_IntegratedPlatform_FinalizeDeferredUserLogoutOptions;
Input parameters for the EOS_IntegratedPlatform_FinalizeDeferredUserLogout function.

Aliased Type

#[repr(C)]
pub struct EOS_IntegratedPlatform_FinalizeDeferredUserLogoutOptions { pub ApiVersion: i32, pub PlatformType: *const i8, pub LocalPlatformUserId: *const i8, pub ExpectedLoginStatus: i32, }

Fields

ApiVersion: i32

API Version: Set this to EOS_INTEGRATEDPLATFORM_FINALIZEDEFERREDUSERLOGOUT_API_LATEST.

PlatformType: *const i8

The integrated platform this user belongs to.

LocalPlatformUserId: *const i8

String version of the integrated platform-dependent user id.

ExpectedLoginStatus: i32

The logged-in state the user is expected to be (EOS_LS_LoggedIn or EOS_LS_NotLoggedIn). If the provided state does not match internal EOS state, this function will return in failure. If the state is incorrect, the application should wait and attempt to call the function again next tick, after both updating its own state from the system and calling EOS_Platform_Tick, allowing the SDK to update its state from the system as well.