EOS_IntegratedPlatform_UserLoginStatusChangedCallbackInfo

Type Alias EOS_IntegratedPlatform_UserLoginStatusChangedCallbackInfo 

pub type EOS_IntegratedPlatform_UserLoginStatusChangedCallbackInfo = _tagEOS_IntegratedPlatform_UserLoginStatusChangedCallbackInfo;
Data about which integrated platform and which user that had a login status change and what the login status changed to.

Aliased Type

#[repr(C)]
pub struct EOS_IntegratedPlatform_UserLoginStatusChangedCallbackInfo { pub ClientData: *mut c_void, pub PlatformType: *const i8, pub LocalPlatformUserId: *const i8, pub AccountId: *mut EOS_EpicAccountIdDetails, pub ProductUserId: *mut EOS_ProductUserIdDetails, pub PreviousLoginStatus: i32, pub CurrentLoginStatus: i32, }

Fields

ClientData: *mut c_void

Context that was passed into EOS_IntegratedPlatform_AddNotifyUserLoginStatusChanged

PlatformType: *const i8

The integrated platform of the local platform user.

LocalPlatformUserId: *const i8

String version of platform’s user id.

AccountId: *mut EOS_EpicAccountIdDetails

The Epic Games Account ID associated with this Integrated Platform’s User (if there is one)

ProductUserId: *mut EOS_ProductUserIdDetails

The EOS Product User ID associated with this Integrated Platform’s User (if there is one)

PreviousLoginStatus: i32

The login status prior to this change.

CurrentLoginStatus: i32

The login status at the time of this notification.