pub type EOS_KWS_QueryAgeGateCallbackInfo = _tagEOS_KWS_QueryAgeGateCallbackInfo;Expand description
Output parameters for the EOS_KWS_QueryAgeGate Function. These parameters are received through the callback provided to EOS_KWS_QueryAgeGate
Aliased Type
#[repr(C)]pub struct EOS_KWS_QueryAgeGateCallbackInfo {
pub ResultCode: i32,
pub ClientData: *mut c_void,
pub CountryCode: *const u8,
pub AgeOfConsent: u32,
}Fields
ResultCode: i32The EOS_EResult code for the operation. EOS_Success indicates that the operation succeeded; other codes indicate errors.
ClientData: *mut c_voidContext that was passed into EOS_KWS_QueryAgeGate
CountryCode: *const u8Country code determined for this request based on the local client’s ip address that the backend resolves
AgeOfConsent: u32Age of consent in the given country