EOS_KWS_QueryPermissionsCallbackInfo

Type Alias EOS_KWS_QueryPermissionsCallbackInfo 

pub type EOS_KWS_QueryPermissionsCallbackInfo = _tagEOS_KWS_QueryPermissionsCallbackInfo;
Output parameters for the EOS_KWS_QueryPermissionsOptions Function. These parameters are received through the callback provided to EOS_KWS_QueryPermissions

Aliased Type

#[repr(C)]
pub struct EOS_KWS_QueryPermissionsCallbackInfo { pub ResultCode: i32, pub ClientData: *mut c_void, pub LocalUserId: *mut EOS_ProductUserIdDetails, pub KWSUserId: *const u8, pub DateOfBirth: *const u8, pub bIsMinor: i32, pub ParentEmail: *const u8, }

Fields

ResultCode: i32

The EOS_EResult code for the operation. EOS_Success indicates that the operation succeeded; other codes indicate errors.

ClientData: *mut c_void

Context that was passed into EOS_KWS_QueryPermissions

LocalUserId: *mut EOS_ProductUserIdDetails

Local user querying their permissions

KWSUserId: *const u8

KWS UserId created

DateOfBirth: *const u8

Date of birth in ISO8601 form (YYYY-MM-DD)

bIsMinor: i32

Is this user a minor

ParentEmail: *const u8

Parent email. This value may be set to an empty string if the originally registered email recipient declined to be the right person to give consent.