EOS_Leaderboards_QueryLeaderboardDefinitionsOptions

Type Alias EOS_Leaderboards_QueryLeaderboardDefinitionsOptions 

pub type EOS_Leaderboards_QueryLeaderboardDefinitionsOptions = _tagEOS_Leaderboards_QueryLeaderboardDefinitionsOptions;
Input parameters for the EOS_Leaderboards_QueryLeaderboardDefinitions function. StartTime and EndTime are optional parameters, they can be used to limit the list of definitions to overlap the time window specified.

Aliased Type

#[repr(C)]
pub struct EOS_Leaderboards_QueryLeaderboardDefinitionsOptions { pub ApiVersion: i32, pub StartTime: i64, pub EndTime: i64, pub LocalUserId: *mut EOS_ProductUserIdDetails, }

Fields

ApiVersion: i32

API Version: Set this to EOS_LEADERBOARDS_QUERYLEADERBOARDDEFINITIONS_API_LATEST.

StartTime: i64

An optional POSIX timestamp for the leaderboard’s start time, or EOS_LEADERBOARDS_TIME_UNDEFINED

EndTime: i64

An optional POSIX timestamp for the leaderboard’s end time, or EOS_LEADERBOARDS_TIME_UNDEFINED

LocalUserId: *mut EOS_ProductUserIdDetails

Product User ID for user who is querying definitions. Must be set when using a client policy that requires a valid logged in user. Not used for Dedicated Server where no user is available.