pub type EOS_Leaderboards_QueryLeaderboardRanksOptions = _tagEOS_Leaderboards_QueryLeaderboardRanksOptions;Expand description
Input parameters for the EOS_Leaderboards_QueryLeaderboardRanks function.
@see EOS_Leaderboards_Definition
Aliased Type
#[repr(C)]pub struct EOS_Leaderboards_QueryLeaderboardRanksOptions {
pub ApiVersion: i32,
pub LeaderboardId: *const i8,
pub LocalUserId: *mut EOS_ProductUserIdDetails,
}Fields
ApiVersion: i32API Version: Set this to EOS_LEADERBOARDS_QUERYLEADERBOARDRANKS_API_LATEST.
LeaderboardId: *const i8The ID of the leaderboard whose information you want to retrieve.
LocalUserId: *mut EOS_ProductUserIdDetailsProduct User ID for user who is querying ranks. Must be set when using a client policy that requires a valid logged in user. Not used for Dedicated Server where no user is available.