pub type EOS_LobbyModification_AddMemberAttributeOptions = _tagEOS_LobbyModification_AddMemberAttributeOptions;Expand description
Input parameters for the EOS_LobbyModification_AddMemberAttribute function.
Aliased Type
#[repr(C)]pub struct EOS_LobbyModification_AddMemberAttributeOptions {
pub ApiVersion: i32,
pub Attribute: *const _tagEOS_Lobby_AttributeData,
pub Visibility: i32,
}Fields
ApiVersion: i32API Version: Set this to EOS_LOBBYMODIFICATION_ADDMEMBERATTRIBUTE_API_LATEST.
Attribute: *const _tagEOS_Lobby_AttributeDataKey/Value pair describing the attribute to add to the lobby member
Visibility: i32Is this attribute public or private to the rest of the lobby members