EOS_LobbyModification_SetAllowedPlatformIdsOptions

Type Alias EOS_LobbyModification_SetAllowedPlatformIdsOptions 

pub type EOS_LobbyModification_SetAllowedPlatformIdsOptions = _tagEOS_LobbyModification_SetAllowedPlatformIdsOptions;
Input parameters for the EOS_LobbyModification_SetAllowedPlatformIdsOptions function.

Aliased Type

#[repr(C)]
pub struct EOS_LobbyModification_SetAllowedPlatformIdsOptions { pub ApiVersion: i32, pub AllowedPlatformIds: *const u32, pub AllowedPlatformIdsCount: u32, }

Fields

ApiVersion: i32

API Version: Set this to EOS_LOBBYMODIFICATION_SETALLOWEDPLATFORMIDS_API_LATEST.

AllowedPlatformIds: *const u32

Array of platform IDs indicating the player platforms allowed to register with the lobby. Platform IDs are found in the EOS header file (eos_common.h), for example EOS_OPT_Epic. For some platforms the value will be in the EOS Platform specific header file. If null, the lobby will be unrestricted.

AllowedPlatformIdsCount: u32

Number of platform IDs in the array