pub type EOS_LobbySearch_SetParameterOptions = _tagEOS_LobbySearch_SetParameterOptions;Expand description
Input parameters for the EOS_LobbySearch_SetParameter function.
Aliased Type
#[repr(C)]pub struct EOS_LobbySearch_SetParameterOptions {
pub ApiVersion: i32,
pub Parameter: *const _tagEOS_Lobby_AttributeData,
pub ComparisonOp: i32,
}Fields
ApiVersion: i32API Version: Set this to EOS_LOBBYSEARCH_SETPARAMETER_API_LATEST.
Parameter: *const _tagEOS_Lobby_AttributeDataSearch parameter describing a key and a value to compare
ComparisonOp: i32The type of comparison to make against the search parameter