pub type EOS_Lobby_AddNotifyRTCRoomConnectionChangedOptions = _tagEOS_Lobby_AddNotifyRTCRoomConnectionChangedOptions;Expand description
Input parameters for the EOS_Lobby_AddNotifyRTCRoomConnectionChanged function.
Aliased Type
#[repr(C)]pub struct EOS_Lobby_AddNotifyRTCRoomConnectionChangedOptions {
pub ApiVersion: i32,
pub LobbyId_DEPRECATED: *const u8,
pub LocalUserId_DEPRECATED: *mut EOS_ProductUserIdDetails,
}Fields
ApiVersion: i32API Version: Set this to EOS_LOBBY_ADDNOTIFYRTCROOMCONNECTIONCHANGED_API_LATEST.
LobbyId_DEPRECATED: *const u8The ID of the lobby to receive RTC Room connection change notifications for This is deprecated and no longer needed. The notification is raised for any LobbyId or LocalUserId. If any filtering is required, the callback struct (EOS_Lobby_RTCRoomConnectionChangedCallbackInfo) has both a LobbyId and LocalUserId field.
LocalUserId_DEPRECATED: *mut EOS_ProductUserIdDetailsThe Product User ID of the local user in the lobby This is deprecated and no longer needed. The notification is raised for any LobbyId or LocalUserId. If any filtering is required, the callback struct (EOS_Lobby_RTCRoomConnectionChangedCallbackInfo) has both a LobbyId and LocalUserId field.