EOS_Lobby_JoinLobbyByIdOptions

Type Alias EOS_Lobby_JoinLobbyByIdOptions 

pub type EOS_Lobby_JoinLobbyByIdOptions = _tagEOS_Lobby_JoinLobbyByIdOptions;
Input parameters for the EOS_Lobby_JoinLobbyById function.

Aliased Type

#[repr(C)]
pub struct EOS_Lobby_JoinLobbyByIdOptions { pub ApiVersion: i32, pub LobbyId: *const i8, pub LocalUserId: *mut EOS_ProductUserIdDetails, pub bPresenceEnabled: i32, pub LocalRTCOptions: *const _tagEOS_Lobby_LocalRTCOptions, pub bCrossplayOptOut: i32, pub RTCRoomJoinActionType: i32, }

Fields

ApiVersion: i32

API Version: Set this to EOS_LOBBY_JOINLOBBYBYID_API_LATEST.

LobbyId: *const i8

The ID of the lobby

LocalUserId: *mut EOS_ProductUserIdDetails

The Product User ID of the local user joining the lobby

bPresenceEnabled: i32

If true, this lobby will be associated with the user’s presence information. A user can only associate one lobby at a time with their presence information. This affects the ability of the Social Overlay to show game related actions to take in the user’s social graph.

@note The Social Overlay can handle only one of the following three options at a time:

  • using the bPresenceEnabled flags within the Sessions interface
  • using the bPresenceEnabled flags within the Lobby interface
  • using EOS_PresenceModification_SetJoinInfo

@see EOS_PresenceModification_SetJoinInfoOptions @see EOS_Lobby_CreateLobbyOptions @see EOS_Lobby_JoinLobbyOptions @see EOS_Lobby_JoinLobbyByIdOptions @see EOS_Sessions_CreateSessionModificationOptions @see EOS_Sessions_JoinSessionOptions

LocalRTCOptions: *const _tagEOS_Lobby_LocalRTCOptions

(Optional) Set this value to override the default local options for the RTC Room, if it is enabled for this lobby. Set this to NULL if your application does not use the Lobby RTC Rooms feature, or if you would like to use the default settings. This option is ignored if the specified lobby does not have an RTC Room enabled and will not cause errors.

bCrossplayOptOut: i32

This value indicates whether or not the local user allows crossplay interactions. If it is false, the local user will be treated as allowing crossplay.

RTCRoomJoinActionType: i32

For lobbies with the RTC Room feature enabled, this value indicates the action to take against the RTC Room when joining the lobby. This may be used to indicate the RTCRoom should be joined immediately or manually at a later time.