pub type EOS_Lobby_LocalRTCOptions = _tagEOS_Lobby_LocalRTCOptions;Expand description
Input parameters to use with Lobby RTC Rooms.
Aliased Type
#[repr(C)]pub struct EOS_Lobby_LocalRTCOptions {
pub ApiVersion: i32,
pub Flags: u32,
pub bUseManualAudioInput: i32,
pub bUseManualAudioOutput: i32,
pub bLocalAudioDeviceInputStartsMuted: i32,
pub Reserved: *mut c_void,
}Fields
ApiVersion: i32API Version: Set this to EOS_LOBBY_LOCALRTCOPTIONS_API_LATEST.
Flags: u32Flags for the local user in this room. The default is 0 if this struct is not specified. @see EOS_RTC_JoinRoomOptions::Flags
bUseManualAudioInput: i32Set to EOS_TRUE to enable Manual Audio Input. If manual audio input is enabled, audio recording is not started and the audio buffers must be passed manually using EOS_RTCAudio_SendAudio. The default is EOS_FALSE if this struct is not specified.
bUseManualAudioOutput: i32Set to EOS_TRUE to enable Manual Audio Output. If manual audio output is enabled, audio rendering is not started and the audio buffers must be received with EOS_RTCAudio_AddNotifyAudioBeforeRender and rendered manually. The default is EOS_FALSE if this struct is not specified.
bLocalAudioDeviceInputStartsMuted: i32Set to EOS_TRUE to start the audio input device’s stream as muted when first connecting to the RTC room.
It must be manually unmuted with a call to EOS_RTCAudio_UpdateSending. If manual audio output is enabled, this value is ignored. The default value is EOS_FALSE if this struct is not specified.
Reserved: *mut c_voidReserved field, should be nullptr by default