EOS_Lobby_SendLobbyNativeInviteRequestedCallbackInfo

Type Alias EOS_Lobby_SendLobbyNativeInviteRequestedCallbackInfo 

pub type EOS_Lobby_SendLobbyNativeInviteRequestedCallbackInfo = _tagEOS_Lobby_SendLobbyNativeInviteRequestedCallbackInfo;
Output parameters for the EOS_Lobby_OnSendLobbyNativeInviteRequestedCallback Function.

Aliased Type

#[repr(C)]
pub struct EOS_Lobby_SendLobbyNativeInviteRequestedCallbackInfo { pub ClientData: *mut c_void, pub UiEventId: u64, pub LocalUserId: *mut EOS_ProductUserIdDetails, pub TargetNativeAccountType: *const u8, pub TargetUserNativeAccountId: *const u8, pub LobbyId: *const u8, }

Fields

ClientData: *mut c_void

Context that was passed into EOS_Lobby_AddNotifySendLobbyNativeInviteRequested

UiEventId: u64

Identifies this event which will need to be acknowledged with EOS_UI_AcknowledgeEventId(). @see EOS_UI_AcknowledgeEventId

LocalUserId: *mut EOS_ProductUserIdDetails

The Product User ID of the local user who is inviting.

TargetNativeAccountType: *const u8

The Native Platform Account Type. If only a single integrated platform is configured then this will always reference that platform.

TargetUserNativeAccountId: *const u8

The Native Platform Account ID of the target user being invited.

LobbyId: *const u8

Lobby ID that the user is being invited to