pub type EOS_Lobby_UpdateLobbyModificationOptions = _tagEOS_Lobby_UpdateLobbyModificationOptions;Expand description
Input parameters for the EOS_Lobby_UpdateLobbyModification function.
Aliased Type
#[repr(C)]pub struct EOS_Lobby_UpdateLobbyModificationOptions {
pub ApiVersion: i32,
pub LocalUserId: *mut EOS_ProductUserIdDetails,
pub LobbyId: *const u8,
}Fields
ApiVersion: i32API Version: Set this to EOS_LOBBY_UPDATELOBBYMODIFICATION_API_LATEST.
LocalUserId: *mut EOS_ProductUserIdDetailsThe ID of the local user making modifications. Must be the owner to modify lobby data, but any lobby member can modify their own attributes.
LobbyId: *const u8The ID of the lobby