EOS_Mods_EnumerateModsCallbackInfo

Type Alias EOS_Mods_EnumerateModsCallbackInfo 

pub type EOS_Mods_EnumerateModsCallbackInfo = _tagEOS_Mods_EnumerateModsCallbackInfo;
Output parameters for the EOS_Mods_EnumerateMods Function. These parameters are received through the callback provided to EOS_Mods_EnumerateMods

Aliased Type

#[repr(C)]
pub struct EOS_Mods_EnumerateModsCallbackInfo { pub ResultCode: i32, pub LocalUserId: *mut EOS_EpicAccountIdDetails, pub ClientData: *mut c_void, pub Type: i32, }

Fields

ResultCode: i32

Result code for the operation. EOS_Success is returned if the enumeration was successful, otherwise one of the error codes is returned.

LocalUserId: *mut EOS_EpicAccountIdDetails

The Epic Account ID of the user for which mod enumeration was requested

ClientData: *mut c_void

Context that is passed into EOS_Mods_EnumerateMods

Type: i32

Type of the enumerated mods