EOS_Mods_InstallModOptions

Type Alias EOS_Mods_InstallModOptions 

pub type EOS_Mods_InstallModOptions = _tagEOS_Mods_InstallModOptions;
Input parameters for the EOS_Mods_InstallMod Function.

Aliased Type

#[repr(C)]
pub struct EOS_Mods_InstallModOptions { pub ApiVersion: i32, pub LocalUserId: *mut EOS_EpicAccountIdDetails, pub Mod: *const _tagEOS_Mod_Identifier, pub bRemoveAfterExit: i32, }

Fields

ApiVersion: i32

API Version: Set this to EOS_MODS_INSTALLMOD_API_LATEST.

LocalUserId: *mut EOS_EpicAccountIdDetails

The Epic Account ID of the user for which the mod should be installed

Mod: *const _tagEOS_Mod_Identifier

The mod to install

bRemoveAfterExit: i32

Indicates whether the mod should be uninstalled after exiting the game or not.