EOS_Mods_UninstallModCallbackInfo

Type Alias EOS_Mods_UninstallModCallbackInfo 

pub type EOS_Mods_UninstallModCallbackInfo = _tagEOS_Mods_UninstallModCallbackInfo;
Output parameters for the EOS_Mods_UninstallMod Function. These parameters are received through the callback provided to EOS_Mods_UninstallMod

Aliased Type

#[repr(C)]
pub struct EOS_Mods_UninstallModCallbackInfo { pub ResultCode: i32, pub LocalUserId: *mut EOS_EpicAccountIdDetails, pub ClientData: *mut c_void, pub Mod: *const _tagEOS_Mod_Identifier, }

Fields

ResultCode: i32

Result code for the operation. EOS_Success is returned if the uninstallation was successful, otherwise one of the error codes is returned.

LocalUserId: *mut EOS_EpicAccountIdDetails

The Epic Account ID of the user for which mod uninstallation was requested

ClientData: *mut c_void

Context that is passed into EOS_Mods_UninstallMod

Mod: *const _tagEOS_Mod_Identifier

Mod for which uninstallation was requested