EOS_Mods_UpdateModCallbackInfo

Type Alias EOS_Mods_UpdateModCallbackInfo 

pub type EOS_Mods_UpdateModCallbackInfo = _tagEOS_Mods_UpdateModCallbackInfo;
Output parameters for the EOS_Mods_UpdateMod Function. These parameters are received through the callback provided to EOS_Mods_UpdateMod

Aliased Type

#[repr(C)]
pub struct EOS_Mods_UpdateModCallbackInfo { pub ResultCode: i32, pub LocalUserId: *mut EOS_EpicAccountIdDetails, pub ClientData: *mut c_void, pub Mod: *const _tagEOS_Mod_Identifier, }

Fields

ResultCode: i32

Result code for the operation. EOS_Success is returned if the request to update was successful, otherwise one of the error codes is returned.

LocalUserId: *mut EOS_EpicAccountIdDetails

The Epic Account ID of the user for which mod update was requested

ClientData: *mut c_void

Context that is passed into EOS_Mods_UpdateMod

Mod: *const _tagEOS_Mod_Identifier

Mod for which update was requested