EOS_P2P_AcceptConnectionOptions

Type Alias EOS_P2P_AcceptConnectionOptions 

pub type EOS_P2P_AcceptConnectionOptions = _tagEOS_P2P_AcceptConnectionOptions;
Structure containing information about who would like to accept a connection, and which connection.

Aliased Type

#[repr(C)]
pub struct EOS_P2P_AcceptConnectionOptions { pub ApiVersion: i32, pub LocalUserId: *mut EOS_ProductUserIdDetails, pub RemoteUserId: *mut EOS_ProductUserIdDetails, pub SocketId: *const _tagEOS_P2P_SocketId, }

Fields

ApiVersion: i32

API Version: Set this to EOS_P2P_ACCEPTCONNECTION_API_LATEST.

LocalUserId: *mut EOS_ProductUserIdDetails

The Product User ID of the local user who is accepting any pending or future connections with RemoteUserId

RemoteUserId: *mut EOS_ProductUserIdDetails

The Product User ID of the remote user who has either sent a connection request or is expected to in the future

SocketId: *const _tagEOS_P2P_SocketId

The socket ID of the connection to accept on