EOS_P2P_AddNotifyPeerConnectionClosedOptions

Type Alias EOS_P2P_AddNotifyPeerConnectionClosedOptions 

pub type EOS_P2P_AddNotifyPeerConnectionClosedOptions = _tagEOS_P2P_AddNotifyPeerConnectionClosedOptions;
Structure containing information about who would like notifications about closed connections, and for which socket.

Aliased Type

#[repr(C)]
pub struct EOS_P2P_AddNotifyPeerConnectionClosedOptions { pub ApiVersion: i32, pub LocalUserId: *mut EOS_ProductUserIdDetails, pub SocketId: *const _tagEOS_P2P_SocketId, }

Fields

ApiVersion: i32

API Version: Set this to EOS_P2P_ADDNOTIFYPEERCONNECTIONCLOSED_API_LATEST.

LocalUserId: *mut EOS_ProductUserIdDetails

The Product User ID of the local user who would like notifications

SocketId: *const _tagEOS_P2P_SocketId

The optional socket ID to listen for to be closed. If NULL, this function handler will be called for all closed connections