EOS_P2P_AddNotifyPeerConnectionEstablishedOptions

Type Alias EOS_P2P_AddNotifyPeerConnectionEstablishedOptions 

pub type EOS_P2P_AddNotifyPeerConnectionEstablishedOptions = _tagEOS_P2P_AddNotifyPeerConnectionEstablishedOptions;
Structure containing information about which connections should be notified

Aliased Type

#[repr(C)]
pub struct EOS_P2P_AddNotifyPeerConnectionEstablishedOptions { pub ApiVersion: i32, pub LocalUserId: *mut EOS_ProductUserIdDetails, pub SocketId: *const _tagEOS_P2P_SocketId, }

Fields

ApiVersion: i32

API Version: Set this to EOS_P2P_ADDNOTIFYPEERCONNECTIONESTABLISHED_API_LATEST.

LocalUserId: *mut EOS_ProductUserIdDetails

The Product User ID of the local user who would like to receive notifications

SocketId: *const _tagEOS_P2P_SocketId

The optional socket ID, used as a filter for established connections. If NULL, this function handler will be called for all sockets