EOS_P2P_AddNotifyPeerConnectionInterruptedOptions

Type Alias EOS_P2P_AddNotifyPeerConnectionInterruptedOptions 

pub type EOS_P2P_AddNotifyPeerConnectionInterruptedOptions = _tagEOS_P2P_AddNotifyPeerConnectionInterruptedOptions;
Structure containing information about who would like notifications about interrupted connections, and for which socket.

Aliased Type

#[repr(C)]
pub struct EOS_P2P_AddNotifyPeerConnectionInterruptedOptions { pub ApiVersion: i32, pub LocalUserId: *mut EOS_ProductUserIdDetails, pub SocketId: *const _tagEOS_P2P_SocketId, }

Fields

ApiVersion: i32

API Version: Set this to EOS_P2P_ADDNOTIFYPEERCONNECTIONINTERRUPTED_API_LATEST.

LocalUserId: *mut EOS_ProductUserIdDetails

The Product User ID of the local user who would like notifications

SocketId: *const _tagEOS_P2P_SocketId

An optional socket ID to filter interrupted connections on. If NULL, this function handler will be called for all interrupted connections