EOS_P2P_AddNotifyPeerConnectionRequestOptions

Type Alias EOS_P2P_AddNotifyPeerConnectionRequestOptions 

pub type EOS_P2P_AddNotifyPeerConnectionRequestOptions = _tagEOS_P2P_AddNotifyPeerConnectionRequestOptions;
Structure containing information about who would like connection notifications, and about which socket.

Aliased Type

#[repr(C)]
pub struct EOS_P2P_AddNotifyPeerConnectionRequestOptions { pub ApiVersion: i32, pub LocalUserId: *mut EOS_ProductUserIdDetails, pub SocketId: *const _tagEOS_P2P_SocketId, }

Fields

ApiVersion: i32

API Version: Set this to EOS_P2P_ADDNOTIFYPEERCONNECTIONREQUEST_API_LATEST.

LocalUserId: *mut EOS_ProductUserIdDetails

The Product User ID of the user who is listening for incoming connection requests

SocketId: *const _tagEOS_P2P_SocketId

The optional socket ID to listen for, used as a filter for incoming connection requests; If NULL, incoming connection requests will not be filtered