EOS_P2P_CloseConnectionOptions

Type Alias EOS_P2P_CloseConnectionOptions 

pub type EOS_P2P_CloseConnectionOptions = _tagEOS_P2P_CloseConnectionOptions;
Structure containing information about who would like to close a connection, and which connection.

Aliased Type

#[repr(C)]
pub struct EOS_P2P_CloseConnectionOptions { pub ApiVersion: i32, pub LocalUserId: *mut EOS_ProductUserIdDetails, pub RemoteUserId: *mut EOS_ProductUserIdDetails, pub SocketId: *const _tagEOS_P2P_SocketId, }

Fields

ApiVersion: i32

API Version: Set this to EOS_P2P_CLOSECONNECTION_API_LATEST.

LocalUserId: *mut EOS_ProductUserIdDetails

The Product User ID of the local user who would like to close a previously accepted connection (or decline a pending invite)

RemoteUserId: *mut EOS_ProductUserIdDetails

The Product User ID of the remote user to disconnect from (or to reject a pending invite from)

SocketId: *const _tagEOS_P2P_SocketId

The socket ID of the connection to close (or optionally NULL to not accept any connection requests from the Remote User)