EOS_P2P_CloseConnectionsOptions

Type Alias EOS_P2P_CloseConnectionsOptions 

pub type EOS_P2P_CloseConnectionsOptions = _tagEOS_P2P_CloseConnectionsOptions;
Structure containing information about who would like to close connections, and by what socket ID

Aliased Type

#[repr(C)]
pub struct EOS_P2P_CloseConnectionsOptions { pub ApiVersion: i32, pub LocalUserId: *mut EOS_ProductUserIdDetails, pub SocketId: *const _tagEOS_P2P_SocketId, }

Fields

ApiVersion: i32

API Version: Set this to EOS_P2P_CLOSECONNECTIONS_API_LATEST.

LocalUserId: *mut EOS_ProductUserIdDetails

The Product User ID of the local user who would like to close all connections that use a particular socket ID

SocketId: *const _tagEOS_P2P_SocketId

The socket ID of the connections to close