pub type EOS_P2P_OnIncomingConnectionRequestInfo = _tagEOS_P2P_OnIncomingConnectionRequestInfo;Expand description
Structure containing information about an incoming connection request.
Aliased Type
#[repr(C)]pub struct EOS_P2P_OnIncomingConnectionRequestInfo {
pub ClientData: *mut c_void,
pub LocalUserId: *mut EOS_ProductUserIdDetails,
pub RemoteUserId: *mut EOS_ProductUserIdDetails,
pub SocketId: *const _tagEOS_P2P_SocketId,
}Fields
ClientData: *mut c_voidClient-specified data passed into EOS_Presence_AddNotifyOnPresenceChanged
LocalUserId: *mut EOS_ProductUserIdDetailsThe Product User ID of the local user who is being requested to open a P2P session with RemoteUserId
RemoteUserId: *mut EOS_ProductUserIdDetailsThe Product User ID of the remote user who requested a peer connection with the local user
SocketId: *const _tagEOS_P2P_SocketIdThe ID of the socket the Remote User wishes to communicate on