EOS_P2P_OnIncomingPacketQueueFullInfo

Type Alias EOS_P2P_OnIncomingPacketQueueFullInfo 

pub type EOS_P2P_OnIncomingPacketQueueFullInfo = _tagEOS_P2P_OnIncomingPacketQueueFullInfo;
Structure containing information about the packet queue’s state and the incoming packet that would overflow the queue

Aliased Type

#[repr(C)]
pub struct EOS_P2P_OnIncomingPacketQueueFullInfo { pub ClientData: *mut c_void, pub PacketQueueMaxSizeBytes: u64, pub PacketQueueCurrentSizeBytes: u64, pub OverflowPacketLocalUserId: *mut EOS_ProductUserIdDetails, pub OverflowPacketChannel: u8, pub OverflowPacketSizeBytes: u32, }

Fields

ClientData: *mut c_void

Client-specified data passed into AddNotifyIncomingPacketQueueFull

PacketQueueMaxSizeBytes: u64

The maximum size in bytes the incoming packet queue is allowed to use

PacketQueueCurrentSizeBytes: u64

The current size in bytes the incoming packet queue is currently using

OverflowPacketLocalUserId: *mut EOS_ProductUserIdDetails

The Product User ID of the local user who is receiving the packet that would overflow the queue

OverflowPacketChannel: u8

The channel the incoming packet is for

OverflowPacketSizeBytes: u32

The size in bytes of the incoming packet (and related metadata) that would overflow the queue