pub type EOS_P2P_OnPeerConnectionEstablishedInfo = _tagEOS_P2P_OnPeerConnectionEstablishedInfo;Expand description
Structure containing information about a connection being established
Aliased Type
#[repr(C)]pub struct EOS_P2P_OnPeerConnectionEstablishedInfo {
pub ClientData: *mut c_void,
pub LocalUserId: *mut EOS_ProductUserIdDetails,
pub RemoteUserId: *mut EOS_ProductUserIdDetails,
pub SocketId: *const _tagEOS_P2P_SocketId,
pub ConnectionType: i32,
pub NetworkType: i32,
}Fields
ClientData: *mut c_voidClient-specified data passed into EOS_P2P_AddNotifyPeerConnectionEstablished
LocalUserId: *mut EOS_ProductUserIdDetailsThe Product User ID of the local user who is being notified of a connection being established
RemoteUserId: *mut EOS_ProductUserIdDetailsThe Product User ID of the remote user who this connection was with
SocketId: *const _tagEOS_P2P_SocketIdThe socket ID of the connection being established
ConnectionType: i32Information if this is a new connection or reconnection
NetworkType: i32What type of network connection is being used for this connection