pub type EOS_P2P_OnRemoteConnectionClosedInfo = _tagEOS_P2P_OnRemoteConnectionClosedInfo;Expand description
Structure containing information about an connection request that is being closed.
Aliased Type
#[repr(C)]pub struct EOS_P2P_OnRemoteConnectionClosedInfo {
pub ClientData: *mut c_void,
pub LocalUserId: *mut EOS_ProductUserIdDetails,
pub RemoteUserId: *mut EOS_ProductUserIdDetails,
pub SocketId: *const _tagEOS_P2P_SocketId,
pub Reason: i32,
}Fields
ClientData: *mut c_voidClient-specified data passed into EOS_Presence_AddNotifyOnPresenceChanged
LocalUserId: *mut EOS_ProductUserIdDetailsThe local user who is being notified of a connection being closed
RemoteUserId: *mut EOS_ProductUserIdDetailsThe Product User ID of the remote user who this connection was with
SocketId: *const _tagEOS_P2P_SocketIdThe socket ID of the connection being closed
Reason: i32The reason the connection was closed (if known)