pub type EOS_P2P_ReceivePacketOptions = _tagEOS_P2P_ReceivePacketOptions;Expand description
Structure containing information about who would like to receive a packet, and how much data can be stored safely.
Aliased Type
#[repr(C)]pub struct EOS_P2P_ReceivePacketOptions {
pub ApiVersion: i32,
pub LocalUserId: *mut EOS_ProductUserIdDetails,
pub MaxDataSizeBytes: u32,
pub RequestedChannel: *const u8,
}Fields
ApiVersion: i32API Version: Set this to EOS_P2P_RECEIVEPACKET_API_LATEST.
LocalUserId: *mut EOS_ProductUserIdDetailsThe Product User ID of the user who is receiving the packet
MaxDataSizeBytes: u32The maximum amount of data in bytes that can be safely copied to OutData in the function call
RequestedChannel: *const u8An optional channel to request the data for. If NULL, we’re retrieving the next packet on any channel