EOS_P2P_SendPacketOptions

Type Alias EOS_P2P_SendPacketOptions 

pub type EOS_P2P_SendPacketOptions = _tagEOS_P2P_SendPacketOptions;
Structure containing information about the data being sent and to which player

Aliased Type

#[repr(C)]
pub struct EOS_P2P_SendPacketOptions { pub ApiVersion: i32, pub LocalUserId: *mut EOS_ProductUserIdDetails, pub RemoteUserId: *mut EOS_ProductUserIdDetails, pub SocketId: *const _tagEOS_P2P_SocketId, pub Channel: u8, pub DataLengthBytes: u32, pub Data: *const c_void, pub bAllowDelayedDelivery: i32, pub Reliability: i32, pub bDisableAutoAcceptConnection: i32, }

Fields

ApiVersion: i32

API Version: Set this to EOS_P2P_SENDPACKET_API_LATEST.

LocalUserId: *mut EOS_ProductUserIdDetails

The Product User ID of the local user who is sending this packet

RemoteUserId: *mut EOS_ProductUserIdDetails

The Product User ID of the Peer you would like to send a packet to

SocketId: *const _tagEOS_P2P_SocketId

The socket ID for data you are sending in this packet

Channel: u8

Channel associated with this data

DataLengthBytes: u32

The size of the data to be sent to the RemoteUser

Data: *const c_void

The data to be sent to the RemoteUser

bAllowDelayedDelivery: i32

If false and we do not already have an established connection to the peer, this data will be dropped

Reliability: i32

Sets the reliability of the delivery of this packet. The reliability can be EOS_PR_UnreliableUnordered, EOS_PR_ReliableUnordered, or EOS_PR_ReliableOrdered.

bDisableAutoAcceptConnection: i32

If set to EOS_TRUE, EOS_P2P_SendPacket will not automatically establish a connection with the RemoteUserId and will require explicit calls to EOS_P2P_AcceptConnection first whenever the connection is closed. If set to EOS_FALSE, EOS_P2P_SendPacket will automatically accept and start the connection any time it is called and the connection is not already open.