pub type EOS_P2P_SetPortRangeOptions = _tagEOS_P2P_SetPortRangeOptions;Expand description
Structure containing information about new port range settings.
Aliased Type
#[repr(C)]pub struct EOS_P2P_SetPortRangeOptions {
pub ApiVersion: i32,
pub Port: u16,
pub MaxAdditionalPortsToTry: u16,
}Fields
ApiVersion: i32API Version: Set this to EOS_P2P_SETPORTRANGE_API_LATEST.
Port: u16The ideal port to use for P2P traffic. The default value is 7777. If set to 0, the OS will choose a port. If set to 0, MaxAdditionalPortsToTry must be set to 0.
MaxAdditionalPortsToTry: u16The maximum amount of additional ports to try if Port is unavailable. Ports will be tried from Port to Port + MaxAdditionalPortsToTry inclusive, until one is available or we run out of ports. If no ports are available, P2P connections will fail. The default value is 99.