EOS_PlayerDataStorage_DeleteCacheCallbackInfo

Type Alias EOS_PlayerDataStorage_DeleteCacheCallbackInfo 

pub type EOS_PlayerDataStorage_DeleteCacheCallbackInfo = _tagEOS_PlayerDataStorage_DeleteCacheCallbackInfo;
Structure containing the result of a delete cache operation

Aliased Type

#[repr(C)]
pub struct EOS_PlayerDataStorage_DeleteCacheCallbackInfo { pub ResultCode: i32, pub ClientData: *mut c_void, pub LocalUserId: *mut EOS_ProductUserIdDetails, }

Fields

ResultCode: i32

Result code for the operation. EOS_Success is returned for a successful request, other codes indicate an error

ClientData: *mut c_void

Client-specified data passed into the delete cache request

LocalUserId: *mut EOS_ProductUserIdDetails

Product User ID of the local user who initiated this request