EOS_PlayerDataStorage_DuplicateFileCallbackInfo

Type Alias EOS_PlayerDataStorage_DuplicateFileCallbackInfo 

pub type EOS_PlayerDataStorage_DuplicateFileCallbackInfo = _tagEOS_PlayerDataStorage_DuplicateFileCallbackInfo;
Data containing the result information for a duplicate file request

Aliased Type

#[repr(C)]
pub struct EOS_PlayerDataStorage_DuplicateFileCallbackInfo { pub ResultCode: i32, pub ClientData: *mut c_void, pub LocalUserId: *mut EOS_ProductUserIdDetails, }

Fields

ResultCode: i32

Result code for the operation. EOS_Success is returned for a successful request, other codes indicate an error

ClientData: *mut c_void

Client-specified data passed into the file duplicate request

LocalUserId: *mut EOS_ProductUserIdDetails

The Product User ID of the local user who initiated this request