pub type EOS_PlayerDataStorage_FileMetadata = _tagEOS_PlayerDataStorage_FileMetadata;Expand description
Metadata information for a specific file
Aliased Type
#[repr(C)]pub struct EOS_PlayerDataStorage_FileMetadata {
pub ApiVersion: i32,
pub FileSizeBytes: u32,
pub MD5Hash: *const i8,
pub Filename: *const i8,
pub LastModifiedTime: i64,
pub UnencryptedDataSizeBytes: u32,
}Fields
ApiVersion: i32API Version: Set this to EOS_PLAYERDATASTORAGE_FILEMETADATA_API_LATEST.
FileSizeBytes: u32The total size of the file in bytes (Includes file header in addition to file contents)
MD5Hash: *const i8The MD5 Hash of the entire file (including additional file header), in hex digits
Filename: *const i8The file’s name
LastModifiedTime: i64The POSIX timestamp when the file was saved last time or EOS_PLAYERDATASTORAGE_TIME_UNDEFINED if the time is undefined. It will be undefined after a file is written and uploaded at first before a query operation is completed.
UnencryptedDataSizeBytes: u32The size of data (payload) in file in unencrypted (original) form.