EOS_PlayerDataStorage_OnWriteFileDataCallback

Type Alias EOS_PlayerDataStorage_OnWriteFileDataCallback 

pub type EOS_PlayerDataStorage_OnWriteFileDataCallback = Option<unsafe extern "C" fn(Data: *const EOS_PlayerDataStorage_WriteFileDataCallbackInfo, OutDataBuffer: *mut c_void, OutDataWritten: *mut u32) -> EOS_PlayerDataStorage_EWriteResult>;
Callback for when we are ready to get more data to be written into the requested file. It is undefined how often this will be called during a single tick.

@param Data Struct containing metadata for the file being written to, as well as the max length in bytes that can be safely written to DataBuffer @param OutDataBuffer A buffer to write data into, to be appended to the end of the file that is being written to. The maximum length of this value is provided in the Info parameter. The number of bytes written to this buffer should be set in OutDataWritten. @param OutDataWritten The length of the data written to OutDataBuffer. This must be less than or equal than the DataBufferLengthBytes provided in the Info parameter @return The result of the write operation. If this value is not EOS_WR_ContinueWriting, this callback will not be called again for the same request. If this is set to EOS_WR_FailRequest or EOS_WR_CancelRequest, all data written during the request will not be saved

Aliased Type

pub enum EOS_PlayerDataStorage_OnWriteFileDataCallback {
    None,
    Some(unsafe extern "C" fn(*const _tagEOS_PlayerDataStorage_WriteFileDataCallbackInfo, *mut c_void, *mut u32) -> i32),
}

Variants

1.0.0

None

No value.

1.0.0

Some(unsafe extern "C" fn(*const _tagEOS_PlayerDataStorage_WriteFileDataCallbackInfo, *mut c_void, *mut u32) -> i32)

Some value of type T.