pub type EOS_PlayerDataStorage_QueryFileCallbackInfo = _tagEOS_PlayerDataStorage_QueryFileCallbackInfo;Expand description
Data containing information about a query file request
Aliased Type
#[repr(C)]pub struct EOS_PlayerDataStorage_QueryFileCallbackInfo {
pub ResultCode: i32,
pub ClientData: *mut c_void,
pub LocalUserId: *mut EOS_ProductUserIdDetails,
}Fields
ResultCode: i32Result code for the operation. EOS_Success is returned for a successful request, other codes indicate an error
ClientData: *mut c_voidClient-specified data passed into the file query request
LocalUserId: *mut EOS_ProductUserIdDetailsThe Product User ID of the local user who initiated this request