EOS_PlayerDataStorage_WriteFileCallbackInfo

Type Alias EOS_PlayerDataStorage_WriteFileCallbackInfo 

pub type EOS_PlayerDataStorage_WriteFileCallbackInfo = _tagEOS_PlayerDataStorage_WriteFileCallbackInfo;
The result information for a request to write data to a file

Aliased Type

#[repr(C)]
pub struct EOS_PlayerDataStorage_WriteFileCallbackInfo { pub ResultCode: i32, pub ClientData: *mut c_void, pub LocalUserId: *mut EOS_ProductUserIdDetails, pub Filename: *const i8, }

Fields

ResultCode: i32

The result code for the operation. EOS_Success: The request was successful. EOS_Canceled: The request was canceled. EOS_TooManyRequests: There are too many requests in progress for the local user at this time. EOS_AlreadyPending: There is another requests in progress for the specified file by this user. EOS_CacheDirectoryMissing: The cache directory was not set when calling EOS_Platform_Create. EOS_CacheDirectoryInvalid: The cache directory provided when calling EOS_Platform_Create was invalid. EOS_PlayerDataStorage_UserThrottled: There were too many requests to the Data Storage service recently by the local user. The application must wait some time before trying again. EOS_PlayerDataStorage_EncryptionKeyNotSet: The encryption key value was not set when calling EOS_Platform_Create. EOS_InvalidState: The read operation is not allowed (e.g. when application is suspended). EOS_UnexpectedError: An unexpected error occurred either downloading, or reading the downloaded file. This most commonly means there were file IO issues such as: permission issues, disk is full, etc. (potentially retryable)

ClientData: *mut c_void

Client-specified data passed into the file write request

LocalUserId: *mut EOS_ProductUserIdDetails

The Product User ID of the local user who initiated this request

Filename: *const i8

The file name that is being written to