EOS_PlayerDataStorage_WriteFileDataCallbackInfo

Type Alias EOS_PlayerDataStorage_WriteFileDataCallbackInfo 

pub type EOS_PlayerDataStorage_WriteFileDataCallbackInfo = _tagEOS_PlayerDataStorage_WriteFileDataCallbackInfo;
Data containing data for a chunk of a file being written

Aliased Type

#[repr(C)]
pub struct EOS_PlayerDataStorage_WriteFileDataCallbackInfo { pub ClientData: *mut c_void, pub LocalUserId: *mut EOS_ProductUserIdDetails, pub Filename: *const i8, pub DataBufferLengthBytes: u32, }

Fields

ClientData: *mut c_void

Client-specified data passed into the file write request

LocalUserId: *mut EOS_ProductUserIdDetails

The Product User ID of the local user who initiated this request

Filename: *const i8

The file name that is being written to

DataBufferLengthBytes: u32

The maximum amount of data in bytes that can be written safely to DataBuffer