EOS_PlayerDataStorage_WriteFileOptions

Type Alias EOS_PlayerDataStorage_WriteFileOptions 

pub type EOS_PlayerDataStorage_WriteFileOptions = _tagEOS_PlayerDataStorage_WriteFileOptions;
Input data for the EOS_PlayerDataStorage_WriteFile function

Aliased Type

#[repr(C)]
pub struct EOS_PlayerDataStorage_WriteFileOptions { pub ApiVersion: i32, pub LocalUserId: *mut EOS_ProductUserIdDetails, pub Filename: *const i8, pub ChunkLengthBytes: u32, pub WriteFileDataCallback: Option<unsafe extern "C" fn(*const _tagEOS_PlayerDataStorage_WriteFileDataCallbackInfo, *mut c_void, *mut u32) -> i32>, pub FileTransferProgressCallback: Option<unsafe extern "C" fn(*const _tagEOS_PlayerDataStorage_FileTransferProgressCallbackInfo)>, }

Fields

ApiVersion: i32

API Version: Set this to EOS_PLAYERDATASTORAGE_WRITEFILE_API_LATEST.

LocalUserId: *mut EOS_ProductUserIdDetails

The Product User ID of the local user who is writing the requested file to the cloud

Filename: *const i8

The name of the file to write; if this file already exists, the contents will be replaced if the write request completes successfully

ChunkLengthBytes: u32

Requested maximum amount of data (in bytes) that can be written to the file per tick

WriteFileDataCallback: Option<unsafe extern "C" fn(*const _tagEOS_PlayerDataStorage_WriteFileDataCallbackInfo, *mut c_void, *mut u32) -> i32>

Callback function that provides chunks of data to be written into the requested file

FileTransferProgressCallback: Option<unsafe extern "C" fn(*const _tagEOS_PlayerDataStorage_FileTransferProgressCallbackInfo)>

Optional callback function to inform the application of upload progress; will be called at least once if set