EOS_Presence_Info

Type Alias EOS_Presence_Info 

pub type EOS_Presence_Info = _tagEOS_Presence_Info;
All the known presence information for a specific user. This object must be released by calling EOS_Presence_Info_Release.

@see EOS_Presence_CopyPresence @see EOS_Presence_Info_Release

Aliased Type

#[repr(C)]
pub struct EOS_Presence_Info { pub ApiVersion: i32, pub Status: i32, pub UserId: *mut EOS_EpicAccountIdDetails, pub ProductId: *const i8, pub ProductVersion: *const i8, pub Platform: *const i8, pub RichText: *const i8, pub RecordsCount: i32, pub Records: *const _tagEOS_Presence_DataRecord, pub ProductName: *const i8, pub IntegratedPlatform: *const i8, }

Fields

ApiVersion: i32

API Version: Set this to EOS_PRESENCE_INFO_API_LATEST.

Status: i32

The status of the user

UserId: *mut EOS_EpicAccountIdDetails

The Epic Account ID of the user

ProductId: *const i8

The product ID that the user is logged in from

ProductVersion: *const i8

The version of the product the user is logged in from

Platform: *const i8

The platform of that the user is logged in from

RichText: *const i8

Rich text of the user.

RecordsCount: i32

The count of records available

Records: *const _tagEOS_Presence_DataRecord

The first data record, or NULL if RecordsCount is not at least 1

ProductName: *const i8

The user-facing name for the product the user is logged in from

IntegratedPlatform: *const i8

The integrated platform that the user is logged in with