pub type EOS_Presence_QueryPresenceCallbackInfo = _tagEOS_Presence_QueryPresenceCallbackInfo;Expand description
The result meta-data for a presence query.
Aliased Type
#[repr(C)]pub struct EOS_Presence_QueryPresenceCallbackInfo {
pub ResultCode: i32,
pub ClientData: *mut c_void,
pub LocalUserId: *mut EOS_EpicAccountIdDetails,
pub TargetUserId: *mut EOS_EpicAccountIdDetails,
}Fields
ResultCode: i32Result code for the operation. EOS_Success is returned for a successful query, other codes indicate an error
ClientData: *mut c_voidClient-specified data passed into EOS_Presence_QueryPresence
LocalUserId: *mut EOS_EpicAccountIdDetailsThe Epic Account ID of the local user who made this request
TargetUserId: *mut EOS_EpicAccountIdDetailsThe Epic Account ID of the user whose presence was potentially queried