EOS_Presence_QueryPresenceOptions

Type Alias EOS_Presence_QueryPresenceOptions 

pub type EOS_Presence_QueryPresenceOptions = _tagEOS_Presence_QueryPresenceOptions;
Data for the EOS_Presence_QueryPresence function

Aliased Type

#[repr(C)]
pub struct EOS_Presence_QueryPresenceOptions { pub ApiVersion: i32, pub LocalUserId: *mut EOS_EpicAccountIdDetails, pub TargetUserId: *mut EOS_EpicAccountIdDetails, }

Fields

ApiVersion: i32

API Version: Set this to EOS_PRESENCE_QUERYPRESENCE_API_LATEST.

LocalUserId: *mut EOS_EpicAccountIdDetails

The Epic Account ID of the local, logged-in user making the request

TargetUserId: *mut EOS_EpicAccountIdDetails

The Epic Account ID of the user whose presence data you want to retrieve; this value must be either the user making the request, or a friend of that user