EOS_RTCAdmin_QueryJoinRoomTokenCompleteCallbackInfo

Type Alias EOS_RTCAdmin_QueryJoinRoomTokenCompleteCallbackInfo 

pub type EOS_RTCAdmin_QueryJoinRoomTokenCompleteCallbackInfo = _tagEOS_RTCAdmin_QueryJoinRoomTokenCompleteCallbackInfo;
Data containing the result information for a query join room token request.

Aliased Type

#[repr(C)]
pub struct EOS_RTCAdmin_QueryJoinRoomTokenCompleteCallbackInfo { pub ResultCode: i32, pub ClientData: *mut c_void, pub RoomName: *const u8, pub ClientBaseUrl: *const u8, pub QueryId: u32, pub TokenCount: u32, }

Fields

ResultCode: i32

The EOS_EResult code for the operation. EOS_Success indicates that the operation succeeded; other codes indicate errors.

ClientData: *mut c_void

Context that was passed into EOS_RTCAdmin_QueryJoinRoomToken.

RoomName: *const u8

Room the request was made for.

ClientBaseUrl: *const u8

URL passed to backend to join room.

QueryId: u32

If the query completed successfully, this contains an identifier that should be used to retrieve the tokens. This identifier is only valid for the duration of the callback.

@see EOS_RTCAdmin_CopyUserTokenByIndex @see EOS_RTCAdmin_CopyUserTokenByUserId

TokenCount: u32

How many token received as result of the query