pub type EOS_RTCAdmin_UserToken = _tagEOS_RTCAdmin_UserToken;Expand description
Contains information about a collection of user tokens for joining a room.
Aliased Type
#[repr(C)]pub struct EOS_RTCAdmin_UserToken {
pub ApiVersion: i32,
pub ProductUserId: *mut EOS_ProductUserIdDetails,
pub Token: *const u8,
}Fields
ApiVersion: i32API Version: Set this to EOS_RTCADMIN_USERTOKEN_API_LATEST.
ProductUserId: *mut EOS_ProductUserIdDetailsThe Product User ID for the user who owns this user token.
Token: *const u8Access token to enable a user to join a room