EOS_RTC_DisconnectedCallbackInfo

Type Alias EOS_RTC_DisconnectedCallbackInfo 

pub type EOS_RTC_DisconnectedCallbackInfo = _tagEOS_RTC_DisconnectedCallbackInfo;
This struct is passed in with a call to EOS_RTC_AddNotifyDisconnected registered event.

Aliased Type

#[repr(C)]
pub struct EOS_RTC_DisconnectedCallbackInfo { pub ResultCode: i32, pub ClientData: *mut c_void, pub LocalUserId: *mut EOS_ProductUserIdDetails, pub RoomName: *const u8, }

Fields

ResultCode: i32

This returns: EOS_Success The room was left cleanly. EOS_NoConnection: There was a network issue connecting to the server (retryable). EOS_RTC_UserKicked: The user has been kicked by the server (retryable). EOS_ServiceFailure: A known error occurred during interaction with the server (retryable). EOS_UnexpectedError Unexpected error (retryable).

ClientData: *mut c_void

Client-specified data passed into EOS_RTC_AddNotifyDisconnected.

LocalUserId: *mut EOS_ProductUserIdDetails

The Product User ID of the user who initiated this request.

RoomName: *const u8

The room associated with this event.