pub type EOS_RTC_OnRoomBeforeJoinCallback = Option<unsafe extern "C" fn(Data: *const EOS_RTC_RoomBeforeJoinCallbackInfo)>;Expand description
Function prototype definition for notifications that comes from EOS_RTC_AddNotifyRoomBeforeJoin
@param Data containing the RTC room name which is about to be created and joined.
Aliased Type
pub enum EOS_RTC_OnRoomBeforeJoinCallback {
None,
Some(unsafe extern "C" fn(*const _tagEOS_RTC_RoomBeforeJoinCallbackInfo)),
}Variants
None
No value.
Some(unsafe extern "C" fn(*const _tagEOS_RTC_RoomBeforeJoinCallbackInfo))
Some value of type T.