EOS_RTC_ParticipantStatusChangedCallbackInfo

Type Alias EOS_RTC_ParticipantStatusChangedCallbackInfo 

pub type EOS_RTC_ParticipantStatusChangedCallbackInfo = _tagEOS_RTC_ParticipantStatusChangedCallbackInfo;
This struct is passed in with a call to EOS_RTC_AddNotifyParticipantStatusChanged registered event.

Aliased Type

#[repr(C)]
pub struct EOS_RTC_ParticipantStatusChangedCallbackInfo { pub ClientData: *mut c_void, pub LocalUserId: *mut EOS_ProductUserIdDetails, pub RoomName: *const i8, pub ParticipantId: *mut EOS_ProductUserIdDetails, pub ParticipantStatus: i32, pub ParticipantMetadataCount: u32, pub ParticipantMetadata: *const _tagEOS_RTC_ParticipantMetadata, pub bParticipantInBlocklist: i32, }

Fields

ClientData: *mut c_void

Client-specified data passed into EOS_RTC_AddNotifyParticipantStatusChanged.

LocalUserId: *mut EOS_ProductUserIdDetails

The Product User ID of the user who initiated this request.

RoomName: *const i8

The room associated with this event.

ParticipantId: *mut EOS_ProductUserIdDetails

The participant whose status changed.

ParticipantStatus: i32

What status change occurred

ParticipantMetadataCount: u32

The participant metadata items count. This is only set for the first notification where ParticipantStatus is EOS_RTCPS_Joined. Subsequent notifications such as when bParticipantInBlocklist changes will not contain any metadata.

ParticipantMetadata: *const _tagEOS_RTC_ParticipantMetadata

The participant metadata items. This is only set for the first notification where ParticipantStatus is EOS_RTCPS_Joined. Subsequent notifications such as when bParticipantInBlocklist changes will not contain any metadata.

bParticipantInBlocklist: i32

The participant’s block list status, if ParticipantStatus is EOS_RTCPS_Joined. This is set to true if the participant is in any of the local user’s applicable block lists, such Epic block list or any of the current platform’s block lists. It can be used to detect when an internal automatic RTC block is applied because of trust and safety restrictions.