pub type EOS_RTC_SetRoomSettingOptions = _tagEOS_RTC_SetRoomSettingOptions;Expand description
This struct is used to call EOS_RTC_SetRoomSetting
Available values of SettingName:
- DisableEchoCancelation: Disables the use of echo cancellation for the audio channel. Default “False”.
- DisableNoiseSupression: Disables the use of noise suppression for the audio channel. Default “False”.
- DisableAutoGainControl: Disables the use of auto gain control for the audio channel. Default “False”.
- DisableDtx: Allows to disable the use of DTX. Default “False”.
Aliased Type
#[repr(C)]pub struct EOS_RTC_SetRoomSettingOptions {
pub ApiVersion: i32,
pub LocalUserId: *mut EOS_ProductUserIdDetails,
pub RoomName: *const i8,
pub SettingName: *const i8,
pub SettingValue: *const i8,
}Fields
ApiVersion: i32API Version: Set this to EOS_RTC_SETROOMSETTING_API_LATEST.
LocalUserId: *mut EOS_ProductUserIdDetailsThe Product User ID of the user trying to request this operation.
RoomName: *const i8The room the setting will be applied to.
SettingName: *const i8Setting that should be set.
SettingValue: *const i8Value to set the setting to.