EOS_RTC_SetSettingOptions

Type Alias EOS_RTC_SetSettingOptions 

pub type EOS_RTC_SetSettingOptions = _tagEOS_RTC_SetSettingOptions;
This struct is used to call EOS_RTC_SetSetting

Available values of SettingName:

  • DisableEchoCancelation: Disables the use of echo cancellation for the audio channel. Default “False”.
  • DisableNoiseSupression: Disables the use of noise suppression for the audio channel. Default “False”.
  • DisableAutoGainControl: Disables the use of auto gain control for the audio channel. Default “False”.
  • DisableDtx: Allows to disable the use of DTX. Default “False”.

Aliased Type

#[repr(C)]
pub struct EOS_RTC_SetSettingOptions { pub ApiVersion: i32, pub SettingName: *const u8, pub SettingValue: *const u8, }

Fields

ApiVersion: i32

API Version: Set this to EOS_RTC_SETSETTING_API_LATEST.

SettingName: *const u8

Setting that should be set.

SettingValue: *const u8

Value to set the setting to.