EOS_ReleaseMemoryFunc

Type Alias EOS_ReleaseMemoryFunc 

pub type EOS_ReleaseMemoryFunc = Option<unsafe extern "C" fn(Pointer: *mut c_void)>;
Function prototype type definition for functions that release memory.

When the SDK is done with memory that has been allocated by a custom allocator passed to EOS_Initialize, it will call the corresponding memory release function.

Aliased Type

pub enum EOS_ReleaseMemoryFunc {
    None,
    Some(unsafe extern "C" fn(*mut c_void)),
}

Variants

1.0.0

None

No value.

1.0.0

Some(unsafe extern "C" fn(*mut c_void))

Some value of type T.