pub type EOS_Sanctions_CopyPlayerSanctionByIndexOptions = _tagEOS_Sanctions_CopyPlayerSanctionByIndexOptions;Expand description
Input parameters for the EOS_Sanctions_CopyPlayerSanctionByIndex function
Aliased Type
#[repr(C)]pub struct EOS_Sanctions_CopyPlayerSanctionByIndexOptions {
pub ApiVersion: i32,
pub TargetUserId: *mut EOS_ProductUserIdDetails,
pub SanctionIndex: u32,
}Fields
ApiVersion: i32API Version: Set this to EOS_SANCTIONS_COPYPLAYERSANCTIONBYINDEX_API_LATEST.
TargetUserId: *mut EOS_ProductUserIdDetailsProduct User ID of the user whose active sanctions are to be copied
SanctionIndex: u32Index of the sanction to retrieve from the cache