pub type EOS_SessionDetails_Info = _tagEOS_SessionDetails_Info;Expand description
Internal details about a session, found on both active sessions and within search results
Aliased Type
#[repr(C)]pub struct EOS_SessionDetails_Info {
pub ApiVersion: i32,
pub SessionId: *const u8,
pub HostAddress: *const u8,
pub NumOpenPublicConnections: u32,
pub Settings: *const _tagEOS_SessionDetails_Settings,
pub OwnerUserId: *mut EOS_ProductUserIdDetails,
pub OwnerServerClientId: *const u8,
}Fields
ApiVersion: i32API Version: Set this to EOS_SESSIONDETAILS_INFO_API_LATEST.
SessionId: *const u8Session ID assigned by the backend service
HostAddress: *const u8IP address of this session as visible by the backend service
NumOpenPublicConnections: u32Number of remaining open spaces on the session (NumPublicConnections - RegisteredPlayers
Settings: *const _tagEOS_SessionDetails_SettingsReference to the additional settings associated with this session
OwnerUserId: *mut EOS_ProductUserIdDetailsThe Product User ID of the session owner. Null if the session is not owned by a user.
OwnerServerClientId: *const u8The client id of the session owner. Null if the session is not owned by a server. The session is owned by a server if EOS_Platform_Options::bIsServer is EOS_TRUE.