EOS_Sessions_CreateSessionModificationOptions

Type Alias EOS_Sessions_CreateSessionModificationOptions 

pub type EOS_Sessions_CreateSessionModificationOptions = _tagEOS_Sessions_CreateSessionModificationOptions;
Input parameters for the EOS_Sessions_CreateSessionModification function.

Aliased Type

#[repr(C)]
pub struct EOS_Sessions_CreateSessionModificationOptions { pub ApiVersion: i32, pub SessionName: *const u8, pub BucketId: *const u8, pub MaxPlayers: u32, pub LocalUserId: *mut EOS_ProductUserIdDetails, pub bPresenceEnabled: i32, pub SessionId: *const u8, pub bSanctionsEnabled: i32, pub AllowedPlatformIds: *const u32, pub AllowedPlatformIdsCount: u32, }

Fields

ApiVersion: i32

API Version: Set this to EOS_SESSIONS_CREATESESSIONMODIFICATION_API_LATEST.

SessionName: *const u8

Name of the session to create

BucketId: *const u8

Bucket ID associated with the session

MaxPlayers: u32

Maximum number of players allowed in the session

LocalUserId: *mut EOS_ProductUserIdDetails

The Product User ID of the local user associated with the session

bPresenceEnabled: i32

Determines whether or not this session should be the one associated with the local user’s presence information. If true, this session will be associated with presence. Only one session at a time can have this flag true. This affects the ability of the Social Overlay to show game related actions to take in the user’s social graph.

@note The Social Overlay can handle only one of the following three options at a time:

  • using the bPresenceEnabled flags within the Sessions interface
  • using the bPresenceEnabled flags within the Lobby interface
  • using EOS_PresenceModification_SetJoinInfo

@see EOS_PresenceModification_SetJoinInfoOptions @see EOS_Lobby_CreateLobbyOptions @see EOS_Lobby_JoinLobbyOptions @see EOS_Sessions_JoinSessionOptions

SessionId: *const u8

Optional session id - set to a globally unique value to override the backend assignment If not specified the backend service will assign one to the session. Do not mix and match. This value can be of size [EOS_SESSIONMODIFICATION_MIN_SESSIONIDOVERRIDE_LENGTH, EOS_SESSIONMODIFICATION_MAX_SESSIONIDOVERRIDE_LENGTH]

bSanctionsEnabled: i32

If true, sanctioned players can neither join nor register with this session and, in the case of join, will return EOS_EResult code EOS_Sessions_PlayerSanctioned

AllowedPlatformIds: *const u32

Array of platform IDs indicating the player platforms allowed to register with the session. Platform IDs are found in the EOS header file (eos_common.h), for example EOS_OPT_Epic. For some platforms the value will be in the EOS Platform specific header file. If null, the session will be unrestricted.

AllowedPlatformIdsCount: u32

Number of platform IDs in the array