EOS_Sessions_LeaveSessionRequestedCallbackInfo

Type Alias EOS_Sessions_LeaveSessionRequestedCallbackInfo 

pub type EOS_Sessions_LeaveSessionRequestedCallbackInfo = _tagEOS_Sessions_LeaveSessionRequestedCallbackInfo;
Output parameters for the EOS_Sessions_OnLeaveSessionRequestedCallback Function.

Aliased Type

#[repr(C)]
pub struct EOS_Sessions_LeaveSessionRequestedCallbackInfo { pub ClientData: *mut c_void, pub LocalUserId: *mut EOS_ProductUserIdDetails, pub SessionName: *const i8, }

Fields

ClientData: *mut c_void

Context that was passed into EOS_Sessions_OnLeaveSessionRequestedCallback

LocalUserId: *mut EOS_ProductUserIdDetails

The Product User ID of the local user who received the leave session notification.

SessionName: *const i8

Name of the session associated with the leave session request.