pub type EOS_Sessions_OnJoinSessionAcceptedCallback = Option<unsafe extern "C" fn(Data: *const EOS_Sessions_JoinSessionAcceptedCallbackInfo)>;Expand description
Function prototype definition for notifications that come from EOS_Sessions_AddNotifyJoinSessionAccepted
@param Data A EOS_Sessions_JoinSessionAcceptedCallbackInfo containing the output information and result
@note The session for the join game must be joined.
@see EOS_Sessions_CopySessionHandleByUiEventId @see EOS_Sessions_JoinSession
Aliased Type
pub enum EOS_Sessions_OnJoinSessionAcceptedCallback {
None,
Some(unsafe extern "C" fn(*const _tagEOS_Sessions_JoinSessionAcceptedCallbackInfo)),
}Variants
None
No value.
Some(unsafe extern "C" fn(*const _tagEOS_Sessions_JoinSessionAcceptedCallbackInfo))
Some value of type T.