pub type EOS_Sessions_OnSessionInviteAcceptedCallback = Option<unsafe extern "C" fn(Data: *const EOS_Sessions_SessionInviteAcceptedCallbackInfo)>;Expand description
Function prototype definition for notifications that come from EOS_Sessions_AddNotifySessionInviteAccepted
@param Data A EOS_Sessions_SessionInviteAcceptedCallbackInfo containing the output information and result
@note The session for the invite must be joined.
@see EOS_Sessions_CopySessionHandleByInviteId @see EOS_Sessions_JoinSession
Aliased Type
pub enum EOS_Sessions_OnSessionInviteAcceptedCallback {
None,
Some(unsafe extern "C" fn(*const _tagEOS_Sessions_SessionInviteAcceptedCallbackInfo)),
}Variants
None
No value.
Some(unsafe extern "C" fn(*const _tagEOS_Sessions_SessionInviteAcceptedCallbackInfo))
Some value of type T.