pub type EOS_Sessions_RegisterPlayersCallbackInfo = _tagEOS_Sessions_RegisterPlayersCallbackInfo;Expand description
Output parameters for the EOS_Sessions_RegisterPlayers function.
Aliased Type
#[repr(C)]pub struct EOS_Sessions_RegisterPlayersCallbackInfo {
pub ResultCode: i32,
pub ClientData: *mut c_void,
pub RegisteredPlayers: *mut *mut EOS_ProductUserIdDetails,
pub RegisteredPlayersCount: u32,
pub SanctionedPlayers: *mut *mut EOS_ProductUserIdDetails,
pub SanctionedPlayersCount: u32,
}Fields
ResultCode: i32The EOS_EResult code for the operation. EOS_Success indicates that the operation succeeded; other codes indicate errors.
ClientData: *mut c_voidContext that was passed into EOS_Sessions_RegisterPlayers
RegisteredPlayers: *mut *mut EOS_ProductUserIdDetailsThe players that were successfully registered
RegisteredPlayersCount: u32The number of players successfully registered
SanctionedPlayers: *mut *mut EOS_ProductUserIdDetailsThe players that failed to register because they are sanctioned
SanctionedPlayersCount: u32The number of players that failed to register because they are sanctioned