EOS_Sessions_SendSessionNativeInviteRequestedCallbackInfo

Type Alias EOS_Sessions_SendSessionNativeInviteRequestedCallbackInfo 

pub type EOS_Sessions_SendSessionNativeInviteRequestedCallbackInfo = _tagEOS_Sessions_SendSessionNativeInviteRequestedCallbackInfo;
Output parameters for the EOS_Sessions_OnSendSessionNativeInviteRequestedCallback Function.

Aliased Type

#[repr(C)]
pub struct EOS_Sessions_SendSessionNativeInviteRequestedCallbackInfo { pub ClientData: *mut c_void, pub UiEventId: u64, pub LocalUserId: *mut EOS_ProductUserIdDetails, pub TargetNativeAccountType: *const u8, pub TargetUserNativeAccountId: *const u8, pub SessionId: *const u8, }

Fields

ClientData: *mut c_void

Context that was passed into EOS_Sessions_AddNotifySendSessionNativeInviteRequested

UiEventId: u64

Identifies this event which will need to be acknowledged with EOS_UI_AcknowledgeEventId(). @see EOS_UI_AcknowledgeEventId

LocalUserId: *mut EOS_ProductUserIdDetails

The Product User ID of the local user who is inviting.

TargetNativeAccountType: *const u8

The Native Platform Account Type. If only a single integrated platform is configured then this will always reference that platform.

TargetUserNativeAccountId: *const u8

The Native Platform Account ID of the target user being invited.

SessionId: *const u8

Session ID that the user is being invited to