EOS_Stats_IngestStatCompleteCallbackInfo

Type Alias EOS_Stats_IngestStatCompleteCallbackInfo 

pub type EOS_Stats_IngestStatCompleteCallbackInfo = _tagEOS_Stats_IngestStatCompleteCallbackInfo;
Data containing the result information for an ingest stat request.

NOTE: A result code of EOS_Success indicates the ingest request reached the server successfully, but does not guarantee successful processing. For example, if an incorrect StatName value is provided in the ingest call, processing may still fail.

Aliased Type

#[repr(C)]
pub struct EOS_Stats_IngestStatCompleteCallbackInfo { pub ResultCode: i32, pub ClientData: *mut c_void, pub LocalUserId: *mut EOS_ProductUserIdDetails, pub TargetUserId: *mut EOS_ProductUserIdDetails, }

Fields

ResultCode: i32

Result code for the operation. EOS_Success is returned for a successful request, other codes indicate an error.

ClientData: *mut c_void

Context that was passed into EOS_Stats_IngestStat.

LocalUserId: *mut EOS_ProductUserIdDetails

The Product User ID for the user requesting the ingest

TargetUserId: *mut EOS_ProductUserIdDetails

The Product User ID for the user whose stat is being ingested