EOS_Stats_QueryStatsOptions

Type Alias EOS_Stats_QueryStatsOptions 

pub type EOS_Stats_QueryStatsOptions = _tagEOS_Stats_QueryStatsOptions;
Input parameters for the EOS_Stats_QueryStats function.

Aliased Type

#[repr(C)]
pub struct EOS_Stats_QueryStatsOptions { pub ApiVersion: i32, pub LocalUserId: *mut EOS_ProductUserIdDetails, pub StartTime: i64, pub EndTime: i64, pub StatNames: *mut *const u8, pub StatNamesCount: u32, pub TargetUserId: *mut EOS_ProductUserIdDetails, }

Fields

ApiVersion: i32

API Version: Set this to EOS_STATS_QUERYSTATS_API_LATEST.

LocalUserId: *mut EOS_ProductUserIdDetails

The Product User ID of the local user requesting the stats. Set to null for dedicated server.

StartTime: i64

If not EOS_STATS_TIME_UNDEFINED then this is the POSIX timestamp for start time (Optional - set to EOS_STATS_TIME_UNDEFINED to ignore this parameter).

EndTime: i64

If not EOS_STATS_TIME_UNDEFINED then this is the POSIX timestamp for end time (Optional - set to EOS_STATS_TIME_UNDEFINED to ignore this parameter).

StatNames: *mut *const u8

An array of stat names to query for (Optional - set to nullptr to query for all stats).

StatNamesCount: u32

The number of stat names included in query (Optional - set to 0 when querying for all stats), may not exceed EOS_STATS_MAX_QUERY_STATS.

TargetUserId: *mut EOS_ProductUserIdDetails

The Product User ID for the user whose stats are being retrieved