pub type EOS_TitleStorage_DeleteCacheCallbackInfo = _tagEOS_TitleStorage_DeleteCacheCallbackInfo;Expand description
Structure containing the result of a delete cache operation
Aliased Type
#[repr(C)]pub struct EOS_TitleStorage_DeleteCacheCallbackInfo {
pub ResultCode: i32,
pub ClientData: *mut c_void,
pub LocalUserId: *mut EOS_ProductUserIdDetails,
}Fields
ResultCode: i32Result code for the operation. EOS_Success is returned for a successful request, other codes indicate an error
ClientData: *mut c_voidClient-specified data passed into the delete cache request
LocalUserId: *mut EOS_ProductUserIdDetailsProduct User ID of the local user who initiated this request (optional, will only be present in case it was provided during operation start)