EOS_TitleStorage_FileTransferProgressCallbackInfo

Type Alias EOS_TitleStorage_FileTransferProgressCallbackInfo 

pub type EOS_TitleStorage_FileTransferProgressCallbackInfo = _tagEOS_TitleStorage_FileTransferProgressCallbackInfo;
Structure containing the information about a file transfer in progress (or one that has completed)

Aliased Type

#[repr(C)]
pub struct EOS_TitleStorage_FileTransferProgressCallbackInfo { pub ClientData: *mut c_void, pub LocalUserId: *mut EOS_ProductUserIdDetails, pub Filename: *const i8, pub BytesTransferred: u32, pub TotalFileSizeBytes: u32, }

Fields

ClientData: *mut c_void

Client-specified data passed into the file request

LocalUserId: *mut EOS_ProductUserIdDetails

Product User ID of the local user who initiated this request (optional, will only be present in case it was provided during operation start)

Filename: *const i8

The file name of the file being transferred

BytesTransferred: u32

Amount of bytes transferred so far in this request, out of TotalFileSizeBytes

TotalFileSizeBytes: u32

The total size of the file being transferred (Includes file header in addition to file contents, can be slightly more than expected)