EOS_TitleStorage_OnReadFileDataCallback

Type Alias EOS_TitleStorage_OnReadFileDataCallback 

pub type EOS_TitleStorage_OnReadFileDataCallback = Option<unsafe extern "C" fn(Data: *const EOS_TitleStorage_ReadFileDataCallbackInfo) -> EOS_TitleStorage_EReadResult>;
Callback for when we have data ready to be read from the requested file. It is undefined how often this will be called during a single tick.

@param Data Struct containing a chunk of data to read, as well as some metadata for the file being read @return The result of the read operation. If this value is not EOS_TS_RR_ContinueReading, this callback will not be called again for the same request

Aliased Type

pub enum EOS_TitleStorage_OnReadFileDataCallback {
    None,
    Some(unsafe extern "C" fn(*const _tagEOS_TitleStorage_ReadFileDataCallbackInfo) -> i32),
}

Variants

1.0.0

None

No value.

1.0.0

Some(unsafe extern "C" fn(*const _tagEOS_TitleStorage_ReadFileDataCallbackInfo) -> i32)

Some value of type T.