pub type EOS_TitleStorage_ReadFileDataCallbackInfo = _tagEOS_TitleStorage_ReadFileDataCallbackInfo;Expand description
Structure containing data for a chunk of a file being read
Aliased Type
#[repr(C)]pub struct EOS_TitleStorage_ReadFileDataCallbackInfo {
pub ClientData: *mut c_void,
pub LocalUserId: *mut EOS_ProductUserIdDetails,
pub Filename: *const i8,
pub TotalFileSizeBytes: u32,
pub bIsLastChunk: i32,
pub DataChunkLengthBytes: u32,
pub DataChunk: *const c_void,
}Fields
ClientData: *mut c_voidClient-specified data passed into the file request
LocalUserId: *mut EOS_ProductUserIdDetailsProduct User ID of the local user who initiated this request (optional, will only be present in case it was provided during operation start)
Filename: *const i8The file name being read
TotalFileSizeBytes: u32The total file size of the file being read
bIsLastChunk: i32Is this chunk the last chunk of data?
DataChunkLengthBytes: u32The length of DataChunk in bytes that can be safely read
DataChunk: *const c_voidPointer to the start of data to be read