EOS_TitleStorage_ReadFileOptions

Type Alias EOS_TitleStorage_ReadFileOptions 

pub type EOS_TitleStorage_ReadFileOptions = _tagEOS_TitleStorage_ReadFileOptions;
Input data for the EOS_TitleStorage_ReadFile function

Aliased Type

#[repr(C)]
pub struct EOS_TitleStorage_ReadFileOptions { pub ApiVersion: i32, pub LocalUserId: *mut EOS_ProductUserIdDetails, pub Filename: *const i8, pub ReadChunkLengthBytes: u32, pub ReadFileDataCallback: Option<unsafe extern "C" fn(*const _tagEOS_TitleStorage_ReadFileDataCallbackInfo) -> i32>, pub FileTransferProgressCallback: Option<unsafe extern "C" fn(*const _tagEOS_TitleStorage_FileTransferProgressCallbackInfo)>, }

Fields

ApiVersion: i32

API Version: Set this to EOS_TITLESTORAGE_READFILE_API_LATEST.

LocalUserId: *mut EOS_ProductUserIdDetails

Product User ID of the local user who is reading the requested file (optional)

Filename: *const i8

The file name to read; this file must already exist

ReadChunkLengthBytes: u32

The maximum amount of data in bytes should be available to read in a single EOS_TitleStorage_OnReadFileDataCallback call

ReadFileDataCallback: Option<unsafe extern "C" fn(*const _tagEOS_TitleStorage_ReadFileDataCallbackInfo) -> i32>

Callback function to handle copying read data

FileTransferProgressCallback: Option<unsafe extern "C" fn(*const _tagEOS_TitleStorage_FileTransferProgressCallbackInfo)>

Optional callback function to be informed of download progress, if the file is not already locally cached. If set, this will be called at least once before completion if the request is successfully started