EOS_UI_ConfigureOnScreenKeyboardOptions

Type Alias EOS_UI_ConfigureOnScreenKeyboardOptions 

pub type EOS_UI_ConfigureOnScreenKeyboardOptions = _tagEOS_UI_ConfigureOnScreenKeyboardOptions;
Input parameters for the EOS_UI_ConfigureOnScreenKeyboard function.

Aliased Type

#[repr(C)]
pub struct EOS_UI_ConfigureOnScreenKeyboardOptions { pub ApiVersion: i32, pub Behavior: i32, pub bIsDeviceChecksEnabled: i32, }

Fields

ApiVersion: i32

API Version: Set this to EOS_UI_CONFIGUREONSCREENKEYBOARD_API_LATEST.

Behavior: i32

The behavior of the on screen keyboard.

bIsDeviceChecksEnabled: i32

Whether to enable device checks. When enabled, the overlay will use a number of heuristics based on the device’s configuration to determine whether an on screen keyboard should be requested. When disabled, on screen keyboards will always be requested regardless of device configuration. Note, by setting environment variable “EOS_OVERLAY_OSK” to 0, on screen keyboard requests will always fail, and by setting it to 1, device checks will always succeed.