pub type EOS_UI_OnDisplaySettingsUpdatedCallbackInfo = _tagEOS_UI_OnDisplaySettingsUpdatedCallbackInfo;Expand description
Output parameters for the EOS_UI_AddNotifyDisplaySettingsUpdated function.
Aliased Type
#[repr(C)]pub struct EOS_UI_OnDisplaySettingsUpdatedCallbackInfo {
pub ClientData: *mut c_void,
pub bIsVisible: i32,
pub bIsExclusiveInput: i32,
}Fields
ClientData: *mut c_voidContext that was passed into EOS_UI_AddNotifyDisplaySettingsUpdated
bIsVisible: i32True when any portion of the overlay is visible.
bIsExclusiveInput: i32True when the overlay has switched to exclusive input mode. While in exclusive input mode, no keyboard or mouse input will be sent to the game.