EOS_UI_ReportInputStateOptions

Type Alias EOS_UI_ReportInputStateOptions 

pub type EOS_UI_ReportInputStateOptions = _tagEOS_UI_ReportInputStateOptions;
Input parameters for the EOS_UI_ReportInputState function.

Aliased Type

#[repr(C)]
pub struct EOS_UI_ReportInputStateOptions {
Show 13 fields pub ApiVersion: i32, pub ButtonDownFlags: i32, pub bAcceptIsFaceButtonRight: i32, pub bMouseButtonDown: i32, pub MousePosX: u32, pub MousePosY: u32, pub GamepadIndex: u32, pub LeftStickX: f32, pub LeftStickY: f32, pub RightStickX: f32, pub RightStickY: f32, pub LeftTrigger: f32, pub RightTrigger: f32,
}

Fields

ApiVersion: i32

API Version: Set this to EOS_UI_REPORTINPUTSTATE_API_LATEST.

ButtonDownFlags: i32

Flags to identify the current buttons which are pressed.

bAcceptIsFaceButtonRight: i32

Whether the current platform and configuration uses the right face button as the default accept button. When this flag is true, the right face button is the accept action, and the down face button is the cancel action. When this flag is false, the right face button is the cancel action, and the down face button is the accept action.

bMouseButtonDown: i32

The current state of the mouse button.

MousePosX: u32

The current x-position of the mouse.

MousePosY: u32

The current y-position of the mouse.

GamepadIndex: u32

The gamepad or player index

LeftStickX: f32

Left analog stick horizontal movement in [-1, 1]. Negative for left, positive for right

LeftStickY: f32

Left analog stick vertical movement in [-1, 1]. Negative for up, positive for down

RightStickX: f32

Right analog stick horizontal movement in [-1, 1]. Negative for left, positive for right

RightStickY: f32

Right analog stick vertical movement in [-1, 1]. Negative for up, positive for down

LeftTrigger: f32

Left trigger analog value in [0, 1]

RightTrigger: f32

Right trigger analog value in [0, 1]