EOS_UI_SetToggleFriendsKeyOptions

Type Alias EOS_UI_SetToggleFriendsKeyOptions 

pub type EOS_UI_SetToggleFriendsKeyOptions = _tagEOS_UI_SetToggleFriendsKeyOptions;
Input parameters for the EOS_UI_SetToggleFriendsKey function.

Aliased Type

#[repr(C)]
pub struct EOS_UI_SetToggleFriendsKeyOptions { pub ApiVersion: i32, pub KeyCombination: i32, }

Fields

ApiVersion: i32

API Version: Set this to EOS_UI_SETTOGGLEFRIENDSKEY_API_LATEST.

KeyCombination: i32

The new key combination which will be used to toggle the friends overlay. The combination can be any set of modifiers and one key. A value of EOS_UIK_None will cause the key to revert to the default.