EOS_UserInfo_BestDisplayName

Type Alias EOS_UserInfo_BestDisplayName 

pub type EOS_UserInfo_BestDisplayName = _tagEOS_UserInfo_BestDisplayName;
A structure that contains the user information. These structures are created by EOS_UserInfo_CopyBestDisplayName or EOS_UserInfo_CopyBestDisplayNameWithPlatform and must be passed to EOS_UserInfo_BestDisplayName_Release.

Aliased Type

#[repr(C)]
pub struct EOS_UserInfo_BestDisplayName { pub ApiVersion: i32, pub UserId: *mut EOS_EpicAccountIdDetails, pub DisplayName: *const u8, pub DisplayNameSanitized: *const u8, pub Nickname: *const u8, pub PlatformType: u32, }

Fields

ApiVersion: i32

API Version: Set this to EOS_USERINFO_BESTDISPLAYNAME_API_LATEST.

UserId: *mut EOS_EpicAccountIdDetails

The Epic Account ID of the user

DisplayName: *const u8

The display name (un-sanitized). This may be null

DisplayNameSanitized: *const u8

The raw display name (sanitized). This may be null

Nickname: *const u8

A nickname/alias for the target user assigned by the local user. This may be null

PlatformType: u32

The platform type for the user which corresponds to the display name