pub type EOS_UserInfo_CopyBestDisplayNameWithPlatformOptions = _tagEOS_UserInfo_CopyBestDisplayNameWithPlatformOptions;Expand description
Input parameters for the EOS_UserInfo_CopyBestDisplayNameWithPlatform function.
Aliased Type
#[repr(C)]pub struct EOS_UserInfo_CopyBestDisplayNameWithPlatformOptions {
pub ApiVersion: i32,
pub LocalUserId: *mut EOS_EpicAccountIdDetails,
pub TargetUserId: *mut EOS_EpicAccountIdDetails,
pub TargetPlatformType: u32,
}Fields
ApiVersion: i32API Version: Set this to EOS_USERINFO_COPYBESTDISPLAYNAMEWITHPLATFORM_API_LATEST.
LocalUserId: *mut EOS_EpicAccountIdDetailsThe Epic Account ID of the local player requesting the information
TargetUserId: *mut EOS_EpicAccountIdDetailsThe Epic Account ID of the player whose information is being retrieved
TargetPlatformType: u32The platform type of the player whose information is being retrieved