EOS_UserInfo_CopyExternalUserInfoByAccountTypeOptions

Type Alias EOS_UserInfo_CopyExternalUserInfoByAccountTypeOptions 

pub type EOS_UserInfo_CopyExternalUserInfoByAccountTypeOptions = _tagEOS_UserInfo_CopyExternalUserInfoByAccountTypeOptions;
Input parameters for the EOS_UserInfo_CopyExternalUserInfoByAccountType function.

Aliased Type

#[repr(C)]
pub struct EOS_UserInfo_CopyExternalUserInfoByAccountTypeOptions { pub ApiVersion: i32, pub LocalUserId: *mut EOS_EpicAccountIdDetails, pub TargetUserId: *mut EOS_EpicAccountIdDetails, pub AccountType: i32, }

Fields

ApiVersion: i32

API Version: Set this to EOS_USERINFO_COPYEXTERNALUSERINFOBYACCOUNTTYPE_API_LATEST.

LocalUserId: *mut EOS_EpicAccountIdDetails

The Epic Account ID of the local player requesting the information

TargetUserId: *mut EOS_EpicAccountIdDetails

The Epic Account ID of the player whose information is being retrieved

AccountType: i32

Account type of the external user info to retrieve from the cache