EOS_UserInfo_CopyExternalUserInfoByIndexOptions

Type Alias EOS_UserInfo_CopyExternalUserInfoByIndexOptions 

pub type EOS_UserInfo_CopyExternalUserInfoByIndexOptions = _tagEOS_UserInfo_CopyExternalUserInfoByIndexOptions;
Input parameters for the EOS_UserInfo_CopyExternalUserInfoByIndex function.

Aliased Type

#[repr(C)]
pub struct EOS_UserInfo_CopyExternalUserInfoByIndexOptions { pub ApiVersion: i32, pub LocalUserId: *mut EOS_EpicAccountIdDetails, pub TargetUserId: *mut EOS_EpicAccountIdDetails, pub Index: u32, }

Fields

ApiVersion: i32

API Version: Set this to EOS_USERINFO_COPYEXTERNALUSERINFOBYINDEX_API_LATEST.

LocalUserId: *mut EOS_EpicAccountIdDetails

The Epic Account ID of the local player requesting the information

TargetUserId: *mut EOS_EpicAccountIdDetails

The Epic Account ID of the player whose information is being retrieved

Index: u32

Index of the external user info to retrieve from the cache