pub type EOS_UserInfo_QueryUserInfoByDisplayNameCallbackInfo = _tagEOS_UserInfo_QueryUserInfoByDisplayNameCallbackInfo;Expand description
Output parameters for the EOS_UserInfo_QueryUserInfoByDisplayName Function.
Aliased Type
#[repr(C)]pub struct EOS_UserInfo_QueryUserInfoByDisplayNameCallbackInfo {
pub ResultCode: i32,
pub ClientData: *mut c_void,
pub LocalUserId: *mut EOS_EpicAccountIdDetails,
pub TargetUserId: *mut EOS_EpicAccountIdDetails,
pub DisplayName: *const u8,
}Fields
ResultCode: i32The EOS_EResult code for the operation. EOS_Success indicates that the operation succeeded; other codes indicate errors.
ClientData: *mut c_voidContext that was passed into EOS_UserInfo_QueryUserInfoByDisplayName
LocalUserId: *mut EOS_EpicAccountIdDetailsThe Epic Account ID of the local player requesting the information
TargetUserId: *mut EOS_EpicAccountIdDetailsThe Epic Account ID of the player whose information is being retrieved
DisplayName: *const u8Display name (un-sanitized) of the player being queried. This memory is only valid during the scope of the callback.