EOS_UserInfo_QueryUserInfoByExternalAccountOptions

Type Alias EOS_UserInfo_QueryUserInfoByExternalAccountOptions 

pub type EOS_UserInfo_QueryUserInfoByExternalAccountOptions = _tagEOS_UserInfo_QueryUserInfoByExternalAccountOptions;
Input parameters for the EOS_UserInfo_QueryUserInfoByExternalAccount function.

Aliased Type

#[repr(C)]
pub struct EOS_UserInfo_QueryUserInfoByExternalAccountOptions { pub ApiVersion: i32, pub LocalUserId: *mut EOS_EpicAccountIdDetails, pub ExternalAccountId: *const i8, pub AccountType: i32, }

Fields

ApiVersion: i32

API Version: Set this to EOS_USERINFO_QUERYUSERINFOBYEXTERNALACCOUNT_API_LATEST.

LocalUserId: *mut EOS_EpicAccountIdDetails

The Epic Account ID of the local player requesting the information

ExternalAccountId: *const i8

External account ID of the user whose information is being retrieved

AccountType: i32

Account type of the external user info to query