pub unsafe extern "C" fn EOS_Auth_CopyUserAuthToken(
Handle: EOS_HAuth,
Options: *const EOS_Auth_CopyUserAuthTokenOptions,
LocalUserId: EOS_EpicAccountId,
OutUserAuthToken: *mut *mut EOS_Auth_Token,
) -> EOS_EResultExpand description
Fetch a user auth token for an Epic Account ID.
A user authentication token allows any code with possession (backend/client) to perform certain actions on behalf of the user. Because of this, for the purposes of user identity verification, the EOS_Auth_CopyIdToken API should be used instead.
@param Options Structure containing the api version of CopyUserAuthToken to use @param LocalUserId The Epic Account ID of the user being queried @param OutUserAuthToken The auth token for the given user, if it exists and is valid; use EOS_Auth_Token_Release when finished
@see EOS_Auth_CopyUserAuthTokenOptions @see EOS_Auth_Token @see EOS_Auth_Token_Release
@return EOS_EResult containing the result of the operation. Possible result codes:
- EOS_Success if the information is available and passed out in OutUserAuthToken
- EOS_InvalidParameters if you pass a null pointer for the out parameter
- EOS_NotFound if the auth token is not found or expired.