EOS_Auth_GetLoggedInAccountByIndex

Function EOS_Auth_GetLoggedInAccountByIndex 

pub unsafe extern "C" fn EOS_Auth_GetLoggedInAccountByIndex(
    Handle: EOS_HAuth,
    Index: i32,
) -> EOS_EpicAccountId
Fetch an Epic Account ID that is logged in.

@param Index An index into the list of logged in accounts. If the index is out of bounds, the returned Epic Account ID will be invalid.

@return The Epic Account ID associated with the index passed