pub unsafe extern "C" fn EOS_Auth_GetMergedAccountByIndex(
Handle: EOS_HAuth,
LocalUserId: EOS_EpicAccountId,
Index: u32,
) -> EOS_EpicAccountIdExpand description
Fetch one of the merged account IDs for a given logged in account.
@param LocalUserId The account ID of a currently logged in account. @param Index An index into the list of merged accounts. If the index is out of bounds, the returned Epic Account ID will be invalid.
@return The Epic Account ID associated with the index passed.