pub unsafe extern "C" fn EOS_Auth_GetMergedAccountsCount(
Handle: EOS_HAuth,
LocalUserId: EOS_EpicAccountId,
) -> u32Expand description
Fetch the number of merged accounts for a given logged in account.
@param LocalUserId The account ID of a currently logged in account.
@return the number of merged accounts for the logged in account.