pub unsafe extern "C" fn EOS_Auth_GetSelectedAccountId(
Handle: EOS_HAuth,
LocalUserId: EOS_EpicAccountId,
OutSelectedAccountId: *mut EOS_EpicAccountId,
) -> EOS_EResultExpand description
Fetch the selected account ID to the current application for a local authenticated user.
@param LocalUserId The account ID of a currently logged in account. @param OutSelectedAccountId The selected account ID corresponding to the given account ID.
@return EOS_EResult containing the result of the operation. Possible result codes:
- EOS_Success if the user is logged in and the information is available.
- EOS_InvalidParameters if the output parameter is NULL.
- EOS_InvalidUser if the input account ID is not locally known.
- EOS_InvalidAuth if the input account ID is not locally logged in.
- EOS_NotFound otherwise.