pub unsafe extern "C" fn EOS_Auth_Logout(
Handle: EOS_HAuth,
Options: *const EOS_Auth_LogoutOptions,
ClientData: *mut c_void,
CompletionDelegate: EOS_Auth_OnLogoutCallback,
)Expand description
Signs the player out of the online service.
@param Options structure containing information about which account to log out. @param ClientData arbitrary data that is passed back to you in the CompletionDelegate @param CompletionDelegate a callback that is fired when the logout operation completes, either successfully or in error
@see EOS_Auth_LogoutOptions @see EOS_Auth_OnLogoutCallback