pub unsafe extern "C" fn EOS_Auth_QueryIdToken(
Handle: EOS_HAuth,
Options: *const EOS_Auth_QueryIdTokenOptions,
ClientData: *mut c_void,
CompletionDelegate: EOS_Auth_OnQueryIdTokenCallback,
)Expand description
Query the backend for an ID token that describes one of the merged account IDs of a local authenticated user.
The ID token can be used to impersonate a merged account ID when communicating with online services.
An ID token for the selected account ID of a locally authenticated user will always be readily available and does not need to be queried explicitly.
@param Options Structure containing the merged account ID for which to query an ID token. @param ClientData Arbitrary data that is passed back to you in the CompletionDelegate. @param CompletionDelegate A callback that is fired when the operation completes, either successfully or in error.
@see EOS_Auth_QueryIdTokenOptions @see EOS_Auth_OnQueryIdTokenCallback