EOS_Connect_AddNotifyAuthExpiration

Function EOS_Connect_AddNotifyAuthExpiration 

pub unsafe extern "C" fn EOS_Connect_AddNotifyAuthExpiration(
    Handle: EOS_HConnect,
    Options: *const EOS_Connect_AddNotifyAuthExpirationOptions,
    ClientData: *mut c_void,
    Notification: EOS_Connect_OnAuthExpirationCallback,
) -> EOS_NotificationId
Register to receive upcoming authentication expiration notifications. Notification is approximately 1 minute prior to expiration. Call EOS_Connect_Login again with valid third party credentials to refresh access.

@note If the returned NotificationId is valid, you must call EOS_Connect_RemoveNotifyAuthExpiration when you no longer wish to have your NotificationHandler called.

@param Options structure containing the API version of the callback to use. @param ClientData arbitrary data that is passed back to you in the callback. @param Notification a callback that is fired when the authentication is about to expire.

@see EOS_Connect_AddNotifyAuthExpirationOptions @see EOS_Connect_OnAuthExpirationCallback

@return handle representing the registered callback.