pub unsafe extern "C" fn EOS_Connect_CopyIdToken(
Handle: EOS_HConnect,
Options: *const EOS_Connect_CopyIdTokenOptions,
OutIdToken: *mut *mut EOS_Connect_IdToken,
) -> EOS_EResultExpand description
Fetches an ID token for a Product User ID.
@param Options Structure containing information about the ID token to copy. @param OutIdToken The ID token for the given user, if it exists and is valid; use EOS_Connect_IdToken_Release when finished.
@see EOS_Connect_CopyIdTokenOptions @see EOS_Connect_IdToken @see EOS_Connect_IdToken_Release
@return EOS_EResult containing the result of the operation. Possible result codes:
- EOS_Success if the information is available and passed out in OutIdToken.
- EOS_InvalidParameters if you pass a null pointer for the out parameter.
- EOS_NotFound if the ID token is not found or expired.