pub unsafe extern "C" fn EOS_Connect_CopyProductUserExternalAccountByAccountId(
Handle: EOS_HConnect,
Options: *const EOS_Connect_CopyProductUserExternalAccountByAccountIdOptions,
OutExternalAccountInfo: *mut *mut EOS_Connect_ExternalAccountInfo,
) -> EOS_EResultExpand description
Fetch information about an external account linked to a Product User ID. On a successful call, the caller must release the returned structure using the EOS_Connect_ExternalAccountInfo_Release API.
@param Options Structure containing the target external account ID. @param OutExternalAccountInfo The external account info data for the user with given external account ID.
@see EOS_Connect_CopyProductUserExternalAccountByAccountIdOptions @see EOS_Connect_ExternalAccountInfo @see EOS_Connect_ExternalAccountInfo_Release
@return An EOS_EResult that indicates the external account data was copied into the OutExternalAccountInfo.
- EOS_Success if the information is available and passed out in OutExternalAccountInfo.
- EOS_InvalidParameters if you pass a null pointer for the out parameter.
- EOS_NotFound if the account data doesn’t exist or hasn’t been queried yet.