pub unsafe extern "C" fn EOS_Connect_CreateUser(
Handle: EOS_HConnect,
Options: *const EOS_Connect_CreateUserOptions,
ClientData: *mut c_void,
CompletionDelegate: EOS_Connect_OnCreateUserCallback,
)Expand description
Create an account association with the Epic Online Service as a product user given their external auth credentials.
@param Options structure containing a continuance token from a “user not found” response during Login (always try login first). @param ClientData arbitrary data that is passed back to you in the CompletionDelegate. @param CompletionDelegate a callback that is fired when the create operation completes, either successfully or in error.
@see EOS_Connect_CreateUserOptions @see EOS_Connect_OnCreateUserCallback