EOS_Connect_GetExternalAccountMapping

Function EOS_Connect_GetExternalAccountMapping 

pub unsafe extern "C" fn EOS_Connect_GetExternalAccountMapping(
    Handle: EOS_HConnect,
    Options: *const EOS_Connect_GetExternalAccountMappingsOptions,
) -> EOS_ProductUserId
Fetch a Product User ID that maps to an external account ID cached from a previous query.

@param Options structure containing the local user and target external account ID.

@see EOS_Connect_GetExternalAccountMappingsOptions

@return The Product User ID, previously retrieved from the backend service, for the given target external account.