pub unsafe extern "C" fn EOS_Connect_GetProductUserIdMapping(
Handle: EOS_HConnect,
Options: *const EOS_Connect_GetProductUserIdMappingOptions,
OutBuffer: *mut c_char,
InOutBufferLength: *mut i32,
) -> EOS_EResultExpand description
Fetch an external account ID, in string form, that maps to a given Product User ID.
@param Options structure containing the local user and target Product User ID. @param OutBuffer The buffer into which the external account ID data should be written. The buffer must be long enough to hold a string of EOS_CONNECT_EXTERNAL_ACCOUNT_ID_MAX_LENGTH. @param InOutBufferLength The size of the OutBuffer in characters. The input buffer should include enough space to be null-terminated. When the function returns, this parameter will be filled with the length of the string copied into OutBuffer.
@see EOS_Connect_GetProductUserIdMappingOptions
@return An EOS_EResult that indicates the external account ID was copied into the OutBuffer.
- EOS_Success if the information is available and passed out in OutUserInfo.
- EOS_InvalidParameters if you pass a null pointer for the out parameter.
- EOS_NotFound if the mapping doesn’t exist or hasn’t been queried yet.
- EOS_LimitExceeded if the OutBuffer is not large enough to receive the external account ID. InOutBufferLength contains the required minimum length to perform the operation successfully.