pub unsafe extern "C" fn EOS_Connect_VerifyIdToken(
Handle: EOS_HConnect,
Options: *const EOS_Connect_VerifyIdTokenOptions,
ClientData: *mut c_void,
CompletionDelegate: EOS_Connect_OnVerifyIdTokenCallback,
)Expand description
Verify a given ID token for authenticity and validity.
@param Options structure containing information about the ID token to verify. @param ClientData arbitrary data that is passed back to you in the callback. @param CompletionDelegate a callback that is fired when the operation completes, either successfully or in error.
@see EOS_Connect_VerifyIdTokenOptions @see EOS_Connect_OnVerifyIdTokenCallback