pub unsafe extern "C" fn EOS_ENetworkStatus_ToString(
NetworkStatus: EOS_ENetworkStatus,
) -> *const c_charExpand description
Gets the string representation of an EOS_ENetworkStatus value.
Example: EOS_ENetworkStatus_ToString(EOS_ENetworkStatus::EOS_NS_Online) returns “EOS_NS_Online”.
@param NetworkStatus EOS_ENetworkStatus value to get as string.
@return Pointer to a static string representing the input enum value. The returned string is guaranteed to be non-null, and must not be freed by the application.