pub unsafe extern "C" fn EOS_IntegratedPlatform_CreateIntegratedPlatformOptionsContainer(
Options: *const EOS_IntegratedPlatform_CreateIntegratedPlatformOptionsContainerOptions,
OutIntegratedPlatformOptionsContainerHandle: *mut EOS_HIntegratedPlatformOptionsContainer,
) -> EOS_EResultExpand description
Creates an integrated platform options container handle. This handle can used to add multiple options to your container which will then be applied with EOS_Platform_Create. The resulting handle must be released by calling EOS_IntegratedPlatformOptionsContainer_Release once it has been passed to EOS_Platform_Create.
@param Options structure containing operation input parameters. @param OutIntegratedPlatformOptionsContainerHandle Pointer to an integrated platform options container handle to be set if successful. @return Success if we successfully created the integrated platform options container handle pointed at in OutIntegratedPlatformOptionsContainerHandle, or an error result if the input data was invalid.
@see EOS_IntegratedPlatformOptionsContainer_Release @see EOS_Platform_Create @see EOS_IntegratedPlatformOptionsContainer_Add