EOS_LobbyDetails_CopyAttributeByKey

Function EOS_LobbyDetails_CopyAttributeByKey 

pub unsafe extern "C" fn EOS_LobbyDetails_CopyAttributeByKey(
    Handle: EOS_HLobbyDetails,
    Options: *const EOS_LobbyDetails_CopyAttributeByKeyOptions,
    OutAttribute: *mut *mut EOS_Lobby_Attribute,
) -> EOS_EResult
EOS_LobbyDetails_CopyAttributeByKey is used to immediately retrieve a copy of a lobby attribute from a given source such as a existing lobby or a search result. If the call returns an EOS_Success result, the out parameter, OutAttribute, must be passed to EOS_Lobby_Attribute_Release to release the memory associated with it.

@param Options Structure containing the input parameters @param OutAttribute Out parameter used to receive the EOS_Lobby_Attribute structure.

@return EOS_EResult containing the result of the operation. Possible result codes:

  • EOS_Success if the information is available and passed out in OutAttribute
  • EOS_InvalidParameters if you pass a null pointer for the out parameter
  • EOS_IncompatibleVersion if the API version passed in is incorrect

@see EOS_Lobby_Attribute @see EOS_LobbyDetails_CopyAttributeByKeyOptions @see EOS_Lobby_Attribute_Release