EOS_LobbyModification_AddAttribute

Function EOS_LobbyModification_AddAttribute 

pub unsafe extern "C" fn EOS_LobbyModification_AddAttribute(
    Handle: EOS_HLobbyModification,
    Options: *const EOS_LobbyModification_AddAttributeOptions,
) -> EOS_EResult
Associate an attribute with this lobby An attribute is something may be public or private with the lobby. If public, it can be queried for in a search, otherwise the data remains known only to lobby members

@param Options Options to set the attribute and its visibility state

@return EOS_EResult containing the result of the operation. Possible result codes:

  • EOS_Success if setting this parameter was successful
  • EOS_InvalidParameters if the attribute is missing information or otherwise invalid
  • EOS_IncompatibleVersion if the API version passed in is incorrect

@see EOS_LobbyModification_AddAttributeOptions