EOS_LobbyModification_AddMemberAttribute

Function EOS_LobbyModification_AddMemberAttribute 

pub unsafe extern "C" fn EOS_LobbyModification_AddMemberAttribute(
    Handle: EOS_HLobbyModification,
    Options: *const EOS_LobbyModification_AddMemberAttributeOptions,
) -> EOS_EResult
Associate an attribute with a member of the lobby Lobby member data is always private to the lobby

@param Options Options to set the attribute and its visibility state

@return EOS_EResult containing the result of the operation. Possible result codes:

  • EOS_Success if setting this parameter was successful
  • EOS_InvalidParameters if the attribute is missing information or otherwise invalid
  • EOS_IncompatibleVersion if the API version passed in is incorrect

@see EOS_LobbyModification_AddMemberAttributeOptions