pub unsafe extern "C" fn EOS_LobbySearch_GetSearchResultCount(
Handle: EOS_HLobbySearch,
Options: *const EOS_LobbySearch_GetSearchResultCountOptions,
) -> u32Expand description
Get the number of search results found by the search parameters in this search
@param Options Options associated with the search count
@return return the number of search results found by the query or 0 if search is not complete
@see EOS_LobbySearch_GetSearchResultCountOptions