pub unsafe extern "C" fn EOS_LobbySearch_RemoveParameter(
Handle: EOS_HLobbySearch,
Options: *const EOS_LobbySearch_RemoveParameterOptions,
) -> EOS_EResultExpand description
Remove a parameter from the array of search criteria.
@params Options a search parameter key name to remove
@return EOS_EResult containing the result of the operation. Possible result codes:
- EOS_Success if removing this search parameter was successful
- EOS_InvalidParameters if the search key is invalid or null
- EOS_NotFound if the parameter was not a part of the search criteria
- EOS_IncompatibleVersion if the API version passed in is incorrect
@see EOS_LobbySearch_RemoveParameterOptions