pub unsafe extern "C" fn EOS_Lobby_AddNotifyLeaveLobbyRequested(
Handle: EOS_HLobby,
Options: *const EOS_Lobby_AddNotifyLeaveLobbyRequestedOptions,
ClientData: *mut c_void,
NotificationFn: EOS_Lobby_OnLeaveLobbyRequestedCallback,
) -> EOS_NotificationIdExpand description
Register to receive notifications about leave lobby requests performed by the local user via the overlay. When user requests to leave the lobby in the social overlay, the SDK does not automatically leave the lobby, it is up to the game to perform any necessary cleanup and call the EOS_Lobby_LeaveLobby method using the lobbyId sent in the notification function. @note If the returned NotificationId is valid, you must call EOS_Lobby_RemoveNotifyLeaveLobbyRequested when you no longer wish to have your NotificationHandler called.
@param Options Structure containing information about the request. @param ClientData Arbitrary data that is passed back to you in the CompletionDelegate. @param NotificationFn A callback that is fired when a notification is received.
@return handle representing the registered callback
@see EOS_Lobby_AddNotifyLeaveLobbyRequestedOptions @see EOS_Lobby_OnLeaveLobbyRequestedCallback