pub unsafe extern "C" fn EOS_Lobby_AddNotifyLobbyInviteAccepted(
Handle: EOS_HLobby,
Options: *const EOS_Lobby_AddNotifyLobbyInviteAcceptedOptions,
ClientData: *mut c_void,
NotificationFn: EOS_Lobby_OnLobbyInviteAcceptedCallback,
) -> EOS_NotificationIdExpand description
Register to receive notifications about lobby invites accepted by local user via the overlay. @note If the returned NotificationId is valid, you must call EOS_Lobby_RemoveNotifyLobbyInviteAccepted when you no longer wish to have your NotificationHandler called.
@param Options Structure containing information about the request. @param ClientData Arbitrary data that is passed back to you in the CompletionDelegate. @param NotificationFn A callback that is fired when a a notification is received.
@return handle representing the registered callback
@see EOS_Lobby_AddNotifyLobbyInviteAcceptedOptions @see EOS_Lobby_OnLobbyInviteAcceptedCallback