pub unsafe extern "C" fn EOS_Lobby_AddNotifyLobbyMemberStatusReceived(
Handle: EOS_HLobby,
Options: *const EOS_Lobby_AddNotifyLobbyMemberStatusReceivedOptions,
ClientData: *mut c_void,
NotificationFn: EOS_Lobby_OnLobbyMemberStatusReceivedCallback,
) -> EOS_NotificationIdExpand description
Register to receive notifications about the changing status of lobby members. @note If the returned NotificationId is valid, you must call EOS_Lobby_RemoveNotifyLobbyMemberStatusReceived when you no longer wish to have your NotificationHandler called.
@param Options Structure containing information about the request. @param ClientData Arbitrary data that is passed back to you in the CompletionDelegate. @param NotificationFn A callback that is fired when a a notification is received.
@return handle representing the registered callback
@see EOS_Lobby_AddNotifyLobbyMemberStatusReceivedOptions @see EOS_Lobby_OnLobbyMemberStatusReceivedCallback