pub unsafe extern "C" fn EOS_Lobby_CopyLobbyDetailsHandle(
Handle: EOS_HLobby,
Options: *const EOS_Lobby_CopyLobbyDetailsHandleOptions,
OutLobbyDetailsHandle: *mut EOS_HLobbyDetails,
) -> EOS_EResultExpand description
Create a handle to an existing lobby. If the call returns an EOS_Success result, the out parameter, OutLobbyDetailsHandle, must be passed to EOS_LobbyDetails_Release to release the memory associated with it.
@param Options Structure containing information about the lobby to retrieve @param OutLobbyDetailsHandle The new active lobby handle or null if there was an error
@return EOS_EResult containing the result of the operation. Possible result codes:
- EOS_Success if the lobby handle was created successfully
- EOS_InvalidParameters if any of the options are incorrect
- EOS_IncompatibleVersion if the API version passed in is incorrect
- EOS_NotFound if the lobby doesn’t exist
@see EOS_Lobby_CopyLobbyDetailsHandleOptions @see EOS_HLobbyDetails