pub unsafe extern "C" fn EOS_Lobby_CreateLobbySearch(
Handle: EOS_HLobby,
Options: *const EOS_Lobby_CreateLobbySearchOptions,
OutLobbySearchHandle: *mut EOS_HLobbySearch,
) -> EOS_EResultExpand description
Create a lobby search handle. This handle may be modified to include various search parameters. Searching is possible in three methods, all mutually exclusive
- set the lobby ID to find a specific lobby
- set the target user ID to find a specific user
- set lobby parameters to find an array of lobbies that match the search criteria
@param Options Structure containing required parameters such as the maximum number of search results @param OutLobbySearchHandle The new search handle or null if there was an error creating the search handle
@return EOS_EResult containing the result of the operation. Possible result codes:
- EOS_Success if the search creation completes successfully
- EOS_InvalidParameters if any of the options are incorrect
@see EOS_Lobby_CreateLobbySearchOptions @see EOS_HLobbySearch