pub unsafe extern "C" fn EOS_Lobby_DestroyLobby(
Handle: EOS_HLobby,
Options: *const EOS_Lobby_DestroyLobbyOptions,
ClientData: *mut c_void,
CompletionDelegate: EOS_Lobby_OnDestroyLobbyCallback,
)Expand description
Destroy a lobby given a lobby ID
@param Options Structure containing information about the lobby to be destroyed @param ClientData Arbitrary data that is passed back to you in the CompletionDelegate @param CompletionDelegate A callback that is fired when the destroy operation completes, either successfully or in error
@see EOS_Lobby_DestroyLobbyOptions @see EOS_Lobby_OnDestroyLobbyCallback