pub unsafe extern "C" fn EOS_Lobby_GetRTCRoomName(
Handle: EOS_HLobby,
Options: *const EOS_Lobby_GetRTCRoomNameOptions,
OutBuffer: *mut c_char,
InOutBufferLength: *mut u32,
) -> EOS_EResultExpand description
Get the name of the RTC room associated with a specific lobby a local user belongs to.
This value can be used whenever you need a RoomName value in the RTC_* suite of functions. RTC Room Names must not be used with EOS_RTC_JoinRoom, EOS_RTC_LeaveRoom, or EOS_RTC_AddNotifyDisconnected. Doing so will return EOS_AccessDenied or EOS_INVALID_NOTIFICATIONID if used with those functions.
This function will only succeed when called on a lobby the local user is currently a member of.
@param Options Structure containing information about the RTC room name to retrieve @param OutBuffer The buffer to store the null-terminated room name string within @param InOutBufferLength In: The maximum amount of writable chars in OutBuffer, Out: The minimum amount of chars needed in OutBuffer to store the RTC room name (including the null-terminator)
@return EOS_EResult containing the result of the operation. Possible result codes:
- EOS_Success if a room exists for the specified lobby, there was enough space in OutBuffer, and the name was written successfully
- EOS_NotFound if the lobby does not exist
- EOS_Disabled if the lobby exists, but did not have the RTC Room feature enabled when created
- EOS_InvalidParameters if you pass a null pointer on invalid length for any of the parameters
- EOS_LimitExceeded The OutBuffer is not large enough to receive the room name. InOutBufferLength contains the required minimum length to perform the operation successfully.
@see EOS_Lobby_GetRTCRoomNameOptions