pub unsafe extern "C" fn EOS_Lobby_JoinLobbyById(
Handle: EOS_HLobby,
Options: *const EOS_Lobby_JoinLobbyByIdOptions,
ClientData: *mut c_void,
CompletionDelegate: EOS_Lobby_OnJoinLobbyByIdCallback,
)Expand description
This is a special case of EOS_Lobby_JoinLobby. It should only be used if the lobby has had Join-by-ID enabled. Additionally, Join-by-ID should only be enabled to support native invites on an integrated platform.
@param Options Structure containing information about the lobby to be joined @param ClientData Arbitrary data that is passed back to you in the CompletionDelegate @param CompletionDelegate A callback that is fired when the join operation completes, either successfully or in error
@see EOS_Lobby_JoinLobbyByIdOptions @see EOS_Lobby_OnJoinLobbyByIdCallback @see EOS_Lobby_JoinLobby