EOS_Lobby_ParseConnectString

Function EOS_Lobby_ParseConnectString 

pub unsafe extern "C" fn EOS_Lobby_ParseConnectString(
    Handle: EOS_HLobby,
    Options: *const EOS_Lobby_ParseConnectStringOptions,
    OutBuffer: *mut c_char,
    InOutBufferLength: *mut u32,
) -> EOS_EResult
Parse the ConnectString for an EOS lobby invitation to extract just the lobby ID. Used for joining a lobby from a connection string (as generated by GetConnectString) found in a platform invitation or presence.

@param Options Structure containing the input parameters. API version and ConnectString. @param OutBuffer The buffer to store the null-terminated lobby ID within @param InOutBufferLength In: The maximum amount of writable chars in OutBuffer see EOS_LOBBY_PARSECONNECTSTRING_BUFFER_SIZE, Out: The minimum amount of chars needed in OutBuffer to store the LobbyID (including the null-terminator). May be set to zero depending on the error result.

@return EOS_EResult containing the result of the operation. Possible result codes:

  • EOS_Success if retrieving the string was successful.
  • EOS_InvalidParameters if the OutBuffer or InOutBufferLength are null.
  • EOS_IncompatibleVersion if the API version passed in is incorrect.
  • EOS_LimitExceeded if the provided InOutBufferLength is too small to contain the resulting string.

@see EOS_Lobby_ParseConnectStringOptions