pub unsafe extern "C" fn EOS_Lobby_QueryInvites(
Handle: EOS_HLobby,
Options: *const EOS_Lobby_QueryInvitesOptions,
ClientData: *mut c_void,
CompletionDelegate: EOS_Lobby_OnQueryInvitesCallback,
)Expand description
Retrieve all existing invites for a single user
@param Options Structure containing information about the invites to query @param ClientData Arbitrary data that is passed back to you in the CompletionDelegate @param CompletionDelegate A callback that is fired when the query invites operation completes, either successfully or in error
@see EOS_Lobby_QueryInvitesOptions @see EOS_Lobby_OnQueryInvitesCallback