EOS_Lobby_UpdateLobbyModification

Function EOS_Lobby_UpdateLobbyModification 

pub unsafe extern "C" fn EOS_Lobby_UpdateLobbyModification(
    Handle: EOS_HLobby,
    Options: *const EOS_Lobby_UpdateLobbyModificationOptions,
    OutLobbyModificationHandle: *mut EOS_HLobbyModification,
) -> EOS_EResult
Creates a lobby modification handle (EOS_HLobbyModification). The lobby modification handle is used to modify an existing lobby and can be applied with EOS_Lobby_UpdateLobby. The EOS_HLobbyModification must be released by calling EOS_LobbyModification_Release once it is no longer needed.

@param Options Required fields such as lobby ID @param OutLobbyModificationHandle Pointer to a Lobby Modification Handle only set if successful @return EOS_EResult containing the result of the operation. Possible result codes:

  • EOS_Success if we successfully created the Lobby Modification Handle pointed at in OutLobbyModificationHandle, or an error result if the input data was invalid
  • EOS_InvalidParameters if any of the options are incorrect

@see EOS_LobbyModification_Release @see EOS_Lobby_UpdateLobby @see EOS_Lobby_UpdateLobbyModificationOptions @see EOS_HLobbyModification