pub unsafe extern "C" fn EOS_P2P_AddNotifyPeerConnectionClosed(
Handle: EOS_HP2P,
Options: *const EOS_P2P_AddNotifyPeerConnectionClosedOptions,
ClientData: *mut c_void,
ConnectionClosedHandler: EOS_P2P_OnRemoteConnectionClosedCallback,
) -> EOS_NotificationIdExpand description
Listen for when a previously accepted connection that was either open or pending is closed. When a connection closes, packets are flushed. This includes reliable packets.
@param Options Information about who would like notifications about closed connections, and for which socket @param ClientData This value is returned to the caller when ConnectionClosedHandler is invoked @param ConnectionClosedHandler The callback to be fired when an open connection has been closed @return A valid notification ID if successfully bound, or EOS_INVALID_NOTIFICATIONID otherwise
@see EOS_P2P_AddNotifyPeerConnectionClosedOptions @see EOS_P2P_OnRemoteConnectionClosedCallback @see EOS_P2P_AddNotifyPeerConnectionEstablished @see EOS_P2P_AddNotifyPeerConnectionInterrupted @see EOS_P2P_RemoveNotifyPeerConnectionClosed