pub unsafe extern "C" fn EOS_P2P_CloseConnections(
Handle: EOS_HP2P,
Options: *const EOS_P2P_CloseConnectionsOptions,
) -> EOS_EResultExpand description
Close any open Connections for a specific Peer Connection ID.
@param Options Information about who would like to close connections, and by what socket ID @return EOS_EResult containing the result of the operation. Possible result codes:
- EOS_Success - if the provided data is valid
- EOS_InvalidParameters - if the provided data is invalid
@see EOS_P2P_CloseConnectionsOptions