EOS_P2P_GetNextReceivedPacketSize

Function EOS_P2P_GetNextReceivedPacketSize 

pub unsafe extern "C" fn EOS_P2P_GetNextReceivedPacketSize(
    Handle: EOS_HP2P,
    Options: *const EOS_P2P_GetNextReceivedPacketSizeOptions,
    OutPacketSizeBytes: *mut u32,
) -> EOS_EResult
Gets the size of the packet that will be returned by ReceivePacket for a particular user, if there is any available packets to be retrieved.

@param Options Information about who is requesting the size of their next packet @param OutPacketSizeBytes The amount of bytes required to store the data of the next packet for the requested user @return EOS_EResult containing the result of the operation. Possible result codes:

  • EOS_Success - If OutPacketSizeBytes was successfully set and there is data to be received
  • EOS_InvalidParameters - If input was invalid
  • EOS_NotFound - If there are no packets available for the requesting user

@see EOS_P2P_GetNextReceivedPacketSizeOptions