pub unsafe extern "C" fn EOS_P2P_GetPortRange(
Handle: EOS_HP2P,
Options: *const EOS_P2P_GetPortRangeOptions,
OutPort: *mut u16,
OutNumAdditionalPortsToTry: *mut u16,
) -> EOS_EResultExpand description
Get the current chosen port and the amount of other ports to try above the chosen port if the chosen port is unavailable.
@param Options Information about what version of the EOS_P2P_GetPortRange API is supported @param OutPort The port that will be tried first @param OutNumAdditionalPortsToTry The amount of ports to try above the value in OutPort, if OutPort is unavailable @return EOS_EResult containing the result of the operation. Possible result codes:
- EOS_Success - if the input options were valid
- EOS_InvalidParameters - if the input was invalid in some way
@see EOS_P2P_GetPortRangeOptions