pub unsafe extern "C" fn EOS_P2P_SetRelayControl(
Handle: EOS_HP2P,
Options: *const EOS_P2P_SetRelayControlOptions,
) -> EOS_EResultExpand description
Set how relay servers are to be used. This setting does not immediately apply to existing connections, but may apply to existing connections if the connection requires renegotiation.
@param Options Information about relay server config options @return EOS_EResult containing the result of the operation. Possible result codes:
- EOS_Success - if the options were set successfully
- EOS_InvalidParameters - if the options are invalid in some way
@see EOS_P2P_SetRelayControlOptions @see EOS_ERelayControl