pub unsafe extern "C" fn EOS_Platform_GetOverrideCountryCode(
Handle: EOS_HPlatform,
OutBuffer: *mut c_char,
InOutBufferLength: *mut i32,
) -> EOS_EResultExpand description
Get the override country code that the SDK will send to services which require it. This is not currently used for anything internally.
@param OutBuffer The buffer into which the character data should be written. The buffer must be long enough to hold a string of EOS_COUNTRYCODE_MAX_LENGTH. @param InOutBufferLength The size of the OutBuffer in characters. The input buffer should include enough space to be null-terminated. When the function returns, this parameter will be filled with the length of the string copied into OutBuffer.
@return An EOS_EResult that indicates whether the override country code string was copied into the OutBuffer.
- EOS_Success if the information is available and passed out in OutBuffer
- EOS_InvalidParameters if you pass a null pointer for the out parameter
- EOS_LimitExceeded - The OutBuffer is not large enough to receive the country code string. InOutBufferLength contains the required minimum length to perform the operation successfully.
@see eos_ecom.h @see EOS_COUNTRYCODE_MAX_LENGTH