pub unsafe extern "C" fn EOS_Platform_Release(Handle: EOS_HPlatform)Expand description
Release an Epic Online Services platform instance previously returned from EOS_Platform_Create.
This function should only be called once per instance returned by EOS_Platform_Create. Undefined behavior will result in calling it with a single instance more than once. Typically only a single platform instance needs to be created during the lifetime of a game. You should release each platform instance before calling the EOS_Shutdown function.