pub unsafe extern "C" fn EOS_PresenceModification_Release(
PresenceModificationHandle: EOS_HPresenceModification,
)Expand description
Release the memory associated with an EOS_HPresenceModification handle. This must be called on Handles retrieved from EOS_Presence_CreatePresenceModification. This can be safely called on a NULL presence modification handle. This also may be safely called while a call to SetPresence is still pending.
@param PresenceModificationHandle The presence modification handle to release
@see EOS_Presence_CreatePresenceModification