pub unsafe extern "C" fn EOS_ProductUserId_FromString(
ProductUserIdString: *const c_char,
) -> EOS_ProductUserIdExpand description
Retrieve an EOS_ProductUserId from a raw string representing an Epic Online Services Product User ID. The input string must be null-terminated. NOTE: There is no validation on the string format, this should only be used with values serialized from legitimate sources such as EOS_ProductUserId_ToString
@param ProductUserIdString The stringified product user ID for which to retrieve the Epic Online Services Product User ID @return The EOS_ProductUserId that corresponds to the ProductUserIdString