#[repr(C)]pub struct _tagEOS_Achievements_DefinitionV2 {
pub ApiVersion: i32,
pub AchievementId: *const c_char,
pub UnlockedDisplayName: *const c_char,
pub UnlockedDescription: *const c_char,
pub LockedDisplayName: *const c_char,
pub LockedDescription: *const c_char,
pub FlavorText: *const c_char,
pub UnlockedIconURL: *const c_char,
pub LockedIconURL: *const c_char,
pub bIsHidden: EOS_Bool,
pub StatThresholdsCount: u32,
pub StatThresholds: *const EOS_Achievements_StatThresholds,
}Expand description
Contains information about a single achievement definition with localized text.
Fields
ApiVersion: i32API Version: Set this to EOS_ACHIEVEMENTS_DEFINITIONV2_API_LATEST.
AchievementId: *const c_charAchievement ID that can be used to uniquely identify the achievement.
UnlockedDisplayName: *const c_charLocalized display name for the achievement when it has been unlocked.
UnlockedDescription: *const c_charLocalized description for the achievement when it has been unlocked.
LockedDisplayName: *const c_charLocalized display name for the achievement when it is locked or hidden.
LockedDescription: *const c_charLocalized description for the achievement when it is locked or hidden.
FlavorText: *const c_charLocalized flavor text that can be used by the game in an arbitrary manner. This may be null if there is no data configured in the dev portal.
UnlockedIconURL: *const c_charURL of an icon to display for the achievement when it is unlocked. This may be null if there is no data configured in the dev portal.
LockedIconURL: *const c_charURL of an icon to display for the achievement when it is locked or hidden. This may be null if there is no data configured in the dev portal.
bIsHidden: EOS_BoolEOS_TRUE if the achievement is hidden; EOS_FALSE otherwise.
StatThresholdsCount: u32The number of stat thresholds used to monitor progress towards this achievement.
StatThresholds: *const EOS_Achievements_StatThresholdsArray of EOS_Achievements_StatThresholds that need to be satisfied to unlock this achievement. Consists of Name and Threshold Value.