#[repr(C)]pub struct _tagEOS_AntiCheatCommon_LogPlayerTakeDamageOptions {Show 20 fields
pub ApiVersion: i32,
pub VictimPlayerHandle: EOS_AntiCheatCommon_ClientHandle,
pub VictimPlayerPosition: *mut EOS_AntiCheatCommon_Vec3f,
pub VictimPlayerViewRotation: *mut EOS_AntiCheatCommon_Quat,
pub AttackerPlayerHandle: EOS_AntiCheatCommon_ClientHandle,
pub AttackerPlayerPosition: *mut EOS_AntiCheatCommon_Vec3f,
pub AttackerPlayerViewRotation: *mut EOS_AntiCheatCommon_Quat,
pub bIsHitscanAttack: EOS_Bool,
pub bHasLineOfSight: EOS_Bool,
pub bIsCriticalHit: EOS_Bool,
pub HitBoneId_DEPRECATED: u32,
pub DamageTaken: f32,
pub HealthRemaining: f32,
pub DamageSource: EOS_EAntiCheatCommonPlayerTakeDamageSource,
pub DamageType: EOS_EAntiCheatCommonPlayerTakeDamageType,
pub DamageResult: EOS_EAntiCheatCommonPlayerTakeDamageResult,
pub PlayerUseWeaponData: *mut EOS_AntiCheatCommon_LogPlayerUseWeaponData,
pub TimeSincePlayerUseWeaponMs: u32,
pub DamagePosition: *mut EOS_AntiCheatCommon_Vec3f,
pub AttackerPlayerViewPosition: *mut EOS_AntiCheatCommon_Vec3f,
}Expand description
Input parameters for the EOS_AntiCheatServer_LogPlayerTakeDamage function.
Fields
ApiVersion: i32API Version: Set this to EOS_ANTICHEATCOMMON_LOGPLAYERTAKEDAMAGE_API_LATEST.
VictimPlayerHandle: EOS_AntiCheatCommon_ClientHandleLocally unique value used in RegisterClient/RegisterPeer
VictimPlayerPosition: *mut EOS_AntiCheatCommon_Vec3fVictim player character’s world position as a 3D vector. This should be the center of the character.
VictimPlayerViewRotation: *mut EOS_AntiCheatCommon_QuatVictim player camera’s world rotation as a quaternion.
AttackerPlayerHandle: EOS_AntiCheatCommon_ClientHandleLocally unique value used in RegisterClient/RegisterPeer if applicable, otherwise 0.
AttackerPlayerPosition: *mut EOS_AntiCheatCommon_Vec3fAttacker player character’s world position as a 3D vector if applicable, otherwise NULL.
AttackerPlayerViewRotation: *mut EOS_AntiCheatCommon_QuatAttacker player camera’s world rotation as a quaternion if applicable, otherwise NULL.
bIsHitscanAttack: EOS_BoolTrue if the damage was applied instantly at the time of attack from the game simulation’s perspective, otherwise false (simulated ballistics, arrow, etc).
bHasLineOfSight: EOS_BoolTrue if there is a visible line of sight between the attacker and the victim at the time that damage is being applied, false if there is an obstacle like a wall or terrain in the way. For some situations like melee or hitscan weapons this is trivially true, for others like projectiles with simulated physics it may not be e.g. a player could fire a slow moving projectile and then move behind cover before it strikes.
This can be an estimate, or can simply be always set to true if it is not feasible to compute in your game.
bIsCriticalHit: EOS_BoolTrue if this was a critical hit that causes extra damage (e.g. headshot)
HitBoneId_DEPRECATED: u32Deprecated - use DamagePosition instead
DamageTaken: f32Number of health points that the victim lost due to this damage event
HealthRemaining: f32Number of health points that the victim has remaining after this damage event
DamageSource: EOS_EAntiCheatCommonPlayerTakeDamageSourceSource of the damage event
DamageType: EOS_EAntiCheatCommonPlayerTakeDamageTypeType of the damage being applied
DamageResult: EOS_EAntiCheatCommonPlayerTakeDamageResultResult of the damage for the victim, if any
PlayerUseWeaponData: *mut EOS_AntiCheatCommon_LogPlayerUseWeaponDataPlayerUseWeaponData associated with this damage event if available, otherwise NULL
TimeSincePlayerUseWeaponMs: u32Time in milliseconds since the associated PlayerUseWeaponData event occurred if available, otherwise 0
DamagePosition: *mut EOS_AntiCheatCommon_Vec3fWorld position where damage hit the victim as a 3D vector if available, otherwise NULL
AttackerPlayerViewPosition: *mut EOS_AntiCheatCommon_Vec3fAttacker player camera’s world position as a 3D vector if applicable, otherwise NULL