_tagEOS_AntiCheatServer_RegisterClientOptions

Struct _tagEOS_AntiCheatServer_RegisterClientOptions 

#[repr(C)]
pub struct _tagEOS_AntiCheatServer_RegisterClientOptions { pub ApiVersion: i32, pub ClientHandle: EOS_AntiCheatCommon_ClientHandle, pub ClientType: EOS_EAntiCheatCommonClientType, pub ClientPlatform: EOS_EAntiCheatCommonClientPlatform, pub AccountId_DEPRECATED: *const c_char, pub IpAddress: *const c_char, pub UserId: EOS_ProductUserId, pub Reserved01: i32, }
Input parameters for the EOS_AntiCheatServer_RegisterClient function.

Fields

ApiVersion: i32

API Version: Set this to EOS_ANTICHEATSERVER_REGISTERCLIENT_API_LATEST.

ClientHandle: EOS_AntiCheatCommon_ClientHandle

Locally unique value describing the remote user (e.g. a player object pointer)

ClientType: EOS_EAntiCheatCommonClientType

Type of remote user being registered

ClientPlatform: EOS_EAntiCheatCommonClientPlatform

Remote user’s platform, if known

AccountId_DEPRECATED: *const c_char

DEPRECATED - New code should set this to null and specify UserId instead.

Identifier for the remote user. This is typically a string representation of an account ID, but it can be any string which is both unique (two different users will never have the same string) and consistent (if the same user connects to this game session twice, the same string will be used) in the scope of a single protected game session.

IpAddress: *const c_char

Optional IP address for the remote user. May be null if not available. IPv4 format: “0.0.0.0” IPv6 format: “0:0:0:0:0:0:0:0”

UserId: EOS_ProductUserId

The Product User ID for the remote user who is being registered.

Reserved01: i32

Reserved for future use. Must be set to 0.