#[repr(C)]pub struct _tagEOS_Connect_TransferDeviceIdAccountOptions {
pub ApiVersion: i32,
pub PrimaryLocalUserId: EOS_ProductUserId,
pub LocalDeviceUserId: EOS_ProductUserId,
pub ProductUserIdToPreserve: EOS_ProductUserId,
}Expand description
Input parameters for the EOS_Connect_TransferDeviceIdAccount Function.
Fields
ApiVersion: i32API Version: Set this to EOS_CONNECT_TRANSFERDEVICEIDACCOUNT_API_LATEST.
PrimaryLocalUserId: EOS_ProductUserIdThe primary product user id, currently logged in, that is already associated with a real external user account (such as Epic Games, PlayStation(TM)Network, Xbox Live and other).
The account linking keychain that owns this product user will be preserved and receive the Device ID login credentials under it.
LocalDeviceUserId: EOS_ProductUserIdThe product user id, currently logged in, that has been originally created using the anonymous local Device ID login type, and whose Device ID login will be transferred to the keychain of the PrimaryLocalUserId.
ProductUserIdToPreserve: EOS_ProductUserIdSpecifies which EOS_ProductUserId (i.e. game progression) will be preserved in the operation.
After a successful transfer operation, subsequent logins using the same external account or the same local Device ID login will return user session for the ProductUserIdToPreserve.
Set to either PrimaryLocalUserId or LocalDeviceUserId.