#[repr(C)]pub struct _tagEOS_Connect_UnlinkAccountCallbackInfo {
pub ResultCode: EOS_EResult,
pub ClientData: *mut c_void,
pub LocalUserId: EOS_ProductUserId,
}Expand description
Output parameters for the EOS_Connect_UnlinkAccount Function.
Fields
ResultCode: EOS_EResultThe EOS_EResult code for the operation. EOS_Success indicates that the operation succeeded; other codes indicate errors.
ClientData: *mut c_voidContext that was passed into EOS_Connect_UnlinkAccount.
LocalUserId: EOS_ProductUserIdThe product user that was subject for the unlinking operation.
On a successful operation, the local authentication session for the product user will have been invalidated. As such, the LocalUserId value will no longer be valid in any context unless the user is logged into it again.