#[repr(C)]pub struct _tagEOS_Connect_VerifyIdTokenCallbackInfo {
pub ResultCode: EOS_EResult,
pub ClientData: *mut c_void,
pub ProductUserId: EOS_ProductUserId,
pub bIsAccountInfoPresent: EOS_Bool,
pub AccountIdType: EOS_EExternalAccountType,
pub AccountId: *const c_char,
pub Platform: *const c_char,
pub DeviceType: *const c_char,
pub ClientId: *const c_char,
pub ProductId: *const c_char,
pub SandboxId: *const c_char,
pub DeploymentId: *const c_char,
}Expand description
Output parameters for the EOS_Connect_VerifyIdToken Function.
Fields
ResultCode: EOS_EResultThe EOS_EResult code for the operation. EOS_Success indicates that the operation succeeded; other codes indicate errors.
ClientData: *mut c_voidContext that was passed into EOS_Connect_VerifyIdToken
ProductUserId: EOS_ProductUserIdThe Product User ID associated with the ID token.
bIsAccountInfoPresent: EOS_BoolFlag set to indicate whether account information is available. Applications must always first check this value to be set before attempting to read the AccountType, AccountId, Platform and DeviceType fields.
This flag is always false for users that authenticated using EOS Connect Device ID.
AccountIdType: EOS_EExternalAccountTypeThe identity provider that the user authenticated with to EOS Connect.
If bIsAccountInfoPresent is set, this field describes the external account type.
AccountId: *const c_charThe external account ID of the authenticated user.
This value may be set to an empty string.
Platform: *const c_charPlatform that the user is connected from.
This value may be set to an empty string.
DeviceType: *const c_charIdentifies the device type that the user is connected from. Can be used to securely verify that the user is connected through a real Console device.
This value may be set to an empty string.
ClientId: *const c_charClient ID of the authorized client.
ProductId: *const c_charProduct ID.
SandboxId: *const c_charSandbox ID.
DeploymentId: *const c_charDeployment ID.