#[repr(C)]pub struct _tagEOS_CustomInvites_SendCustomNativeInviteRequestedCallbackInfo {
pub ClientData: *mut c_void,
pub UiEventId: EOS_UI_EventId,
pub LocalUserId: EOS_ProductUserId,
pub TargetNativeAccountType: EOS_IntegratedPlatformType,
pub TargetUserNativeAccountId: *const c_char,
pub InviteId: *const c_char,
}Expand description
Output parameters for the EOS_CustomInvites_OnSendCustomNativeInviteRequestedCallback Function.
Fields
ClientData: *mut c_voidContext that was passed into EOS_CustomInvites_AddNotifySendCustomNativeInviteRequested
UiEventId: EOS_UI_EventIdIdentifies this event which will need to be acknowledged with EOS_UI_AcknowledgeEventId(). @see EOS_UI_AcknowledgeEventId
LocalUserId: EOS_ProductUserIdThe Product User ID of the local user who is inviting.
TargetNativeAccountType: EOS_IntegratedPlatformTypeThe Native Platform Account Type. If only a single integrated platform is configured then this will always reference that platform.
TargetUserNativeAccountId: *const c_charThe Native Platform Account ID of the target user being invited.
InviteId: *const c_charInvite ID that the user is being invited to