_tagEOS_Ecom_CheckoutOptions

Struct _tagEOS_Ecom_CheckoutOptions 

#[repr(C)]
pub struct _tagEOS_Ecom_CheckoutOptions { pub ApiVersion: i32, pub LocalUserId: EOS_EpicAccountId, pub OverrideCatalogNamespace: *const c_char, pub EntryCount: u32, pub Entries: *const EOS_Ecom_CheckoutEntry, pub PreferredOrientation: EOS_ECheckoutOrientation, }
Input parameters for the EOS_Ecom_Checkout function.

Fields

ApiVersion: i32

API Version: Set this to EOS_ECOM_CHECKOUT_API_LATEST.

LocalUserId: EOS_EpicAccountId

The Epic Account ID of the local user who is making the purchase

OverrideCatalogNamespace: *const c_char

The catalog namespace will be the current Sandbox ID (in EOS_Platform_Options) unless overridden by this field

EntryCount: u32

The number of EOS_Ecom_CheckoutEntry elements contained in Entries

Entries: *const EOS_Ecom_CheckoutEntry

An array of EOS_Ecom_CheckoutEntry elements, each containing the details of a single offer

PreferredOrientation: EOS_ECheckoutOrientation

Preferred device orientation, specifies Default, Portrait or Landscape. This is used only on mobile platforms currently. SDK can use it to optimize how the Checkout page should be displayed. Please check the mobile SDK documentation for additional required setup.