#[repr(C)]pub struct _tagEOS_Initialize_ThreadAffinity {
pub ApiVersion: i32,
pub NetworkWork: u64,
pub StorageIo: u64,
pub WebSocketIo: u64,
pub P2PIo: u64,
pub HttpRequestIo: u64,
pub RTCIo: u64,
pub EmbeddedOverlayMainThread: u64,
pub EmbeddedOverlayWorkerThreads: u64,
pub CryptographyWork: u64,
}Expand description
Options for initializing defining thread affinity for use by Epic Online Services SDK. Set the affinity to 0 to allow EOS SDK to use a platform specific default value.
Fields
ApiVersion: i32API Version: Set this to EOS_INITIALIZE_THREADAFFINITY_API_LATEST.
NetworkWork: u64Any thread related to network management that is not IO.
StorageIo: u64Any thread that will interact with a storage device.
WebSocketIo: u64Any thread that will generate web socket IO.
P2PIo: u64Any thread that will generate IO related to P2P traffic and management.
HttpRequestIo: u64Any thread that will generate http request IO.
RTCIo: u64Any thread that will generate IO related to RTC traffic and management.
EmbeddedOverlayMainThread: u64Main thread of the external overlay
EmbeddedOverlayWorkerThreads: u64Worker threads of the external overlay
CryptographyWork: u64Any thread that process cryptography work