_tagEOS_P2P_PacketQueueInfo

Struct _tagEOS_P2P_PacketQueueInfo 

#[repr(C)]
pub struct _tagEOS_P2P_PacketQueueInfo { pub IncomingPacketQueueMaxSizeBytes: u64, pub IncomingPacketQueueCurrentSizeBytes: u64, pub IncomingPacketQueueCurrentPacketCount: u64, pub OutgoingPacketQueueMaxSizeBytes: u64, pub OutgoingPacketQueueCurrentSizeBytes: u64, pub OutgoingPacketQueueCurrentPacketCount: u64, }
Information related to the current state of the packet queues. It is possible for the current size to be larger than the maximum size if the maximum size changes or if the maximum queue size is set to EOS_P2P_MAX_QUEUE_SIZE_UNLIMITED.

Fields

IncomingPacketQueueMaxSizeBytes: u64

The maximum size in bytes of the incoming packet queue

IncomingPacketQueueCurrentSizeBytes: u64

The current size in bytes of the incoming packet queue

IncomingPacketQueueCurrentPacketCount: u64

The current number of queued packets in the incoming packet queue

OutgoingPacketQueueMaxSizeBytes: u64

The maximum size in bytes of the outgoing packet queue

OutgoingPacketQueueCurrentSizeBytes: u64

The current size in bytes of the outgoing packet queue

OutgoingPacketQueueCurrentPacketCount: u64

The current amount of queued packets in the outgoing packet queue