#[repr(C)]pub struct _tagEOS_P2P_SendPacketOptions {
pub ApiVersion: i32,
pub LocalUserId: EOS_ProductUserId,
pub RemoteUserId: EOS_ProductUserId,
pub SocketId: *const EOS_P2P_SocketId,
pub Channel: u8,
pub DataLengthBytes: u32,
pub Data: *const c_void,
pub bAllowDelayedDelivery: EOS_Bool,
pub Reliability: EOS_EPacketReliability,
pub bDisableAutoAcceptConnection: EOS_Bool,
}Expand description
Structure containing information about the data being sent and to which player
Fields
ApiVersion: i32API Version: Set this to EOS_P2P_SENDPACKET_API_LATEST.
LocalUserId: EOS_ProductUserIdThe Product User ID of the local user who is sending this packet
RemoteUserId: EOS_ProductUserIdThe Product User ID of the Peer you would like to send a packet to
SocketId: *const EOS_P2P_SocketIdThe socket ID for data you are sending in this packet
Channel: u8Channel associated with this data
DataLengthBytes: u32The size of the data to be sent to the RemoteUser
Data: *const c_voidThe data to be sent to the RemoteUser
bAllowDelayedDelivery: EOS_BoolIf false and we do not already have an established connection to the peer, this data will be dropped
Reliability: EOS_EPacketReliabilitySets the reliability of the delivery of this packet. The reliability can be EOS_PR_UnreliableUnordered, EOS_PR_ReliableUnordered, or EOS_PR_ReliableOrdered.
bDisableAutoAcceptConnection: EOS_BoolIf set to EOS_TRUE, EOS_P2P_SendPacket will not automatically establish a connection with the RemoteUserId and will require explicit calls to EOS_P2P_AcceptConnection first whenever the connection is closed. If set to EOS_FALSE, EOS_P2P_SendPacket will automatically accept and start the connection any time it is called and the connection is not already open.