#[repr(C)]pub struct _tagEOS_RTC_JoinRoomOptions {
pub ApiVersion: i32,
pub LocalUserId: EOS_ProductUserId,
pub RoomName: *const c_char,
pub ClientBaseUrl: *const c_char,
pub ParticipantToken: *const c_char,
pub ParticipantId: EOS_ProductUserId,
pub Flags: u32,
pub bManualAudioInputEnabled: EOS_Bool,
pub bManualAudioOutputEnabled: EOS_Bool,
}Expand description
This struct is used to call EOS_RTC_JoinRoom.
Fields
ApiVersion: i32API Version: Set this to EOS_RTC_JOINROOM_API_LATEST.
LocalUserId: EOS_ProductUserIdThe product user id of the user trying to request this operation.
RoomName: *const c_charThe room the user would like to join.
ClientBaseUrl: *const c_charThe room the user would like to join.
ParticipantToken: *const c_charAuthorization credential token to join the room.
ParticipantId: EOS_ProductUserIdThe participant id used to join the room. If set to NULL the LocalUserId will be used instead.
Flags: u32Join room flags, e.g. EOS_RTC_JOINROOMFLAGS_ENABLE_ECHO. This is a bitwise-or union of the defined flags.
bManualAudioInputEnabled: EOS_BoolEnable or disable Manual Audio Input. If manual audio input is enabled audio recording is not started and the audio buffers must be passed manually using EOS_RTCAudio_SendAudio.
bManualAudioOutputEnabled: EOS_BoolEnable or disable Manual Audio Output. If manual audio output is enabled audio rendering is not started and the audio buffers must be received with EOS_RTCAudio_AddNotifyAudioBeforeRender and rendered manually.