#[repr(C)]pub struct _tagEOS_RTC_ParticipantStatusChangedCallbackInfo {
pub ClientData: *mut c_void,
pub LocalUserId: EOS_ProductUserId,
pub RoomName: *const c_char,
pub ParticipantId: EOS_ProductUserId,
pub ParticipantStatus: EOS_ERTCParticipantStatus,
pub ParticipantMetadataCount: u32,
pub ParticipantMetadata: *const EOS_RTC_ParticipantMetadata,
pub bParticipantInBlocklist: EOS_Bool,
}Expand description
This struct is passed in with a call to EOS_RTC_AddNotifyParticipantStatusChanged registered event.
Fields
ClientData: *mut c_voidClient-specified data passed into EOS_RTC_AddNotifyParticipantStatusChanged.
LocalUserId: EOS_ProductUserIdThe Product User ID of the user who initiated this request.
RoomName: *const c_charThe room associated with this event.
ParticipantId: EOS_ProductUserIdThe participant whose status changed.
ParticipantStatus: EOS_ERTCParticipantStatusWhat status change occurred
ParticipantMetadataCount: u32The participant metadata items count. This is only set for the first notification where ParticipantStatus is EOS_RTCPS_Joined. Subsequent notifications such as when bParticipantInBlocklist changes will not contain any metadata.
ParticipantMetadata: *const EOS_RTC_ParticipantMetadataThe participant metadata items. This is only set for the first notification where ParticipantStatus is EOS_RTCPS_Joined. Subsequent notifications such as when bParticipantInBlocklist changes will not contain any metadata.
bParticipantInBlocklist: EOS_BoolThe participant’s block list status, if ParticipantStatus is EOS_RTCPS_Joined. This is set to true if the participant is in any of the local user’s applicable block lists, such Epic block list or any of the current platform’s block lists. It can be used to detect when an internal automatic RTC block is applied because of trust and safety restrictions.