#[repr(C)]pub struct _tagEOS_SessionDetails_Settings {
pub ApiVersion: i32,
pub BucketId: *const c_char,
pub NumPublicConnections: u32,
pub bAllowJoinInProgress: EOS_Bool,
pub PermissionLevel: EOS_EOnlineSessionPermissionLevel,
pub bInvitesAllowed: EOS_Bool,
pub bSanctionsEnabled: EOS_Bool,
pub AllowedPlatformIds: *const u32,
pub AllowedPlatformIdsCount: u32,
}Expand description
Common settings associated with a single session
Fields
ApiVersion: i32API Version: Set this to EOS_SESSIONDETAILS_SETTINGS_API_LATEST.
BucketId: *const c_charThe main indexed parameter for this session, can be any string (i.e. “Region:GameMode”)
NumPublicConnections: u32Number of total players allowed in the session
bAllowJoinInProgress: EOS_BoolAre players allowed to join the session while it is in the “in progress” state
PermissionLevel: EOS_EOnlineSessionPermissionLevelPermission level describing allowed access to the session when joining or searching for the session
bInvitesAllowed: EOS_BoolAre players allowed to send invites for the session
bSanctionsEnabled: EOS_BoolAre sanctioned players allowed to join - sanctioned players will be rejected if set to true
AllowedPlatformIds: *const u32Array of platform IDs indicating the player platforms allowed to register with the session. Platform IDs are found in the EOS header file, e.g. EOS_OPT_Epic. For some platforms, the value will be in the EOS Platform specific header file. If null, the session will be unrestricted.
AllowedPlatformIdsCount: u32Number of platform IDs in the array