#[repr(C)]pub struct _tagEOS_Sessions_CreateSessionModificationOptions {
pub ApiVersion: i32,
pub SessionName: *const c_char,
pub BucketId: *const c_char,
pub MaxPlayers: u32,
pub LocalUserId: EOS_ProductUserId,
pub bPresenceEnabled: EOS_Bool,
pub SessionId: *const c_char,
pub bSanctionsEnabled: EOS_Bool,
pub AllowedPlatformIds: *const u32,
pub AllowedPlatformIdsCount: u32,
}Expand description
Input parameters for the EOS_Sessions_CreateSessionModification function.
Fields
ApiVersion: i32API Version: Set this to EOS_SESSIONS_CREATESESSIONMODIFICATION_API_LATEST.
SessionName: *const c_charName of the session to create
BucketId: *const c_charBucket ID associated with the session
MaxPlayers: u32Maximum number of players allowed in the session
LocalUserId: EOS_ProductUserIdThe Product User ID of the local user associated with the session
bPresenceEnabled: EOS_BoolDetermines whether or not this session should be the one associated with the local user’s presence information. If true, this session will be associated with presence. Only one session at a time can have this flag true. This affects the ability of the Social Overlay to show game related actions to take in the user’s social graph.
@note The Social Overlay can handle only one of the following three options at a time:
- using the bPresenceEnabled flags within the Sessions interface
- using the bPresenceEnabled flags within the Lobby interface
- using EOS_PresenceModification_SetJoinInfo
@see EOS_PresenceModification_SetJoinInfoOptions @see EOS_Lobby_CreateLobbyOptions @see EOS_Lobby_JoinLobbyOptions @see EOS_Sessions_JoinSessionOptions
SessionId: *const c_charOptional session id - set to a globally unique value to override the backend assignment If not specified the backend service will assign one to the session. Do not mix and match. This value can be of size [EOS_SESSIONMODIFICATION_MIN_SESSIONIDOVERRIDE_LENGTH, EOS_SESSIONMODIFICATION_MAX_SESSIONIDOVERRIDE_LENGTH]
bSanctionsEnabled: EOS_BoolIf true, sanctioned players can neither join nor register with this session and, in the case of join, will return EOS_EResult code EOS_Sessions_PlayerSanctioned
AllowedPlatformIds: *const u32Array of platform IDs indicating the player platforms allowed to register with the session. Platform IDs are found in the EOS header file (eos_common.h), for example EOS_OPT_Epic. For some platforms the value will be in the EOS Platform specific header file. If null, the session will be unrestricted.
AllowedPlatformIdsCount: u32Number of platform IDs in the array