#[repr(C)]pub struct _tagEOS_Stats_IngestStatCompleteCallbackInfo {
pub ResultCode: EOS_EResult,
pub ClientData: *mut c_void,
pub LocalUserId: EOS_ProductUserId,
pub TargetUserId: EOS_ProductUserId,
}Expand description
Data containing the result information for an ingest stat request.
NOTE: A result code of EOS_Success indicates the ingest request reached the server successfully, but does not guarantee successful processing. For example, if an incorrect StatName value is provided in the ingest call, processing may still fail.
Fields
ResultCode: EOS_EResultResult code for the operation. EOS_Success is returned for a successful request, other codes indicate an error.
ClientData: *mut c_voidContext that was passed into EOS_Stats_IngestStat.
LocalUserId: EOS_ProductUserIdThe Product User ID for the user requesting the ingest
TargetUserId: EOS_ProductUserIdThe Product User ID for the user whose stat is being ingested