#[repr(C)]pub struct _tagEOS_UI_ConfigureOnScreenKeyboardOptions {
pub ApiVersion: i32,
pub Behavior: EOS_UI_EOnScreenKeyboardBehavior,
pub bIsDeviceChecksEnabled: EOS_Bool,
}Expand description
Input parameters for the EOS_UI_ConfigureOnScreenKeyboard function.
Fields
ApiVersion: i32API Version: Set this to EOS_UI_CONFIGUREONSCREENKEYBOARD_API_LATEST.
Behavior: EOS_UI_EOnScreenKeyboardBehaviorThe behavior of the on screen keyboard.
bIsDeviceChecksEnabled: EOS_BoolWhether to enable device checks. When enabled, the overlay will use a number of heuristics based on the device’s configuration to determine whether an on screen keyboard should be requested. When disabled, on screen keyboards will always be requested regardless of device configuration. Note, by setting environment variable “EOS_OVERLAY_OSK” to 0, on screen keyboard requests will always fail, and by setting it to 1, device checks will always succeed.