pub type EOS_Achievements_Definition = _tagEOS_Achievements_Definition;Expand description
Contains information about a single achievement definition with localized text.
Aliased Type
#[repr(C)]pub struct EOS_Achievements_Definition {Show 13 fields
pub ApiVersion: i32,
pub AchievementId: *const u8,
pub DisplayName: *const u8,
pub Description: *const u8,
pub LockedDisplayName: *const u8,
pub LockedDescription: *const u8,
pub HiddenDescription: *const u8,
pub CompletionDescription: *const u8,
pub UnlockedIconId: *const u8,
pub LockedIconId: *const u8,
pub bIsHidden: i32,
pub StatThresholdsCount: i32,
pub StatThresholds: *const _tagEOS_Achievements_StatThresholds,
}Fields
ApiVersion: i32API Version: Set this to EOS_ACHIEVEMENTS_DEFINITION_API_LATEST.
AchievementId: *const u8Achievement ID that can be used to uniquely identify the achievement.
DisplayName: *const u8Text representing the Name to display in-game when achievement has been unlocked.
Description: *const u8Text representing the description to display in-game when achievement has been unlocked.
LockedDisplayName: *const u8Text representing the name to display in-game when achievement is locked.
LockedDescription: *const u8Text representing the description of what needs to be done to trigger the unlock of this achievement.
HiddenDescription: *const u8Text representing the description to display in-game when achievement is hidden.
CompletionDescription: *const u8Text representing the description of what happens when the achievement is unlocked.
UnlockedIconId: *const u8Text representing the icon to display in-game when achievement is unlocked.
LockedIconId: *const u8Text representing the icon to display in-game when achievement is locked.
bIsHidden: i32True if achievement is hidden, false otherwise.
StatThresholdsCount: i32The number of stat thresholds.
StatThresholds: *const _tagEOS_Achievements_StatThresholdsArray of stat thresholds that need to be satisfied to unlock the achievement.