pub type EOS_Achievements_DefinitionV2 = _tagEOS_Achievements_DefinitionV2;Expand description
Contains information about a single achievement definition with localized text.
Aliased Type
#[repr(C)]pub struct EOS_Achievements_DefinitionV2 {
pub ApiVersion: i32,
pub AchievementId: *const u8,
pub UnlockedDisplayName: *const u8,
pub UnlockedDescription: *const u8,
pub LockedDisplayName: *const u8,
pub LockedDescription: *const u8,
pub FlavorText: *const u8,
pub UnlockedIconURL: *const u8,
pub LockedIconURL: *const u8,
pub bIsHidden: i32,
pub StatThresholdsCount: u32,
pub StatThresholds: *const _tagEOS_Achievements_StatThresholds,
}Fields
ApiVersion: i32API Version: Set this to EOS_ACHIEVEMENTS_DEFINITIONV2_API_LATEST.
AchievementId: *const u8Achievement ID that can be used to uniquely identify the achievement.
UnlockedDisplayName: *const u8Localized display name for the achievement when it has been unlocked.
UnlockedDescription: *const u8Localized description for the achievement when it has been unlocked.
LockedDisplayName: *const u8Localized display name for the achievement when it is locked or hidden.
LockedDescription: *const u8Localized description for the achievement when it is locked or hidden.
FlavorText: *const u8Localized flavor text that can be used by the game in an arbitrary manner. This may be null if there is no data configured in the dev portal.
UnlockedIconURL: *const u8URL of an icon to display for the achievement when it is unlocked. This may be null if there is no data configured in the dev portal.
LockedIconURL: *const u8URL of an icon to display for the achievement when it is locked or hidden. This may be null if there is no data configured in the dev portal.
bIsHidden: i32EOS_TRUE if the achievement is hidden; EOS_FALSE otherwise.
StatThresholdsCount: u32The number of stat thresholds used to monitor progress towards this achievement.
StatThresholds: *const _tagEOS_Achievements_StatThresholdsArray of EOS_Achievements_StatThresholds that need to be satisfied to unlock this achievement. Consists of Name and Threshold Value.