pub type EOS_Achievements_PlayerAchievement = _tagEOS_Achievements_PlayerAchievement;Expand description
Contains information about a single player achievement.
Aliased Type
#[repr(C)]pub struct EOS_Achievements_PlayerAchievement {
pub ApiVersion: i32,
pub AchievementId: *const i8,
pub Progress: f64,
pub UnlockTime: i64,
pub StatInfoCount: i32,
pub StatInfo: *const _tagEOS_Achievements_PlayerStatInfo,
pub DisplayName: *const i8,
pub Description: *const i8,
pub IconURL: *const i8,
pub FlavorText: *const i8,
}Fields
ApiVersion: i32API Version: Set this to EOS_ACHIEVEMENTS_PLAYERACHIEVEMENT_API_LATEST.
AchievementId: *const i8This achievement’s unique identifier.
Progress: f64Progress towards completing this achievement (as a percentage).
UnlockTime: i64The POSIX timestamp when the achievement was unlocked. If the achievement has not been unlocked, this value will be EOS_ACHIEVEMENTS_ACHIEVEMENT_UNLOCKTIME_UNDEFINED.
StatInfoCount: i32The number of player stat info entries associated with this achievement.
StatInfo: *const _tagEOS_Achievements_PlayerStatInfoArray of EOS_Achievements_PlayerStatInfo structures containing information about stat thresholds used to unlock the achievement and the player’s current values for those stats.
DisplayName: *const i8Localized display name for the achievement based on this specific player’s current progress on the achievement. @note The current progress is updated when EOS_Achievements_QueryPlayerAchievements succeeds and when an achievement is unlocked.
Description: *const i8Localized description for the achievement based on this specific player’s current progress on the achievement. @note The current progress is updated when EOS_Achievements_QueryPlayerAchievements succeeds and when an achievement is unlocked.
IconURL: *const i8URL of an icon to display for the achievement based on this specific player’s current progress on the achievement. This may be null if there is no data configured in the dev portal. @note The current progress is updated when EOS_Achievements_QueryPlayerAchievements succeeds and when an achievement is unlocked.
FlavorText: *const i8Localized flavor text that can be used by the game in an arbitrary manner. This may be null if there is no data configured in the dev portal.