EOS_Achievements_PlayerStatInfo

Type Alias EOS_Achievements_PlayerStatInfo 

pub type EOS_Achievements_PlayerStatInfo = _tagEOS_Achievements_PlayerStatInfo;
Contains information about a collection of stat info data.

@see EOS_Achievements_PlayerAchievement

Aliased Type

#[repr(C)]
pub struct EOS_Achievements_PlayerStatInfo { pub ApiVersion: i32, pub Name: *const i8, pub CurrentValue: i32, pub ThresholdValue: i32, }

Fields

ApiVersion: i32

API Version: Set this to EOS_ACHIEVEMENTS_PLAYERSTATINFO_API_LATEST.

Name: *const i8

The name of the stat.

CurrentValue: i32

The current value of the stat.

ThresholdValue: i32

The threshold value of the stat, used in determining when to unlock an achievement.