pub type EOS_Achievements_QueryDefinitionsOptions = _tagEOS_Achievements_QueryDefinitionsOptions;Expand description
Input parameters for the EOS_Achievements_QueryDefinitions function.
Aliased Type
#[repr(C)]pub struct EOS_Achievements_QueryDefinitionsOptions {
pub ApiVersion: i32,
pub LocalUserId: *mut EOS_ProductUserIdDetails,
pub EpicUserId_DEPRECATED: *mut EOS_EpicAccountIdDetails,
pub HiddenAchievementIds_DEPRECATED: *mut *const i8,
pub HiddenAchievementsCount_DEPRECATED: u32,
}Fields
ApiVersion: i32API Version: Set this to EOS_ACHIEVEMENTS_QUERYDEFINITIONS_API_LATEST.
LocalUserId: *mut EOS_ProductUserIdDetailsProduct User ID for user who is querying definitions. The localized text returned will be based on the locale code of the given user if they have a linked Epic Account ID. The localized text returned can also be overridden using EOS_Platform_SetOverrideLocaleCode to override the locale. If the locale code is not overridden and LocalUserId is not valid, default text will be returned.
EpicUserId_DEPRECATED: *mut EOS_EpicAccountIdDetailsDeprecated
HiddenAchievementIds_DEPRECATED: *mut *const i8Deprecated
HiddenAchievementsCount_DEPRECATED: u32Deprecated