pub type EOS_Achievements_StatThresholds = _tagEOS_Achievements_StatThresholds;Expand description
Contains information about a collection of stat threshold data.
The threshold will depend on the stat aggregate type: LATEST (Tracks the latest value) MAX (Tracks the maximum value) MIN (Tracks the minimum value) SUM (Generates a rolling sum of the value)
@see EOS_Achievements_Definition
Aliased Type
#[repr(C)]pub struct EOS_Achievements_StatThresholds {
pub ApiVersion: i32,
pub Name: *const i8,
pub Threshold: i32,
}Fields
ApiVersion: i32API Version: Set this to EOS_ACHIEVEMENTS_STATTHRESHOLDS_API_LATEST.
Name: *const i8The name of the stat.
Threshold: i32The value that the stat must surpass to satisfy the requirement for unlocking an achievement.