pub type EOS_AntiCheatClient_OnClientIntegrityViolatedCallbackInfo = _tagEOS_AntiCheatClient_OnClientIntegrityViolatedCallbackInfo;Expand description
Structure containing details about integrity violation related to the local client
Aliased Type
#[repr(C)]pub struct EOS_AntiCheatClient_OnClientIntegrityViolatedCallbackInfo {
pub ClientData: *mut c_void,
pub ViolationType: i32,
pub ViolationMessage: *const u8,
}Fields
ClientData: *mut c_voidCaller-specified context data
ViolationType: i32Code describing the violation that occurred
ViolationMessage: *const u8String describing the violation which should be displayed to the user