pub type EOS_AntiCheatClient_OnMessageToPeerCallback = Option<unsafe extern "C" fn(Data: *const EOS_AntiCheatCommon_OnMessageToClientCallbackInfo)>;Expand description
Callback issued when a new message must be dispatched to a connected peer.
Messages contain opaque binary data and must be transmitted to the correct peer using the game’s own networking layer, then delivered to the client anti-cheat instance using the EOS_AntiCheatClient_ReceiveMessageFromPeer function. The upper limit of the message size is EOS_ANTICHEATCLIENT_ONMESSAGETOPEERCALLBACK_MAX_MESSAGE_SIZE.
This callback is always issued from within EOS_Platform_Tick on its calling thread.
Aliased Type
pub enum EOS_AntiCheatClient_OnMessageToPeerCallback {
None,
Some(unsafe extern "C" fn(*const _tagEOS_AntiCheatCommon_OnMessageToClientCallbackInfo)),
}Variants
None
No value.
Some(unsafe extern "C" fn(*const _tagEOS_AntiCheatCommon_OnMessageToClientCallbackInfo))
Some value of type T.