pub type EOS_AntiCheatCommon_ClientHandle = *mut c_void;Expand description
Arbitrary data that is a unique local identifier for a single remote client or peer.
Typically this is a pointer to an object describing the player, but it can be anything that is locally unique.