pub type EOS_AntiCheatCommon_LogGameRoundStartOptions = _tagEOS_AntiCheatCommon_LogGameRoundStartOptions;Expand description
Input parameters for the EOS_AntiCheatServer_LogGameRoundStart function.
Aliased Type
#[repr(C)]pub struct EOS_AntiCheatCommon_LogGameRoundStartOptions {
pub ApiVersion: i32,
pub SessionIdentifier: *const u8,
pub LevelName: *const u8,
pub ModeName: *const u8,
pub RoundTimeSeconds: u32,
pub CompetitionType: i32,
}Fields
ApiVersion: i32API Version: Set this to EOS_ANTICHEATCOMMON_LOGGAMEROUNDSTART_API_LATEST.
SessionIdentifier: *const u8Optional game session or match identifier useful for some backend API integrations
LevelName: *const u8Optional name of the map being played
ModeName: *const u8Optional name of the game mode being played
RoundTimeSeconds: u32Optional length of the game round to be played, in seconds. If none, use 0.
CompetitionType: i32Type of competition for this game round