EOS_AntiCheatCommon_LogPlayerTakeDamageOptions

Type Alias EOS_AntiCheatCommon_LogPlayerTakeDamageOptions 

pub type EOS_AntiCheatCommon_LogPlayerTakeDamageOptions = _tagEOS_AntiCheatCommon_LogPlayerTakeDamageOptions;
Input parameters for the EOS_AntiCheatServer_LogPlayerTakeDamage function.

Aliased Type

#[repr(C)]
pub struct EOS_AntiCheatCommon_LogPlayerTakeDamageOptions {
Show 20 fields pub ApiVersion: i32, pub VictimPlayerHandle: *mut c_void, pub VictimPlayerPosition: *mut _tagEOS_AntiCheatCommon_Vec3f, pub VictimPlayerViewRotation: *mut _tagEOS_AntiCheatCommon_Quat, pub AttackerPlayerHandle: *mut c_void, pub AttackerPlayerPosition: *mut _tagEOS_AntiCheatCommon_Vec3f, pub AttackerPlayerViewRotation: *mut _tagEOS_AntiCheatCommon_Quat, pub bIsHitscanAttack: i32, pub bHasLineOfSight: i32, pub bIsCriticalHit: i32, pub HitBoneId_DEPRECATED: u32, pub DamageTaken: f32, pub HealthRemaining: f32, pub DamageSource: i32, pub DamageType: i32, pub DamageResult: i32, pub PlayerUseWeaponData: *mut _tagEOS_AntiCheatCommon_LogPlayerUseWeaponData, pub TimeSincePlayerUseWeaponMs: u32, pub DamagePosition: *mut _tagEOS_AntiCheatCommon_Vec3f, pub AttackerPlayerViewPosition: *mut _tagEOS_AntiCheatCommon_Vec3f,
}

Fields

ApiVersion: i32

API Version: Set this to EOS_ANTICHEATCOMMON_LOGPLAYERTAKEDAMAGE_API_LATEST.

VictimPlayerHandle: *mut c_void

Locally unique value used in RegisterClient/RegisterPeer

VictimPlayerPosition: *mut _tagEOS_AntiCheatCommon_Vec3f

Victim player character’s world position as a 3D vector. This should be the center of the character.

VictimPlayerViewRotation: *mut _tagEOS_AntiCheatCommon_Quat

Victim player camera’s world rotation as a quaternion.

AttackerPlayerHandle: *mut c_void

Locally unique value used in RegisterClient/RegisterPeer if applicable, otherwise 0.

AttackerPlayerPosition: *mut _tagEOS_AntiCheatCommon_Vec3f

Attacker player character’s world position as a 3D vector if applicable, otherwise NULL.

AttackerPlayerViewRotation: *mut _tagEOS_AntiCheatCommon_Quat

Attacker player camera’s world rotation as a quaternion if applicable, otherwise NULL.

bIsHitscanAttack: i32

True if the damage was applied instantly at the time of attack from the game simulation’s perspective, otherwise false (simulated ballistics, arrow, etc).

bHasLineOfSight: i32

True if there is a visible line of sight between the attacker and the victim at the time that damage is being applied, false if there is an obstacle like a wall or terrain in the way. For some situations like melee or hitscan weapons this is trivially true, for others like projectiles with simulated physics it may not be e.g. a player could fire a slow moving projectile and then move behind cover before it strikes.

This can be an estimate, or can simply be always set to true if it is not feasible to compute in your game.

bIsCriticalHit: i32

True if this was a critical hit that causes extra damage (e.g. headshot)

HitBoneId_DEPRECATED: u32

Deprecated - use DamagePosition instead

DamageTaken: f32

Number of health points that the victim lost due to this damage event

HealthRemaining: f32

Number of health points that the victim has remaining after this damage event

DamageSource: i32

Source of the damage event

DamageType: i32

Type of the damage being applied

DamageResult: i32

Result of the damage for the victim, if any

PlayerUseWeaponData: *mut _tagEOS_AntiCheatCommon_LogPlayerUseWeaponData

PlayerUseWeaponData associated with this damage event if available, otherwise NULL

TimeSincePlayerUseWeaponMs: u32

Time in milliseconds since the associated PlayerUseWeaponData event occurred if available, otherwise 0

DamagePosition: *mut _tagEOS_AntiCheatCommon_Vec3f

World position where damage hit the victim as a 3D vector if available, otherwise NULL

AttackerPlayerViewPosition: *mut _tagEOS_AntiCheatCommon_Vec3f

Attacker player camera’s world position as a 3D vector if applicable, otherwise NULL