pub type EOS_Auth_AccountFeatureRestrictedInfo = _tagEOS_Auth_AccountFeatureRestrictedInfo;Expand description
Intermediate data needed to complete account restriction verification during login flow, returned by EOS_Auth_LoginCallbackInfo when the ResultCode is EOS_Auth_AccountFeatureRestricted. The URI inside should be exposed to the user for entry in a web browser. The URI must be copied out of this struct before completion of the callback.
Aliased Type
#[repr(C)]pub struct EOS_Auth_AccountFeatureRestrictedInfo {
pub ApiVersion: i32,
pub VerificationURI: *const u8,
}Fields
ApiVersion: i32API Version: Set this to EOS_AUTH_ACCOUNTFEATURERESTRICTEDINFO_API_LATEST.
VerificationURI: *const u8The end-user verification URI. Users must be asked to open the page in a browser to address the restrictions.