pub type EOS_Auth_PinGrantInfo = _tagEOS_Auth_PinGrantInfo;Expand description
Intermediate data for completing Epic account login, when neither the in-game overlay or a platform browser is used. The EOS_Auth_PinGrantInfo struct is returned as part of the EOS_Auth_LoginCallbackInfo and EOS_Auth_LinkAccountCallbackInfo structs. The data inside should be exposed to the user for entry on a secondary device. All data must be copied out before the completion of this callback.
Aliased Type
#[repr(C)]pub struct EOS_Auth_PinGrantInfo {
pub ApiVersion: i32,
pub UserCode: *const i8,
pub VerificationURI: *const i8,
pub ExpiresIn: i32,
pub VerificationURIComplete: *const i8,
}Fields
ApiVersion: i32API Version: Set this to EOS_AUTH_PINGRANTINFO_API_LATEST.
UserCode: *const i8Code the user must input on an external device to activate the login.
VerificationURI: *const i8The end-user verification URI. Users can be asked to manually type this into their browser.
ExpiresIn: i32Time the user has, in seconds, to complete the process or else timeout.
VerificationURIComplete: *const i8A verification URI that includes the user code. Useful for non-textual transmission.