pub type EOS_Auth_QueryIdTokenOptions = _tagEOS_Auth_QueryIdTokenOptions;Expand description
Input parameters for the EOS_Auth_QueryIdToken function.
Aliased Type
#[repr(C)]pub struct EOS_Auth_QueryIdTokenOptions {
pub ApiVersion: i32,
pub LocalUserId: *mut EOS_EpicAccountIdDetails,
pub TargetAccountId: *mut EOS_EpicAccountIdDetails,
}Fields
ApiVersion: i32API Version: Set this to EOS_AUTH_QUERYIDTOKEN_API_LATEST.
LocalUserId: *mut EOS_EpicAccountIdDetailsThe Epic Account ID of the local authenticated user.
TargetAccountId: *mut EOS_EpicAccountIdDetailsThe target Epic Account ID for which to query an ID token. This account id may be the same as the input LocalUserId or another merged account id associated with the local user’s Epic account.
An ID token for the selected account id of a locally authenticated user will always be readily available. To retrieve it for the selected account ID, you can use EOS_Auth_CopyIdToken directly after a successful user login.