EOS_Auth_Token

Type Alias EOS_Auth_Token 

pub type EOS_Auth_Token = _tagEOS_Auth_Token;
A structure that contains an auth token. These structures are created by EOS_Auth_CopyUserAuthToken and must be passed to EOS_Auth_Token_Release.

Aliased Type

#[repr(C)]
pub struct EOS_Auth_Token { pub ApiVersion: i32, pub App: *const i8, pub ClientId: *const i8, pub AccountId: *mut EOS_EpicAccountIdDetails, pub AccessToken: *const i8, pub ExpiresIn: f64, pub ExpiresAt: *const i8, pub AuthType: i32, pub RefreshToken: *const i8, pub RefreshExpiresIn: f64, pub RefreshExpiresAt: *const i8, }

Fields

ApiVersion: i32

API Version: Set this to EOS_AUTH_TOKEN_API_LATEST.

App: *const i8

Name of the app related to the client ID involved with this token

ClientId: *const i8

Client ID that requested this token

AccountId: *mut EOS_EpicAccountIdDetails

The Epic Account ID associated with this auth token

AccessToken: *const i8

Access token for the current user login session

ExpiresIn: f64

Time before the access token expires, in seconds, relative to the call to EOS_Auth_CopyUserAuthToken

ExpiresAt: *const i8

Absolute time in UTC before the access token expires, in ISO 8601 format

AuthType: i32

Type of auth token

RefreshToken: *const i8

Refresh token.

@see EOS_ELoginCredentialType::EOS_LCT_RefreshToken

RefreshExpiresIn: f64

Time before the access token expires, in seconds, relative to the call to EOS_Auth_CopyUserAuthToken

RefreshExpiresAt: *const i8

Absolute time in UTC before the refresh token expires, in ISO 8601 format