EOS_Auth_VerifyIdTokenCallbackInfo

Type Alias EOS_Auth_VerifyIdTokenCallbackInfo 

pub type EOS_Auth_VerifyIdTokenCallbackInfo = _tagEOS_Auth_VerifyIdTokenCallbackInfo;
Output parameters for the EOS_Auth_VerifyIdToken Function.

Aliased Type

#[repr(C)]
pub struct EOS_Auth_VerifyIdTokenCallbackInfo {
Show 13 fields pub ResultCode: i32, pub ClientData: *mut c_void, pub ApplicationId: *const u8, pub ClientId: *const u8, pub ProductId: *const u8, pub SandboxId: *const u8, pub DeploymentId: *const u8, pub DisplayName: *const u8, pub bIsExternalAccountInfoPresent: i32, pub ExternalAccountIdType: i32, pub ExternalAccountId: *const u8, pub ExternalAccountDisplayName: *const u8, pub Platform: *const u8,
}

Fields

ResultCode: i32

The EOS_EResult code for the operation. EOS_Success indicates that the operation succeeded; other codes indicate errors.

ClientData: *mut c_void

Context that was passed into EOS_Auth_VerifyIdToken

ApplicationId: *const u8

Epic Account Services Application ID.

ClientId: *const u8

Client ID of the authorized client.

ProductId: *const u8

Product ID.

SandboxId: *const u8

Sandbox ID.

DeploymentId: *const u8

Deployment ID.

DisplayName: *const u8

Epic Account display name.

This value may be set to an empty string.

bIsExternalAccountInfoPresent: i32

Flag set to indicate whether external account information is present. Applications must always first check this value to be set before attempting to read the ExternalAccountIdType, ExternalAccountId, ExternalAccountDisplayName and Platform fields.

This flag is set when the user has logged in to their Epic Account using external account credentials, e.g. through local platform authentication.

ExternalAccountIdType: i32

The identity provider that the user logged in with to their Epic Account.

If bIsExternalAccountInfoPresent is set, this field describes the external account type.

ExternalAccountId: *const u8

The external account ID of the logged in user.

This value may be set to an empty string.

ExternalAccountDisplayName: *const u8

The external account display name.

This value may be set to an empty string.

Platform: *const u8

Platform that the user is connected from.

This value may be set to an empty string.