pub type EOS_Connect_TransferDeviceIdAccountCallbackInfo = _tagEOS_Connect_TransferDeviceIdAccountCallbackInfo;Expand description
Output parameters for the EOS_Connect_TransferDeviceIdAccount Function.
Aliased Type
#[repr(C)]pub struct EOS_Connect_TransferDeviceIdAccountCallbackInfo {
pub ResultCode: i32,
pub ClientData: *mut c_void,
pub LocalUserId: *mut EOS_ProductUserIdDetails,
}Fields
ResultCode: i32The EOS_EResult code for the operation. EOS_Success indicates that the operation succeeded; other codes indicate errors.
ClientData: *mut c_voidContext that was passed into EOS_Connect_TransferDeviceIdAccount.
LocalUserId: *mut EOS_ProductUserIdDetailsThe ProductUserIdToPreserve that was passed to the original EOS_Connect_TransferDeviceIdAccount call.
On successful operation, this EOS_ProductUserId will have a valid authentication session and the other EOS_ProductUserId value has been discarded and lost forever.
The application should remove any registered notification callbacks for the discarded EOS_ProductUserId as obsolete.