pub type EOS_Connect_VerifyIdTokenCallbackInfo = _tagEOS_Connect_VerifyIdTokenCallbackInfo;Expand description
Output parameters for the EOS_Connect_VerifyIdToken Function.
Aliased Type
#[repr(C)]pub struct EOS_Connect_VerifyIdTokenCallbackInfo {
pub ResultCode: i32,
pub ClientData: *mut c_void,
pub ProductUserId: *mut EOS_ProductUserIdDetails,
pub bIsAccountInfoPresent: i32,
pub AccountIdType: i32,
pub AccountId: *const u8,
pub Platform: *const u8,
pub DeviceType: *const u8,
pub ClientId: *const u8,
pub ProductId: *const u8,
pub SandboxId: *const u8,
pub DeploymentId: *const u8,
}Fields
ResultCode: i32The EOS_EResult code for the operation. EOS_Success indicates that the operation succeeded; other codes indicate errors.
ClientData: *mut c_voidContext that was passed into EOS_Connect_VerifyIdToken
ProductUserId: *mut EOS_ProductUserIdDetailsThe Product User ID associated with the ID token.
bIsAccountInfoPresent: i32Flag set to indicate whether account information is available. Applications must always first check this value to be set before attempting to read the AccountType, AccountId, Platform and DeviceType fields.
This flag is always false for users that authenticated using EOS Connect Device ID.
AccountIdType: i32The identity provider that the user authenticated with to EOS Connect.
If bIsAccountInfoPresent is set, this field describes the external account type.
AccountId: *const u8The external account ID of the authenticated user.
This value may be set to an empty string.
Platform: *const u8Platform that the user is connected from.
This value may be set to an empty string.
DeviceType: *const u8Identifies the device type that the user is connected from. Can be used to securely verify that the user is connected through a real Console device.
This value may be set to an empty string.
ClientId: *const u8Client ID of the authorized client.
ProductId: *const u8Product ID.
SandboxId: *const u8Sandbox ID.
DeploymentId: *const u8Deployment ID.