pub type EOS_CustomInvites_SendCustomInviteCallbackInfo = _tagEOS_CustomInvites_SendCustomInviteCallbackInfo;Expand description
Output parameters for the EOS_CustomInvites_SendCustomInvite Function. These parameters are received through the callback provided to EOS_CustomInvites_SendCustomInvite
Aliased Type
#[repr(C)]pub struct EOS_CustomInvites_SendCustomInviteCallbackInfo {
pub ResultCode: i32,
pub ClientData: *mut c_void,
pub LocalUserId: *mut EOS_ProductUserIdDetails,
pub TargetUserIds: *mut *mut EOS_ProductUserIdDetails,
pub TargetUserIdsCount: u32,
}Fields
ResultCode: i32The EOS_EResult code for the operation. EOS_Success indicates that the operation succeeded; other codes indicate errors.
ClientData: *mut c_voidContext that was passed into EOS_CustomInvites_SendCustomInvite
LocalUserId: *mut EOS_ProductUserIdDetailsLocal user sending a CustomInvite
TargetUserIds: *mut *mut EOS_ProductUserIdDetailsUsers to whom the invites were successfully sent (can be different than original call if an invite for same Payload was previously sent)
TargetUserIdsCount: u32The number of users we are sending to