pub type EOS_CustomInvites_SendCustomNativeInviteRequestedCallbackInfo = _tagEOS_CustomInvites_SendCustomNativeInviteRequestedCallbackInfo;Expand description
Output parameters for the EOS_CustomInvites_OnSendCustomNativeInviteRequestedCallback Function.
Aliased Type
#[repr(C)]pub struct EOS_CustomInvites_SendCustomNativeInviteRequestedCallbackInfo {
pub ClientData: *mut c_void,
pub UiEventId: u64,
pub LocalUserId: *mut EOS_ProductUserIdDetails,
pub TargetNativeAccountType: *const i8,
pub TargetUserNativeAccountId: *const i8,
pub InviteId: *const i8,
}Fields
ClientData: *mut c_voidContext that was passed into EOS_CustomInvites_AddNotifySendCustomNativeInviteRequested
UiEventId: u64Identifies this event which will need to be acknowledged with EOS_UI_AcknowledgeEventId(). @see EOS_UI_AcknowledgeEventId
LocalUserId: *mut EOS_ProductUserIdDetailsThe Product User ID of the local user who is inviting.
TargetNativeAccountType: *const i8The Native Platform Account Type. If only a single integrated platform is configured then this will always reference that platform.
TargetUserNativeAccountId: *const i8The Native Platform Account ID of the target user being invited.
InviteId: *const i8Invite ID that the user is being invited to