pub type EOS_ELobbyAttributeType = c_int;Expand description
Supported types of data that can be stored with inside an attribute (used by sessions/lobbies/etc)
@see EOS_LobbySearch_SetParameter @see EOS_SessionSearch_SetParameter Supported types of data that can be stored with inside an attribute (used by sessions/lobbies/etc)
@see EOS_LobbySearch_SetParameter @see EOS_SessionSearch_SetParameter