EOS_Ecom_CheckoutCallbackInfo

Type Alias EOS_Ecom_CheckoutCallbackInfo 

pub type EOS_Ecom_CheckoutCallbackInfo = _tagEOS_Ecom_CheckoutCallbackInfo;
Output parameters for the EOS_Ecom_Checkout Function.

Aliased Type

#[repr(C)]
pub struct EOS_Ecom_CheckoutCallbackInfo { pub ResultCode: i32, pub ClientData: *mut c_void, pub LocalUserId: *mut EOS_EpicAccountIdDetails, pub TransactionId: *const i8, }

Fields

ResultCode: i32

Result code for the operation. EOS_Success is returned for a successful request, otherwise one of the error codes is returned. See eos_common.h

ClientData: *mut c_void

Context that was passed into EOS_Ecom_Checkout

LocalUserId: *mut EOS_EpicAccountIdDetails

The Epic Account ID of the user who initiated the purchase

TransactionId: *const i8

The transaction ID which can be used to obtain an EOS_Ecom_HTransaction using EOS_Ecom_CopyTransactionById.