pub type EOS_Ecom_CheckoutEntry = _tagEOS_Ecom_CheckoutEntry;Expand description
Contains information about a request to purchase a single offer. This structure is set as part of the EOS_Ecom_CheckoutOptions structure.
Aliased Type
#[repr(C)]pub struct EOS_Ecom_CheckoutEntry {
pub ApiVersion: i32,
pub OfferId: *const i8,
}Fields
ApiVersion: i32API Version: Set this to EOS_ECOM_CHECKOUTENTRY_API_LATEST.
OfferId: *const i8The ID of the offer to purchase