EOS_Ecom_CopyEntitlementByNameAndIndexOptions

Type Alias EOS_Ecom_CopyEntitlementByNameAndIndexOptions 

pub type EOS_Ecom_CopyEntitlementByNameAndIndexOptions = _tagEOS_Ecom_CopyEntitlementByNameAndIndexOptions;
Input parameters for the EOS_Ecom_CopyEntitlementByNameAndIndex function.

Aliased Type

#[repr(C)]
pub struct EOS_Ecom_CopyEntitlementByNameAndIndexOptions { pub ApiVersion: i32, pub LocalUserId: *mut EOS_EpicAccountIdDetails, pub EntitlementName: *const u8, pub Index: u32, }

Fields

ApiVersion: i32

API Version: Set this to EOS_ECOM_COPYENTITLEMENTBYNAMEANDINDEX_API_LATEST.

LocalUserId: *mut EOS_EpicAccountIdDetails

The Epic Account ID of the local user whose entitlement is being copied

EntitlementName: *const u8

Name of the entitlement to retrieve from the cache

Index: u32

Index of the entitlement within the named set to retrieve from the cache.