pub type EOS_Ecom_CopyItemReleaseByIndexOptions = _tagEOS_Ecom_CopyItemReleaseByIndexOptions;Expand description
Input parameters for the EOS_Ecom_CopyItemReleaseByIndex function.
Aliased Type
#[repr(C)]pub struct EOS_Ecom_CopyItemReleaseByIndexOptions {
pub ApiVersion: i32,
pub LocalUserId: *mut EOS_EpicAccountIdDetails,
pub ItemId: *const u8,
pub ReleaseIndex: u32,
}Fields
ApiVersion: i32API Version: Set this to EOS_ECOM_COPYITEMRELEASEBYINDEX_API_LATEST.
LocalUserId: *mut EOS_EpicAccountIdDetailsThe Epic Account ID of the local user whose item release is being copied
ItemId: *const u8The ID of the item to get the releases for.
ReleaseIndex: u32The index of the release to get.