pub type EOS_Ecom_CopyLastRedeemEntitlementsResultByIndexOptions = _tagEOS_Ecom_CopyLastRedeemEntitlementsResultByIndexOptions;Expand description
Input parameters for the EOS_Ecom_CopyLastRedeemEntitlementsResultByIndex function.
Aliased Type
#[repr(C)]pub struct EOS_Ecom_CopyLastRedeemEntitlementsResultByIndexOptions {
pub ApiVersion: i32,
pub LocalUserId: *mut EOS_EpicAccountIdDetails,
pub EntitlementIndex: u32,
pub ResultType: i32,
}Fields
ApiVersion: i32API Version: Set this to EOS_ECOM_COPYLASTREDEEMENTITLEMENTSRESULTBYINDEX_API_LATEST.
LocalUserId: *mut EOS_EpicAccountIdDetailsThe Epic Account ID of the local user whose last redeemed entitlement id is being copied
EntitlementIndex: u32Index of the entitlement of the given result type.
ResultType: i32The Redeem Entitlements Result Type.