EOS_Ecom_CopyOfferItemByIndexOptions

Type Alias EOS_Ecom_CopyOfferItemByIndexOptions 

pub type EOS_Ecom_CopyOfferItemByIndexOptions = _tagEOS_Ecom_CopyOfferItemByIndexOptions;
Input parameters for the EOS_Ecom_CopyOfferItemByIndex function.

Aliased Type

#[repr(C)]
pub struct EOS_Ecom_CopyOfferItemByIndexOptions { pub ApiVersion: i32, pub LocalUserId: *mut EOS_EpicAccountIdDetails, pub OfferId: *const u8, pub ItemIndex: u32, }

Fields

ApiVersion: i32

API Version: Set this to EOS_ECOM_COPYOFFERITEMBYINDEX_API_LATEST.

LocalUserId: *mut EOS_EpicAccountIdDetails

The Epic Account ID of the local user whose item is being copied

OfferId: *const u8

The ID of the offer to get the items for.

ItemIndex: u32

The index of the item to get.