EOS_Ecom_GetEntitlementsByNameCountOptions

Type Alias EOS_Ecom_GetEntitlementsByNameCountOptions 

pub type EOS_Ecom_GetEntitlementsByNameCountOptions = _tagEOS_Ecom_GetEntitlementsByNameCountOptions;
Input parameters for the EOS_Ecom_GetEntitlementsByNameCount function.

Aliased Type

#[repr(C)]
pub struct EOS_Ecom_GetEntitlementsByNameCountOptions { pub ApiVersion: i32, pub LocalUserId: *mut EOS_EpicAccountIdDetails, pub EntitlementName: *const u8, }

Fields

ApiVersion: i32

API Version: Set this to EOS_ECOM_GETENTITLEMENTSBYNAMECOUNT_API_LATEST.

LocalUserId: *mut EOS_EpicAccountIdDetails

The Epic Account ID of the local user for which to retrieve the entitlement count

EntitlementName: *const u8

Name of the entitlement to count in the cache