EOS_Ecom_GetItemReleaseCountOptions

Type Alias EOS_Ecom_GetItemReleaseCountOptions 

pub type EOS_Ecom_GetItemReleaseCountOptions = _tagEOS_Ecom_GetItemReleaseCountOptions;
Input parameters for the EOS_Ecom_GetItemReleaseCount function.

Aliased Type

#[repr(C)]
pub struct EOS_Ecom_GetItemReleaseCountOptions { pub ApiVersion: i32, pub LocalUserId: *mut EOS_EpicAccountIdDetails, pub ItemId: *const i8, }

Fields

ApiVersion: i32

API Version: Set this to EOS_ECOM_GETITEMRELEASECOUNT_API_LATEST.

LocalUserId: *mut EOS_EpicAccountIdDetails

The Epic Account ID of the local user whose item release is being accessed

ItemId: *const i8

The ID of the item to get the releases for.