pub type EOS_Ecom_GetOfferItemCountOptions = _tagEOS_Ecom_GetOfferItemCountOptions;Expand description
Input parameters for the EOS_Ecom_GetOfferItemCount function.
Aliased Type
#[repr(C)]pub struct EOS_Ecom_GetOfferItemCountOptions {
pub ApiVersion: i32,
pub LocalUserId: *mut EOS_EpicAccountIdDetails,
pub OfferId: *const u8,
}Fields
ApiVersion: i32API Version: Set this to EOS_ECOM_GETOFFERITEMCOUNT_API_LATEST.
LocalUserId: *mut EOS_EpicAccountIdDetailsThe Epic Account ID of the local user who made the initial request for the Catalog Offer through EOS_Ecom_QueryOffers
OfferId: *const u8An ID that corresponds to a cached Catalog Offer (retrieved by EOS_Ecom_CopyOfferByIndex)