pub type EOS_Ecom_KeyImageInfo = _tagEOS_Ecom_KeyImageInfo;Expand description
Contains information about a key image used by the catalog. Instances of this structure are created by EOS_Ecom_CopyItemImageInfoByIndex. They must be passed to EOS_Ecom_KeyImageInfo_Release. A Key Image is defined within Dev Portal and is associated with a Catalog Item. A Key Image is intended to be used to provide imagery for an in-game store.
@see EOS_Ecom_CopyItemImageInfoByIndex @see EOS_Ecom_KeyImageInfo_Release
Aliased Type
#[repr(C)]pub struct EOS_Ecom_KeyImageInfo {
pub ApiVersion: i32,
pub Type: *const u8,
pub Url: *const u8,
pub Width: u32,
pub Height: u32,
}Fields
ApiVersion: i32API Version: Set this to EOS_ECOM_KEYIMAGEINFO_API_LATEST.
Type: *const u8Describes the usage of the image (ex: home_thumbnail)
Url: *const u8The URL of the image
Width: u32The expected width in pixels of the image
Height: u32The expected height in pixels of the image