pub type EOS_Ecom_QueryEntitlementTokenCallbackInfo = _tagEOS_Ecom_QueryEntitlementTokenCallbackInfo;Expand description
Output parameters for the EOS_Ecom_QueryEntitlementToken Function.
Aliased Type
#[repr(C)]pub struct EOS_Ecom_QueryEntitlementTokenCallbackInfo {
pub ResultCode: i32,
pub ClientData: *mut c_void,
pub LocalUserId: *mut EOS_EpicAccountIdDetails,
pub EntitlementToken: *const i8,
}Fields
ResultCode: i32The EOS_EResult code for the operation. EOS_Success indicates that the operation succeeded; other codes indicate errors.
ClientData: *mut c_voidContext that was passed into EOS_Ecom_QueryEntitlementToken
LocalUserId: *mut EOS_EpicAccountIdDetailsThe Epic Account ID of the local user whose entitlement was queried
EntitlementToken: *const i8Entitlements token containing details about the catalog items queried