pub type EOS_Ecom_QueryOwnershipBySandboxIdsCallbackInfo = _tagEOS_Ecom_QueryOwnershipBySandboxIdsCallbackInfo;Expand description
Output parameters for the EOS_Ecom_QueryOwnershipBySandboxIds Function.
Aliased Type
#[repr(C)]pub struct EOS_Ecom_QueryOwnershipBySandboxIdsCallbackInfo {
pub ResultCode: i32,
pub ClientData: *mut c_void,
pub LocalUserId: *mut EOS_EpicAccountIdDetails,
pub SandboxIdItemOwnerships: *const _tagEOS_Ecom_SandboxIdItemOwnership,
pub SandboxIdItemOwnershipsCount: u32,
}Fields
ResultCode: i32The EOS_EResult code for the operation. EOS_Success indicates that the operation succeeded; other codes indicate errors.
ClientData: *mut c_voidContext that was passed into EOS_Ecom_QueryOwnership
LocalUserId: *mut EOS_EpicAccountIdDetailsThe Epic Account ID of the local user whose ownership was queried
SandboxIdItemOwnerships: *const _tagEOS_Ecom_SandboxIdItemOwnershipList of SandboxIds and their corresponding owned catalog item Ids. If there are no ownership items, the OwnedCatalogItemIdsCount is 0 and OwnedCatalogItemIds is null.
SandboxIdItemOwnershipsCount: u32Number of ownership results are included in this callback