pub type EOS_Ecom_QueryOwnershipOptions = _tagEOS_Ecom_QueryOwnershipOptions;Expand description
Input parameters for the EOS_Ecom_QueryOwnership function.
Aliased Type
#[repr(C)]pub struct EOS_Ecom_QueryOwnershipOptions {
pub ApiVersion: i32,
pub LocalUserId: *mut EOS_EpicAccountIdDetails,
pub CatalogItemIds: *mut *const i8,
pub CatalogItemIdCount: u32,
pub CatalogNamespace: *const i8,
}Fields
ApiVersion: i32API Version: Set this to EOS_ECOM_QUERYOWNERSHIP_API_LATEST.
LocalUserId: *mut EOS_EpicAccountIdDetailsThe Epic Account ID of the local user whose ownership to query
CatalogItemIds: *mut *const i8The array of Catalog Item IDs to check for ownership
CatalogItemIdCount: u32The number of Catalog Item IDs to in the array
CatalogNamespace: *const i8Optional product namespace, if not the one specified during initialization