pub type EOS_Friends_SendInviteCallbackInfo = _tagEOS_Friends_SendInviteCallbackInfo;Expand description
Output parameters for the EOS_Friends_SendInvite API.
Aliased Type
#[repr(C)]pub struct EOS_Friends_SendInviteCallbackInfo {
pub ResultCode: i32,
pub ClientData: *mut c_void,
pub LocalUserId: *mut EOS_EpicAccountIdDetails,
pub TargetUserId: *mut EOS_EpicAccountIdDetails,
}Fields
ResultCode: i32Result code for the operation. EOS_Success is returned if the invitation was sent, otherwise one of the error codes is returned. See eos_common.h
ClientData: *mut c_voidContext that was passed into EOS_Friends_SendInvite
LocalUserId: *mut EOS_EpicAccountIdDetailsThe Epic Account ID of the user who sent the friends list invitation
TargetUserId: *mut EOS_EpicAccountIdDetailsThe Epic Account ID of the user to whom the friends list invitation was sent