pub type EOS_KWS_QueryPermissionsCallbackInfo = _tagEOS_KWS_QueryPermissionsCallbackInfo;Expand description
Output parameters for the EOS_KWS_QueryPermissionsOptions Function. These parameters are received through the callback provided to EOS_KWS_QueryPermissions
Aliased Type
#[repr(C)]pub struct EOS_KWS_QueryPermissionsCallbackInfo {
pub ResultCode: i32,
pub ClientData: *mut c_void,
pub LocalUserId: *mut EOS_ProductUserIdDetails,
pub KWSUserId: *const i8,
pub DateOfBirth: *const i8,
pub bIsMinor: i32,
pub ParentEmail: *const i8,
}Fields
ResultCode: i32The EOS_EResult code for the operation. EOS_Success indicates that the operation succeeded; other codes indicate errors.
ClientData: *mut c_voidContext that was passed into EOS_KWS_QueryPermissions
LocalUserId: *mut EOS_ProductUserIdDetailsLocal user querying their permissions
KWSUserId: *const i8KWS UserId created
DateOfBirth: *const i8Date of birth in ISO8601 form (YYYY-MM-DD)
bIsMinor: i32Is this user a minor
ParentEmail: *const i8Parent email. This value may be set to an empty string if the originally registered email recipient declined to be the right person to give consent.