pub type EOS_LobbyDetails_Info = _tagEOS_LobbyDetails_Info;Expand description
Contains information about a single lobby.
Aliased Type
#[repr(C)]pub struct EOS_LobbyDetails_Info {Show 15 fields
pub ApiVersion: i32,
pub LobbyId: *const i8,
pub LobbyOwnerUserId: *mut EOS_ProductUserIdDetails,
pub PermissionLevel: i32,
pub AvailableSlots: u32,
pub MaxMembers: u32,
pub bAllowInvites: i32,
pub BucketId: *const i8,
pub bAllowHostMigration: i32,
pub bRTCRoomEnabled: i32,
pub bAllowJoinById: i32,
pub bRejoinAfterKickRequiresInvite: i32,
pub bPresenceEnabled: i32,
pub AllowedPlatformIds: *const u32,
pub AllowedPlatformIdsCount: u32,
}Fields
ApiVersion: i32API Version: Set this to EOS_LOBBYDETAILS_INFO_API_LATEST.
LobbyId: *const i8Lobby ID
LobbyOwnerUserId: *mut EOS_ProductUserIdDetailsThe Product User ID of the current owner of the lobby
PermissionLevel: i32Permission level of the lobby
AvailableSlots: u32Current available space
MaxMembers: u32Max allowed members in the lobby
bAllowInvites: i32If true, users can invite others to this lobby
BucketId: *const i8The main indexed parameter for this lobby, can be any string (i.e. “Region:GameMode”)
bAllowHostMigration: i32Is host migration allowed
bRTCRoomEnabled: i32Was a Real-Time Communication (RTC) room enabled at lobby creation?
bAllowJoinById: i32Is EOS_Lobby_JoinLobbyById allowed
bRejoinAfterKickRequiresInvite: i32Does rejoining after being kicked require an invite
bPresenceEnabled: i32If true, this lobby will be associated with the local user’s presence information.
AllowedPlatformIds: *const u32Array of platform IDs indicating the player platforms allowed to register with the lobby. Platform IDs are found in the EOS header file (eos_common.h), for example EOS_OPT_Epic. For some platforms the value will be in the EOS Platform specific header file. If null, the lobby will be unrestricted.
AllowedPlatformIdsCount: u32Number of platform IDs in the array