pub type EOS_Lobby_Attribute = _tagEOS_Lobby_Attribute;Expand description
An attribute and its visibility setting stored with a lobby. Used to store both lobby and lobby member data
Aliased Type
#[repr(C)]pub struct EOS_Lobby_Attribute {
pub ApiVersion: i32,
pub Data: *mut _tagEOS_Lobby_AttributeData,
pub Visibility: i32,
}Fields
ApiVersion: i32API Version: Set this to EOS_LOBBY_ATTRIBUTE_API_LATEST.
Data: *mut _tagEOS_Lobby_AttributeDataKey/Value pair describing the attribute
Visibility: i32Is this attribute public or private to the lobby and its members