pub type EOS_Lobby_GetConnectStringOptions = _tagEOS_Lobby_GetConnectStringOptions;Expand description
Input parameters for the EOS_Lobby_GetConnectString function.
Aliased Type
#[repr(C)]pub struct EOS_Lobby_GetConnectStringOptions {
pub ApiVersion: i32,
pub LocalUserId: *mut EOS_ProductUserIdDetails,
pub LobbyId: *const u8,
}Fields
ApiVersion: i32API Version: Set this to EOS_LOBBY_GETCONNECTSTRING_API_LATEST.
LocalUserId: *mut EOS_ProductUserIdDetailsThe Product User ID of the local user requesting the connection string generated from the lobby; this user must currently own the lobby
LobbyId: *const u8The ID of the lobby to generate a connection string for