pub type EOS_Lobby_RTCRoomConnectionChangedCallbackInfo = _tagEOS_Lobby_RTCRoomConnectionChangedCallbackInfo;Expand description
Output parameters for the EOS_Lobby_AddNotifyRTCRoomConnectionChanged function.
Aliased Type
#[repr(C)]pub struct EOS_Lobby_RTCRoomConnectionChangedCallbackInfo {
pub ClientData: *mut c_void,
pub LobbyId: *const i8,
pub LocalUserId: *mut EOS_ProductUserIdDetails,
pub bIsConnected: i32,
pub DisconnectReason: i32,
}Fields
ClientData: *mut c_voidContext that was passed into EOS_Lobby_AddNotifyRTCRoomConnectionChanged
LobbyId: *const i8The ID of the lobby which had a RTC Room connection state change
LocalUserId: *mut EOS_ProductUserIdDetailsThe Product User ID of the local user who is in the lobby and registered for notifications
bIsConnected: i32The new connection state of the room
DisconnectReason: i32If bIsConnected is EOS_FALSE, this result will be the reason we were disconnected. EOS_Success: The room was left locally. This may be because: the associated lobby was Left or Destroyed, the connection to the lobby was interrupted, or because the SDK is being shutdown. If the lobby connection returns (lobby did not permanently go away), we will reconnect. EOS_NoConnection: There was a network issue connecting to the server. We will attempt to reconnect soon. EOS_RTC_UserKicked: The user has been kicked by the server. We will not reconnect. EOS_RTC_UserBanned: The user has been banned by the server. We will not reconnect. EOS_ServiceFailure: A known error occurred during interaction with the server. We will attempt to reconnect soon. EOS_UnexpectedError: Unexpected error. We will attempt to reconnect soon.