pub type EOS_Metrics_BeginPlayerSessionOptions = _tagEOS_Metrics_BeginPlayerSessionOptions;Expand description
BeginPlayerSession.
Aliased Type
#[repr(C)]pub struct EOS_Metrics_BeginPlayerSessionOptions {
pub ApiVersion: i32,
pub AccountIdType: i32,
pub AccountId: _tagEOS_Metrics_BeginPlayerSessionOptions__bindgen_ty_1,
pub DisplayName: *const u8,
pub ControllerType: i32,
pub ServerIp: *const u8,
pub GameSessionId: *const u8,
}Fields
ApiVersion: i32API Version: Set this to EOS_METRICS_BEGINPLAYERSESSION_API_LATEST.
AccountIdType: i32Account ID type that is set in the union.
AccountId: _tagEOS_Metrics_BeginPlayerSessionOptions__bindgen_ty_1The Account ID for the player whose session is beginning.
DisplayName: *const u8The in-game display name for the user as UTF-8 string.
ControllerType: i32The user’s game controller type.
ServerIp: *const u8IP address of the game server hosting the game session. For a localhost session, set to NULL.
@details Must be in either one of the following IPv4 or IPv6 string formats:
- “127.0.0.1”.
- “1200:0000:AB00:1234:0000:2552:7777:1313”. If both IPv4 and IPv6 addresses are available, use the IPv6 address.
GameSessionId: *const u8Optional, application-defined custom match session identifier. If the identifier is not used, set to NULL.
@details The game can tag each game session with a custom session match identifier, which will be shown in the Played Sessions listing at the user profile dashboard.