pub type EOS_Mods_InstallModOptions = _tagEOS_Mods_InstallModOptions;Expand description
Input parameters for the EOS_Mods_InstallMod Function.
Aliased Type
#[repr(C)]pub struct EOS_Mods_InstallModOptions {
pub ApiVersion: i32,
pub LocalUserId: *mut EOS_EpicAccountIdDetails,
pub Mod: *const _tagEOS_Mod_Identifier,
pub bRemoveAfterExit: i32,
}Fields
ApiVersion: i32API Version: Set this to EOS_MODS_INSTALLMOD_API_LATEST.
LocalUserId: *mut EOS_EpicAccountIdDetailsThe Epic Account ID of the user for which the mod should be installed
Mod: *const _tagEOS_Mod_IdentifierThe mod to install
bRemoveAfterExit: i32Indicates whether the mod should be uninstalled after exiting the game or not.