pub type EOS_P2P_AcceptConnectionOptions = _tagEOS_P2P_AcceptConnectionOptions;Expand description
Structure containing information about who would like to accept a connection, and which connection.
Aliased Type
#[repr(C)]pub struct EOS_P2P_AcceptConnectionOptions {
pub ApiVersion: i32,
pub LocalUserId: *mut EOS_ProductUserIdDetails,
pub RemoteUserId: *mut EOS_ProductUserIdDetails,
pub SocketId: *const _tagEOS_P2P_SocketId,
}Fields
ApiVersion: i32API Version: Set this to EOS_P2P_ACCEPTCONNECTION_API_LATEST.
LocalUserId: *mut EOS_ProductUserIdDetailsThe Product User ID of the local user who is accepting any pending or future connections with RemoteUserId
RemoteUserId: *mut EOS_ProductUserIdDetailsThe Product User ID of the remote user who has either sent a connection request or is expected to in the future
SocketId: *const _tagEOS_P2P_SocketIdThe socket ID of the connection to accept on