pub type EOS_P2P_AddNotifyPeerConnectionClosedOptions = _tagEOS_P2P_AddNotifyPeerConnectionClosedOptions;Expand description
Structure containing information about who would like notifications about closed connections, and for which socket.
Aliased Type
#[repr(C)]pub struct EOS_P2P_AddNotifyPeerConnectionClosedOptions {
pub ApiVersion: i32,
pub LocalUserId: *mut EOS_ProductUserIdDetails,
pub SocketId: *const _tagEOS_P2P_SocketId,
}Fields
ApiVersion: i32API Version: Set this to EOS_P2P_ADDNOTIFYPEERCONNECTIONCLOSED_API_LATEST.
LocalUserId: *mut EOS_ProductUserIdDetailsThe Product User ID of the local user who would like notifications
SocketId: *const _tagEOS_P2P_SocketIdThe optional socket ID to listen for to be closed. If NULL, this function handler will be called for all closed connections