pub type EOS_P2P_ClearPacketQueueOptions = _tagEOS_P2P_ClearPacketQueueOptions;Expand description
Structure containing information about the packet queue to be cleared
Aliased Type
#[repr(C)]pub struct EOS_P2P_ClearPacketQueueOptions {
pub ApiVersion: i32,
pub LocalUserId: *mut EOS_ProductUserIdDetails,
pub RemoteUserId: *mut EOS_ProductUserIdDetails,
pub SocketId: *const _tagEOS_P2P_SocketId,
}Fields
ApiVersion: i32API Version: Set this to EOS_P2P_CLEARPACKETQUEUE_API_LATEST.
LocalUserId: *mut EOS_ProductUserIdDetailsThe Product User ID of the local user for whom we want to clear the queued packets
RemoteUserId: *mut EOS_ProductUserIdDetailsThe Product User ID to who (outgoing) or from who (incoming) packets are queued
SocketId: *const _tagEOS_P2P_SocketIdThe socket used for packets to be cleared