pub type EOS_P2P_CloseConnectionsOptions = _tagEOS_P2P_CloseConnectionsOptions;Expand description
Structure containing information about who would like to close connections, and by what socket ID
Aliased Type
#[repr(C)]pub struct EOS_P2P_CloseConnectionsOptions {
pub ApiVersion: i32,
pub LocalUserId: *mut EOS_ProductUserIdDetails,
pub SocketId: *const _tagEOS_P2P_SocketId,
}Fields
ApiVersion: i32API Version: Set this to EOS_P2P_CLOSECONNECTIONS_API_LATEST.
LocalUserId: *mut EOS_ProductUserIdDetailsThe Product User ID of the local user who would like to close all connections that use a particular socket ID
SocketId: *const _tagEOS_P2P_SocketIdThe socket ID of the connections to close