pub type EOS_P2P_OnIncomingPacketQueueFullInfo = _tagEOS_P2P_OnIncomingPacketQueueFullInfo;Expand description
Structure containing information about the packet queue’s state and the incoming packet that would overflow the queue
Aliased Type
#[repr(C)]pub struct EOS_P2P_OnIncomingPacketQueueFullInfo {
pub ClientData: *mut c_void,
pub PacketQueueMaxSizeBytes: u64,
pub PacketQueueCurrentSizeBytes: u64,
pub OverflowPacketLocalUserId: *mut EOS_ProductUserIdDetails,
pub OverflowPacketChannel: u8,
pub OverflowPacketSizeBytes: u32,
}Fields
ClientData: *mut c_voidClient-specified data passed into AddNotifyIncomingPacketQueueFull
PacketQueueMaxSizeBytes: u64The maximum size in bytes the incoming packet queue is allowed to use
PacketQueueCurrentSizeBytes: u64The current size in bytes the incoming packet queue is currently using
OverflowPacketLocalUserId: *mut EOS_ProductUserIdDetailsThe Product User ID of the local user who is receiving the packet that would overflow the queue
OverflowPacketChannel: u8The channel the incoming packet is for
OverflowPacketSizeBytes: u32The size in bytes of the incoming packet (and related metadata) that would overflow the queue