pub type EOS_P2P_OnPeerConnectionInterruptedInfo = _tagEOS_P2P_OnPeerConnectionInterruptedInfo;Expand description
Structure containing information about an connection request that is that was interrupted.
Aliased Type
#[repr(C)]pub struct EOS_P2P_OnPeerConnectionInterruptedInfo {
pub ClientData: *mut c_void,
pub LocalUserId: *mut EOS_ProductUserIdDetails,
pub RemoteUserId: *mut EOS_ProductUserIdDetails,
pub SocketId: *const _tagEOS_P2P_SocketId,
}Fields
ClientData: *mut c_voidClient-specified data passed into EOS_Presence_AddNotifyOnPresenceChanged
LocalUserId: *mut EOS_ProductUserIdDetailsThe local user who is being notified of a connection that was interrupted
RemoteUserId: *mut EOS_ProductUserIdDetailsThe Product User ID of the remote user who this connection was with
SocketId: *const _tagEOS_P2P_SocketIdThe socket ID of the connection that was interrupted