pub type EOS_P2P_SocketId = _tagEOS_P2P_SocketId;Expand description
P2P Socket ID
The Socket ID contains an application-defined name for the connection between a local person and another peer.
When a remote user receives a connection request from you, they will receive this information. It can be important to only accept connections with a known socket-name and/or from a known user, to prevent leaking of private information, such as a user’s IP address. Using the socket name as a secret key can help prevent such leaks. Shared private data, like a private match’s Session ID are good candidates for a socket name.
Aliased Type
#[repr(C)]pub struct EOS_P2P_SocketId {
pub ApiVersion: i32,
pub SocketName: [u8; 33],
}Fields
ApiVersion: i32API Version: Set this to EOS_P2P_SOCKETID_API_LATEST.
SocketName: [u8; 33]A name for the connection. Must be a NULL-terminated string of between 1-32 alpha-numeric characters (A-Z, a-z, 0-9, ‘-’, ‘_’, ’ ’, ‘+’, ‘=’, ‘.’)