pub type EOS_Platform_DesktopCrossplayStatusInfo = _tagEOS_Platform_DesktopCrossplayStatusInfo;Expand description
Output parameters for the EOS_Platform_GetDesktopCrossplayStatus function.
Aliased Type
#[repr(C)]pub struct EOS_Platform_DesktopCrossplayStatusInfo {
pub Status: i32,
pub ServiceInitResult: i32,
}Fields
Status: i32Status for the availability of desktop crossplay functionality.
It is recommended to include this value in application logs, and as part of any player-facing error screens to help troubleshooting possible issues.
ServiceInitResult: i32This field is set when the Status is EOS_DCS_ServiceStartFailed.
Possible values for this field are not documented. However, it is recommended to be also included in application logs, and as part of any player-facing error screens.