pub type EOS_Platform_Options = _tagEOS_Platform_Options;Expand description
Platform options for EOS_Platform_Create.
Aliased Type
#[repr(C)]pub struct EOS_Platform_Options {Show 17 fields
pub ApiVersion: i32,
pub Reserved: *mut c_void,
pub ProductId: *const i8,
pub SandboxId: *const i8,
pub ClientCredentials: _tagEOS_Platform_ClientCredentials,
pub bIsServer: i32,
pub EncryptionKey: *const i8,
pub OverrideCountryCode: *const i8,
pub OverrideLocaleCode: *const i8,
pub DeploymentId: *const i8,
pub Flags: u64,
pub CacheDirectory: *const i8,
pub TickBudgetInMilliseconds: u32,
pub RTCOptions: *const _tagEOS_Platform_RTCOptions,
pub IntegratedPlatformOptionsContainerHandle: *mut EOS_IntegratedPlatformOptionsContainerHandle,
pub SystemSpecificOptions: *const c_void,
pub TaskNetworkTimeoutSeconds: *mut f64,
}Fields
ApiVersion: i32API Version: Set this to EOS_PLATFORM_OPTIONS_API_LATEST.
Reserved: *mut c_voidA reserved field that should always be nulled.
ProductId: *const i8The product ID for the running application, found on the dev portal. Max length is EOS_PLATFORM_OPTIONS_PRODUCTID_MAX_LENGTH.
SandboxId: *const i8The sandbox ID for the running application, found on the dev portal. Max length is EOS_PLATFORM_OPTIONS_SANDBOXID_MAX_LENGTH.
ClientCredentials: _tagEOS_Platform_ClientCredentialsSet of service permissions associated with the running application
bIsServer: i32Set this to EOS_FALSE if the application is running as a client with a local user, otherwise set to EOS_TRUE (e.g. for a dedicated game server)
EncryptionKey: *const i8Used by Player Data Storage and Title Storage. Must be null initialized if unused. 256-bit Encryption Key for file encryption in hexadecimal format; EOS_PLATFORM_OPTIONS_ENCRYPTIONKEY_LENGTH hex chars.
OverrideCountryCode: *const i8The override country code to use for the logged in user. (EOS_COUNTRYCODE_MAX_LENGTH)
OverrideLocaleCode: *const i8The override locale code to use for the logged in user. This follows ISO 639. (EOS_LOCALECODE_MAX_LENGTH)
DeploymentId: *const i8The deployment ID for the running application, found on the dev portal. Max length is EOS_PLATFORM_OPTIONS_DEPLOYMENTID_MAX_LENGTH.
Flags: u64Platform creation flags, e.g. EOS_PF_LOADING_IN_EDITOR. This is a bitwise-or union of the defined flags.
CacheDirectory: *const i8Used by Player Data Storage and Title Storage. Must be null initialized if unused. Cache directory path. Absolute path to the folder that is going to be used for caching temporary data. The path is created if it’s missing.
TickBudgetInMilliseconds: u32A budget, measured in milliseconds, for EOS_Platform_Tick to do its work. When the budget is met or exceeded (or if no work is available), EOS_Platform_Tick will return. This allows your game to amortize the cost of SDK work across multiple frames in the event that a lot of work is queued for processing. Zero is interpreted as “perform all available work”.
RTCOptions: *const _tagEOS_Platform_RTCOptionsRTC options. Setting to NULL will disable RTC features (e.g. voice)
IntegratedPlatformOptionsContainerHandle: *mut EOS_IntegratedPlatformOptionsContainerHandleA handle that contains all the options for setting up integrated platforms. When set to NULL, the EOS Integrated Platform behavior for the host platform will be disabled.
SystemSpecificOptions: *const c_voidPointer to EOS_“PLATFORM_NAME”SystemSpecificOptions. This structure will be located in “PLATFORM_NAME”/eos“PLATFORM_NAME”.h
TaskNetworkTimeoutSeconds: *mut f64Number of seconds for a task to wait for the network to become available before timing out with an EOS_TimedOut error. This timeout period applies when the network status is not EOS_NS_Online. Tasks that need the network will queue for up to this timeout until EOS_Platform_SetNetworkStatus is used to set the network status to online.
Pass a null pointer to use the default. Otherwise, pass a pointer to a double containing the number of seconds for tasks that are waiting for network to time out.
@see EOS_Platform_SetNetworkStatus @see EOS_ENetworkStatus