pub type EOS_Platform_RTCOptions = _tagEOS_Platform_RTCOptions;Expand description
Platform RTC options.
Aliased Type
#[repr(C)]pub struct EOS_Platform_RTCOptions {
pub ApiVersion: i32,
pub PlatformSpecificOptions: *mut c_void,
pub BackgroundMode: i32,
pub Reserved: *mut c_void,
}Fields
ApiVersion: i32API Version: Set this to EOS_PLATFORM_RTCOPTIONS_API_LATEST.
PlatformSpecificOptions: *mut c_voidThis field is for platform specific initialization if any.
If provided then the structure will be located in “PLATFORM_NAME”/eos_“PLATFORM_NAME”.h. The structure will be named EOS_“PLATFORM_NAME”_RTCOptions.
BackgroundMode: i32Configures RTC behavior upon entering to any background application statuses
Reserved: *mut c_voidReserved field, should be nullptr by default