pub type EOS_PlayerDataStorage_DuplicateFileCallbackInfo = _tagEOS_PlayerDataStorage_DuplicateFileCallbackInfo;Expand description
Data containing the result information for a duplicate file request
Aliased Type
#[repr(C)]pub struct EOS_PlayerDataStorage_DuplicateFileCallbackInfo {
pub ResultCode: i32,
pub ClientData: *mut c_void,
pub LocalUserId: *mut EOS_ProductUserIdDetails,
}Fields
ResultCode: i32Result code for the operation. EOS_Success is returned for a successful request, other codes indicate an error
ClientData: *mut c_voidClient-specified data passed into the file duplicate request
LocalUserId: *mut EOS_ProductUserIdDetailsThe Product User ID of the local user who initiated this request