EOS_PlayerDataStorage_ReadFileDataCallbackInfo

Type Alias EOS_PlayerDataStorage_ReadFileDataCallbackInfo 

pub type EOS_PlayerDataStorage_ReadFileDataCallbackInfo = _tagEOS_PlayerDataStorage_ReadFileDataCallbackInfo;
Data containing data for a chunk of a file being read

Aliased Type

#[repr(C)]
pub struct EOS_PlayerDataStorage_ReadFileDataCallbackInfo { pub ClientData: *mut c_void, pub LocalUserId: *mut EOS_ProductUserIdDetails, pub Filename: *const i8, pub TotalFileSizeBytes: u32, pub bIsLastChunk: i32, pub DataChunkLengthBytes: u32, pub DataChunk: *const c_void, }

Fields

ClientData: *mut c_void

Client-specified data passed into the file request

LocalUserId: *mut EOS_ProductUserIdDetails

The Product User ID of the local user who initiated this request

Filename: *const i8

The file name being read

TotalFileSizeBytes: u32

The total file size of the file being read

bIsLastChunk: i32

Is this chunk the last chunk of data?

DataChunkLengthBytes: u32

The length of DataChunk in bytes that can be safely read

DataChunk: *const c_void

Pointer to the start of data to be read