EOS_PlayerDataStorage_ReadFileOptions

Type Alias EOS_PlayerDataStorage_ReadFileOptions 

pub type EOS_PlayerDataStorage_ReadFileOptions = _tagEOS_PlayerDataStorage_ReadFileOptions;
Input data for the EOS_PlayerDataStorage_ReadFile function

Aliased Type

#[repr(C)]
pub struct EOS_PlayerDataStorage_ReadFileOptions { pub ApiVersion: i32, pub LocalUserId: *mut EOS_ProductUserIdDetails, pub Filename: *const i8, pub ReadChunkLengthBytes: u32, pub ReadFileDataCallback: Option<unsafe extern "C" fn(*const _tagEOS_PlayerDataStorage_ReadFileDataCallbackInfo) -> i32>, pub FileTransferProgressCallback: Option<unsafe extern "C" fn(*const _tagEOS_PlayerDataStorage_FileTransferProgressCallbackInfo)>, }

Fields

ApiVersion: i32

API Version: Set this to EOS_PLAYERDATASTORAGE_READFILE_API_LATEST.

LocalUserId: *mut EOS_ProductUserIdDetails

The Product User ID of the local user who is reading the requested file

Filename: *const i8

The file name to read; this file must already exist

ReadChunkLengthBytes: u32

The maximum amount of data in bytes should be available to read in a single EOS_PlayerDataStorage_OnReadFileDataCallback call

ReadFileDataCallback: Option<unsafe extern "C" fn(*const _tagEOS_PlayerDataStorage_ReadFileDataCallbackInfo) -> i32>

Callback function that handles data as it comes in, and can stop the transfer early

FileTransferProgressCallback: Option<unsafe extern "C" fn(*const _tagEOS_PlayerDataStorage_FileTransferProgressCallbackInfo)>

Optional callback function to be informed of download progress, if the file is not already locally cached; if provided, this will be called at least once before completion if the request is successfully started