pub type EOS_Presence_JoinGameAcceptedCallbackInfo = _tagEOS_Presence_JoinGameAcceptedCallbackInfo;Expand description
Output parameters for the EOS_Presence_OnJoinGameAcceptedCallback Function.
Aliased Type
#[repr(C)]pub struct EOS_Presence_JoinGameAcceptedCallbackInfo {
pub ClientData: *mut c_void,
pub JoinInfo: *const i8,
pub LocalUserId: *mut EOS_EpicAccountIdDetails,
pub TargetUserId: *mut EOS_EpicAccountIdDetails,
pub UiEventId: u64,
}Fields
ClientData: *mut c_voidContext that was passed into EOS_Presence_AddNotifyJoinGameAccepted
JoinInfo: *const i8The Join Info custom game-data string to use to join the target user. Set to a null pointer to delete the value.
LocalUserId: *mut EOS_EpicAccountIdDetailsThe Epic Account ID of the user who accepted the invitation
TargetUserId: *mut EOS_EpicAccountIdDetailsThe Epic Account ID of the user who sent the invitation
UiEventId: u64If the value is not EOS_UI_EVENTID_INVALID then it must be passed back to the SDK using EOS_UI_AcknowledgeEventId.
This should be done after attempting to join the game and either succeeding or failing to connect.
This is necessary to allow the Social Overlay UI to manage the Join button.