pub type EOS_Presence_QueryPresenceOptions = _tagEOS_Presence_QueryPresenceOptions;Expand description
Data for the EOS_Presence_QueryPresence function
Aliased Type
#[repr(C)]pub struct EOS_Presence_QueryPresenceOptions {
pub ApiVersion: i32,
pub LocalUserId: *mut EOS_EpicAccountIdDetails,
pub TargetUserId: *mut EOS_EpicAccountIdDetails,
}Fields
ApiVersion: i32API Version: Set this to EOS_PRESENCE_QUERYPRESENCE_API_LATEST.
LocalUserId: *mut EOS_EpicAccountIdDetailsThe Epic Account ID of the local, logged-in user making the request
TargetUserId: *mut EOS_EpicAccountIdDetailsThe Epic Account ID of the user whose presence data you want to retrieve; this value must be either the user making the request, or a friend of that user