pub type EOS_Presence_SetPresenceCallbackInfo = _tagEOS_Presence_SetPresenceCallbackInfo;Expand description
The result meta-data from setting a user’s presence.
Aliased Type
#[repr(C)]pub struct EOS_Presence_SetPresenceCallbackInfo {
pub ResultCode: i32,
pub ClientData: *mut c_void,
pub LocalUserId: *mut EOS_EpicAccountIdDetails,
pub RichPresenceResultCode: i32,
}Fields
ResultCode: i32Result code for the operation. EOS_Success is returned if presence was successfully set, other codes indicate an error
ClientData: *mut c_voidClient-specified data passed into EOS_Presence_SetPresence
LocalUserId: *mut EOS_EpicAccountIdDetailsThe Epic Account ID of the local user that had their presence set
RichPresenceResultCode: i32Result code for the Rich presence operation. EOS_Success is returned if the Rich presence was successfully set, other code indicates an error.