pub type EOS_RTCAdmin_CopyUserTokenByIndexOptions = _tagEOS_RTCAdmin_CopyUserTokenByIndexOptions;Expand description
Input parameters for the EOS_RTCAdmin_CopyUserTokenByIndex function.
Aliased Type
#[repr(C)]pub struct EOS_RTCAdmin_CopyUserTokenByIndexOptions {
pub ApiVersion: i32,
pub UserTokenIndex: u32,
pub QueryId: u32,
}Fields
ApiVersion: i32API Version: Set this to EOS_RTCADMIN_COPYUSERTOKENBYINDEX_API_LATEST.
UserTokenIndex: u32Index of the user token to retrieve from the cache.
QueryId: u32Query identifier received as part of a previous query. @see EOS_RTCAdmin_QueryJoinRoomTokenCompleteCallbackInfo