pub type EOS_RTCAdmin_QueryJoinRoomTokenCompleteCallbackInfo = _tagEOS_RTCAdmin_QueryJoinRoomTokenCompleteCallbackInfo;Expand description
Data containing the result information for a query join room token request.
Aliased Type
#[repr(C)]pub struct EOS_RTCAdmin_QueryJoinRoomTokenCompleteCallbackInfo {
pub ResultCode: i32,
pub ClientData: *mut c_void,
pub RoomName: *const i8,
pub ClientBaseUrl: *const i8,
pub QueryId: u32,
pub TokenCount: u32,
}Fields
ResultCode: i32The EOS_EResult code for the operation. EOS_Success indicates that the operation succeeded; other codes indicate errors.
ClientData: *mut c_voidContext that was passed into EOS_RTCAdmin_QueryJoinRoomToken.
RoomName: *const i8Room the request was made for.
ClientBaseUrl: *const i8URL passed to backend to join room.
QueryId: u32If the query completed successfully, this contains an identifier that should be used to retrieve the tokens. This identifier is only valid for the duration of the callback.
@see EOS_RTCAdmin_CopyUserTokenByIndex @see EOS_RTCAdmin_CopyUserTokenByUserId
TokenCount: u32How many token received as result of the query