pub type EOS_RTC_BlockParticipantOptions = _tagEOS_RTC_BlockParticipantOptions;Expand description
This struct is passed in with a call to EOS_RTC_BlockParticipant.
Aliased Type
#[repr(C)]pub struct EOS_RTC_BlockParticipantOptions {
pub ApiVersion: i32,
pub LocalUserId: *mut EOS_ProductUserIdDetails,
pub RoomName: *const u8,
pub ParticipantId: *mut EOS_ProductUserIdDetails,
pub bBlocked: i32,
}Fields
ApiVersion: i32API Version: Set this to EOS_RTC_BLOCKPARTICIPANT_API_LATEST.
LocalUserId: *mut EOS_ProductUserIdDetailsProduct User ID of the user trying to request this operation.
RoomName: *const u8The room the users should be blocked on.
ParticipantId: *mut EOS_ProductUserIdDetailsProduct User ID of the participant to block
bBlocked: i32Block or unblock the participant