pub type EOS_RTC_DisconnectedCallbackInfo = _tagEOS_RTC_DisconnectedCallbackInfo;Expand description
This struct is passed in with a call to EOS_RTC_AddNotifyDisconnected registered event.
Aliased Type
#[repr(C)]pub struct EOS_RTC_DisconnectedCallbackInfo {
pub ResultCode: i32,
pub ClientData: *mut c_void,
pub LocalUserId: *mut EOS_ProductUserIdDetails,
pub RoomName: *const i8,
}Fields
ResultCode: i32This returns: EOS_Success The room was left cleanly. EOS_NoConnection: There was a network issue connecting to the server (retryable). EOS_RTC_UserKicked: The user has been kicked by the server (retryable). EOS_ServiceFailure: A known error occurred during interaction with the server (retryable). EOS_UnexpectedError Unexpected error (retryable).
ClientData: *mut c_voidClient-specified data passed into EOS_RTC_AddNotifyDisconnected.
LocalUserId: *mut EOS_ProductUserIdDetailsThe Product User ID of the user who initiated this request.
RoomName: *const i8The room associated with this event.