EOS_RTC_JoinRoomCallbackInfo

Type Alias EOS_RTC_JoinRoomCallbackInfo 

pub type EOS_RTC_JoinRoomCallbackInfo = _tagEOS_RTC_JoinRoomCallbackInfo;
This struct is passed in with a call to EOS_RTC_OnJoinRoomCallback.

Aliased Type

#[repr(C)]
pub struct EOS_RTC_JoinRoomCallbackInfo { pub ResultCode: i32, pub ClientData: *mut c_void, pub LocalUserId: *mut EOS_ProductUserIdDetails, pub RoomName: *const i8, pub RoomOptionsCount: u32, pub RoomOptions: *const _tagEOS_RTC_Option, }

Fields

ResultCode: i32

This returns: EOS_Success if the channel was successfully joined. EOS_NoConnection: unable to connect to RTC servers (retryable). EOS_InvalidAuth: if the token is invalid (not retryable). EOS_RTC_TooManyParticipants: if the room cannot accept more participants (not retryable). EOS_AccessDenied: if the room name belongs to the Lobby voice system (not retryable). EOS_UnexpectedError otherwise (retryable).

ClientData: *mut c_void

Client-specified data passed into EOS_RTC_JoinRoom.

LocalUserId: *mut EOS_ProductUserIdDetails

The Product User ID of the user who initiated this request.

RoomName: *const i8

The room the user was trying to join.

RoomOptionsCount: u32

The room option items count.

RoomOptions: *const _tagEOS_RTC_Option

The room option items.