pub type EOS_RTC_JoinRoomOptions = _tagEOS_RTC_JoinRoomOptions;Expand description
This struct is used to call EOS_RTC_JoinRoom.
Aliased Type
#[repr(C)]pub struct EOS_RTC_JoinRoomOptions {
pub ApiVersion: i32,
pub LocalUserId: *mut EOS_ProductUserIdDetails,
pub RoomName: *const u8,
pub ClientBaseUrl: *const u8,
pub ParticipantToken: *const u8,
pub ParticipantId: *mut EOS_ProductUserIdDetails,
pub Flags: u32,
pub bManualAudioInputEnabled: i32,
pub bManualAudioOutputEnabled: i32,
}Fields
ApiVersion: i32API Version: Set this to EOS_RTC_JOINROOM_API_LATEST.
LocalUserId: *mut EOS_ProductUserIdDetailsThe product user id of the user trying to request this operation.
RoomName: *const u8The room the user would like to join.
ClientBaseUrl: *const u8The room the user would like to join.
ParticipantToken: *const u8Authorization credential token to join the room.
ParticipantId: *mut EOS_ProductUserIdDetailsThe participant id used to join the room. If set to NULL the LocalUserId will be used instead.
Flags: u32Join room flags, e.g. EOS_RTC_JOINROOMFLAGS_ENABLE_ECHO. This is a bitwise-or union of the defined flags.
bManualAudioInputEnabled: i32Enable or disable Manual Audio Input. If manual audio input is enabled audio recording is not started and the audio buffers must be passed manually using EOS_RTCAudio_SendAudio.
bManualAudioOutputEnabled: i32Enable or disable Manual Audio Output. If manual audio output is enabled audio rendering is not started and the audio buffers must be received with EOS_RTCAudio_AddNotifyAudioBeforeRender and rendered manually.