pub type EOS_RTC_LeaveRoomCallbackInfo = _tagEOS_RTC_LeaveRoomCallbackInfo;Expand description
This struct is passed in with a call to EOS_RTC_OnLeaveRoomCallback.
Aliased Type
#[repr(C)]pub struct EOS_RTC_LeaveRoomCallbackInfo {
pub ResultCode: i32,
pub ClientData: *mut c_void,
pub LocalUserId: *mut EOS_ProductUserIdDetails,
pub RoomName: *const u8,
}Fields
ResultCode: i32This returns: EOS_Success if the channel was successfully left. EOS_AccessDenied if the room name belongs to the Lobby voice system. EOS_UnexpectedError otherwise.
ClientData: *mut c_voidClient-specified data passed into EOS_RTC_LeaveRoomOptions.
LocalUserId: *mut EOS_ProductUserIdDetailsThe Product User ID of the user who initiated this request.
RoomName: *const u8The room the user was trying to leave.