EOS_RTC_OnRoomBeforeJoinCallback

Type Alias EOS_RTC_OnRoomBeforeJoinCallback 

pub type EOS_RTC_OnRoomBeforeJoinCallback = Option<unsafe extern "C" fn(Data: *const EOS_RTC_RoomBeforeJoinCallbackInfo)>;
Function prototype definition for notifications that comes from EOS_RTC_AddNotifyRoomBeforeJoin

@param Data containing the RTC room name which is about to be created and joined.

Aliased Type

pub enum EOS_RTC_OnRoomBeforeJoinCallback {
    None,
    Some(unsafe extern "C" fn(*const _tagEOS_RTC_RoomBeforeJoinCallbackInfo)),
}

Variants

1.0.0

None

No value.

1.0.0

Some(unsafe extern "C" fn(*const _tagEOS_RTC_RoomBeforeJoinCallbackInfo))

Some value of type T.