EOS_RTC_SetRoomSettingOptions

Type Alias EOS_RTC_SetRoomSettingOptions 

pub type EOS_RTC_SetRoomSettingOptions = _tagEOS_RTC_SetRoomSettingOptions;
This struct is used to call EOS_RTC_SetRoomSetting

Available values of SettingName:

  • DisableEchoCancelation: Disables the use of echo cancellation for the audio channel. Default “False”.
  • DisableNoiseSupression: Disables the use of noise suppression for the audio channel. Default “False”.
  • DisableAutoGainControl: Disables the use of auto gain control for the audio channel. Default “False”.
  • DisableDtx: Allows to disable the use of DTX. Default “False”.

Aliased Type

#[repr(C)]
pub struct EOS_RTC_SetRoomSettingOptions { pub ApiVersion: i32, pub LocalUserId: *mut EOS_ProductUserIdDetails, pub RoomName: *const u8, pub SettingName: *const u8, pub SettingValue: *const u8, }

Fields

ApiVersion: i32

API Version: Set this to EOS_RTC_SETROOMSETTING_API_LATEST.

LocalUserId: *mut EOS_ProductUserIdDetails

The Product User ID of the user trying to request this operation.

RoomName: *const u8

The room the setting will be applied to.

SettingName: *const u8

Setting that should be set.

SettingValue: *const u8

Value to set the setting to.