pub type EOS_RTC_SetSettingOptions = _tagEOS_RTC_SetSettingOptions;Expand description
This struct is used to call EOS_RTC_SetSetting
Available values of SettingName:
- DisableEchoCancelation: Disables the use of echo cancellation for the audio channel. Default “False”.
- DisableNoiseSupression: Disables the use of noise suppression for the audio channel. Default “False”.
- DisableAutoGainControl: Disables the use of auto gain control for the audio channel. Default “False”.
- DisableDtx: Allows to disable the use of DTX. Default “False”.
Aliased Type
#[repr(C)]pub struct EOS_RTC_SetSettingOptions {
pub ApiVersion: i32,
pub SettingName: *const i8,
pub SettingValue: *const i8,
}Fields
ApiVersion: i32API Version: Set this to EOS_RTC_SETSETTING_API_LATEST.
SettingName: *const i8Setting that should be set.
SettingValue: *const i8Value to set the setting to.