pub type EOS_ReallocateMemoryFunc = Option<unsafe extern "C" fn(Pointer: *mut c_void, SizeInBytes: usize, Alignment: usize) -> *mut c_void>;Expand description
Function prototype type definition for functions that reallocate memory.
Functions passed to EOS_Initialize to serve as memory reallocators should return a pointer to the reallocated memory. The returned pointer should have at least SizeInBytes available capacity and the memory address should be a multiple of alignment. The SDK will always call the provided function with an Alignment that is a power of 2. Reallocation failures should return a null pointer.
Aliased Type
pub enum EOS_ReallocateMemoryFunc {
None,
Some(unsafe extern "C" fn(*mut c_void, usize, usize) -> *mut c_void),
}