pub type EOS_ReleaseMemoryFunc = Option<unsafe extern "C" fn(Pointer: *mut c_void)>;Expand description
Function prototype type definition for functions that release memory.
When the SDK is done with memory that has been allocated by a custom allocator passed to EOS_Initialize, it will call the corresponding memory release function.
Aliased Type
pub enum EOS_ReleaseMemoryFunc {
None,
Some(unsafe extern "C" fn(*mut c_void)),
}