EOS_SessionDetails_Settings

Type Alias EOS_SessionDetails_Settings 

pub type EOS_SessionDetails_Settings = _tagEOS_SessionDetails_Settings;
Common settings associated with a single session

Aliased Type

#[repr(C)]
pub struct EOS_SessionDetails_Settings { pub ApiVersion: i32, pub BucketId: *const u8, pub NumPublicConnections: u32, pub bAllowJoinInProgress: i32, pub PermissionLevel: i32, pub bInvitesAllowed: i32, pub bSanctionsEnabled: i32, pub AllowedPlatformIds: *const u32, pub AllowedPlatformIdsCount: u32, }

Fields

ApiVersion: i32

API Version: Set this to EOS_SESSIONDETAILS_SETTINGS_API_LATEST.

BucketId: *const u8

The main indexed parameter for this session, can be any string (i.e. “Region:GameMode”)

NumPublicConnections: u32

Number of total players allowed in the session

bAllowJoinInProgress: i32

Are players allowed to join the session while it is in the “in progress” state

PermissionLevel: i32

Permission level describing allowed access to the session when joining or searching for the session

bInvitesAllowed: i32

Are players allowed to send invites for the session

bSanctionsEnabled: i32

Are sanctioned players allowed to join - sanctioned players will be rejected if set to true

AllowedPlatformIds: *const u32

Array of platform IDs indicating the player platforms allowed to register with the session. Platform IDs are found in the EOS header file, e.g. EOS_OPT_Epic. For some platforms, the value will be in the EOS Platform specific header file. If null, the session will be unrestricted.

AllowedPlatformIdsCount: u32

Number of platform IDs in the array