EOS_SessionModification_SetAllowedPlatformIdsOptions

Type Alias EOS_SessionModification_SetAllowedPlatformIdsOptions 

pub type EOS_SessionModification_SetAllowedPlatformIdsOptions = _tagEOS_SessionModification_SetAllowedPlatformIdsOptions;
Input parameters for the EOS_SessionModification_SetAllowedPlatformIds function.

Aliased Type

#[repr(C)]
pub struct EOS_SessionModification_SetAllowedPlatformIdsOptions { pub ApiVersion: i32, pub AllowedPlatformIds: *const u32, pub AllowedPlatformIdsCount: u32, }

Fields

ApiVersion: i32

API Version: Set this to EOS_SESSIONMODIFICATION_SETALLOWEDPLATFORMIDS_API_LATEST.

AllowedPlatformIds: *const u32

Array of platform IDs indicating the player platforms allowed to register with the session. Platform IDs are found in the EOS header file, e.g. EOS_OPT_Epic. For some platforms, the value will be in the EOS Platform specific header file. If null, the session will be unrestricted.

AllowedPlatformIdsCount: u32

Number of platform IDs in the array