EOS_SessionSearch_RemoveParameterOptions

Type Alias EOS_SessionSearch_RemoveParameterOptions 

pub type EOS_SessionSearch_RemoveParameterOptions = _tagEOS_SessionSearch_RemoveParameterOptions;
Input parameters for the EOS_SessionSearch_RemoveParameter function.

Removal requires both the key and its comparator in order to remove as the same key can be used in more than one operation

Aliased Type

#[repr(C)]
pub struct EOS_SessionSearch_RemoveParameterOptions { pub ApiVersion: i32, pub Key: *const i8, pub ComparisonOp: i32, }

Fields

ApiVersion: i32

API Version: Set this to EOS_SESSIONSEARCH_REMOVEPARAMETER_API_LATEST.

Key: *const i8

Search parameter key to remove from the search

ComparisonOp: i32

Search comparison operation associated with the key to remove