EOS_SessionSearch_SetParameterOptions

Type Alias EOS_SessionSearch_SetParameterOptions 

pub type EOS_SessionSearch_SetParameterOptions = _tagEOS_SessionSearch_SetParameterOptions;
Input parameters for the EOS_SessionSearch_SetParameter function.

A search key may be set more than once to make multiple comparisons The two comparisons are AND’d together (ie, Key GREATER_THAN 5, Key NOT_EQUALS 10)

Aliased Type

#[repr(C)]
pub struct EOS_SessionSearch_SetParameterOptions { pub ApiVersion: i32, pub Parameter: *const _tagEOS_Sessions_AttributeData, pub ComparisonOp: i32, }

Fields

ApiVersion: i32

API Version: Set this to EOS_SESSIONSEARCH_SETPARAMETER_API_LATEST.

Parameter: *const _tagEOS_Sessions_AttributeData

Search parameter describing a key and a value to compare

ComparisonOp: i32

The type of comparison to make against the search parameter