pub type EOS_Sessions_JoinSessionOptions = _tagEOS_Sessions_JoinSessionOptions;Expand description
Input parameters for the EOS_Sessions_JoinSession function.
Aliased Type
#[repr(C)]pub struct EOS_Sessions_JoinSessionOptions {
pub ApiVersion: i32,
pub SessionName: *const i8,
pub SessionHandle: *mut EOS_SessionDetailsHandle,
pub LocalUserId: *mut EOS_ProductUserIdDetails,
pub bPresenceEnabled: i32,
}Fields
ApiVersion: i32API Version: Set this to EOS_SESSIONS_JOINSESSION_API_LATEST.
SessionName: *const i8Name of the session to create after joining session
SessionHandle: *mut EOS_SessionDetailsHandleSession handle to join
LocalUserId: *mut EOS_ProductUserIdDetailsThe Product User ID of the local user who is joining the session
bPresenceEnabled: i32Determines whether or not this session should be the one associated with the local user’s presence information. If true, this session will be associated with presence. Only one session at a time can have this flag true. This affects the ability of the Social Overlay to show game related actions to take in the user’s social graph.
@note The Social Overlay can handle only one of the following three options at a time:
- using the bPresenceEnabled flags within the Sessions interface
- using the bPresenceEnabled flags within the Lobby interface
- using EOS_PresenceModification_SetJoinInfo
@see EOS_PresenceModification_SetJoinInfoOptions @see EOS_Lobby_CreateLobbyOptions @see EOS_Lobby_JoinLobbyOptions @see EOS_Sessions_CreateSessionModificationOptions