pub type EOS_Sessions_LeaveSessionRequestedCallbackInfo = _tagEOS_Sessions_LeaveSessionRequestedCallbackInfo;Expand description
Output parameters for the EOS_Sessions_OnLeaveSessionRequestedCallback Function.
Aliased Type
#[repr(C)]pub struct EOS_Sessions_LeaveSessionRequestedCallbackInfo {
pub ClientData: *mut c_void,
pub LocalUserId: *mut EOS_ProductUserIdDetails,
pub SessionName: *const u8,
}Fields
ClientData: *mut c_voidContext that was passed into EOS_Sessions_OnLeaveSessionRequestedCallback
LocalUserId: *mut EOS_ProductUserIdDetailsThe Product User ID of the local user who received the leave session notification.
SessionName: *const u8Name of the session associated with the leave session request.