pub type EOS_TitleStorage_ReadFileCallbackInfo = _tagEOS_TitleStorage_ReadFileCallbackInfo;Expand description
Structure containing the result of a read file request
Aliased Type
#[repr(C)]pub struct EOS_TitleStorage_ReadFileCallbackInfo {
pub ResultCode: i32,
pub ClientData: *mut c_void,
pub LocalUserId: *mut EOS_ProductUserIdDetails,
pub Filename: *const i8,
}Fields
ResultCode: i32Result code for the operation. EOS_Success is returned for a successful request, other codes indicate an error
ClientData: *mut c_voidClient-specified data passed into the file read request
LocalUserId: *mut EOS_ProductUserIdDetailsProduct User ID of the local user who initiated this request (optional, will only be present in case it was provided during operation start)
Filename: *const i8The filename of the file that has been finished reading