EOS_UI_ShowNativeProfileOptions

Type Alias EOS_UI_ShowNativeProfileOptions 

pub type EOS_UI_ShowNativeProfileOptions = _tagEOS_UI_ShowNativeProfileOptions;
Parameters for the EOS_UI_ShowNativeProfile function.

Aliased Type

#[repr(C)]
pub struct EOS_UI_ShowNativeProfileOptions { pub ApiVersion: i32, pub LocalUserId: *mut EOS_EpicAccountIdDetails, pub TargetUserId: *mut EOS_EpicAccountIdDetails, }

Fields

ApiVersion: i32

API Version: Set this to EOS_UI_SHOWNATIVEPROFILE_API_LATEST.

LocalUserId: *mut EOS_EpicAccountIdDetails

The Epic Online Services Account ID of the user who is requesting the profile.

TargetUserId: *mut EOS_EpicAccountIdDetails

The Epic Online Services Account ID of the user whose profile is being requested.