pub type EOS_UserInfo_CopyExternalUserInfoByAccountTypeOptions = _tagEOS_UserInfo_CopyExternalUserInfoByAccountTypeOptions;Expand description
Input parameters for the EOS_UserInfo_CopyExternalUserInfoByAccountType function.
Aliased Type
#[repr(C)]pub struct EOS_UserInfo_CopyExternalUserInfoByAccountTypeOptions {
pub ApiVersion: i32,
pub LocalUserId: *mut EOS_EpicAccountIdDetails,
pub TargetUserId: *mut EOS_EpicAccountIdDetails,
pub AccountType: i32,
}Fields
ApiVersion: i32API Version: Set this to EOS_USERINFO_COPYEXTERNALUSERINFOBYACCOUNTTYPE_API_LATEST.
LocalUserId: *mut EOS_EpicAccountIdDetailsThe Epic Account ID of the local player requesting the information
TargetUserId: *mut EOS_EpicAccountIdDetailsThe Epic Account ID of the player whose information is being retrieved
AccountType: i32Account type of the external user info to retrieve from the cache