pub type EOS_UserInfo_CopyExternalUserInfoByIndexOptions = _tagEOS_UserInfo_CopyExternalUserInfoByIndexOptions;Expand description
Input parameters for the EOS_UserInfo_CopyExternalUserInfoByIndex function.
Aliased Type
#[repr(C)]pub struct EOS_UserInfo_CopyExternalUserInfoByIndexOptions {
pub ApiVersion: i32,
pub LocalUserId: *mut EOS_EpicAccountIdDetails,
pub TargetUserId: *mut EOS_EpicAccountIdDetails,
pub Index: u32,
}Fields
ApiVersion: i32API Version: Set this to EOS_USERINFO_COPYEXTERNALUSERINFOBYINDEX_API_LATEST.
LocalUserId: *mut EOS_EpicAccountIdDetailsThe Epic Account ID of the local player requesting the information
TargetUserId: *mut EOS_EpicAccountIdDetailsThe Epic Account ID of the player whose information is being retrieved
Index: u32Index of the external user info to retrieve from the cache