EOS_UserInfo_QueryUserInfoByExternalAccountCallbackInfo

Type Alias EOS_UserInfo_QueryUserInfoByExternalAccountCallbackInfo 

pub type EOS_UserInfo_QueryUserInfoByExternalAccountCallbackInfo = _tagEOS_UserInfo_QueryUserInfoByExternalAccountCallbackInfo;
Output parameters for the EOS_UserInfo_QueryUserInfoByExternalAccount Function.

Aliased Type

#[repr(C)]
pub struct EOS_UserInfo_QueryUserInfoByExternalAccountCallbackInfo { pub ResultCode: i32, pub ClientData: *mut c_void, pub LocalUserId: *mut EOS_EpicAccountIdDetails, pub ExternalAccountId: *const u8, pub AccountType: i32, pub TargetUserId: *mut EOS_EpicAccountIdDetails, }

Fields

ResultCode: i32

The EOS_EResult code for the operation. EOS_Success indicates that the operation succeeded; other codes indicate errors.

ClientData: *mut c_void

Context that was passed into EOS_UserInfo_QueryUserInfoByExternalAccount

LocalUserId: *mut EOS_EpicAccountIdDetails

The Epic Account ID of the local player who requested the information

ExternalAccountId: *const u8

External account id of the user whose information has been retrieved

AccountType: i32

Account type of the external account id

TargetUserId: *mut EOS_EpicAccountIdDetails

Account ID of the player whose information has been retrieved