pub type EOS_UserInfo_QueryUserInfoByExternalAccountOptions = _tagEOS_UserInfo_QueryUserInfoByExternalAccountOptions;Expand description
Input parameters for the EOS_UserInfo_QueryUserInfoByExternalAccount function.
Aliased Type
#[repr(C)]pub struct EOS_UserInfo_QueryUserInfoByExternalAccountOptions {
pub ApiVersion: i32,
pub LocalUserId: *mut EOS_EpicAccountIdDetails,
pub ExternalAccountId: *const u8,
pub AccountType: i32,
}Fields
ApiVersion: i32API Version: Set this to EOS_USERINFO_QUERYUSERINFOBYEXTERNALACCOUNT_API_LATEST.
LocalUserId: *mut EOS_EpicAccountIdDetailsThe Epic Account ID of the local player requesting the information
ExternalAccountId: *const u8External account ID of the user whose information is being retrieved
AccountType: i32Account type of the external user info to query